(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3596167,      73749]*)
(*NotebookOutlinePosition[   3700148,      77043]*)
(*  CellTagsIndexPosition[   3685000,      76551]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "9. Introduction to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Title",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"chapter 1", "c:1"}],

Cell[TextData[{
  "\tThis chapter will introduce you to some of the capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The complete software package is very complex, and takes years to master \
in all its glory.  ",
  StyleBox[ButtonBox["The Mathematica Book",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ", the standard reference to the software,  is 1470 pages long in its \
current edition, and weighs almost 10 pounds. With an information density \
akin to the user manual for the space shuttle, and a size and weight \
reminiscent of the Gutenberg bible, merely carrying ",
  StyleBox["the",
    FontSlant->"Italic"],
  " ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Book",
    FontSlant->"Italic"],
  " home from the bookstore is a daunting task.   "
}], "Text"],

Cell[TextData[{
  "\t But take heart-- you don't need to know everything about this software \
to use it effectively! The basics of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are quite straightforward. By the end of ",
  ButtonBox["Sec. 9.2",
    ButtonData:>"Sec. 9.2",
    ButtonStyle->"Hyperlink"],
  ", you will know how to use ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "as a calculator.  In ",
  ButtonBox["Sec. 9.4",
    ButtonData:>"Sec. 9.4",
    ButtonStyle->"Hyperlink"],
  ", you will learn how to define variables, and in ",
  ButtonBox["Sec. 9.5",
    ButtonData:>"Sec. 9.5",
    ButtonStyle->"Hyperlink"],
  ",  to create and manipulate vectors and matrices (termed lists in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). You will then learn basic plotting skills, and how to define your own \
functions. Following a quick course in the basics of computer algebra in ",
  ButtonBox["Sec. 9.8",
    ButtonData:>"Sec. 9.8",
    ButtonStyle->"Hyperlink"],
  ", you will learn in ",
  ButtonBox["Sec. 9.9",
    ButtonData:>"Sec. 9.9",
    ButtonStyle->"Hyperlink"],
  " how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to take derivatives, make power series expansions, and evaluate \
integrals. Finally, in Secs. ",
  ButtonBox["9.10",
    ButtonData:>"Sec. 9.10",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["9.11",
    ButtonData:>"Sec. 9.11",
    ButtonStyle->"Hyperlink"],
  " you will investigate analytical and numerical methods for the solution of \
algebraic equations, and interpolation and fitting of numerical data."
}], "Text"],

Cell[TextData[{
  "\t Of course, this only scratches the surface, but it will be enough for \
us to begin work in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  ",  using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as an aid in the solution of ordinary differential equations.  Other ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "techniques are presented in subsequent chapters as they are needed."
}], "Text"],

Cell[TextData[{
  "\t  After you have mastered the relatively straightforward material \
presented in this first chapter, you will probably find it useful to refer to \
",
  StyleBox["The",
    FontSlant->"Italic"],
  " ",
  StyleBox["Mathematica Book",
    FontSlant->"Italic"],
  " for more advanced and comprehensive discussions of the software's \
capabilities, as necessary. A complete electronic copy of this reference is \
provided free with every copy of the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "software package (see ",
  ButtonBox["Sec. 9.7",
    ButtonData:>"Sec. 9.7",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  "\tBefore you begin, a word of advice. When attempting problems from the \
exercises that have a computational component, I suggest that you keep a pad  \
and a pencil handy. Many of these problems require some setting up,  such as \
formulating the correct equations to solve, or sketching out a programming \
approach. This sort of work is best done using paper and pencil. Only after \
you know what you want to do should you turn to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell["\<\
A few quiet thoughtful moments spent away from the computer can \
often eliminate hours of wasted effort at the keyboard.\
\>", "Text",
  CellFrame->True,
  TextAlignment->Center,
  TextJustification->0,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\t ",
  StyleBox["Sections of this book can be opened and closed by double-clicking \
on the blue brackets to the right (the ones with the half arrows on the \
bottoms.)",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "9.1 Starting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Subtitle",
  CellTags->{"Sec. 9.1", "c:2"}],

Cell[TextData[{
  "The way that you start the  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program depends on the type of computer that you use.  For systems \
running Windows, for Macintoshes, or for any other computer with a \
\"graphical user interface\", you start the program by double-clicking the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " icon.  Under Windows, you will also find the program listed under the \
Start command on the Windows task bar at the lower ",
  "left-hand",
  " side of the screen. For systems with text-based interfaces such as Unix, \
you usually start the program by typing ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " at the prompt. If this doesn't work, read the manual that came with the \
copy of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for your computer, or contact your system manager or your teacher."
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox["In  this book, I will assume that you are working on a computer \
with a graphical user interface, so that the results of calculations appear \
in a Mathematica notebook described below.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\tA \"",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook\" is the name we give to the blank open window that appears when \
you start the program.  This notebook  is where you will enter mathematical \
expressions (or text or figures or anything else you wish), where the results \
of your calculations will be presented, and where you will save your results. \
 This chapter is itself a ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "notebook."
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  "\tIn order to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to evaluate a mathematical expression, first enter the expression into \
the notebook from the keyboard. For example, let's evaluate 1+1. Click \
somewhere on the notebook to make it active. Then type ",
  StyleBox["1+1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " into the notebook.  In order to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to evaluate this expression, select the expression, or merely place the \
cursor somewhere within the expression,  and press the Enter key (or \
SHIFT-Return).  (Note that Return, rather than SHIFT-Return, just takes you \
to the next line, where you can continue typing. This can be useful for long \
expressions.) After a moment, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will display the result :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 + 1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.1"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If you actually evaluate the above expression by selecting it and hitting \
the enter key , you will see that  the  input statement ",
  StyleBox["1+1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has now been modified to include ",
  StyleBox["In[1]:=",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  ", which is ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s way of saying that this is the first input statement of this session. \
The result of the evaluation, ",
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  is displayed below the input statement, and is labeled by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as ",
  StyleBox["Out[1]=",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " , the first output statement of the session.  We will see in Sec. ",
  ButtonBox["9.4.1",
    ButtonData:>"c:13",
    ButtonStyle->"Hyperlink"],
  "   that this labeling allows us to recall previous calculations. "
}], "Text"],

Cell[TextData[{
  "\tThe ",
  StyleBox["In",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Out",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " labels are usually stripped off when the file is saved to the hard disk. \
This is because the order in which the calculations are performed is up to \
the user.  Whenever a notebook is opened in a new ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, new ",
  StyleBox["In",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Out",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " labels will be generated each time calculations are evaluated, providing \
the new  order of the evaluations."
}], "Text"],

Cell[TextData[{
  "\tIn the electronic version of the book there are brackets on the \
right-hand side that group the input and output statements together into ",
  StyleBox["cells",
    FontSlant->"Italic"],
  ".  As you can see, there can be cells within cells. Here an outer cell \
groups together the input and output cells from our first evaluation. The \
cell around that delineates ",
  ButtonBox["Sec. 9.1",
    ButtonData:>"Sec. 9.1",
    ButtonStyle->"Hyperlink"],
  " of this chapter, and the outermost cell is for everything in Chapter ",
  ButtonBox["9",
    ButtonData:>{"Chapter9.nb", None},
    ButtonStyle->"Hyperlink"],
  ". There are little marks on some of these brackets, referring to \
properties of the cells,  but they need not concern us at this point. \n\t  \
In this book, input cells are also numbered consecutively in the upper ",
  "left-hand",
  " corner and hyperlinked,  for ease of reference. For instance, the above \
cell is called ",
  ButtonBox["Cell 9.1",
    ButtonData:>"Cell 9.1",
    ButtonStyle->"Hyperlink"],
  ".  Cells are labeled in the hardcopy version of the book as well. By \
default, user-created cells do not have these labels. "
}], "Text",
  CellTags->"i:4"],

Cell[TextData[{
  "\tYou can save your calculation or quit the program by choosing ",
  StyleBox["Save",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Quit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["File",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " menu. (In the Macintosh OS X system ",
  StyleBox["Quit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is found under the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " menu.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.2 ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Calculations"
}], "Subtitle",
  CellTags->{"Sec. 9.2", "c:3"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["9.2.1 Arithmetic", "Subsubtitle",
  CellTags->"c:4"],

Cell[TextData[{
  "We now know enough to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a calculator, evaluating numerical expressions. For example, we can do \
addition, subtraction, and division:"
}], "Text"],

Cell["Addition/subtraction:\t ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2.3 + 5.4 - 8.7\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.2"],

Cell[BoxData[
    \(\(-0.9999999999999991`\)\)], "Output"]
}, Open  ]],

Cell["Division:\t ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(12.5/2.1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.3"],

Cell[BoxData[
    \(5.952380952380952`\)], "Output"]
}, Open  ]],

Cell["\<\
Multiplication can be performed either using the * symbol or just \
by leaving a space between two numbers:\
\>", "Text"],

Cell["Multiplication:\t ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(3.8*6.2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.4"],

Cell[BoxData[
    \(23.56`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\n",
  StyleBox["\t",
    FontSize->8],
  "                       or\n "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(3.8\ \ 6.2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.5"],

Cell[BoxData[
    \(23.56`\)], "Output"]
}, Open  ]],

Cell["Powers are taken using the ^ symbol:", "Text"],

Cell["Powers:\t ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(4^3\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.6"],

Cell[BoxData[
    \(64\)], "Output"]
}, Open  ]],

Cell["\<\
In order to determine the order of calculation, we use parentheses \
( ):\
\>", "Text"],

Cell["Parentheses:\t", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2 \((3 + 4)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.7"],

Cell[BoxData[
    \(14\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that ONLY round brackets may be used as parentheses to determine the \
order of a calculation. Square ",
  StyleBox["[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and curly ",
  StyleBox["{}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " brackets are reserved for other uses. These facts are summarized in Table \
",
  ButtonBox["9.1",
    ButtonData:>"Table 9.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:115"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            RowBox[{
              StyleBox["Table",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["9",
                FontSize->9], 
              StyleBox[".1",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Arithmetic",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Operations",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["in",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Mathematica",
                FontSize->9,
                FontSlant->"Italic"]}], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  StyleBox[\(x + y + z\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], "Add"},
                {
                  StyleBox[\(-x\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], "Subtract"},
                {
                  StyleBox[\(x/y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], "Divide"},
                {
                  StyleBox[\(x^y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], \(Raise\ to\ a\ power\)},
                {
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["y",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["z",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["or",
                      FontFamily->"Times",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["*",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["y",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["*",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["z",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "Multiply"},
                {
                  StyleBox[\(\((x + y)\) z\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Order\ operations\ with\ parentheses\)}
                },
              ColumnSpacings->3.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.2.2 Exact vs. Approximate Results", "Subsubtitle",
  CellTags->"c:5"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can give exact results for numerical calculations, without roundoff \
error. For example, it will compute the sum of two fractions exactly:"
}], "Text",
  CellTags->"i:16"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1/3\  + \ 2/7\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.8"],

Cell[BoxData[
    \(13\/21\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can compute very large or very small numbers exactly:  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(12^22\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.9"],

Cell[BoxData[
    \(552061438912436417593344\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(53^4/89^12\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.10"],

Cell[BoxData[
    \(7890481\/246990403565262140303521\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Numbers this large or small tend to be incomprehensible. You can tell ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to give you an approximate numerical result in scientific notation by \
adding ",
  StyleBox["//N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at the end of the line:"
}], "Text",
  CellTags->"i:17"],

Cell[CellGroupData[{

Cell[BoxData[
    \(12^22\  // N\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.11"],

Cell[BoxData[
    \(5.520614389124364`*^23\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "(We will discuss the meaning of the symbol  ",
  StyleBox["//N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in Sec. ",
  ButtonBox["9.8.4",
    ButtonData:>"c:44",
    ButtonStyle->"Hyperlink"],
  "  )."
}], "Text"],

Cell[TextData[{
  "\tWhen you input an integer into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", for example, ",
  StyleBox["731",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes that it is an exact number and will try to do all calculations \
involving it exactly. However, if you type a number like ",
  StyleBox["731.0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes that this number is accurate only up to a fixed number of \
significant figures, called the machine precision. The machine precision is \
usually around 16, depending on the computer being used. You can check the \
precision of your system by typing ",
  StyleBox["$MachinePrecision",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and hitting Enter or Shift-return.  (A word on the meaning of the term \
significant figures: For a number such as 0.0731, the number of significant \
figures is the number of digits appearing to the right of the zeros , in this \
case 3. For a number like 731.0, the number of significant figures is 4.  For \
computers with a machine precision of 16, when either 0.0731 or 731.0 is \
entered, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes the number is accurate to 16 significant figures. This means that \
in all calculations involving these numbers, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will add the appropriate number of zeros on the ",
  "right-hand",
  " side until each number has 16 significant figures, and then will perform \
all calculations by rounding off the result to 16 figures. )"
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  "\t If you mix an exact number like ",
  StyleBox["2/7",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with an inexact number like ",
  StyleBox["0.1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in a calculation,  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will round off the calculation to the machine precision, and furthermore \
will only display 6 significant figures of the result:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2/7\  + \ 0.1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.12"],

Cell[BoxData[
    \(0.3857142857142857`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "(To view more than six significant figures in this result, see Sec. ",
  ButtonBox["9.2.6",
    ButtonData:>"c:9",
    ButtonStyle->"Hyperlink"],
  ".) Although only six significant figures are being displayed, rest assured \
that the calculation is accurate up to the full machine precision. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.2.3 Some Intrinsic Functions", "Subsubtitle",
  CellTags->"c:6"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a huge library of pre-defined functions (termed ",
  StyleBox["intrinsic",
    FontSlant->"Italic"],
  " functions).  A few of the more commonly used  intrinsic functions are \
shown in Table ",
  ButtonBox["9.2",
    ButtonData:>"Table 9.2",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:18"],

Cell[TextData[{
  Cell[BoxData[GridBox[{
          {
            RowBox[{
              StyleBox[\(Table  9  .2\ Some\ Intrinsic\ Functions\),
                FontSize->9], "\[IndentingNewLine]"}]},
          {GridBox[{
                {
                  StyleBox[
                    RowBox[{
                      StyleBox["Sqrt",
                        FontFamily->"Courier"], 
                      StyleBox["[",
                        FontFamily->"Courier"], 
                      StyleBox["x",
                        FontFamily->"Times"], 
                      StyleBox["]",
                        FontFamily->"Times"]}],
                    FontWeight->"Bold"], 
                  StyleBox[
                    SqrtBox[
                      StyleBox["x",
                        FontFamily->"Times",
                        FontSlant->"Italic"]],
                    FontFamily->"Times"]},
                {
                  StyleBox[\(Exp[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      StyleBox["x",
                        FontSlant->"Italic"]],
                    FontFamily->"Times"]},
                {
                  StyleBox[\(Log[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["ln",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["x",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["  ",
                      FontFamily->"Courier"], 
                    StyleBox["or",
                      FontFamily->"Times"], 
                    StyleBox[
                      FormBox[
                        RowBox[{
                          StyleBox[\(log\_e\),
                            FontFamily->"Times"], 
                          StyleBox["x",
                            FontFamily->"Times",
                            FontSlant->"Italic"]}],
                        "TraditionalForm"],
                      FontFamily->"Times"]}]},
                {
                  StyleBox[\(Log[b, x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[
                    FormBox[
                      StyleBox[\(\(log\_b\) x\),
                        FontFamily->"Times"],
                      "TraditionalForm"],
                    FontFamily->"Times"]},
                {
                  RowBox[{
                    StyleBox[\(Sin[x]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontFamily->"Courier"], 
                    StyleBox[\(Cos[x]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontFamily->"Courier"], 
                    StyleBox[\(Tan[x]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  
                  StyleBox[\(Trigonometric\ functions\ \((arguments\ in\ \
radians)\)\),
                    FontFamily->"Times"]},
                {
                  RowBox[{
                    StyleBox[\(ArcSin[x]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontFamily->"Courier"], 
                    StyleBox[" ",
                      FontFamily->"Courier"], 
                    StyleBox[\(ArcCos[x]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[",",
                      FontFamily->"Courier"], 
                    StyleBox[" ",
                      FontFamily->"Courier"], 
                    StyleBox[\(ArcTan[x]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  StyleBox[\(Inverse\ trigonometric\ functions\),
                    FontFamily->"Times"]},
                {
                  StyleBox[\(n!\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[\(Factorial\ function\),
                    FontFamily->"Times"]},
                {
                  StyleBox[\(Abs[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["|",
                      FontFamily->"Times"], Cell[TextData[StyleBox["x",
                      FontFamily->"Times",
                      FontSlant->"Italic"]]], 
                    StyleBox["|",
                      FontFamily->"Times"]}]},
                {
                  StyleBox[\(Round[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["Closest",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["integer",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["to",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["x",
                      FontFamily->"Times",
                      FontSlant->"Italic"]}]},
                {
                  RowBox[{
                    StyleBox[\(Random[]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  
                  StyleBox[\(Pseudo - 
                      random\ real\ number\ in\ the\ range\ [0, 1]\),
                    FontFamily->"Times"]}
                },
              ColumnSpacings->3.8,
              ColumnAlignments->{Left}]}
          }]]],
  StyleBox["   ",
    FontFamily->"Courier"]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->{"i:96", "Table 9.2"}],

Cell[TextData[{
  StyleBox["\n",
    FontSize->9],
  "Note that the names of ",
  StyleBox["all intrinsic functions",
    FontSlant->"Italic"],
  " start with a capital letter. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is ",
  StyleBox["case-sensitive",
    FontSlant->"Italic"],
  ", so ",
  StyleBox["cos[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not the same as ",
  StyleBox["Cos[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  Also, note that ",
  StyleBox["only ",
    FontSlant->"Italic"],
  "square brackets are used to enclose the arguments of the functions, so ",
  StyleBox["Cos(3)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not mean the Cosine of 3. "
}], "Text"],

Cell[TextData[StyleBox["These two points are very important, and are the \
reason for a good fraction of the mistakes made by novice Mathematica users. \
",
  FontWeight->"Bold",
  FontSlant->"Italic"]], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            RowBox[{
              StyleBox["Two",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Important",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Points",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Concerning",
                FontSize->9], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Mathematica",
                FontSize->9,
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSize->9], 
              StyleBox["Functions",
                FontSize->9]}], "\[IndentingNewLine]"}]},
        {GridBox[{
              {
                RowBox[{
                  StyleBox["\[Bullet]",
                    FontFamily->"Symbol"], 
                  StyleBox[" ",
                    FontFamily->"Arial"], 
                  StyleBox["The",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["arguments",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["all",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["Mathematica",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["functions",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["are",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["enclosed",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["in",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["square",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  RowBox[{
                    StyleBox["brackets",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[".",
                      FontFamily->"Times"]}]}]},
              {
                RowBox[{
                  StyleBox["\[Bullet]",
                    FontFamily->"Symbol"], 
                  StyleBox[" ",
                    FontFamily->"Arial"], 
                  StyleBox["The",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["names",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["intrinsic",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["Mathematica",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["functions",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["begin",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["with",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["capital",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  RowBox[{
                    StyleBox["letters",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[".",
                      FontFamily->"Times"]}]}]}
              },
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.2.4 Special Numbers", "Subsubtitle",
  CellTags->"c:7"],

Cell[TextData[{
  "In addition to the library of intrinsic functions, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also defines certain special numbers. Some of these are given in Table ",
  ButtonBox["9.3",
    ButtonData:>"Table 9.3",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox[\(Table  9  .3\ Some\ Special\ Numbers\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {GridBox[{
              {
                StyleBox["Pi",
                  FontWeight->"Bold"], 
                StyleBox[Cell[TextData[{
                    StyleBox["\[Pi]",
                      FontFamily->"Times"],
                    " (",
                    StyleBox["3.14159...",
                      FontFamily->"Times"],
                    ")"
                  }]],
                  FontFamily->"Times"]},
              {
                StyleBox["E",
                  FontWeight->"Bold"], 
                StyleBox[\(\[ExponentialE]\ \((2.71828 ... )\)\),
                  FontFamily->"Times"]},
              {
                StyleBox["I",
                  FontWeight->"Bold"], 
                StyleBox[
                  RowBox[{"\[ImaginaryI]", "   ", Cell[TextData[{
                      "(",
                      Cell[BoxData[
                          FormBox[
                            SqrtBox[
                              StyleBox[\(-1\),
                                FontFamily->"Times"]], TraditionalForm]]],
                      ")"
                    }]]}],
                  FontFamily->"Times"]},
              {
                StyleBox["Infinity",
                  FontWeight->"Bold"], 
                StyleBox["\[Infinity]",
                  FontFamily->"Times"]},
              {
                StyleBox["Degree",
                  FontWeight->"Bold"], 
                StyleBox[
                  RowBox[{Cell[TextData[{
                      StyleBox["\[Pi]",
                        FontFamily->"Times"],
                      "/",
                      StyleBox["180",
                        FontFamily->"Times"]
                    }]], "  ", \((degree\ to\ radian\ conversion\ factor)\)}],
                  
                  FontFamily->"Times"]}
              },
            ColumnSpacings->3.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.3"],

Cell["\<\
Like the intrinsic functions, these special numbers  are always \
capitalized. \
\>", "Text"],

Cell[TextData[{
  "The following examples show how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s intrinsic functions and special numbers can be used in numerical \
calculations.\n(1) Find the sine of a 45-degree angle:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[45\ Degree]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.13"],

Cell[BoxData[
    \(1\/\@2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is an exact expression. To get a numerical result, one can \
either type ",
  StyleBox["Sin[45.0 Degree]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or use the",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["//",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["N",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " notation: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[45\ Degree]\  // N\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.14"],

Cell[BoxData[
    \(0.7071067811865475`\)], "Output"]
}, Open  ]],

Cell["(2) Find the  inverse hyperbolic tangent of 1.2", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ArcTanh[1.2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.15"],

Cell[BoxData[
    \(\(\(1.1989476363991853`\)\(\[InvisibleSpace]\)\) - 
      1.5707963267948966`\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a complex rather than a real number, with both a real and an \
imaginary part.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ability to handle complex numbers is outlined in the next section."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.2.5 Complex Arithmetic", "Subsubtitle",
  CellTags->"c:8"],

Cell[TextData[{
  "Many intrinsic functions in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " work equally well with real or with complex numbers ",
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ x\  + \ \[ImaginaryI]\ y\)]],
  ".  For example, the power, trigonometric, exponential and logarithmic \
functions discussed previously work with complex as well as real arguments. \
Of course, addition, subtraction, multiplication and division all work with \
complex numbers."
}], "Text",
  CellTags->"i:14"],

Cell[TextData[{
  "\tIn addition to these intrinsic functions, several intrinsic functions \
are designed specifically for complex numbers (see Table ",
  ButtonBox["9.4",
    ButtonData:>"Table 9.4",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox["Table",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["9",
              FontSize->9], 
            StyleBox[".4",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Some",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Intrinsic",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Functions",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["for",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Complex",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Numbers",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], Cell[TextData[Cell[BoxData[
                RowBox[{" ", Cell[TextData[Cell[BoxData[
                      \(TraditionalForm\`z = x\  + \ \[ImaginaryI]\ y\)],
                    FontFamily->"Times",
                    FontSize->10]]]}]]]]], 
            StyleBox[" ",
              FontSize->9], Cell[""]}]},
        {
          RowBox[{
            StyleBox["\n",
              FontSlant->"Italic"], 
            StyleBox[GridBox[{
                  {
                    StyleBox[\(Re[z]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"Real", " ", "part", " ", "of", "  ", 
                      RowBox[{
                        StyleBox["z",
                          FontSlant->"Italic"], ":", " ", 
                        RowBox[{
                          StyleBox["x",
                            FontSlant->"Italic"], Cell[""]}]}]}]},
                  {
                    StyleBox[\(Im[z]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"Imaginary", " ", "part", " ", "of", " ", 
                      RowBox[{
                        StyleBox["z",
                          FontSlant->"Italic"], ":", " ", 
                        RowBox[{
                          StyleBox["y",
                            FontSlant->"Italic"], Cell[""]}]}]}]},
                  {
                    StyleBox[\(Abs[z]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"Absolute", " ", "value", " ", "of", " ", 
                      RowBox[{
                        StyleBox["z",
                          FontSlant->"Italic"], ":", " ", 
                        RowBox[{"|", 
                          StyleBox["z",
                            FontSlant->"Italic"], "|"}]}]}]},
                  {
                    StyleBox[\(Arg[z]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    RowBox[{"Argument", " ", "of", " ", 
                      RowBox[{
                        StyleBox["z",
                          FontSlant->"Italic"], ":", " ", Cell[TextData[Cell[
                        BoxData[
                            \(TraditionalForm\`\(tan\^\(-1\)\) y/x\)],
                          FontFamily->"Times"]]]}]}]},
                  {
                    StyleBox[\(Conjugate[z]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      RowBox[{"Complex", " ", "conjugate", " ", "of", " ", 
                        RowBox[{
                          StyleBox["z",
                            FontSlant->"Italic"], ":", "  ", 
                          StyleBox[\(z\^*\),
                            FontSlant->"Italic"]}]}], " ", "=", " ", Cell[
                      TextData[Cell[BoxData[
                          \(TraditionalForm\`x\  - \ \[ImaginaryI]\ y\)],
                        FontFamily->"Times"]]]}]}
                  },
                ColumnSpacings->2.8,
                ColumnAlignments->{Left}],
              FontFamily->"Times"]}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:15"],

Cell[TextData[{
  "Example: Take the real part of ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 + 2\ \[ImaginaryI])\)/\((3\  + \ 
            5\ \[ImaginaryI])\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Re[\((1 + 2  I)\)/\((3 + 5  I)\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.16"],

Cell[BoxData[
    \(13\/34\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["9.2.6 The Function ",
    FontFamily->"Helvetica"],
  StyleBox["N",
    FontFamily->"Courier",
    FontSize->18],
  StyleBox[" and Arbitrary-Precision Numbers",
    FontFamily->"Helvetica"]
}], "Subsubtitle",
  CellTags->"c:9"],

Cell[TextData[{
  "When ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  numerically evaluates an expression such as ",
  StyleBox["Pi //N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", it works only to machine precision, as discussed in Sec. ",
  ButtonBox["9.2.2",
    ButtonData:>"c:5",
    ButtonStyle->"Hyperlink"],
  ".  The notation ",
  StyleBox["Pi//N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " calls for acting on the exact number ",
  StyleBox["Pi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with an intrinsic function ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["N[Pi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This function takes an exact number and approximates it to machine \
precision:  "
}], "Text",
  CellTags->"i:20"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Pi]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.17"],

Cell[BoxData[
    \(3.141592653589793`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tHowever, one can also perform the evaluation to arbitrary numerical \
precision. For example, to obtain a precision of 25 significant figures, one \
adds a second argument to the function ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the precision of the evaluation: "
}], "Text",
  CellTags->"i:6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Pi, 25]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.18"],

Cell[BoxData[
    \(3.1415926535897932384626433832795028842`25\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe function ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " always works at machine precision or above, ",
  StyleBox["even if one asks for a precision less than the machine precision",
    
    FontSlant->"Italic"],
  ". Numbers with precision greater than the machine precision are displayed \
with all of their significant figures, as shown above. Numbers with precision \
less than or equal to the machine precision are displayed with six \
significant figures . For example, on my computer, which has a machine \
precision of 16, the following evaluation displays only six significant \
figures:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Sqrt[2], 9]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.19"],

Cell[BoxData[
    \(1.4142135623730951`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, the evaluation was performed to machine precision, not to nine \
significant figures. To see the full number that is stored in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " rather than the six significant figures displayed above, it is necessary \
to ask for the internal form of the number, with an intrinsic function called \
",
  StyleBox["InputForm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:7"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InputForm[N[Sqrt[2], 9]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.20"],

Cell["1.4142135623730951", "Output"]
}, Open  ]],

Cell[TextData[{
  " The function ",
  StyleBox["InputForm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " displays the actual number stored in memory by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", which can be seen to have machine precision, not nine digits of \
precision. In case you don't know what ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  " is to 16 significant figures, we can verify that the above expression is \
correct by comparing it with a number of higher precision:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Sqrt[2], 20]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.21"],

Cell[BoxData[
    \(1.414213562373095048801688724209698`20\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tNumbers can be evaluated to an arbitrary level of precision using ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". However, the larger the precision asked for, the longer it takes to \
perform the calculation. For example, on my (old, slow) Macintosh, the \
calculation of ",
  StyleBox["N[Sqrt[2],50000]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes roughly 25 seconds. On the other hand, on my (new, fast) Macintosh \
it only takes about a second. I won't bother displaying the result, since it \
would use up several pages; try it yourself."
}], "Text"],

Cell[TextData[{
  "\tIf one adds together two numbers with different precisions, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does the right thing and evaluates the result to the lower of the two \
precisions. The precision of a number can be checked directly using the \
intrinsic function ",
  StyleBox["Precision",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example,"
}], "Text",
  CellTags->"i:21"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[N[Sqrt[6], 200]\  + \ N[Pi, 27]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.22"],

Cell[BoxData[
    \(27\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The functions mentioned above are summarized in Table ",
  ButtonBox["9.5",
    ButtonData:>"Table 9.5",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table  
                9  .5\ Functions\ Useful\ for\ Numerical\ Evaluations\),
              FontSize->9,
              Background->None], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["expr",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Italic"], 
                    StyleBox["//",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["N",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], " ", "or", " ", 
                      RowBox[{
                        StyleBox["N",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["[",
                          FontFamily->"Courier",
                          FontWeight->"Bold",
                          FontSlant->"Italic"], 
                        StyleBox["expr",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["]",
                          FontFamily->"Courier",
                          FontWeight->"Bold",
                          FontSlant->"Italic"]}]}]}], 
                  RowBox[{
                  "Approximate", " ", "numerical", " ", "value", " ", "of", 
                    " ", 
                    StyleBox["expr",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}]},
                {
                  StyleBox[
                    RowBox[{"N", "[", 
                      RowBox[{
                        StyleBox["expr",
                          FontSlant->"Plain"], 
                        StyleBox[",",
                          FontSlant->"Italic"], "n"}], "]"}],
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{"Numerical", " ", "value", " ", "of", " ", 
                      StyleBox["expr",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "evaluated", " ", "with", " ", 
                      StyleBox["n",
                        FontSlant->"Italic"]}], "-", \(digit\ precision\)}]},
                {
                  StyleBox[\(InputForm[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{\(The\ full\), "-", 
                    RowBox[{"precision", " ", "form", " ", "of", " ", 
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "stored", " ", 
                      "internally"}]}]},
                {
                  StyleBox[\(Precision[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                  "Precision", " ", "of", " ", "the", " ", "number", " ", 
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}]}
                },
              ColumnSpacings->3.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.2", "Subsubtitle",
  CellTags->"c:10"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Find a numerical value for ",
  Cell[BoxData[
      \(TraditionalForm\`sin(53  \[Degree])\)]],
  " to six significant figures."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Find the 2001st significant figure of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Is ",
  Cell[BoxData[
      \(TraditionalForm\`\(120!\)\)]],
  " greater or smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`10\^200\)]],
  " ?"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Find ",
  Cell[BoxData[
      \(TraditionalForm\`tanh(50) - 1\)]],
  " to 10 significant figures."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Find the real and imaginary parts of the complex number ",
  Cell[BoxData[
      \(TraditionalForm\`z = \[ExponentialE]\^\(2 + 9\ \[ImaginaryI]\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.3 The ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "Front End",
  StyleBox[" ",
    FontSlant->"Italic"],
  "and ",
  "Kernel"
}], "Subtitle",
  CellTags->{"Sec. 9.3", "c:11"}],

Cell[TextData[{
  "\tBefore  we go on to evaluate more complex expressions,  it is useful to \
take a moment to discuss the structure of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The program comes in two separate parts, the ",
  StyleBox["front end",
    FontSlant->"Italic"],
  ", and the ",
  StyleBox["kernel",
    FontSlant->"Italic"],
  ". When you start a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session by double clicking on the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " icon, you are actually only starting the program's ",
  "front end",
  ". The front end is the part of the program responsible for displaying the \
notebook, accepting input, and displaying the results of calculations.  The \
kernel is the part that is responsible for performing the calculations. It \
does not start up until you perform an evaluation by hitting Enter, (or \
Shift-Return). "
}], "Text",
  CellTags->"i:8"],

Cell["\<\
\tThere are several reasons for this arrangement. One reason is \
that you can display the contents of a notebook without having to start the \
kernel. The kernel takes up quite a bit of computer memory,  and you don't \
need to start it up unless it is really needed to perform a new calculation. \
Another reason is that the kernel doesn't even have to be running on the same \
computer as the front end. Thus, it is theoretically possible to run the \
Kernel on a  fast mainframe at a completely different physical location, \
while you display the results in the front end on your laptop.\
\>", "Text"],

Cell[TextData[{
  "\t A third, more important reason is that when ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "calculations go awry, as they sometimes do,  you can stop the calculation \
without closing your notebook and ending the program. One way to stop the \
calculation is to choose ",
  StyleBox["Interrupt Evaluation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Abort",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Evaluation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from the kernel menu. However, if the kernel is busy with an evaluation, \
it may not respond. In this case, you can stop the calculation by quitting \
the kernel. This leaves the front end running, displaying your previous \
results.  To quit the kernel, choose ",
  StyleBox["Quit Kernel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  from the kernel menu"
}], "Text",
  CellTags->"i:13"],

Cell[TextData[{
  "\tOnce you have quit the kernel, you can simply restart the session by \
typing in a new calculation and hitting Enter or SHIFT-Return, or by \
reevaluating one of your previous calculations.  Note that the numbering of \
the cells starts again from ",
  StyleBox["In[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The kernel is responsible for storing the results of your previous \
calculations, and when you quit the kernel all these previous results are \
lost from memory,  although they continue to be displayed in the notebook.  \
They can be reevaluated merely by choosing one or more of the cells that you \
wish to evaluate and hitting Enter or SHIFT-Return.. \n"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.4 Using Previous Results", "Subtitle",
  CellTags->{"Sec. 9.4", "c:12"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["9.4.1 The % Symbol", "Subsubtitle",
  CellTags->"c:13"],

Cell[TextData[{
  "When building up a complex calculation it is often necessary to refer to \
results from previously evaluated cells. The percent symbol ",
  StyleBox["%",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to refer to the last evaluation.  For example, let's perform \
the following calculation in two steps: ",
  Cell[BoxData[
      \(TraditionalForm\`77\^2 + 1\)]],
  ". First, we square ",
  Cell[BoxData[
      \(TraditionalForm\`77\)]],
  ":"
}], "Text",
  CellTags->"i:22"],

Cell[CellGroupData[{

Cell[BoxData[
    \(77^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.23"],

Cell[BoxData[
    \(5929\)], "Output"]
}, Open  ]],

Cell["In order to add 1 to this result, we can type", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% + 1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.24"],

Cell[BoxData[
    \(5930\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Two percent symbols, ",
  StyleBox["%%",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  denote the next to last result. Thus,  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  - \ %%\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.25"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One could put ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " ",
  StyleBox["%",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " symbols together to denote the ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  "st-to-last result, but this gets a bit confusing. Instead, you can refer \
to a previous result directly by referring to its cell number. For example, \
",
  Cell[BoxData[
      FormBox[
        StyleBox["%1",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " refers to the output of the first cell in the current session:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.26"],

Cell[BoxData[
    \(5929\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, this notation can cause trouble if you quit and restart a \
session, because then cell number 1 may change - see Sec. ",
  ButtonBox["9.3",
    ButtonData:>"Sec. 9.3",
    ButtonStyle->"Hyperlink"],
  ". A better way to refer to previous results is discussed in the next \
subsection."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.4.2 Variables", "Subsubtitle",
  CellTags->"c:14"],

Cell[TextData[{
  "\tUsing cell numbers to refer to previous results has a drawback: as we \
saw in ",
  ButtonBox["Sec. 9.3",
    ButtonData:>"Sec. 9.3",
    ButtonStyle->"Hyperlink"],
  ", the cell numbers disappear when you quit  the kernel. A more permanent \
way to refer to previous results is to give the results names. These names \
are called ",
  StyleBox["variables",
    FontSlant->"Italic"],
  ". Variables can have any name you want, provided that they start with \
letters and that they aren't reserved names like ",
  StyleBox["Pi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Infinity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\tFor example,",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a good name for a variable.",
  StyleBox[" ",
    FontSlant->"Italic"],
  " For one thing, it is lowercase, so it is guaranteed not to conflict with \
any of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s reserved function or variable names. To assign the result of a \
calculation to this variable, simply type ",
  StyleBox["x = expr",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["expr",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " stands for an expression. For example, when you type ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontSlant->"Plain"], " ", "=", " ", \(Tan[60\ Degree]\)}], 
        TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the ",
  "right-hand",
  " side of the equation is immediately evaluated and the result is stored as \
the variable ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = \ Tan[60\ Degree]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.27"],

Cell[BoxData[
    \(\@3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " We can now use ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in any new calculation, for example,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x^4\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.28"],

Cell[BoxData[
    \(9\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can assign a new value to the variable ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at any time:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = Sqrt[14]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.29"],

Cell[BoxData[
    \(\@14\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can also clear from memory any value assigned to the variable by using \
the ",
  StyleBox["Remove",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function:"
}], "Text",
  CellTags->"i:23"],

Cell[BoxData[
    \(Remove[x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.30"],

Cell[TextData[{
  "If you ask for the value of ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " after ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is cleared, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " returns ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " itself, since no value is assigned to it:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.31"],

Cell[BoxData[
    \(x\)], "Output"]
}, Open  ]],

Cell["\<\
If you wish to remove from memory  all the  variables that you have \
defined in the current session, the following command works:\
\>", "Text",
  CellTags->"i:24"],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.32"],

Cell[TextData[{
  "The  ",
  StyleBox["*",
    FontWeight->"Bold"],
  " in this expression is a wildcard, standing in for all variables. The \
expression ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " refers to the ",
  StyleBox["context",
    FontSlant->"Italic"],
  " of the variables. Contexts provide a way of organizing symbols into \
groups. Think of the context as the \"tribe\"  or \"surname\" of a symbol. \
When we create a variable, such as ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", it is given the context ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default, and so has the full name ",
  StyleBox["Global`a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". All symbols have contexts,  including intrinsic variables and functions. \
For instance, the full name for ",
  Cell[BoxData[
      \(TraditionalForm\`Pi\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`System`Pi\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Since the ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context is reserved for variables that we create,  removing all symbols \
in the ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context removes all the symbols that have been created in the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text",
  CellTags->"i:10"],

Cell[TextData[{
  "\t   We do not need to know  more  about contexts in this part of the \
book, so for now, enough said. Those readers who wish to learn more about \
contexts can refer to ",
  StyleBox["The",
    FontSlant->"Italic"],
  " ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" Book",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIt is a good idea to clear variables from memory after a calculation is \
completed, because it is easy to forget  which variables have already been \
defined, and this can lead to errors.  \n\tThe commands in this and the \
preceding subsection are summarized in Table ",
  ButtonBox["9.6",
    ButtonData:>"Table 9.6",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table  9  .6\ Ways\ to\ Refer\ to\ Previous\ Results\),
              
              FontSize->9], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  StyleBox["%",
                    
                    FontFamily->
                      "Courier"], \(The\ last\ result\ generated\)},
                {
                  StyleBox["%%",
                    FontFamily->"Courier"], \(The\ next\ to\ last\ result\)},
                {
                  RowBox[{
                    StyleBox[\(%% ... \),
                      FontFamily->"Courier"], 
                    StyleBox["%",
                      FontFamily->"Courier"], 
                    StyleBox[
                      RowBox[{
                        StyleBox[" ",
                          FontFamily->"Courier"], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["n",
                          FontSlant->"Italic"], " ", "times"}], ")"}]}], 
                  RowBox[{"The", " ", 
                    StyleBox[
                      RowBox[{
                        StyleBox["n",
                          FontSlant->"Italic"], "th"}]], " ", "previous", " ",
                     "result"}]},
                {
                  RowBox[{
                    StyleBox["%",
                      FontFamily->"Courier"], 
                    StyleBox["n",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"The", " ", "result", " ", "in", " ", "cell", " ", 
                    StyleBox[\(Out[n]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}]},
                {
                  StyleBox[\(x = expression\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Evaluates", " ", 
                    StyleBox["expression",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", "and", " ", "assigns", " ", 
                    "the", " ", "result", " ", "to", " ", "the", " ", 
                    "variable", " ", 
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(x = \(y = expression\)\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Evaluates", " ", 
                    StyleBox["expression",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "and", " ", "assigns", 
                    StyleBox[" ",
                      FontSlant->"Italic"], "the", " ", "result", " ", "to", 
                    " ", "both", " ", 
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "and", " ", 
                    StyleBox["y",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(Remove[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Remove", " ", "the", " ", "variable", " ", 
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["   ",
                      FontSlant->"Italic"], "from", " ", "memory"}]},
                {
                  StyleBox[\(Clear[x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                    "Also", " ", "clears", " ", "the", " ", "value", " ", 
                      "of", "  ", 
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[
                        RowBox[{
                          StyleBox[" ",
                            FontSlant->"Italic"], " "}]], "from", " ", 
                      "memory"}], "\[IndentingNewLine]", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"using", " ", 
                          StyleBox["Remove",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], " ", "is", " ", 
                          "recommended"}], 
                        ";", \(it\ does\ a\ more\ complete\ \
\(\(job\)\(.\)\)\)}], " ", ")"}], "\[IndentingNewLine]", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"See", " ", "also", " ", 
                          StyleBox["Unset",
                            FontFamily->"Courier",
                            FontWeight->"Bold"]}], 
                        ",", \(used\ for\ clearing\ specific\ values\ of\ a\ \
\(\(function\)\(.\)\)\)}], ")"}]}]}
                },
              ColumnSpacings->3.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->{"i:25", "Table 9.6"}],

Cell[TextData[StyleBox["",
  FontSize->9]], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox[\(Some\ Things\ to\ Remember\ when\ Using\ Variables\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["y",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], Cell[TextData[StyleBox["",
                      FontFamily->"Times",
                      FontSlant->"Italic"]]]}], 
                  RowBox[{"means", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], " ", "times", " ", 
                    StyleBox["y",
                      FontSlant->"Italic"], Cell[""]}]},
                {
                  StyleBox["xy",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                  "with", " ", "no", " ", "space", " ", "means", " ", "a", 
                    " ", "variable", " ", "named", " ", 
                    StyleBox["xy",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(3  x\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"means", " ", "3", " ", "times", " ", 
                    StyleBox["x",
                      
                      FontSlant->
                        "Italic"], \((with\ or\ without\ a\ space)\)}]},
                {Cell[TextData[StyleBox["x^2y",
                    FontWeight->"Bold"]]], 
                  RowBox[{"means", " ", Cell[TextData[Cell[BoxData[
                        FormBox[
                          StyleBox[\(\(x\^2\) y\),
                            FontFamily->"Times"], TraditionalForm]]]]], "not",
                     " ", Cell[TextData[Cell[BoxData[
                        FormBox[
                          StyleBox[\(x\^\(2  y\)\),
                            FontFamily->"Times"], TraditionalForm]]]]]}]}
                },
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.4.3 Palettes and Keyboard Equivalents", "Subsubtitle",
  CellTags->"c:15"],

Cell[TextData[{
  "\tVariables can also be Greek letters or other special characters, such as \
",
  StyleBox["\[Alpha]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Symbol"],
  " or \[WeierstrassP]. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " supports a large collection of special characters that can be accessed \
using ",
  StyleBox["palettes",
    FontSlant->"Italic"],
  ". These palettes can also be used to implement various intrinsic \
functions.  Palettes are available under the ",
  StyleBox["File",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " menu. There are several palettes, each with different uses. One palette \
that I find useful is the BasicInput palette. An image of this palette is \
shown in Fig. ",
  ButtonBox["9.1",
    ButtonData:>"Fig. 9.1",
    ButtonStyle->"Hyperlink"],
  ".  To use a palette, simply click on the character or function desired. "
}], "Text",
  CellTags->"i:12"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004;0004L2000`400?l00000o`00003oooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`001_ooool50>o_k`030>OWi`3Ng]h0g]kN0080c/k>00<0b/[:0<K6aP36a/H01@2e]KD00`2a
/K40[Jf]0:f][@090:FUY@030:VYZ@2][Jd0[Jf]00<0[Jf]0P2UYJD00`2YZJT0[Jf]0:f][@020:FU
Y@030:VYZ@2][Jd0[Jf]00X0YJFU00<0ZJVY0:f][@2][Jd0302UYJD00`2YZJT0[Jf]0:f][@020:f]
[@040:VYZ@2UYJD0YJFU0:VYZ@80[Jf]0P2UYJD00`2YZJT0[Jf]0:f][@0:0:FUY@030:VYZ@2][Jd0
[Jf]00d0YJFU102][Jd00`2YZJT0YJFU0:FUY@020:f][@040:VYZ@2UYJD0YJFU0:VYZ@80[Jf]2P2U
YJD30:f][@`0YJFU1@2][Jd00`2YZJT0YJFU0:FUY@020:f][@030:VYZ@2UYJD0YJFU0080[Jf]00<0
ZJVY0:FUY@2UYJD0202UYJD20:f][@030:VYZ@2UYJD0YJFU00X0YJFU1@2][Jd30:FUY@80[Jf]00<0
ZJVY0:FUY@2UYJD00P2][Jd00`2YZJT0YJFU0:FUY@080:FUY@80[Jf]00<0ZJVY0:FUY@2UYJD00P2U
YJD60:f][@80]KFe1@2m_Kd20<k>cP030=KFeP3Ng]h0g]kN00<0g]kN0P3gmoL00`3kno/0oooo0?oo
o`08ooooo`001_ooool50>o_k`030>OWi`3Ng]h0g]kN0080c/k>00<0b/[:0<K6aP36a/H01@2e]KD0
0`2a/K40[Jf]0:f][@090:FUY@030:VYZ@2][Jd0[Jf]00<0[Jf]0P2UYJD00`2YZJT0[Jf]0:f][@02
0:FUY@030:VYZ@2][Jd0[Jf]00X0YJFU00<0ZJVY0:f][@2][Jd0302UYJD00`2YZJT0[Jf]0:f][@02
0:f][@040:VYZ@2UYJD0YJFU0:VYZ@80[Jf]0P2UYJD00`2YZJT0[Jf]0:f][@0:0:FUY@030:VYZ@2]
[Jd0[Jf]00d0YJFU102][Jd00`2YZJT0YJFU0:FUY@020:f][@040:VYZ@2UYJD0YJFU0:VYZ@80[Jf]
2P2UYJD30:f][@`0YJFU1@2][Jd00`2YZJT0YJFU0:FUY@020:f][@030:VYZ@2UYJD0YJFU0080[Jf]
00<0ZJVY0:FUY@2UYJD0202UYJD20:f][@030:VYZ@2UYJD0YJFU00X0YJFU1@2][Jd30:FUY@80[Jf]
00<0ZJVY0:FUY@2UYJD00P2][Jd00`2YZJT0YJFU0:FUY@080:FUY@80[Jf]00<0ZJVY0:FUY@2UYJD0
0P2UYJD60:f][@80]KFe1@2m_Kd20<k>cP030=KFeP3Ng]h0g]kN00<0g]kN0P3gmoL00`3kno/0oooo
0?ooo`08ooooo`001_ooool50>o_k`030>OWi`3Ng]h0g]kN0080c/k>00<0b/[:0<K6aP36a/H01@2e
]KD00`2a/K40[Jf]0:f][@090:FUY@030:VYZ@2][Jd0[Jf]00<0[Jf]0P2UYJD00`2YZJT0[Jf]0:f]
[@020:FUY@030:VYZ@2][Jd0[Jf]00X0YJFU00<0ZJVY0:f][@2][Jd0302UYJD00`2YZJT0[Jf]0:f]
[@020:f][@040:VYZ@2UYJD0YJFU0:VYZ@80[Jf]0P2UYJD00`2YZJT0[Jf]0:f][@0:0:FUY@030:VY
Z@2][Jd0[Jf]00d0YJFU102][Jd00`2YZJT0YJFU0:FUY@020:f][@040:VYZ@2UYJD0YJFU0:VYZ@80
[Jf]2P2UYJD30:f][@`0YJFU1@2][Jd00`2YZJT0YJFU0:FUY@020:f][@030:VYZ@2UYJD0YJFU0080
[Jf]00<0ZJVY0:FUY@2UYJD0202UYJD20:f][@030:VYZ@2UYJD0YJFU00X0YJFU1@2][Jd30:FUY@80
[Jf]00<0ZJVY0:FUY@2UYJD00P2][Jd00`2YZJT0YJFU0:FUY@080:FUY@80[Jf]00<0ZJVY0:FUY@2U
YJD00P2UYJD60:f][@80]KFe1@2m_Kd20<k>cP030=KFeP3Ng]h0g]kN00<0g]kN0P3gmoL00`3kno/0
oooo0?ooo`08ooooo`001_ooool30>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P36a/H00`2n_[h0]KFe
0;Fe]@020:f][@040:FUY@2LW9`0W9bL09RHV080U9BD0P2LW9`309BDU080W9bL1@2DU9@00`2HV9P0
W9bL09bLW00209BDU00309RHV02LW9`0W9bL00D0U9BD0`2LW9`509BDU080W9bL00<0V9RH09BDU02D
U9@0202DU9@209bLW0D0U9BD0P2LW9`0102HV9P0U9BD09BDU02HV9P209bLW0D0U9BD0P2LW9`00`2H
V9P0U9BD09BDU00309BDU080W9bL00<0V9RH09BDU02DU9@01`2DU9@309bLW0D0U9BD0P2LW9`00`2H
V9P0U9BD09BDU00209bLW00309RHV02DU9@0U9BD00<0U9BD0P2LW9`00`2HV9P0U9BD09BDU00209BD
U00309RHV02LW9`0W9bL00X0U9BD0`2LW9`509BDU080W9bL00<0V9RH09BDU02DU9@00P2LW9`00`2H
V9P0U9BD09BDU00209BDU00409RHV02LW9`0W9bL09RHV0@0U9BD00<0V9RH09bLW02LW9`02P2DU9@3
09bLW0@0U9BD00<0V9RH09bLW02LW9`00`2DU9@209bLW00309RHV02DU9@0U9BD0080U9BD00<0V9RH
09bLW02LW9`01@2DU9@00`2HV9P0W9bL09bLW00:09BDU0<0W9bL0P2UYJD20:f][@030;6a/@2e]KD0
]KFe0080_Kfm00<0b/[:0=KFeP3Fe]H00`3Ng]h20>o_k`030?Ogm`3oool0oooo00Sooooo0006oooo
o`<0kno_0P3Ng]h00`3Jf]X0e]KF0=KFeP020<K6aP030;jn_P2e]KD0]KFe0080[Jf]00@0YJFU09bL
W02LW9`0V9RH0P2DU9@209bLW0<0U9BD0P2LW9`509BDU00309RHV02LW9`0W9bL0080U9BD00<0V9RH
09bLW02LW9`01@2DU9@309bLW0D0U9BD0P2LW9`00`2HV9P0U9BD09BDU00809BDU080W9bL1@2DU9@2
09bLW00409RHV02DU9@0U9BD09RHV080W9bL1@2DU9@209bLW00309RHV02DU9@0U9BD00<0U9BD0P2L
W9`00`2HV9P0U9BD09BDU00709BDU0<0W9bL1@2DU9@209bLW00309RHV02DU9@0U9BD0080W9bL00<0
V9RH09BDU02DU9@00`2DU9@209bLW00309RHV02DU9@0U9BD0080U9BD00<0V9RH09bLW02LW9`02P2D
U9@309bLW0D0U9BD0P2LW9`00`2HV9P0U9BD09BDU00209bLW00309RHV02DU9@0U9BD0080U9BD00@0
V9RH09bLW02LW9`0V9RH102DU9@00`2HV9P0W9bL09bLW00:09BDU0<0W9bL102DU9@00`2HV9P0W9bL
09bLW00309BDU080W9bL00<0V9RH09BDU02DU9@00P2DU9@00`2HV9P0W9bL09bLW00509BDU00309RH
V02LW9`0W9bL00X0U9BD0`2LW9`20:FUY@80[Jf]00<0/K6a0;Fe]@2e]KD00P2m_Kd00`3:b/X0e]KF
0=KFeP030=kNgP80kno_00<0moOg0?ooo`3oool02?ooool000Kooooo0`3_knl20=[JfP030=KFeP3B
d]80d];B0080_[jn00<0][Jf0:f][@2][Jd00P2UYJD0102OWil0V9RH09RHV02FUYH209BDU080T92@
0`2<S8`209BDU0D0S8b<00<0SXj>092@T02@T9000P2<S8`00`2>SXh0T92@092@T002092@T00308j>
SP2<S8`0S8b<00<0T92@1@2<S8`2092@T00308j>SP2<S8`0S8b<0080T92@1P2<S8`209BDU0D0S8b<
0P2@T900102>SXh0S8b<08b<S02>SXh4092@T00308j>SP2<S8`0S8b<0080T92@00<0SXj>08b<S02<
S8`00`2<S8`2092@T00308j>SP2<S8`0S8b<0080T92@1@2<S8`309BDU0D0S8b<0P2@T9000`2>SXh0
S8b<08b<S005092@T00308j>SP2<S8`0S8b<0080T92@00<0SXj>08b<S02<S8`00P2<S8`00`2>SXh0
T92@092@T00308b<S080T92@00<0SXj>08b<S02<S8`00P2<S8`309BDU0D0S8b<0P2@T9000`2>SXh0
S8b<08b<S005092@T080S8b<00@0SXj>092@T02@T900SXj>102<S8`00`2>SXh0T92@092@T00208b<
S00308j>SP2@T900T92@00D0S8b<0`2DU9@408b<S00308j>SP2@T900T92@00<0S8b<1@2@T90208b<
S00308j>SP2@T900T92@00D0S8b<00<0SXj>092@T02@T9000P2<S8`00`2>SXh0T92@092@T00508b<
S0<0V9RH0P2MWId20:FUY@030:^[Z`2a/K40/K6a0080^KVi00<0a<C40<k>cP3>c/h00`3Ng]h20>o_
k`030?Gem@3kno/0no_k00Sooooo0006ooooo`<0kno_0P3Fe]H00`3Bd]80c/k>0<k>cP020;Fe]@03
0:f][@2UYJD0YJFU0080W9bL00<0V9RH09BDU02DU9@00`2DU9@508B4Q080S8b<3@24Q8@208b<S003
08R8R024Q8@0Q8B400d0Q8B40P2<S8`608B4Q080S8b<3@24Q8@208b<S00308R8R024Q8@0Q8B400d0
Q8B40P2<S8`508B4Q0<0S8b<3024Q8@01028R8P0S8b<08b<S028R8P?08B4Q080S8b<00<0R8R808B4
Q024Q8@00P24Q8@308b<S0`0Q8B400<0R8R808b<S02<S8`03`24Q8@00`28R8P0S8b<08b<S00508B4
Q0<0S8b<3024Q8@00`28R8P0S8b<08b<S00?08B4Q00308R8R02<S8`0S8b<00D0Q8B41@2DU9@209bL
W0030:FUY@2][Jd0[Jf]0080]KFe00<0_[jn0<K6aP36a/H00`3Ng]h20>o_k`030??cl`3gmoL0moOg
00Sooooo0006ooooo`<0kno_0P3Fe]H00`3Bd]80c/k>0<k>cP020;Fe]@030:f][@2UYJD0YJFU0080
W9bL00<0V9RH09BDU02DU9@00`2DU9@508B4Q080S8b<3@24Q8@208b<S00308R8R024Q8@0Q8B400d0
Q8B40P2<S8`608B4Q080S8b<3@24Q8@208b<S00308R8R024Q8@0Q8B400d0Q8B40P2<S8`508B4Q0<0
S8b<3024Q8@01028R8P0S8b<08b<S028R8P?08B4Q080S8b<00<0R8R808B4Q024Q8@00P24Q8@308b<
S0`0Q8B400<0R8R808b<S02<S8`03`24Q8@00`28R8P0S8b<08b<S00508B4Q0<0S8b<3024Q8@00`28
R8P0S8b<08b<S00?08B4Q00308R8R02<S8`0S8b<00D0Q8B41@2DU9@209bLW0030:FUY@2][Jd0[Jf]
0080]KFe00<0_[jn0<K6aP36a/H00`3Ng]h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3>c/h0a/K60<K6aP020;Fe]@030:f][@2UYJD0YJFU0080U9BD00@0T92@08b<S02<
S8`0Q8B42@1kNg/207=cL`0307MgM`1kNg/0Ng]k00<0Ng]k0P1cLg<00`1gMgL0Ng]k07]kN`0207=c
L`0307MgM`1kNg/0Ng]k00P0Ng]k0P1cLg<00`1gMgL0Ng]k07]kN`0207=cL`P0Ng]k0P1cLg<00`1g
MgL0Ng]k07]kN`0207]kN`0407MgM`1cLg<0Lg=c07MgM`80Ng]k0P1cLg<00`1gMgL0Ng]k07]kN`08
07]kN`80Lg=c00<0MgMg07]kN`1kNg/00P1cLg<807]kN`<0Lg=c101kNg/00`1gMgL0Lg=c07=cL`02
07]kN`0407MgM`1cLg<0Lg=c07MgM`T0Ng]k00<0MgMg07=cL`1cLg<00`1kNg/207=cL`0307MgM`1k
Ng/0Ng]k00D0Ng]k0P1cLg<507]kN`0307MgM`1cLg<0Lg=c0080Ng]k00<0MgMg07=cL`1cLg<02P1k
Ng/00`1gMgL0Lg=c07=cL`0207]kN`0307MgM`1cLg<0Lg=c00P0Ng]k0P1cLg<507]kN`<0Lg=c0P1k
Ng/00`1gMgL0Lg=c07=cL`0:07]kN`0307MgM`1cLg<0Lg=c0080Ng]k00<0MgMg07=cL`1cLg<01@1k
Ng/508B4Q080U9BD00<0WIfM0:FUY@2UYJD00P2e]KD00`2n_[h0a/K60<K6aP030=KFeP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K60080]KFe00<0[Jf]
0:FUY@2UYJD00P2DU9@0102@T900S8b<08b<S024Q8@907]kN`80Lg=c00<0MgMg07]kN`1kNg/00`1k
Ng/207=cL`0307MgM`1kNg/0Ng]k0080Lg=c00<0MgMg07]kN`1kNg/0201kNg/207=cL`0307MgM`1k
Ng/0Ng]k0080Lg=c201kNg/207=cL`0307MgM`1kNg/0Ng]k0080Ng]k00@0MgMg07=cL`1cLg<0MgMg
0P1kNg/207=cL`0307MgM`1kNg/0Ng]k00P0Ng]k0P1cLg<00`1gMgL0Ng]k07]kN`0207=cL`P0Ng]k
0`1cLg<407]kN`0307MgM`1cLg<0Lg=c0080Ng]k00@0MgMg07=cL`1cLg<0MgMg2@1kNg/00`1gMgL0
Lg=c07=cL`0307]kN`80Lg=c00<0MgMg07]kN`1kNg/01@1kNg/207=cL`D0Ng]k00<0MgMg07=cL`1c
Lg<00P1kNg/00`1gMgL0Lg=c07=cL`0:07]kN`0307MgM`1cLg<0Lg=c0080Ng]k00<0MgMg07=cL`1c
Lg<0201kNg/207=cL`D0Ng]k0`1cLg<207]kN`0307MgM`1cLg<0Lg=c00X0Ng]k00<0MgMg07=cL`1c
Lg<00P1kNg/00`1gMgL0Lg=c07=cL`0507]kN`D0Q8B40P2DU9@00`2MWId0YJFU0:FUY@020;Fe]@03
0;jn_P36a/H0a/K600<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0c<c<0<;2`P32`/800P3Bd]800`3>c/h0b/[:0<[:bP020<;2`P040<30`02n_[h0_[jn0;Zj^PT0
]KFe0P2a/K400`2c/k<0]KFe0;Fe]@080;Fe]@80/K6a00<0/k>c0;Fe]@2e]KD0202e]KD20;6a/@03
0;>c/`2e]KD0]KFe0080/K6a202e]KD20;6a/@030;>c/`2e]KD0]KFe00P0]KFe0P2a/K400`2c/k<0
]KFe0;Fe]@080;Fe]@80/K6a00<0/k>c0;Fe]@2e]KD00P2a/K480;Fe]@<0/K6a2@2e]KD0102c/k<0
/K6a0;6a/@2c/k<90;Fe]@030;>c/`2a/K40/K6a00<0]KFe0P2a/K400`2c/k<0]KFe0;Fe]@050;Fe
]@80/K6a2P2e]KD00`2c/k<0/K6a0;6a/@0:0;Fe]@030;>c/`2a/K40/K6a0080]KFe00<0/k>c0;6a
/@2a/K40202e]KD20;6a/@X0]KFe00<0/k>c0;6a/@2a/K402P2e]KD00`2c/k<0/K6a0;6a/@020;Fe
]@030;>c/`2a/K40/K6a00D0]KFe1@2j^[X20<;2`P030<K6aP3:b/X0b/[:0080e]KF00<0c<c<0<;2
`P32`/800`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0
_Kfm0;fm_@0L0>o_k`80moOg00<0lo?c0>o_k`3_knl08`3_knl0103clo<0moOg0?Ogm`3clo<U0>o_
k`030??cl`3gmoL0moOg02H0kno_00<0lo?c0?Ogm`3gmoL09P3_knl30?OgmbH0kno_0P3gmoL00`3J
f]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<[:bP2m_Kd0_Kfm01`0kno_0P3gmoL00`3clo<0kno_0>o_k`0S0>o_k`040??cl`3gmoL0moOg0??c
lbD0kno_00<0lo?c0?Ogm`3gmoL09P3_knl00`3clo<0moOg0?Ogm`0V0>o_k`<0moOg9P3_knl20?Og
m`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Ogm`0T0?Ogm`80oooo00<0no_k0?Ogm`3g
moL08`3gmoL00`3kno/0oooo0?ooo`0V0?Ogm`030?_kn`3oool0oooo02H0moOg00<0no_k0?ooo`3o
ool09P3gmoL20?ooo`030?_kn`3gmoL0moOg01T0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_k
n`3gmoL0moOg02@0moOg0P3oool00`3kno/0moOg0?Ogm`0S0?Ogm`030?_kn`3oool0oooo02H0moOg
00<0no_k0?ooo`3oool09P3gmoL00`3kno/0oooo0?ooo`0V0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
6@3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3W
inL20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0oOgm0?_kn`3kno/00P2i^KT00`2l_;`0_[jn0;jn
_P030;jn_P80^KVi1@2n_[h20;Vi^@040;jn_P32`/80`/;20<30`0L0_[jn0P2e]KD00`2j^[X0_[jn
0;jn_P030;jn_P80_Kfm1@2n_[h00`2l_;`0^KVi0;Vi^@020;jn_P<0`/;200<0_[jn0;Vi^@2i^KT0
102n_[h00`2l_;`0^KVi0;Vi^@050;jn_P030;bl_02i^KT0^KVi00L0_[jn00<0`<300<;2`P32`/80
0`2i^KT50;jn_P80^KVi0`32`/820;jn_P<0^KVi0`2n_[h20<;2`P80^KVi00<0_;bl0;jn_P2n_[h0
0P2n_[h0102j^[X0]KFe0;Fe]@2j^[X40;jn_P030<30`032`/80`/;20080_[jn00<0_;bl0;Vi^@2i
^KT01@2n_[h00`2l_;`0^KVi0;Vi^@050;jn_P80^KVi0`32`/820;jn_P030;bl_02i^KT0^KVi00D0
_[jn0P2i^KT0102l_;`0_[jn0;jn_P30`<020<;2`PD0_[jn1@2i^KT30<;2`P80_[jn0`2i^KT20;jn
_P80`/;200<0_[jn0;Vi^@2i^KT01@2n_[h00`2j^[X0]KFe0;Fe]@050;jn_P80`/;200@0`<300;jn
_P2n_[h0_;bl0P2i^KT50;jn_PD0^KVi1@2n_[h70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]k
N`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00@0Q8B408b<S02<S8`0R8R81`24Q8@2
07=cL`0307alO024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0030820P01kNg/0
Ng]k0080Q8B40`2<S8`00`24Q8@0Ng]k07]kN`0408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P820
07]kN`1kNg/02P24Q8@307]kN`D0Q8B40P1kNg/308b<S080Q8B40`1kNg/308B4Q080S8b<0P1kNg/0
0`20P800Q8B408B4Q00208B4Q00407alO01cLg<0Lg=c07alO0T0Q8B400<0P82007]kN`1kNg/01@24
Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k0`2<S8`208B4Q0030820P01kNg/0Ng]k00D0Q8B40P1k
Ng/00`20P800Q8B408B4Q00808B4Q0D0Ng]k0`2<S8`208B4Q0<0Ng]k0P24Q8@208b<S00308B4Q01k
Ng/0Ng]k00D0Q8B400<0O7al07=cL`1cLg<02P24Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24
Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/5
08B4Q080Ng]k00@0Q8B408b<S02<S8`0R8R81`24Q8@207=cL`0307alO024Q8@0Q8B400<0Q8B40P1k
Ng/00`20P800Q8B408B4Q00208B4Q0030820P01kNg/0Ng]k0080Q8B40`2<S8`00`24Q8@0Ng]k07]k
N`0408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/02P24Q8@307]kN`D0Q8B40P1k
Ng/308b<S080Q8B40`1kNg/308B4Q080S8b<0P1kNg/00`20P800Q8B408B4Q00208B4Q00407alO01c
Lg<0Lg=c07alO0T0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k
0`2<S8`208B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q0D0Ng]k
0`2<S8`208B4Q0<0Ng]k0P24Q8@208b<S00308B4Q01kNg/0Ng]k00D0Q8B400<0O7al07=cL`1cLg<0
2P24Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>00<0a/K60;fm_@2m_Kd01@3k
no/20820P00409VIV@2a/K40/K6a0;Rh^080_[jn0P2i^KT30;jn_P80`/;20P2m_Kd01030`<00`/;2
0<;2`P30`<040;jn_P030<30`032`/80`/;20080]KFe00<0^[Zj0;jn_P2n_[h00`32`/820;Vi^@03
0;bl_02n_[h0_[jn0080`/;200<0_[jn0;Vi^@2i^KT00P2a/K4308R8R00308B4Q020P800P8200080
/K6a0P2n_[h00`2l_;`0^KVi0;Vi^@020;jn_P040<30`032`/80`/;20<30`080_Kfm1`2n_[h00`30
`<00`/;20<;2`P030;Vi^@80_[jn00<0`<300<;2`P32`/800P2i^KT30;Fe]@80Q8B40`20P8030;6a
/@80`/;20P2i^KT00`2l_;`0_[jn0;jn_P020<;2`P040;jn_P2i^KT0^KVi0;bl_0L0_[jn0P32`/80
0`2n_[h0^KVi0;Vi^@030;jn_P80`/;200<0_[jn0;Vi^@2i^KT00P2a/K4308B4Q080P8200`2e]KD2
0;jn_P030;bl_02i^KT0^KVi0080_[jn00<0`<300<;2`P32`/800P2m_Kd80;jn_P030<30`032`/80
`/;200D0^KVi0`2e]KD208B4Q0<0P8200P2a/K420<;2`P030;jn_P2i^KT0^KVi00<0_[jn0P32`/80
0`2n_[h0^KVi0;Vi^@070;jn_P040<30`032`/80`/;20;jn_P80^KVi0P2n_[h00`30`<00`/;20<;2
`P050;Vi^@<0/K6a0P24Q8@70?_kn`030=cLg02m_Kd0_Kfm00<0d];B0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0
g]kN0>_[j`L0moOg103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3o
ool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?oo
o`030?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24
Q8@30=kNgPL0moOg1@3oool00`3kno/0moOg0?Ogm`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3g
moL20?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgPL0moOg00<0no_k0?ooo`3oool00P3o
ool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h508B4Q080g]kN203g
moL50?ooo`L0moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg
103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool50?Ogm`80oooo
00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg
00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24Q8@30=kNgPL0moOg
1@3oool00`3kno/0moOg0?Ogm`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_k
n`3gmoL0moOg0080g]kN1@24Q8@30=kNgPL0moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg
0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h508B4Q080g]kN203gmoL50?ooo`L0moOg
00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@70?Ogm`03
0=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>o_kbD0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN7`3oool20?Ogm`<0g]kN1@24Q8@30=kNgQh0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h508B4Q0<0g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0
moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
kno_9@3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]hO0?ooo`80moOg0`3Ng]h508B4Q0<0
g]kN7P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]hI0?ooo`030?_kn`3gmoL0moOg00<0
g]kN1@24Q8@20=kNgR40oooo0`3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80
kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg
0P2<S8`0102e]KD0g]kN0=kNgP3_knlX0?ooo`80kno_1P24Q8@20=kNgR40oooo0`3_knl508B4Q0<0
g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0kno_1@24Q8@20=kNgR@0oooo0`3_knl208B4Q0L0
moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0kno_:03oool20>o_k`H0
Q8B40P3Ng]hQ0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3_knl508B4Q0<0g]kN703oool30>o_k`D0
Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;Fe
]@3Ng]h0g]kN0>o_kbP0oooo0P3_knl608B4Q080g]kN8@3oool30>o_k`D0Q8B40`3Ng]hQ0?ooo`80
kno_1@24Q8@30=kNgQ`0oooo0`3_knl508B4Q080g]kN903oool30>o_k`80Q8B41`3gmoL00`3Jf]X0
_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?OgmbH0oooo0P3Ng]h608B4Q080
kno_0P3gmoL00`3kno/0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL0?ooo`03
0?_kn`3gmoL0moOg0080g]kN0`24Q8@207]kN`<0g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01l0oooo0`3_knl207]kN`L0oooo00<0hn?S0<K6aP36
a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm
0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLV0?ooo`80g]kN1P24Q8@20>o_k`80
moOg00<0no_k0?ooo`3oool06P3oool20?Ogm`<0g]kN1@24Q8@30=kNgP80moOg703oool00`3kno/0
moOg0?Ogm`020=kNgP<0Q8B40P1kNg/30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080
g]kN0P3gmoL00`3kno/0oooo0?ooo`0O0?ooo`<0kno_0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd0
1@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWi`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01X0oooo0P3gmoL30>o_k`D0Q8B40`3Ng]h20?Ogmal0
oooo0P3Ng]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0
kno_1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool0703oool30?Ogm`<0g]kN0P24Q8@70?Ogm`03
0=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWi`80moOg8`3oool00`3kno/0
moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01X0oooo0P3gmoL30>o_k`D0
Q8B40`3Ng]h20?Ogmal0oooo0P3Ng]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`03
0?_kn`3gmoL0moOg00<0kno_1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool0703oool30?Ogm`<0
g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80d];B00<0b<S80;fm_@2m_Kd01@3clo<208B4Q0040:n_[`3Jf]X0f][J0>WYj@80
moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00P0
oooo2P20P8080?ooo`80moOg0`3WinL508B4Q0<0g]kN0P3gmoLL0?ooo`030?gmo@3kno/0no_k0080
g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool0503oool00`3kno/0moOg0?Ogm`030>OWi`D0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41@3clo<20?Ogm`03
0=[JfP2m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>
00<0a/K60;fm_@2m_Kd01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0
moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00P0oooo2P0000080?ooo`80
moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80
moOg00<0no_k0?ooo`3oool0503oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?Ogm`03
0?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd0
1@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00P0oooo2P0000080?ooo`80moOg0`3Ng]h508B4Q0<0
g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3o
ool0503oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0
oooo0`3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3_knl208B4Q0040;6a
/@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`03
0?_kn`3oool0oooo00P0oooo2P0000080?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL0?ooo`03
0?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool0503oool00`3kno/0
moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80
Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0
moOg8@3oool00`3kno/0moOg0?Ogm`020>o_k`H0Q8B40P3Fe]H=0?ooo`80000000<0P8200?ooo`3o
ool00P3oool00`20P8000000000000080?ooo`80moOg0`3Ng]h208B4Q0<0Ng]k0`3Ng]h40?Ogm`03
0?_kn`3oool0oooo01L0oooo00<0no_k0?Ogm`3gmoL00P3_knl307]kN`80S8b<0`3Ng]h20>o_k`03
0?Ogm`3oool0oooo01@0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h208B4Q0<0Ng]k0P3Ng]h50?Ogma`0
oooo0`3gmoL30=kNgP80S8b<1`3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN
0=kNgP3[jn/40?Ogmb40oooo00<0no_k0?Ogm`3gmoL00P3_knl608B4Q080e]KF3@3oool200000003
0820P03oool0oooo0080oooo00<0P820000000000000203oool20?Ogm`<0g]kN0P24Q8@307]kN`<0
g]kN103gmoL00`3kno/0oooo0?ooo`0G0?ooo`030?_kn`3gmoL0moOg0080kno_0`1kNg/208b<S0<0
g]kN0P3_knl00`3gmoL0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN0P24Q8@307]kN`80
g]kN1@3gmoLL0?ooo`<0moOg0`3Ng]h208b<S0L0moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B4
00@0/K6a0=kNgP3Ng]h0inOW0P3_knlN0?ooo`030?_kn`3gmoL0moOg00D0oooo0P3Ng]h608B4Q080
g]kN0P3gmoL00`3kno/0oooo0?ooo`080?ooo`80000000<0P8200?ooo`3oool00P3oool00`20P800
0000000000030?Ogm`D0oooo0P3_knl30=kNgPD0Q8B40`3Ng]h20?Ogma80oooo0P3gmoL00`3kno/0
oooo0?ooo`030?ooo`D0moOg0P3_knl508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0=0?ooo`80
moOg00<0no_k0?ooo`3oool00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`03
0?_kn`3oool0oooo00l0oooo00@0no_k0?Ogm`3gmoL0no_k103oool00`3kno/0moOg0?Ogm`020?oo
o`<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3N
g]h0inOW0P3_knlN0?ooo`030?_kn`3gmoL0moOg00D0oooo0P3Ng]h608B4Q080g]kN0P3gmoL00`3k
no/0oooo0?ooo`080?ooo`80000000<0P8200?ooo`3oool00P3oool00`20P8000000000000030?Og
m`D0oooo0P3_knl30=kNgPD0Q8B40`3Ng]h20?Ogma80oooo0P3gmoL00`3kno/0oooo0?ooo`030?oo
o`D0moOg0P3_knl508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0=0?ooo`80moOg00<0no_k0?oo
o`3oool00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo
00l0oooo00@0no_k0?Ogm`3gmoL0no_k103oool00`3kno/0moOg0?Ogm`020?ooo`<0moOg0`3Ng]h2
08B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<2
0?_kn`d0oooo0P3kno/00`3moOd0oooo0?ooo`0:0?ooo`030?gmo@3kno/0no_k0080oooo00<0oOgm
0?_kn`3kno/00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`040?gmo@3kno/0
no_k0?gmo@80oooo0P0000000`10@400P8200820P0020820P0030410@0000000000000<0no_k1@3o
ool20??cl`<0g]kN1@24Q8@30=[JfP80moOg1@3kno/=0?ooo`80no_k00<0oOgm0?ooo`3oool00`3o
ool20?_kn`030?Ogm`3clo<0lo?c0080inOW1@24Q8@30=kNgP80moOg00<0nOWi0?_kn`3kno/03@3o
ool20?_kn`030?gmo@3oool0oooo0080oooo00<0nOWi0??cl`3clo<00`3Ng]h508B4Q080f][J0P3g
moL00`3inOT0no_k0?_kn`030?_kn``0oooo00@0oOgm0?_kn`3kno/0oOgm103oool00`3moOd0no_k
0?_kn`020?ooo`<0lo?c0`3Ng]h208B4Q0L0no_k00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0
/K6a0=kNgP3Ng]h0jn_[103gmoL=0?ooo`80moOg00<0no_k0?ooo`3oool03`3oool00`3kno/0moOg
0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo0080oooo00@0no_k0?Ogm`3gmoL0
no_k0P3oool:000000P0oooo0P3gmoL30=kNgPD0Q8B40`3Fe]H70?OgmaL0oooo00<0moOg0>o_k`3_
knl00P3Ng]h508B4Q0<0g]kN1@3gmoLD0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=KFePP0
moOg6@3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a
/@3Ng]h0g]kN0>_[j`@0moOg3@3oool20?Ogm`030?_kn`3oool0oooo00l0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`040?_kn`3gmoL0moOg0?_k
n`80oooo2P0000080?ooo`80moOg0`3Ng]h508B4Q0<0e]KF1`3gmoLG0?ooo`030?Ogm`3_knl0kno_
0080g]kN1@24Q8@30=kNgPD0moOg503oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Fe]H80?Og
maT0oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_
knl00P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg1`3oool0103kno/0moOg0?Ogm`3kno/7
0?ooo`X0000000<0P8200?ooo`3oool00P3gmoL00`3clo<0kno_0>o_k`020=kNgPH0Q8B40P3Ng]h5
0?Ogm`D0oooo00<0no_k0?Ogm`3gmoL01@3oool50?Ogm`D0oooo00<0no_k0?Ogm`3gmoL01@3_knl5
08B4Q0<0g]kN0P3_knl=0?ooo`D0moOg1@3oool80?Ogm`80g]kN1@24Q8@30=kNgPD0oooo0P3gmoL0
0`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00<0moOg1@3oool20?Ogm`030??cl`3_knl0
kno_00<0kno_1@24Q8@20=kNgP80kno_00<0moOg0?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`02
0?Ogm`040?_kn`3oool0oooo0?_kn`L0moOg0P3oool30?Ogm`<0kno_0P24Q8@20>o_k`030??cl`3g
moL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080Q8B400@0/K6a
0=kNgP3Ng]h0inOW0P3_knl20?Ogm`L0oooo00@0no_k0?Ogm`3gmoL0no_k1`3oool:000000030820
P03oool0oooo0080moOg00<0lo?c0>o_k`3_knl00P3Ng]h608B4Q080g]kN1@3gmoL50?ooo`030?_k
n`3gmoL0moOg00D0oooo1@3gmoL50?ooo`030?_kn`3gmoL0moOg00D0kno_1@24Q8@30=kNgP80kno_
3@3oool50?Ogm`D0oooo203gmoL20=kNgPD0Q8B40`3Ng]h50?ooo`80moOg00<0no_k0?ooo`3oool0
0P3oool00`3kno/0moOg0?Ogm`030?Ogm`D0oooo0P3gmoL00`3clo<0kno_0>o_k`030>o_k`D0Q8B4
0P3Ng]h20>o_k`030?Ogm`3oool0oooo00X0oooo00<0no_k0?Ogm`3gmoL00P3gmoL0103kno/0oooo
0?ooo`3kno/70?Ogm`80oooo0`3gmoL30>o_k`80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`03
0=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B
00<0b/[:0<;2`P32`/800P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0
moOg0`3kno/20?ooo`D0no_k00<0oOgm0?ooo`3oool00P3oool00`3moOd0no_k0?_kn`0200000003
03hn?P1lO7`0O7al00<0O7al0P0000000`1nOWh0no_k0?_kn`020?Ogm`030?Gem@3clo<0lo?c0080
g]kN1P24Q8@20=kNgP80lo?c00<0mOGe0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`050?ooo`80
moOg00<0nOWi0?_kn`3kno/00`3kno/20?ooo`030?gmo@3kno/0no_k0080moOg0`3WinL508B4Q0<0
g]kN0P3_knl50?ooo`80no_k00@0oOgm0?ooo`3oool0oOgm0P3kno/20?Ogm`030?Win@3kno/0no_k
0080no_k00<0oOgm0?ooo`3oool01@3kno/00`3gmoL0lo?c0??cl`020=kNgP<0Q8B40P20P8030=kN
gPD0no_k0P3gmoL00`3kno/0oooo0?ooo`020?_kn`040?Win@3gmoL0moOg0?Win@@0no_k00<0oOgm
0?ooo`3oool00P3kno/00`3inOT0moOg0?Ogm`030>OWi`D0Q8B40P3Ng]h20>o_k`030?Ogm`3oool0
oooo00<0oooo0P3kno/00`3moOd0oooo0?ooo`020?_kn`030?Win@3gmoL0moOg00l0no_k0`3clo<3
0>OWi`80P8200P3clo<00`3emOD0moOg0?Ogm`020??cl`030=_Kf`32`/80`/;200<0c/k>0P3WinL0
0`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4
Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3gmoL20?ooo`80moOg00<0no_k0?ooo`3oool01@3oool0
0`3kno/0moOg0?Ogm`020000000307alO03gmoL0moOg00<0moOg0P0000000`1lO7`0moOg0?Ogm`05
0?Ogm`80g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`05
0?ooo`80moOg00<0no_k0?ooo`3oool00`3gmoL70?ooo`<0g]kN1@24Q8@30=kNgP80kno_1@3oool2
0?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?oo
o`050?ooo`030?Ogm`3_knl0kno_0080g]kN0`24Q8@207]kN`<0g]kN1`3gmoL00`3kno/0oooo0?oo
o`050?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool01@3oool30=kNgPD0Q8B40P3N
g]h20>o_k`030?Ogm`3oool0oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`80oooo00@0
no_k0?Ogm`3gmoL0no_k1`3oool20?Ogm`<0kno_0`3Ng]h207]kN`L0moOg00<0gmoO0<K6aP36a/H0
0`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6
aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_0P3oool50?Ogm`80oooo0P3gmoL00`3kno/0oooo
0?ooo`050?ooo`030?_kn`3gmoL0moOg0080000000<0O7al0?Ogm`3gmoL00`3gmoL20000000307al
O03gmoL0moOg00D0moOg0P3Ng]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`050?ooo`030?_k
n`3gmoL0moOg00D0oooo0P3gmoL00`3kno/0oooo0?ooo`030?Ogm`L0oooo0`3Ng]h508B4Q0<0g]kN
0P3_knl50?ooo`80moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`020?Ogm`03
0?_kn`3oool0oooo00D0oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q080Ng]k0`3Ng]h70?Ogm`03
0?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`050?ooo`<0
g]kN1@24Q8@20=kNgP80kno_00<0moOg0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo00D0
moOg0P3oool0103kno/0moOg0?Ogm`3kno/70?ooo`80moOg0`3_knl30=kNgP80Ng]k1`3gmoL00`3O
gml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP03
0<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3WinL20>o_k`80oooo3`0000000`20
P800oooo0?ooo`02000000030820P03oool0oooo00<0oooo0P0000000`20P800oooo0?ooo`050?Og
m`80g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL0103kno/0oooo0?ooo`20P80?
00000080moOg00<0no_k0?ooo`3oool00P3_knl30=kNgPD0Q8B40`3Ng]h40?Ogm`030?_kn`3oool0
oooo0080oooo00<0P8200000000000003@0000030?ooo`D0moOg0P3Ng]h508B4Q0<0g]kN0P3_knl0
0`3gmoL0oooo0?ooo`020?ooo`030820P0000000000000d000000P3oool00`3gmoL0kno_0>o_k`03
0=kNgPD0Q8B40P3Ng]h50?Ogm`D0oooo00<0no_k0?Ogm`3gmoL03`0000000`1lO7`0moOg0?Ogm`02
0?ooo`<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kN
gP3Ng]h0inOW0P3_knl20?ooo`l0000000<0P8200?ooo`3oool00P0000000`20P800oooo0?ooo`03
0?ooo`80000000<0P8200?ooo`3oool01@3gmoL20=kNgPH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0
moOg0080moOg00@0no_k0?ooo`3oool0P8203`0000020?Ogm`030?_kn`3oool0oooo0080kno_0`3N
g]h508B4Q0<0g]kN103gmoL00`3kno/0oooo0?ooo`020?ooo`030820P0000000000000d000000`3o
ool50?Ogm`80g]kN1@24Q8@30=kNgP80kno_00<0moOg0?ooo`3oool00P3oool00`20P80000000000
000=00000080oooo00<0moOg0>o_k`3_knl00`3Ng]h508B4Q080g]kN1@3gmoL50?ooo`030?_kn`3g
moL0moOg00l0000000<0O7al0?Ogm`3gmoL00P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K6
0;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN0>OWi`80kno_0P3oool?000000030820P03o
ool0oooo0080000000<0P8200?ooo`3oool00`3oool2000000030820P03oool0oooo00D0moOg0P3N
g]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`040?_kn`3oool0oooo0820P0l00000
0P3gmoL00`3kno/0oooo0?ooo`020>o_k`<0g]kN1@24Q8@30=kNgP@0moOg00<0no_k0?ooo`3oool0
0P3oool00`20P80000000000000=000000<0oooo1@3gmoL20=kNgPD0Q8B40`3Ng]h20>o_k`030?Og
m`3oool0oooo0080oooo00<0P8200000000000003@0000020?ooo`030?Ogm`3_knl0kno_00<0g]kN
1@24Q8@20=kNgPD0moOg1@3oool00`3kno/0moOg0?Ogm`0?0000000307alO03gmoL0moOg0080oooo
0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102][Jd0e]KF0=KF
eP3WinL40?Ogm`l0000000<0O7al0?Ogm`3gmoL02P0000000`1lO7`0moOg0?Ogm`020?Ogm`030??c
l`3_knl0kno_0080g]kN1P24Q8@20=KFeP80kno_00<0moOg0?ooo`3oool01@3gmoL00`1lO7`00000
0000000=00000080oooo00<0no_k0?Ogm`3gmoL00P3gmoL30=KFePD0Q8B40`3Ng]h90?Ogm`0307al
O0000000000000d000000`3gmoL20?Ogo`030??cm`3_knl0kno_0080g]kN1@24Q8@30=kNgP80kno_
00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000=000000D0moOg0`3Fe]H508B4Q080g]kN
2P3gmoL00`3kno/0oooo0?ooo`0?000000030820P03oool0oooo0080moOg0`3_knl30=KFeP80Q8B4
1`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL40?Ogm`l00000
00<0O7al0?Ogm`3gmoL02P0000000`1lO7`0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_0080g]kN
1P24Q8@20=KFeP80kno_00<0moOg0?ooo`3oool01@3gmoL00`1lO7`000000000000=00000080oooo
00<0no_k0?Ogm`3gmoL00P3gmoL30=KFePD0Q8B40`3Ng]h90?Ogm`0307alO0000000000000d00000
0`3gmoL20?Ogo`030??cm`3_knl0kno_0080g]kN1@24Q8@30=kNgP80kno_00<0lo?c0?Ogm`3gmoL0
0P3gmoL00`1lO7`000000000000=000000D0moOg0`3Fe]H508B4Q080g]kN2P3gmoL00`3kno/0oooo
0?ooo`0?000000030820P03oool0oooo0080moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32
`/80`/;200D0lo?c0P24Q8@0102][Jd0e]KF0=KFeP3WinL40?Ogm`l0000000<0OWin0?_kn`3kno/0
2P1lO7`00`2l_;`0no_k0?_kn`020?Ogm`030??cl`3_knl0kno_0080g]kN1P24Q8@20=[JfP80lo?c
00<0moOg0?_kn`3kno/01@3gmoL00`1lO7`000000000000=00000080no_k00<0nOWi0?Ogm`3gmoL0
0P3gmoL30=[JfPD0Q8B40`3Ng]h20??cl`D0moOg0P3kno/00`1nOWh000000000000=000000<0moOg
0P3gmo/00`3cloD0kno_0>o_k`020=kNgPD0Q8B40`3Jf]X20??cl`030?Gem@3gmoL0moOg0080no_k
00<0OWin0000000000003@0000050?Ogm`<0f][J1@24Q8@20=kNgP80lo?c00<0mOGe0?Ogm`3gmoL0
0`3gmoL50?_kn`l0000000<0OWin0?_kn`3kno/00P3gmoL30??cl`<0f][J0P24Q8@50??cl`80moOg
00<0f][J0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW103gmoL?000000030820
P03oool0oooo00X0moOg00<0no_k0?ooo`3oool00P3gmoL00`3clo<0kno_0>o_k`020=kNgPH0Q8B4
0P3Ng]h:0?Ogm`0307alO0000000000000d000001`3gmoL30=kNgPD0Q8B40`3Ng]h20>o_k`D0moOg
0P3oool00`20P80000000000000=000000D0moOg00<0lo?c0>o_k`3_knl00P3Ng]h508B4Q0<0e]KF
1@3gmoL20?ooo`030820P0000000000000d000001@3gmoL30=kNgPD0Q8B40P3Ng]h20>o_k`030??c
l`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`0?0000000307alO03gmoL0moOg00D0moOg
0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102][Jd0e]KF0=KF
eP3WinL40?Ogm`l0000000<0P8200?ooo`3oool02P3gmoL00`3kno/0oooo0?ooo`020?Ogm`030??c
l`3_knl0kno_0080g]kN1P24Q8@20=kNgPX0moOg00<0O7al0000000000003@0000070?Ogm`<0g]kN
1@24Q8@30=kNgP80kno_1@3gmoL20?ooo`030820P0000000000000d000001@3gmoL00`3clo<0kno_
0>o_k`020=kNgPD0Q8B40`3Fe]H50?Ogm`80oooo00<0P8200000000000003@0000050?Ogm`<0g]kN
1@24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg00l00000
00<0O7al0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>
0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3o
ool00`3kno/0moOg0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_0P3gmoL?0000000307al
O03gmoL0moOg0080moOg00<0no_k0?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0moOg00D0moOg
0P3Ng]h307]kN`030820P024Q8@0Q8B40080e]KF0P3_knl00`3gmoL0oooo0?ooo`050?Ogm`0307al
O0000000000000d000001@3gmoL20>o_k`<0e]KF0P24Q8@307]kN`<0g]kN2@3gmoL00`1lO7`00000
0000000=000000D0moOg00<0lo?c0>o_k`3_knl00P3Ng]h307]kN`80Q8B40`3Ng]h20>o_k`030??c
l`3gmoL0moOg0080moOg00<0O7al0000000000003@0000020?ooo`030?Ogm`3_knl0kno_00<0e]KF
0P24Q8@307]kN`80g]kN3@3gmoL?0000000307alO03gmoL0moOg0080moOg0`3_knl30=KFeP80Q8B4
1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kN
gP3WinL20>o_k`80moOg3`0000000`1lO7`0moOg0?Ogm`020?Ogm`030?_kn`3oool0oooo00<0moOg
0P3oool00`3kno/0moOg0?Ogm`050?Ogm`80g]kN0`1kNg/00`20P800Q8B408B4Q0020=KFeP80kno_
00<0moOg0?ooo`3oool01@3gmoL00`1lO7`000000000000=000000D0moOg0P3_knl30=KFeP80Q8B4
0`1kNg/30=kNgPT0moOg00<0O7al0000000000003@0000050?Ogm`030??cl`3_knl0kno_0080g]kN
0`1kNg/208B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`0307alO0000000000000d00000
0P3oool00`3gmoL0kno_0>o_k`030=KFeP80Q8B40`1kNg/20=kNgPd0moOg3`0000000`1lO7`0moOg
0?Ogm`020?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@020?ooo`030?gmo@3k
no/0no_k0080Q8B400@0[jn_0=[JfP3Jf]X0iNGU0P3_knl20?_kn`l0000000<0O7al0?Ogm`3gmoL0
0P3gmoL00`3inOT0no_k0?_kn`050?_kn`030?Win@3gmoL0moOg0080moOg00<0mOGe0??cl`3clo<0
0P3Ng]h608B4Q080f][J0P3_knl00`3emOD0no_k0?_kn`050?Ogm`0307alO0000000000000d00000
1@3gmoL20??cl`<0f][J0P24Q8@30820P0<0f][J2@3gmoL00`1lO7`000000000000=000000D0moOg
00<0mOGe0??cl`3clo<00P3Ng]h30820P080Q8B40`3Jf]X20>o_k`030??cl`3gmoL0moOg0080moOg
00<0O7al0000000000003@0000020?_kn`030?Ogm`3clo<0lo?c00<0f][J0P24Q8@30820P080f][J
3@3gmoL?0000000307inOP3kno/0no_k0080no_k0`3clo<30=KFeP80Q8B41`3kno/00`3Ogml0`/;2
0<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m
_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80oooo3`0000000`1lO7`0moOg
0?Ogm`050?Ogm`<0oooo1`3gmoL00`3clo<0kno_0>o_k`020=kNgP<0S8b<00<0R8R808B4Q024Q8@0
0P3Ng]h20>o_k`030??cl`3gmoL0moOg00D0moOg00<0O7al0000000000003@0000070?Ogm`<0g]kN
1@24Q8@30=KFePT0moOg00<0O7al0000000000003@0000080?Ogm`80g]kN1@24Q8@30=KFeP80kno_
00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000=000000D0moOg0`3Ng]h508B4Q080e]KF
3@3gmoL?000000030820P03oool0oooo0080oooo0`3gmoL30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m
_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80oooo3`0000000`1lO7`0moOg
0?Ogm`050?Ogm`<0oooo1`3gmoL00`3clo<0kno_0>o_k`020=kNgP<0S8b<00<0R8R808B4Q024Q8@0
0P3Ng]h20>o_k`030??cl`3gmoL0moOg00D0moOg00<0O7al0000000000003@0000070?Ogm`<0g]kN
1@24Q8@30=KFePT0moOg00<0O7al0000000000003@0000080?Ogm`80g]kN1@24Q8@30=KFeP80kno_
00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000=000000D0moOg0`3Ng]h508B4Q080e]KF
3@3gmoL?000000030820P03oool0oooo0080oooo0`3gmoL30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m
_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<40>o_k`l0000000<0O7al0?Ogm`3gmoL0
3`3gmoL00`3clo<0kno_0>o_k`020=KFeP<0Ng]k00<0P82008B4Q024Q8@00P3Fe]H50>o_k`D0moOg
00<0O7al0000000000003@0000020?Ogm`030??cl`3_knl0kno_0080kno_0`3Fe]H508B4Q0D0g]kN
1@3gmoL20>o_k`0307QhN0000000000000d000001@3gmoL00`3clo<0kno_0>o_k`020=KFePD0Q8B4
0`3Fe]H20>o_k`030??cl`3gmoL0moOg0080kno_00<0N7Qh0000000000003@0000050>o_k`<0e]KF
1@24Q8@40=kNgP030>_[j`3gmoL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`0?0000000307al
O03gmoL0moOg00D0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0
[Jf]0=KFeP3Fe]H0hn?S103_knl?0000000307alO03gmoL0moOg00l0moOg00<0lo?c0>o_k`3_knl0
0P3Fe]H307]kN`030820P024Q8@0Q8B40080e]KF1@3_knl50?Ogm`0307alO0000000000000d00000
0P3gmoL00`3clo<0kno_0>o_k`020>o_k`<0e]KF1@24Q8@50=kNgPD0moOg0P3_knl00`1hN7P00000
0000000=000000D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0e]KF0P3_knl00`3clo<0moOg
0?Ogm`020>o_k`0307QhN0000000000000d000001@3_knl30=KFePD0Q8B4103Ng]h00`3[jn/0moOg
0?Ogm`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL03`0000000`1lO7`0moOg0?Ogm`050>o_k`<0e]KF
0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<208B4Q0040:n_[`3Jf]X0f][J0>GUi@80kno_
0P3clo<?07alO0030;bl_03kno/0no_k00D0moOg0`3clo<70?Ogm`030??cl`3_knl0kno_0080e]KF
0`20P8000`22PX80Q8B408B4Q0020=KFeP80kno_00<0lO7a0??cl`3clo<01@3gmoL00`2l_;`0P820
0820P00507alO080N7Qh00<0NWYj07alO01lO7`00`1lO7`20?Ogm`030?Gem@3clo<0lo?c0080kno_
0`3Fe]H508B4Q0<0g]kN0P3WinL70?Ogm`030;Zj^P1lO7`0O7al00<0O7al0P1hN7P00`1jNWX0O7al
07alO00507alO0<0moOg0P3clo<00`3alO40kno_0>o_k`020=KFePD0Q8B40`3Jf]X20>o_k`030??c
l`3gmoL0moOg0080moOg00<0^[Zj07alO01lO7`00P1lO7`0101jNWX0N7Qh07QhN01jNWX707alO080
lo?c00<0lO7a0>o_k`3_knl00`3Fe]H508B4Q080g]kN0P3WinL00`3_knl0moOg0?Ogm`080?Ogm`80
O7al00<0NWYj07QhN01hN7P02P1lO7`00`2j^[X0moOg0?Ogm`020??cl`<0kno_0`3Fe]H208B4Q0L0
lo?c00<0fm_K0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knlA0?Ogm`03
0?_kn`3oool0oooo00D0moOg0`3_knl70?Ogm`030??cl`3_knl0kno_0080e]KF1P24Q8@20=KFeP80
kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`80kno_00<0lo?c0?Ogm`3g
moL0203gmoL20>o_k`<0e]KF1@24Q8@30=kNgP80kno_1@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0
moOg0P3_knl00`3clo<0moOg0?Ogm`080?Ogm`D0kno_0P3Fe]H508B4Q0<0g]kN0P3_knl00`3clo<0
moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg0080moOg00@0lo?c0>o_k`3_knl0lo?c2@3gmoL00`3c
lo<0kno_0>o_k`030=KFePD0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg00<0moOg0P3oool00`3k
no/0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_00l0moOg0`3_knl30=KFeP80Q8B41`3_knl00`3F
e]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_ka40moOg00<0no_k0?oo
o`3oool01@3gmoL30>o_k`L0moOg00<0lo?c0>o_k`3_knl00P3Fe]H608B4Q080e]KF0P3_knl00`3c
lo<0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0P3_knl00`3clo<0moOg0?Ogm`080?Og
m`80kno_0`3Fe]H508B4Q0<0g]kN0P3_knl50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20>o_
k`030??cl`3gmoL0moOg00P0moOg1@3_knl20=KFePD0Q8B40`3Ng]h20>o_k`030??cl`3gmoL0moOg
0080oooo00<0no_k0?Ogm`3gmoL00P3gmoL0103clo<0kno_0>o_k`3clo<90?Ogm`030??cl`3_knl0
kno_00<0e]KF1@24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0
moOg0080moOg00<0lo?c0>o_k`3_knl03`3gmoL30>o_k`<0e]KF0P24Q8@70>o_k`030=KFeP2m_Kd0
_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c<c<0<;2
`P32`/801@3clo<208R8R0040;6a/@3Jf]X0f][J0>GUi@80kno_0P3gmoL30??cl`80moOg0P3clo<0
103emOD0moOg0?Ogm`3emOD40??cl`030?Ogm`3kno/0no_k00X0lo?c00<0mOGe0?Ogm`3gmoL00P3g
moL00`3_knl0inOW0>OWi`020=[JfPH0Q8B40P3Fe]H20>OWi`030>o_k`3gmoL0moOg00D0lo?c00<0
moOg0?_kn`3kno/00P3clo<00`3emOD0moOg0?Ogm`050??cl`D0moOg00<0mOGe0??cl`3clo<00P3_
knl30=[JfPD0Q8B40`3Jf]X70??cl`80no_k00@0moOg0??cl`3clo<0mOGe0P3gmoL50??cl`D0moOg
1@3clo<00`3alO40kno_0>o_k`020=KFePD0Q8B40`3Jf]X20>OWi`030>g]k@3clo<0lo?c0080no_k
00<0moOg0??cl`3clo<00P1lO7`0101jNWX0N7Qh07QhN01jNWX207alO0D0moOg0P3clo<00`3alO40
kno_0>o_k`030=[JfPD0Q8B40P3Jf]X80??cl`80no_k00<0moOg0??cl`3clo<00P3gmoL00`3Kfm/0
_[jn0;jn_P020??cl`040=_Kf`32`/80`/;20=gMg@80moOg0P3clo<00`3emOD0moOg0?Ogm`020?Og
m`<0kno_0`3Jf]X208B4Q0L0lo?c00<0f=SH0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0/K6a0=KFeP3F
e]H0hn?S0P3_knl20?Ogm`<0kno_0P3gmoL20>o_k`040??cl`3gmoL0moOg0??cl`@0kno_00<0lo?c
0?Ogm`3gmoL01@3_knl30?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`3[jn/0g]kN0=kNgP02
0=kNgPH0Q8B40P3Fe]H20=kNgP030>_[j`3gmoL0moOg00D0kno_00<0lo?c0?Ogm`3gmoL00P3_knl0
0`3clo<0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_00D0moOg00<0lo?c0>o_k`3_knl00P3_knl3
0=kNgPD0Q8B40`3Fe]H20?Ogm`D0kno_0P3gmoL0103clo<0kno_0>o_k`3clo<40?Ogm`030??cl`3_
knl0kno_00D0moOg0`3_knl20?Ogm`030??cl`3_knl0kno_0080e]KF1@24Q8@30=KFeP80g]kN00<0
inOW0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`08000000D0moOg1@3_knl30=kNgPD0Q8B40P3F
e]H20?Ogm`030??cl`3_knl0kno_00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030<;2`P2<
S8`0S8b<0080kno_00@0_[jn08b<S02<S8`0`/;20P3gmoL20>o_k`030??cl`3gmoL0moOg0080moOg
0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102a/K40e]KF0=KF
eP3Shn<20>o_k`80moOg0`3_knl20?Ogm`80kno_00@0lo?c0?Ogm`3gmoL0lo?c103_knl00`3clo<0
moOg0?Ogm`050>o_k`<0moOg0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030>_[j`3Ng]h0g]kN0080
g]kN1P24Q8@20=KFeP80g]kN00<0jn_[0?Ogm`3gmoL01@3_knl00`3clo<0moOg0?Ogm`020>o_k`03
0??cl`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl01@3gmoL00`3clo<0kno_0>o_k`020>o_k`<0
g]kN1@24Q8@30=KFeP80moOg1@3_knl20?Ogm`040??cl`3_knl0kno_0??cl`@0moOg00<0lo?c0>o_
k`3_knl01@3gmoL30>o_k`80moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0e]KF0P3Ng]h00`3W
inL0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00P000001@3gmoL50>o_k`<0g]kN1@24Q8@20=KF
eP80moOg00<0lo?c0>o_k`3_knl00`3_knl20?Ogm`030??cl`3_knl0kno_0080moOg00<0`/;208b<
S02<S8`00P3_knl0102n_[h0S8b<08b<S032`/820?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL3
0>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF
0=[JfP80g]kN0P3_knl50?Ogm`D0kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`02
0?Ogm`030??cl`3_knl0kno_00<0oooo0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3_knl0
kno_0080e]KF0`1kNg/00`20P800Q8B408B4Q0020=KFeP80g]kN00<0inOW0>o_k`3_knl00P3gmoL0
0`3clo<0kno_0>o_k`030>o_k`80moOg00<0lo?c0>o_k`3_knl00P3oool00`3gmoL0kno_0>o_k`05
0?Ogm`030??cl`3_knl0kno_0080kno_0`3Fe]H508B4Q0<0c/k>0P3Ng]h20?Ogm`030??cl`3_knl0
kno_00D0moOg00<0O7al0000000000001`0000000`1lO7`0moOg0?Ogm`030?Ogm`80kno_00<0inOW
0=kNgP3Ng]h00P3Ng]h308B4Q080Ng]k0`3Fe]H50>o_k`D0moOg0P3_knl0103gmoL0oooo0?ooo`3g
moL20>o_k`D0moOg1@3_knl30=KFePD0Q8B40P3>c/h20=kNgP030>_[j`3gmoL0moOg00<0kno_1@3g
moL20>o_k`030=KFeP2m_Kd0_Kfm0080:BTY00@0Lg=c0;fm_@2m_Kd0f][J103gmoL00`3clo<0kno_
0>o_k`020>o_k`<0moOg0`3Ng]h207]kN`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0
[Jf]0=KFeP3Fe]H0f][J0P3Ng]h20>o_k`D0moOg1@3_knl00`3clo<0moOg0?Ogm`020>o_k`030??c
l`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl00`3oool20>o_k`030??cl`3gmoL0moOg0080moOg
00<0lo?c0>o_k`3_knl00P3Fe]H307]kN`030820P024Q8@0Q8B40080e]KF0P3Ng]h00`3WinL0kno_
0>o_k`020?Ogm`030??cl`3_knl0kno_00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?ooo`030?Og
m`3_knl0kno_00D0moOg00<0lo?c0>o_k`3_knl00P3_knl30=KFePD0Q8B40`3>c/h20=kNgP80moOg
00<0lo?c0>o_k`3_knl01@3gmoL00`1lO7`00000000000070000000307alO03gmoL0moOg00<0moOg
0P3_knl00`3WinL0g]kN0=kNgP020=kNgP<0Q8B40P1kNg/30=KFePD0kno_1@3gmoL20>o_k`040?Og
m`3oool0oooo0?Ogm`80kno_1@3gmoL50>o_k`<0e]KF1@24Q8@20<k>cP80g]kN00<0jn_[0?Ogm`3g
moL00`3_knl50?Ogm`80kno_00<0e]KF0;fm_@2m_Kd00P0Y:BT0101cLg<0_Kfm0;fm_@3Jf]X40?Og
m`030??cl`3_knl0kno_0080kno_0`3gmoL30=kNgP80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgQH0kno_00<0lo?c0?Ogm`3gmoL02P3_knl00`3W
inL0g]kN0=kNgP020=KFePH0Q8B40P3Fe]H20=kNgP030>OWi`3_knl0kno_00X0kno_00<0lo?c0?Og
m`3gmoL02P3_knl00`3WinL0g]kN0=kNgP020>o_k`<0g]kN1@24Q8@30=KFeP`0kno_00<0N7Qh0000
000000001@3_knl20000000307QhN03_knl0kno_00<0moOg1@3_knl20=KFePD0Q8B40`3Fe]H20=kN
gP030>OWi`3_knl0kno_00D0kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80moOg00<0lo?c0>o_
k`3_knl00`3Ng]h508B4Q080e]KF3@3_knl20?Ogm`030??cl`3_knl0kno_00P0kno_0P3gmoL00`3c
lo<0kno_0>o_k`020>o_k`<0g]kN0`3Fe]H208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_
k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80
Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]hF0>o_k`030??cl`3gmoL0moOg00X0kno_00<0inOW0=kN
gP3Ng]h00P3Fe]H608B4Q080e]KF0P3Ng]h00`3WinL0kno_0>o_k`0:0>o_k`030??cl`3gmoL0moOg
00X0kno_00<0inOW0=kNgP3Ng]h00P3_knl30=kNgPD0Q8B40`3Fe]H<0>o_k`0307QhN00000000000
00D0kno_0P0000000`1hN7P0kno_0>o_k`030?Ogm`D0kno_0P3Fe]H508B4Q0<0e]KF0P3Ng]h00`3W
inL0kno_0>o_k`050>o_k`80moOg00<0lo?c0>o_k`3_knl0203_knl20?Ogm`030??cl`3_knl0kno_
00<0g]kN1@24Q8@20=KFePd0kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80moOg00<0lo?c0>o_
k`3_knl00P3_knl30=kNgP<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3c
lo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q004
0:VYZ@3>c/h0c/k>0=KFeP80g]kN5P3_knl00`3clo<0moOg0?Ogm`0:0>o_k`030>OWi`3Ng]h0g]kN
0080e]KF1P24Q8@20=KFeP80g]kN00<0inOW0>o_k`3_knl02P3_knl00`3clo<0moOg0?Ogm`0:0>o_
k`030>OWi`3Ng]h0g]kN0080kno_0`3Ng]h508B4Q0<0e]KF303_knl00`1hN7P00000000000050>o_
k`80000000<0N7Qh0>o_k`3_knl00`3gmoL50>o_k`80e]KF1@24Q8@30=KFeP80g]kN00<0inOW0>o_
k`3_knl01@3_knl20?Ogm`030??cl`3_knl0kno_00P0kno_0P3gmoL00`3clo<0kno_0>o_k`030=kN
gPD0Q8B40P3Fe]H=0>o_k`80moOg00<0lo?c0>o_k`3_knl0203_knl20?Ogm`030??cl`3_knl0kno_
0080kno_0`3Ng]h30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@00`2][Jd0
e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3gmoL00`3[jn/0
g]kN0=kNgP0?0>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/00`20P800Q8B408B4Q0040=KFeP03
0=[JfP3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW103_knl00`3WinL0g]kN0=kNgP020>o_
k`030>OWi`3Ng]h0g]kN00P0kno_0P3Ng]h30=KFeP80Ng]k0`24Q8@50=KFeP80g]kN00<0jn_[0?Og
m`3gmoL00P3Ng]h0103WinL0kno_0>o_k`1hN7P200000080g]kN00<0inOW0>o_k`3_knl00P000000
0`1hN7P0kno_0>o_k`050>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/208B4Q0D0e]KF00<0f][J
0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW
0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP030=KFeP80Ng]k0`24Q8@40=KFeP030=[JfP3Ng]h0
g]kN00<0moOg0P3Ng]h00`3WinL0kno_0>o_k`020>o_k`030>OWi`3Ng]h0g]kN0080kno_00@0inOW
0=kNgP3Ng]h0inOW2@3_knl30=kNgP<0e]KF0P1kNg/50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP05
0>o_k`80Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0kno_0P3Ng]h50>o_k`030>OWi`3Ng]h0
g]kN0080moOg00<0jn_[0=kNgP3Ng]h03`3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k00<0P820
08B4Q024Q8@0103Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`@0kno_00<0
inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP080>o_k`80g]kN0`3Fe]H207]kN`<0Q8B41@3F
e]H20=kNgP030>_[j`3gmoL0moOg0080g]kN00@0inOW0>o_k`3_knl0N7Qh0P0000020=kNgP030>OW
i`3_knl0kno_0080000000<0N7Qh0>o_k`3_knl01@3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k
0P24Q8@50=KFeP030=[JfP3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3WinL0g]kN
0=kNgP020>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00`3Fe]H207]kN`<0Q8B4
103Fe]H00`3Jf]X0g]kN0=kNgP030?Ogm`80g]kN00<0inOW0>o_k`3_knl00P3_knl00`3WinL0g]kN
0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`T0kno_0`3Ng]h30=KFeP80Ng]k1@3_knl20?Ogm`03
0=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3gmoL00`3[jn/0
g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0inOW0>o_k`3_
knl01@3Ng]h20<k>cPH0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0
g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3>c/h508B4Q0<0e]KF2@3Ng]h0103WinL0
kno_0>o_k`1hN7P90000000306m_K`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP020<k>
cP<0Q8B40P2<S8`30<k>cPX0g]kN0P3_knl0103Shn<0e]KF0=KFeP3Jf]X20=kNgP80kno_00<0inOW
0=kNgP3Ng]h01@3Ng]h30<k>cPD0Q8B40P3Fe]H:0=kNgP030>OWi`3_knl0kno_0080g]kN00<0f][J
0=KFeP3Fe]H00P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h2
08b<S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h2
0?Ogm`030>_[j`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0kno_0P3Ng]h0
0`3WinL0kno_0>o_k`050=kNgP80c/k>1P24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl01@3Ng]h2
0>o_k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl00P3Ng]h30<k>cPD0Q8B40`3Fe]H9
0=kNgP040>OWi`3_knl0kno_07QhN0T0000000<0Kfm_0=kNgP3Ng]h00`3Ng]h20>o_k`030>OWi`3N
g]h0g]kN0080c/k>0`24Q8@208b<S0<0c/k>2P3Ng]h20>o_k`040>?Sh`3Fe]H0e]KF0=[JfP80g]kN
0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20=KFePX0g]kN00<0inOW0>o_k`3_knl0
0P3Ng]h00`3Jf]X0e]KF0=KFeP020>o_k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl0
1@3Ng]h30<k>cP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3WinL20=KFeP030<c<c032`/80`/;200D0no_k0P24Q8@0102[Zj/0d];B0=;B
dP3Hf=P20=kNgP80f][J1@3Ng]h20>_[j`040>GUi@3Ng]h0g]kN0=cLg080f][J0P3Shn<00`3QhN40
g]kN0=kNgP020=[JfP030=cLg03Ng]h0g]kN00<0inOW0P3Ng]h00`3Shn<0inOW0>OWi`050=[JfP80
c/k>1P24Q8@20<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h00`3Shn<0inOW0>OWi`050=kNgP80
hn?S00<0hN7Q0=kNgP3Ng]h00`3Jf]X20=kNgP030>?Sh`3WinL0inOW0080f][J0`3>c/h508B4Q0<0
d];B0P3Ng]h20=[JfP030=cLg03Ng]h0g]kN0080g]kN00@0hn?S0>OWi`3WinL0Zj^[0P1_Kfl506][
J`80Kfm_00<0YJFU0=[JfP3Jf]X00`3Ng]h20>OWi`030>7Qh@3Jf]X0f][J0080c/k>0`24Q8@208R8
R0<0c/k>0P3Ng]h00`3Lg=`0f][J0=[JfP050=kNgP80inOW00<0hN7Q0=[JfP3Jf]X00`3Jf]X20>?S
h`030>7Qh@3Ng]h0g]kN00D0f][J0`3>c/h508B4Q080d];B0P3Ng]h00`3Lg=`0f][J0=[JfP050=kN
gP030>?Sh`3WinL0inOW0080g]kN00<0f][J0=KFeP3Fe]H00P3Shn<0103QhN40g]kN0=kNgP3Lg=`2
0=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h30=[JfP<0c/k>0P28R8P70?_kn`030=oOg`32`/80
`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm
_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF0=[JfP80g]kN0P3Fe]H:0=kNgP030=[JfP3Fe]H0
e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3>c/h6
08B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0=0=kNgP80e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H5
0=kNgP80e]KF0`3>c/h508B4Q0<0c/k>0P3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3Fe]H2
0=kNgP030=[JfP3Fe]H0e]KF00D0g]kN00<0f][J0=KFeP3Fe]H00P3>c/h508B4Q0<0c/k>0P3Ng]h0
0`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h01@3Fe]H3
0<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0
103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3oool00`3Ng]h0_Kfm0;fm
_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0
_Kfm00D0oooo0P24Q8@0102][Jd0e]KF0=KFeP3Jf]X20=kNgP80e]KF2P3Ng]h00`3Jf]X0e]KF0=KF
eP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80c/k>1P24
Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H03@3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00<0e]KF1@3N
g]h20=KFeP<0c/k>1@24Q8@30<k>cP80g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3N
g]h00`3Jf]X0e]KF0=KFeP050=kNgP030=[JfP3Fe]H0e]KF0080c/k>1@24Q8@30<k>cP80g]kN00<0
f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00D0e]KF0`3>
c/h508B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00@0
f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd0
0`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm
_@050?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H0
0P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3Fe]H20<k>cPH0Q8B4
0P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00d0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP030=KFePD0g]kN
0P3Fe]H30<k>cPD0Q8B40`3>c/h20=kNgP80e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN
00<0f][J0=KFeP3Fe]H01@3Ng]h00`3Jf]X0e]KF0=KFeP020<k>cPD0Q8B40`3>c/h20=kNgP030=[J
fP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP050=KFeP<0c/k>
1@24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP040=[J
fP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd0
1@3gmoL207=cL`040:VYZ@3Ng]h0g]kN0>_[jah0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`03
0?Ogm`3_knl0kno_0080g]kN0`24Q8@00`20P800Ng]k07]kN`020=kNgQl0moOg0P3_knl30=kNgP80
Q8B40`1kNg/30=KFeQh0moOg00<0lo?c0>o_k`3_knl00P3Ng]h308B4Q080Lg=c0`3Ng]hI0?Ogm`03
0??cl`3_knl0kno_00<0g]kN0P24Q8@307]kN`80e]KF7`3gmoL20?ooo`<0kno_0`3Ng]h208B4Q0L0
moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Lg=c00@0ZJVY0=kNgP3Ng]h0jn_[7P3gmoL20?ooo`03
0?_kn`3gmoL0moOg0080oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q0030820P01kNg/0Ng]k0080
g]kN7`3gmoL20>o_k`<0g]kN0P24Q8@307]kN`<0e]KF7P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0
Q8B40P1cLg<30=kNgQT0moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Fe]HO0?Ogm`80
oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl0
0P24Q8@0102j^[X0kno_0>o_k`3gmoLZ0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0
Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?ooo`80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`03
0=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040;Zj^P3_knl0kno_0?OgmbX0
oooo1P24Q8@20>o_kb@0oooo1@24Q8@30>o_kb<0oooo1@24Q8@30>o_kal0oooo1@24Q8@20>o_kbL0
oooo0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P020?Ogm`030?Ge
m@3clo<0lo?c0080Q8B400@0WinO0;Zj^P2j^[X0_;bl0P2m_Kd50<;2`P80_Kfm4P32`/830;fm_@D0
`/;20P2m_Kd00`30`<00`/;20<;2`P020<K6aPH0Q8B40P2j^[X20;fm_@030<30`032`/80`/;20080
`/;200@0`<300;fm_@2m_Kd0`<304@32`/800`30`<00_Kfm0;fm_@020<K6aP<0`/;21@24Q8@30;Zj
^P80_Kfm1@32`/820;fm_@030<30`032`/80`/;20100`/;20P2m_Kd00`30`<00`/;20<;2`P020<;2
`PD0Q8B40`2j^[X20;fm_@030<30`032`/80`/;20080`/;200<0`<300;fm_@2m_Kd03`32`/800`34
a<@0a/K60<K6aP030<;2`PD0Q8B40P2j^[X20;fm_@030<30`032`/80`/;200<0`/;20P2m_Kd00`30
`<00`/;20<;2`P0?0<;2`P030<30`02m_Kd0_Kfm00P0`/;20P24Q8@20??cl`030?Gem@3gmoL0moOg
0080lo?c00<0fm_K0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80
Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@00P2<S8`808B4Q080Ng]k00<0P82008B4Q024
Q8@00P24Q8@01020P800Ng]k07]kN`20P80A08B4Q0030820P01kNg/0Ng]k0080S8b<2`24Q8@207]k
N`D0Q8B40P1kNg/00`20P800Q8B408B4Q00@08B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]k
N`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/03`24Q8@00`28R8P0S8b<08b<S00:08B4
Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400l0Q8B400<0P82007]k
N`1kNg/02P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL508B4Q0030820P01kNg/0Ng]k00D0
Q8B40P1kNg/B08B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080S8b<2024Q8@207]kN`03
0820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8204@24Q8@00`20P800Ng]k07]kN`0208b<
S0/0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@04024Q8@207]kN`030820P024Q8@0Q8B4
00X0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0030820P01kNg/0Ng]k00l0Q8B400<0R8R808b<
S02<S8`02P24Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00?08B4
Q0030820P01kNg/0Ng]k00X0Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0ooooh00000000`20P800
oooo0?ooo`020?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3ooooP000000030820P03oool0oooo0080oooo
00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3>
c/h00`38b<P0`/;20<;2`P050?_kn`80>SXj00<0?Shn0492@P12@T800`12@T8203hn?PD0@T920P0n
?Sh00`10@400@T920492@P080492@P80?Shn00<0@4100492@P12@T800`12@T8203hn?P030410@012
@T80@T920080@T9200<0@41003hn?P0n?Sh01@12@T800`10@400?Shn03hn?P040492@P030410@00n
?Sh0?Shn00D0@T9200<0@41003hn?P0n?Sh00P16ATH00`14A4@0@T920492@P050492@P<0?Shn1@12
@T8203hn?PD0@T920`0n?Sh50492@P80?Shn00<0@4100492@P12@T800P12@T801010@400?Shn03hn
?P10@4090492@P0303hn?P0j>SX0>SXj00D0@T9200<0@41003hn?P0n?Sh01@12@T8203hn?PD0@T92
00<0?Shn03Xj>P0j>SX00P12@T800`14A4@0ATI604I6AP0203hn?P030410@012@T80@T9200P0@T92
1@0n?Sh50492@P<0?Shn1012@T800`10@400?Shn03hn?P050492@P030410@00n?Sh0?Shn00X0@T92
00<0?Shn03Xj>P0j>SX01@12@T8503hn?PD0@T920P1lO7`00`2l_;`0no_k0?_kn`020?_kn`030=cL
g02m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0
b/[:0<K6aP36a/H01@3gmoL207=cL`0307alO024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0
P82008B4Q024Q8@02024Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4
Q00208B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01024Q8@00`20P800Ng]k07]k
N`0508B4Q0030820P01kNg/0Ng]k0080S8b<00<0R8R808B4Q024Q8@01@24Q8@307]kN`D0Q8B40P1k
Ng/508B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P820
2@24Q8@00`1lO7`0Lg=c07=cL`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/508B4Q00307al
O01cLg<0Lg=c0080Q8B400<0R8R808b<S02<S8`00P1kNg/00`20P800Q8B408B4Q00808B4Q0D0Ng]k
1@24Q8@307]kN`@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q00307al
O01cLg<0Lg=c00D0Q8B41@1kNg/508B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Lg=c00<0
O7al08B4Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k00<0
P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/01@24
Q8@00`20P800Ng]k07]kN`0408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/00P2<
S8`00`28R8P0Q8B408B4Q00508B4Q0<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/508B4Q080Ng]k00<0
P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`20P80908B4Q00307alO01cLg<0Lg=c00D0Q8B4
00<0P82007]kN`1kNg/01@24Q8@207]kN`D0Q8B400<0O7al07=cL`1cLg<00P24Q8@00`28R8P0S8b<
08b<S00207]kN`030820P024Q8@0Q8B400P0Q8B41@1kNg/508B4Q0<0Ng]k1024Q8@00`20P800Ng]k
07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B400<0O7al07=cL`1cLg<01@24Q8@507]kN`D0Q8B4
1`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Ogm`@0oooo
00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?ooo`030?_k
n`3gmoL0moOg0080g]kN1P24Q8@20=kNgPL0moOg00<0no_k0?ooo`3oool00`3oool70?Ogm`030?_k
n`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3gmoL30=kNgPD0Q8B40`3Ng]h70?Ogm`D0oooo
00<0no_k0?Ogm`3gmoL01@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg
0?Ogm`020=kNgPD0Q8B40`3Ng]h70?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL0
1@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN1@24Q8@20=kNgPP0moOg1@3oool70?Ogm`040?_k
n`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41@3_knl20?Ogm`03
0=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg103oool00`3kno/0
moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3o
ool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24Q8@30=kNgPL0moOg1@3oool00`3kno/0
moOg0?Ogm`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080
g]kN1@24Q8@30=kNgPL0moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`050?Ogm`03
0?_kn`3oool0oooo00D0moOg0`3Ng]h508B4Q080g]kN203gmoL50?ooo`L0moOg00@0no_k0?ooo`3o
ool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm
_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0
_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_kn`3gmoL0moOg
00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`020=kN
gPH0Q8B40P3Ng]h70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo0?ooo`050?Og
m`030?_kn`3oool0oooo0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_kn`3gmoL0moOg
00D0moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4
Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?oo
o`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0oooo1`3gmoL0103kno/0oooo0?ooo`3kno/4
0?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@03
0<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm
0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kNgP3_knlU0?ooo`030?_kn`3gmoL0
moOg0080g]kN1P24Q8@20=kNgQl0oooo0P3gmoL30=kNgPD0Q8B40`3Ng]hN0?ooo`030?_kn`3gmoL0
moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN8@3oool3
0?Ogm`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Ogm`0208B4
Q0040;6a/@3Ng]h0g]kN0>o_kbD0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN7`3oool2
0?Ogm`<0g]kN1@24Q8@30=kNgQh0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN6@3oool0
0`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO
0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3Bd]800`38
b<P0_Kfm0;fm_@020?ooo`030?gmo@3kno/0no_k0080Q8B400@0/K6a0=kNgP3Ng]h0kno_9@3oool0
0`3moOd0no_k0?_kn`020>OWi`<0R8R800<0QXJ608B4Q024Q8@00P3Ng]hO0?ooo`80no_k0`3[jn/5
08B4Q0<0g]kN7P3oool00`3moOd0no_k0?_kn`020>OWi`D0Q8B40`3Ng]hI0?ooo`030?gmo@3kno/0
no_k00<0jn_[1@24Q8@20=kNgR40oooo0`3kno/30>OWi`80Q8B41`3kno/00`3Ogml0`/;20<;2`P03
0=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm
00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3_knlX0?ooo`80kno_0`2<S8`00`28R8P0Q8B408B4Q002
0=kNgR40oooo0`3gmoL508B4Q0<0g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0moOg1@24Q8@2
0=kNgR@0oooo0`3_knl208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kN
gP3Ng]h0kno_:03oool20>o_k`<0S8b<00<0R8R808B4Q024Q8@00P3Ng]hQ0?ooo`<0moOg1@24Q8@3
0=kNgR40oooo0P3_knl508B4Q0<0g]kN703oool30?Ogm`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@7
0?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kN
gP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3oool0
0`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]hQ0?ooo`<0g]kN1@24Q8@30>o_k`80moOg703oool0
0`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo01L0oooo0`3Ng]h5
08B4Q080kno_0P3gmoL00`3kno/0oooo0?ooo`0L0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO
0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36
a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0
moOg0080g]kN1P24Q8@20=kNgR40oooo0`3Ng]h508B4Q0<0kno_0P3gmoLL0?ooo`030?_kn`3gmoL0
moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool05`3oool30=kNgPD0Q8B40P3_knl2
0?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP03
0<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;2
00D0lo?c0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h6
08B4Q080g]kN0P3kno/00`3moOd0oooo0?ooo`0J0?ooo`80no_k0`3Ng]h508B4Q0<0inOW0P3gmoLL
0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool0503oool0
0`3moOd0no_k0?_kn`030=kNgPD0Q8B40P3WinL20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL3
0=kNgP80Q8B41`3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/2
0?Ogmb<0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`0J
0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@3
0=kNgP80moOg00<0no_k0?ooo`3oool0503oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h2
0?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@03
0<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K6
00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h6
08B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL
0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool0503oool0
0`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL3
0=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102e]KD0g]kN0=kNgP3[jn/2
0?Ogm`80oooo0`3gmoL20?ooo`80:BTY00@05ADE0000000000005ADE0P0Y:BT20?Ogm`03092@T00Y
:BT0:BTY0080000000<05ADE02TY:@0Y:BT02P3oool00`3gmoL0kno_0>o_k`020=kNgPH0Q8B40P3N
g]h20?Ogm`030?_kn`3oool0oooo0080oooo00<0P820000000000000400000020?ooo`030?_kn`3g
moL0moOg0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL20?ooo`030820P0000000000000X0000000<0
P8200?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgPD0moOg0P3o
ool00`20P80000000000000:000000030820P03oool0oooo00D0moOg0`3Ng]h508B4Q080g]kN203g
moL50?ooo`D000000P3gmoL0103kno/0oooo0?ooo`20P804000000030820P03oool0oooo0080oooo
0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102e]KD0g]kN0=kN
gP3[jn/20?Ogm`80oooo0`3gmoL20?ooo`80:BTY00@05ADE0000000000005ADE0P0Y:BT20?Ogm`03
092@T00Y:BT0:BTY0080000000<05ADE02TY:@0Y:BT02P3oool00`3gmoL0kno_0>o_k`020=kNgPH0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo0080oooo00<0P820000000000000400000020?ooo`03
0?_kn`3gmoL0moOg0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL20?ooo`030820P0000000000000X0
000000<0P8200?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgPD0
moOg0P3oool00`20P80000000000000:000000030820P03oool0oooo00D0moOg0`3Ng]h508B4Q080
g]kN203gmoL50?ooo`D000000P3gmoL0103kno/0oooo0?ooo`20P804000000030820P03oool0oooo
0080oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40
g]kN0=kNgP3WinL20>o_k`80moOg1@3oool20?Ogm`0408R8R00H61P061PH06=SH`80[Jf]0P3gmoL0
0`3Bd]80[Jf]0:f][@0201PH600308R8R03gmoL0moOg00<0oooo0P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3oool0
1020P800000000000020P8040?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL00`00
00050?ooo`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?ooo`030?_kn`3gmoL0moOg00D0oooo00<0
no_k0?Ogm`3gmoL00P0000000`1lO7`0moOg0?Ogm`080?ooo`80moOg00<0lo?c0>o_k`3_knl00P3N
g]h308B4Q080Ng]k0`3Ng]h50?Ogm`D0oooo0P3gmoL0101lO7`000000000001lO7`20?Ogm`L0oooo
00<0moOg0>o_k`3_knl00`3Fe]H508B4Q080e]KF0P3_knl00`3gmoL0oooo0?ooo`030?Ogm`D0oooo
0P3gmoL00`1lO7`00000000000050?Ogm`0307alO000000000000080oooo00<0no_k0?Ogm`3gmoL0
0P3gmoL30?ooo`<0g]kN0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3N
g]h0g]kN0>OWi`80kno_0P3gmoL50?ooo`80moOg00@0R8R801PH600H61P0Hf=S0P2][Jd20?Ogm`03
0=;BdP2][Jd0[Jf]008061PH00<0R8R80?Ogm`3gmoL00`3oool20?Ogm`030?_kn`3oool0oooo0080
oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`020?ooo`04
0820P000000000000820P0@0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`030000
00D0oooo0P3_knl30=KFePD0Q8B40`3Fe]H20>o_k`80oooo00<0no_k0?Ogm`3gmoL01@3oool00`3k
no/0moOg0?Ogm`020000000307alO03gmoL0moOg00P0oooo0P3gmoL00`3clo<0kno_0>o_k`020=kN
gP<0Q8B40P1kNg/30=kNgPD0moOg1@3oool20?Ogm`0407alO0000000000007alO080moOg1`3oool0
0`3gmoL0kno_0>o_k`030=KFePD0Q8B40P3Fe]H20>o_k`030?Ogm`3oool0oooo00<0moOg1@3oool2
0?Ogm`0307alO0000000000000D0moOg00<0O7al0000000000000P3oool00`3kno/0moOg0?Ogm`02
0?Ogm`<0oooo0`3Ng]h207]kN`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kN
gP3Ng]h0inOW0P3_knl20?Ogm`D0oooo0P3gmoL01028R8P061PH01PH601SHf<20:f][@80moOg00<0
d];B0:f][@2][Jd00P0H61P00`28R8P0moOg0?Ogm`030?ooo`80moOg00<0no_k0?ooo`3oool00P3o
ool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080oooo00@0
P820000000000000P820103oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00<00000
1@3oool20>o_k`<0e]KF1@24Q8@30=KFeP80kno_0P3oool00`3kno/0moOg0?Ogm`050?ooo`030?_k
n`3gmoL0moOg0080000000<0O7al0?Ogm`3gmoL0203oool20?Ogm`030??cl`3_knl0kno_0080g]kN
0`24Q8@207]kN`<0g]kN1@3gmoL50?ooo`80moOg00@0O7al000000000000O7al0P3gmoL70?ooo`03
0?Ogm`3_knl0kno_00<0e]KF1@24Q8@20=KFeP80kno_00<0moOg0?ooo`3oool00`3gmoL50?ooo`80
moOg00<0O7al0000000000001@3gmoL00`1lO7`00000000000020?ooo`030?_kn`3gmoL0moOg0080
moOg0`3oool30=kNgP80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102_[jl0f][J
0=[JfP3UiND20>o_k`L0no_k0P3gmoL0102QXJ40BTY:04Y:BP1SHf<207alO080moOg00<0^[Zj07al
O01lO7`00P1:BTX00`2SXj<0no_k0?_kn`030?_kn`80moOg00<0nOWi0?_kn`3kno/00P3kno/00`3i
nOT0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030?Gem@3kno/0no_k0080no_k00@0OWin0000
00000000OWin0P3kno/20820P0030;jn_P3kno/0no_k0080P82000<0_;bl0?Ogm`3gmoL00`000005
0?_kn`80lo?c0`3Jf]X508B4Q0<0f][J0P3clo<20?_kn`030?Win@3gmoL0moOg0080c/k>00@0[Jf]
08b<S02<S8`0Q8B40P1lO7`20000000303hn?P1lO7`0O7al0080S8b<00<0[Jf]0<k>cP3>c/h00`3k
no/20?Ogm`030?Gem@3clo<0lo?c0080g]kN0`24Q8@20820P0<0g]kN0P3clo<00`3emOD0moOg0?Og
m`020<k>cP030:f][@2<S8`0S8b<0080O7al00@0?Shn000000000000?Shn0P1lO7`208b<S0030:f]
[@3>c/h0c/k>0080no_k00<0moOg0??cl`3clo<00`3Jf]X508B4Q080f][J0P3clo<00`3gmoL0no_k
0?_kn`030?Ogm`D0no_k0P32`/800`1QHF400000000000050?Ogm`0307alO000000000000080a/K6
00<0gmoO0?Ogm`3gmoL00P3kno/30?Ogm`<0g]kN0P20P8070?_kn`030=oOg`32`/80`/;200<0d];B
0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3g
moL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_0P3oool70?Ogm`040;Vi^@1kNg/0Ng]k06=SH`80
BTY:0P3gmoL00`2QXJ40BTY:04Y:BP0207]kN`030;fm_@3oool0oooo00d0moOg0P3Ng]h608B4Q080
g]kN0P3_knl00`3gmoL0oooo0?ooo`020?Ogm`0407alO0000000000007alO080moOg0P0000000`20
P800oooo0?ooo`020000000307alO03gmoL0moOg00<000001`3gmoL30=kNgPD0Q8B40`3Ng]h70?Og
m`80W9bL00@0FUYJ01PH600H61P030`<1`00000201PH600305YJFP2LW9`0W9bL00P0moOg0P3Ng]h5
08B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`0209bLW00305YJFP0H61P061PH00P000000P0H61P0
0`1JFUX0W9bL09bLW0050?Ogm`<0g]kN1@24Q8@20=kNgPd0moOg0P2<S8`00`16ATH0000000000005
0?Ogm`0307alO000000000000080S8b<00<0`/;20?Ogm`3gmoL00P3oool30>o_k`<0g]kN0P24Q8@7
0?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kN
gP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_0P3oool7
0?Ogm`040;Vi^@1kNg/0Ng]k06=SH`80BTY:0P3gmoL00`2QXJ40BTY:04Y:BP0207]kN`030;fm_@3o
ool0oooo00d0moOg0P3Ng]h608B4Q080g]kN0P3_knl00`3gmoL0oooo0?ooo`020?Ogm`0407alO000
0000000007alO080moOg0P0000000`20P800oooo0?ooo`020000000307alO03gmoL0moOg00<00000
1`3gmoL30=kNgPD0Q8B40`3Ng]h70?Ogm`80W9bL00@0FUYJ01PH600H61P030`<1`00000201PH6003
05YJFP2LW9`0W9bL00P0moOg0P3Ng]h508B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`0209bLW003
05YJFP0H61P061PH00P000000P0H61P00`1JFUX0W9bL09bLW0050?Ogm`<0g]kN1@24Q8@20=kNgPd0
moOg0P2<S8`00`16ATH00000000000050?Ogm`0307alO000000000000080S8b<00<0`/;20?Ogm`3g
moL00P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3_knl208B4Q0040:f]
[@3Fe]H0e]KF0>?Sh`80kno_2@3gmoL0103[jn/0g]kN0=kNgP1_Kfl200000080c/k>00<0IfMW0000
000000000P3Ng]h00`3[jn/0moOg0?Ogm`0:0?Ogm`030??cl`3_knl0kno_0080e]KF1P24Q8@20=kN
gP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`030?ooo`L0000000<0O7al0?Og
m`3gmoL0203gmoL20>o_k`<0e]KF1@24Q8@30=KFeP80kno_0P3gmoL00`3kno/0oooo0?ooo`020000
000404i>CP2LW9`0W9bL0<[:bP80moOg0P0000000`1lO7`0moOg0?Ogm`020:f][@0305MGE`000000
000000D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0e]KF0P3_knl00`3gmoL0oooo0?ooo`02
0000000303hn?P1kNg/0Ng]k0080moOg00@0O7al000000000000O7al0P3gmoL207]kN`0303hn?P00
000000000080moOg00<0lo?c0>o_k`3_knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Og
m`030?ooo`D0moOg0P0000000`0n?Sh0Ng]k07]kN`050?Ogm`030;Vi^@1kNg/0Ng]k0080000000<0
O7al0?Ogm`3gmoL00P3gmoL30>o_k`<0e]KF0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP05
0>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl90?Ogm`040>_[j`3Ng]h0g]kN06m_K`800000
0P3>c/h00`1WIfL00000000000020=kNgP030>_[j`3gmoL0moOg00X0moOg00<0lo?c0>o_k`3_knl0
0P3Fe]H608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030?_kn`3oool0oooo00<0oooo
1`0000000`1lO7`0moOg0?Ogm`080?Ogm`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?Ogm`030?_k
n`3oool0oooo0080000000@0CTi>09bLW02LW9`0b/[:0P3gmoL20000000307alO03gmoL0moOg0080
[Jf]00<0EeMG0000000000001@3gmoL00`3clo<0kno_0>o_k`020=KFePD0Q8B40`3Fe]H20>o_k`03
0?Ogm`3oool0oooo0080000000<0?Shn07]kN`1kNg/00P3gmoL0101lO7`000000000001lO7`20?Og
m`80Ng]k00<0?Shn0000000000000P3gmoL00`3clo<0kno_0>o_k`030=KFePD0Q8B40P3Fe]H20>o_
k`030??cl`3gmoL0moOg00<0oooo1@3gmoL20000000303hn?P1kNg/0Ng]k00D0moOg00<0^KVi07]k
N`1kNg/00P0000000`1lO7`0moOg0?Ogm`020?Ogm`<0kno_0`3Fe]H208B4Q0D0kno_0P3gmoL00`3J
f]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<k>cP36a/H0a/K600D0moOg0P1kNg/0102YZJT0e]KF0=KFeP3Shn<20>o_k`D0moOg0P3_knl20?oo
o`040?_kn`3gmoL0moOg0:6QX@80BTY:0P0H61P00`0Y:BT0>CTi03Ti>@0=0?Ogm`D0kno_0P3Ng]h3
07]kN`030820P024Q8@0Q8B40080e]KF1@3gmoL20>o_k`0407QhN0000000000007alO080moOg0P00
00000`1lO7`0moOg0?Ogm`020000000307alO03gmoL0moOg00<000001`3gmoL30=KFeP80Q8B40`1k
Ng/30=kNgP80kno_0P3gmoL00`3clo<0kno_0>o_k`0209bLW00405YJFP0H61P061PH00`<30L00000
0P0H61P00`1FEUH0U9BD09BDU0050?Ogm`030??cl`3_knl0kno_0080g]kN0`1kNg/208b<S0<0e]KF
0P3Ng]h00`3[jn/0moOg0?Ogm`020000000307QhN03_knl0kno_0080moOg00@0O7al000000000000
O7al0P3gmoL20?ooo`030820P0000000000000D0moOg0`3Fe]H208B4Q0<0Ng]k0P3Ng]h20>o_k`03
0??cl`3gmoL0moOg00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020000000307alO03gmoL0moOg0080
moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20000000307alO03gmoL0moOg00D0kno_0`3Fe]H208b<
S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Ng]k00@0ZJVY0=KFeP3Fe]H0hn?S0P3_knl50?Og
m`80kno_0P3oool0103kno/0moOg0?Ogm`2QXJ4204Y:BP8061PH00<0:BTY03Ti>@0i>CT03@3gmoL5
0>o_k`80g]kN0`1kNg/00`20P800Q8B408B4Q0020=KFePD0moOg0P3_knl0101hN7P000000000001l
O7`20?Ogm`80000000<0O7al0?Ogm`3gmoL00P0000000`1lO7`0moOg0?Ogm`03000000L0moOg0`3F
e]H208B4Q0<0Ng]k0`3Ng]h20>o_k`80moOg00<0lo?c0>o_k`3_knl00P2LW9`0101JFUX061PH01PH
600<30`70000008061PH00<0EUIF09BDU02DU9@01@3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Ng]k
0P2<S8`30=KFeP80g]kN00<0jn_[0?Ogm`3gmoL00P0000000`1hN7P0kno_0>o_k`020?Ogm`0407al
O0000000000007alO080moOg0P3oool00`20P8000000000000050?Ogm`<0e]KF0P24Q8@307]kN`80
g]kN0P3_knl00`3clo<0moOg0?Ogm`030>o_k`80moOg00<0lo?c0>o_k`3_knl00P0000000`1lO7`0
moOg0?Ogm`020?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P0000000`1lO7`0moOg0?Ogm`050>o_
k`<0e]KF0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL207]kN`040:VYZ@3Fe]H0e]KF0>?S
h`80kno_1@3gmoL20>o_k`80oooo00@0no_k0?Ogm`3gmoL0XJ6Q0P1:BTX201PH600302TY:@0i>CT0
>CTi00d0moOg1@3_knl20=kNgP<0Ng]k00<0P82008B4Q024Q8@00P3Fe]H50?Ogm`80kno_00@0N7Qh
000000000000O7al0P3gmoL20000000307alO03gmoL0moOg0080000000<0O7al0?Ogm`3gmoL00`00
00070?Ogm`<0e]KF0P24Q8@307]kN`<0g]kN0P3_knl20?Ogm`030??cl`3_knl0kno_0080W9bL00@0
FUYJ01PH600H61P030`<1`00000201PH600305IFEP2DU9@0U9BD00D0moOg00<0lo?c0>o_k`3_knl0
0P3Ng]h307]kN`80S8b<0`3Fe]H20=kNgP030>_[j`3gmoL0moOg0080000000<0N7Qh0>o_k`3_knl0
0P3gmoL0101lO7`000000000001lO7`20?Ogm`80oooo00<0P8200000000000001@3gmoL30=KFeP80
Q8B40`1kNg/20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00`3_knl20?Ogm`030??cl`3_knl0kno_0080
000000<0O7al0?Ogm`3gmoL00P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80000000<0O7al0?Og
m`3gmoL01@3_knl30=KFeP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0
e]KF0=KFeP3Jf]X20=kNgP80kno_0`3gmoL70>o_k`030<K6aP2LW9`0W9bL0080000000<0CTi>09bL
W02LW9`00P3_knl00`3clo<0moOg0?Ogm`0:0>o_k`030??cl`3gmoL0moOg0080e]KF1P24Q8@20=KF
eP80g]kN00<0inOW0>o_k`3_knl00P3gmoL0101lO7`000000000001lO7`20?Ogm`80kno_00<0lo?c
0?Ogm`3gmoL01@3_knl300000080kno_00<0lo?c0?Ogm`3gmoL00P3Ng]h30=KFePD0Q8B40`3Fe]H2
0>o_k`80moOg00<0lo?c0>o_k`3_knl00P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80000000<0
N7Qh0>o_k`3_knl01@3_knl30?Ogm`D0kno_0P3Ng]h508B4Q0<0e]KF1@3_knl20?Ogm`030??cl`3_
knl0kno_0080moOg00@0O7al000000000000N7Qh1`3_knl20?Ogm`030>_[j`3Ng]h0g]kN00<0e]KF
1@24Q8@20=KFeP80kno_00<0lo?c0?Ogm`3gmoL00`3_knl20?Ogm`030??cl`3_knl0kno_0080:BTY
00<0@T9205YJFP1JFUX00P3Fe]H0103Shn<0kno_0>o_k`2][Jd206][J`80:BTY00<0S8b<0>o_k`3_
knl01@3_knl30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0e]KF
0=KFeP3Jf]X20=kNgP80kno_0`3gmoL70>o_k`030<K6aP2LW9`0W9bL0080000000<0CTi>09bLW02L
W9`00P3_knl00`3clo<0moOg0?Ogm`0:0>o_k`030??cl`3gmoL0moOg0080e]KF1P24Q8@20=KFeP80
g]kN00<0inOW0>o_k`3_knl00P3gmoL0101lO7`000000000001lO7`20?Ogm`80kno_00<0lo?c0?Og
m`3gmoL01@3_knl300000080kno_00<0lo?c0?Ogm`3gmoL00P3Ng]h30=KFePD0Q8B40`3Fe]H20>o_
k`80moOg00<0lo?c0>o_k`3_knl00P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80000000<0N7Qh
0>o_k`3_knl01@3_knl30?Ogm`D0kno_0P3Ng]h508B4Q0<0e]KF1@3_knl20?Ogm`030??cl`3_knl0
kno_0080moOg00@0O7al000000000000N7Qh1`3_knl20?Ogm`030>_[j`3Ng]h0g]kN00<0e]KF1@24
Q8@20=KFeP80kno_00<0lo?c0?Ogm`3gmoL00`3_knl20?Ogm`030??cl`3_knl0kno_0080:BTY00<0
@T9205YJFP1JFUX00P3Fe]H0103Shn<0kno_0>o_k`2][Jd206][J`80:BTY00<0S8b<0>o_k`3_knl0
1@3_knl30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@00`2][Jd0e]KF0=KF
eP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P0@41000`1gMgL0g]kN0=kN
gP0?0>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/00`20P800Q8B408B4Q0040=KFeP030=[JfP3N
g]h0g]kN0080kno_00<0N7Qh000000000000400000050>o_k`80g]kN0`3Fe]H207]kN`<0Q8B41@3F
e]H20=kNgP030>OWi`3_knl0kno_0080g]kN00<0Kfm_0000000000002P0000000`1hN7P0kno_0>o_
k`050>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/208B4Q0D0e]KF00<0f][J0=kNgP3Ng]h00P3_
knl00`1hN7P000000000000:0000000306m_K`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00`3F
e]H207]kN`<0Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP030>o_k`80g]kN00<0inOW0>o_k`3_knl00P3F
e]H00`28R8P0>CTi03Ti>@050000000302DU9@1:BTX0BTY:0080e]KF00<0hn?S0>o_k`3_knl00P3_
knl30=kNgP<0e]KF0P1cLg<70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0030:f][@3Fe]H0
e]KF00<0e]KF0P3Ng]h30>o_k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP02010@400307MgM`3Ng]h0
g]kN00l0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`030820P024Q8@0Q8B400@0e]KF00<0f][J
0=kNgP3Ng]h00P3_knl00`1hN7P000000000000@000000D0kno_0P3Ng]h30=KFeP80Ng]k0`24Q8@5
0=KFeP80g]kN00<0inOW0>o_k`3_knl00P3Ng]h00`1_Kfl000000000000:0000000307QhN03_knl0
kno_00D0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`80Q8B41@3Fe]H00`3Jf]X0g]kN0=kNgP02
0>o_k`0307QhN0000000000000X0000000<0Kfm_0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP03
0=KFeP80Ng]k0`24Q8@40=KFeP030=[JfP3Ng]h0g]kN00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`02
0=KFeP0308R8R00i>CT0>CTi00D0000000<09BDU04Y:BP1:BTX00P3Fe]H00`3Shn<0kno_0>o_k`02
0>o_k`<0g]kN0`3Fe]H207=cL`L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm_@020?Ogm`030?Gem@3clo<0lo?c
0080Q8B400@0Zj^[0=;BdP3Bd]80e]KF0P3Jf]X20=kNgP<0inOW0P3Ng]h20>o_k`040>_[j`3WinL0
inOW0>?Sh`80g]kN0P20P8000`2_[jl0g]kN0=kNgP050>OWi`<0kno_0P3WinL00`3[jn/0kno_0>o_
k`020>OWi`030>?Sh`3Ng]h0g]kN0080d];B0`20P8000`22PX80Q8B408B4Q0020=;BdP80f][J00<0
g=cL0=kNgP3Ng]h00P3WinL0102[Zj/0Kfm_06m_K`1dM7@207QhN0D0Kfm_0P1hN7P00`1dM7@0Kfm_
06m_K`0306m_K`80inOW00<0jn_[0>o_k`3_knl00P3Ng]h30=;BdP80P8200`24Q8@30=;BdP80f][J
0P3Ng]h00`3Shn<0inOW0>OWi`020=kNgP040:^[Z`1hN7P0N7Qh07AdM0@0Kfm_00<0MWIf07alO01l
O7`00P1_Kfl00`2[Zj/0inOW0>OWi`030>OWi`80kno_00<0inOW0=kNgP3Ng]h00P3Bd]830820P080
Q8B40`3Bd]820=[JfP030=cLg03Ng]h0g]kN0080inOW00<0Zj^[06m_K`1_Kfl00P1hN7P00`1dM7@0
Kfm_06m_K`0306m_K`80N7Qh00<0Zj^[0=kNgP3Ng]h00P3WinL00`3Shn<0g]kN0=kNgP030=;BdP80
P8200`24Q8@20=;BdP80f][J00<0g=cL0=kNgP3Ng]h00`3WinL20=kNgP030>OWi`3_knl0kno_0080
f][J00<0/k>c08b<S02<S8`00P1lO7`0101fMWH0Kfm_06m_K`22PX8209BDU080f][J00<0iNGU0>o_
k`3_knl00P3WinL30=kNgP<0d];B0P1lO7`20??cl`030?Gem@3gmoL0moOg0080lo?c00<0f=SH0;fm
_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0
_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h20>o_
k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0kno_0P3Ng]h00`3W
inL0kno_0>o_k`050=kNgP80c/k>1P24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20>o_
k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl00P3Ng]h30<k>cPD0Q8B40`3>c/h90=kN
gP040>OWi`3_knl0kno_0>OWi`@0g]kN00<0jn_[0?Ogm`3gmoL0203Ng]h20>o_k`030>OWi`3Ng]h0
g]kN0080c/k>1@24Q8@30<k>cPX0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW
0=kNgP3Ng]h01@3Ng]h30<k>cPD0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3gmoL0
0`3[jn/0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q080kno_00<0lo?c
0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102Y
ZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20>o_k`030>OWi`3Ng]h0
g]kN00D0g]kN0`3_knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h608B4Q080c/k>2P3Ng]h0
0`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`02
0=kNgP<0c/k>1@24Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0inOW103Ng]h00`3[jn/0moOg0?Og
m`080=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>2P3Ng]h20>o_k`030>OWi`3N
g]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20<k>cPX0g]kN00<0
inOW0>o_k`3_knl01@3Ng]h20?Ogm`030>_[j`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3N
g]h30<k>cP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/800P3gmoL0
0`3emOD0lo?c0??cl`0208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Jf]X50=kNgP80inOW00@0
hn?S0=kNgP3Ng]h0g=cL0P3Jf]X20>?Sh`030>7Qh@3Ng]h0g]kN0080f][J00<0g=cL0=kNgP3Ng]h0
0`3WinL20=kNgP030>?Sh`3WinL0inOW00D0f][J0P3Bd]8608B4Q080c/k>0P3Ng]h00`3Lg=`0f][J
0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[JfP3Jf]X00P3Shn<00`3QhN40g]kN
0=kNgP030=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h30<k>cPD0Q8B40`3>c/h20=kNgP80f][J
00<0g=cL0=kNgP3Ng]h00P3Ng]h0103Shn<0inOW0>OWi`3Shn<20=kNgP80f][J00<0hN7Q0>OWi`3W
inL00P3Ng]h00`3Lg=`0f][J0=[JfP030=kNgP80inOW00<0hN7Q0=[JfP3Jf]X00P3>c/h508B4Q0<0
c/k>0P3Ng]h00`3Lg=`0f][J0=[JfP050=kNgP80inOW00@0hn?S0=kNgP3Ng]h0g=cL0P3Jf]X20>?S
h`030>7Qh@3Ng]h0g]kN0080f][J00<0g=cL0=kNgP3Ng]h00`3>c/h508B4Q080c/k>0P3Ng]h00`3L
g=`0f][J0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[JfP3Jf]X00P3WinL0103S
hn<0g]kN0=kNgP3Lg=`20=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h30=[JfP<0c/k>0P24Q8@2
0??cl`030?Gem@3gmoL0moOg0080lo?c00<0fm_K0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0ZJVY0<k>
cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP02
0=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1`3Fe]H608B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:
0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H70=kNgP<0c/k>1@24Q8@3
0<k>cP80g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3Ng]h00`3Jf]X0e]KF0=KFeP05
0=kNgP030=[JfP3Fe]H0e]KF0080c/k>1@24Q8@30<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h0
0`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h00`3>c/h5
08B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00@0f][J
0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP05
0?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1`3Fe]H608B4Q080c/k>0P3N
g]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3F
e]H70=kNgP<0c/k>1@24Q8@30<k>cP80g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3N
g]h00`3Jf]X0e]KF0=KFeP050=kNgP030=[JfP3Fe]H0e]KF0080c/k>1@24Q8@30<k>cP80g]kN00<0
f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0
f][J0=kNgP3Ng]h00`3>c/h508B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3F
e]H0e]KF0080e]KF00@0f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4Q0L0moOg
00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>
c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3Ng]h0jn_[7P3gmoL20?ooo`030?_k
n`3gmoL0moOg0080oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q0030820P01kNg/0Ng]k0080g]kN
7`3gmoL20>o_k`<0g]kN0P24Q8@307]kN`<0g]kN7P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Q8B4
0P1kNg/30=kNgQT0moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]hO0?Ogm`80oooo
0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kN
gP3[jn/N0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Q8B4
00<0P82007]kN`1kNg/00P3Ng]hO0?Ogm`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]hN0?Ogm`030??c
l`3_knl0kno_0080g]kN0`24Q8@207]kN`<0g]kN6@3gmoL00`3clo<0kno_0>o_k`030=kNgP80Q8B4
0`1kNg/20=kNgQl0moOg0P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>00<0b<S80<;2`P32`/801@3k
no/20820P0040;Bd]03WinL0inOW0?7alAh0no_k0P3oool00`3moOd0no_k0?_kn`020?ooo`030?_k
n`3gmoL0moOg0080kno_0`24Q8@00`22PX80P8200820P0020>OWial0no_k0P3gmoL30>o_k`80Q8B4
0`20P8030>OWiah0no_k00<0nOWi0?Ogm`3gmoL00P3_knl308B4Q080P8200`3WinLI0?_kn`030?Wi
n@3gmoL0moOg00<0kno_0P24Q8@30820P080inOW7`3kno/20?ooo`<0no_k0`3_knl208B4Q0L0no_k
00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>
c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0^[Zj0>o_k`3_knl0moOg:P3oool608B4Q080kno_
903oool508B4Q0<0kno_8`3oool508B4Q0<0kno_7`3oool508B4Q080kno_9`3oool208B4Q0L0moOg
00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>
c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0^[Zj0>o_k`3_knl0moOg:P3oool608B4Q080kno_
903oool508B4Q0<0kno_8`3oool508B4Q0<0kno_7`3oool508B4Q080kno_9`3oool208B4Q0L0moOg
00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3:b/X0_Kfm0;fm_@050>o_k`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1k
Ng/508B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0
P82007]kN`1kNg/0P8204@24Q8@00`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207]kN`030820
P024Q8@0Q8B40100Q8B40P1kNg/00`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@0
0P24Q8@00`20P800Ng]k07]kN`0L08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820
P024Q8@0Q8B400l0Q8B400<0P82007]kN`1kNg/02P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm
_@050>o_k`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/508B4Q080Ng]k00<0
P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P820
4@24Q8@00`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40100Q8B4
0P1kNg/00`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k
07]kN`0L08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400l0Q8B4
00<0P82007]kN`1kNg/02P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??c
l`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm_@020?Ogm`030?Gem@3c
lo<0lo?c0080P82000@0PX:208B4Q024Q8@0PX:21020P80308B4Q0@0P82000<0PX:208B4Q024Q8@0
2024Q8@20820P00308:2PP24Q8@0Q8B400D0P82000<0PX:208B4Q024Q8@01@20P80508B4Q0030820
P01lO7`0O7al0080Q8B41@20P80208B4Q00308:2PP20P800P82000<0P8201`24Q8@00`26QXH0R8R8
08R8R0030820P080Q8B400<0PX:20820P020P8000P20P80508B4Q0<0P8200`24Q8@40820P00308:2
PP24Q8@0Q8B400D0P82000<0PX:208B4Q024Q8@00P24Q8@00`26QXH0R8R808R8R00208B4Q00308:2
PP20P800P82000<0Q8B41@20P80508B4Q080P8200`24Q8@50820P080Q8B400<0PX:20820P020P800
0P20P8001022PX80Q8B408B4Q026QXH208R8R0D0Q8B41@20P80508B4Q0<0P8200P24Q8@50820P0<0
Q8B41@20P80508B4Q080R8R800@0QXJ608B4Q024Q8@0PX:20P20P80208B4Q00308:2PP20P800P820
0080P8200`1lO7`508B4Q0D0lo?c0P3gmoL00`3MgMd0`/;20<;2`P030<k>cP80inOW00<0kno_0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3g
moL00P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0
Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800
Ng]k07]kN`0508B4Q00307alO01cLg<0Lg=c00@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800
Ng]k07]kN`0708B4Q00308R8R02<S8`0S8b<00<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/508B4Q080
Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`20P80408B4Q00308R8R02<S8`0S8b<
0080Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k1@24Q8@00`20
P800Ng]k07]kN`0508B4Q080Ng]k00@0P82008B4Q024Q8@0R8R80P2<S8`508B4Q0D0Ng]k1@24Q8@3
07]kN`@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0508B4Q080S8b<00@0R8R8
08B4Q024Q8@0P8200P1kNg/508B4Q080Ng]k0`1cLg<508B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@02
0?ooo`030?_kn`3gmoL0moOg0080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/0
0`20P800Q8B408B4Q00808B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0
Q8B40080Q8B400<0P82007]kN`1kNg/01@24Q8@00`1lO7`0Lg=c07=cL`0408B4Q0030820P01kNg/0
Ng]k00D0Q8B400<0P82007]kN`1kNg/01`24Q8@00`28R8P0S8b<08b<S00307]kN`D0Q8B40P1kNg/5
08B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8201024
Q8@00`28R8P0S8b<08b<S00208B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01@24
Q8@207]kN`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`040820P024Q8@0Q8B408R8R080S8b<
1@24Q8@507]kN`D0Q8B40`1kNg/408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/0
1@24Q8@208b<S00408R8R024Q8@0Q8B40820P080Ng]k1@24Q8@207]kN`<0Lg=c1@24Q8@70?Ogm`03
0=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF
00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg0P3oool30?Ogm`L0
oooo00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?ooo`03
0?_kn`3gmoL0moOg0080g]kN0`2<S8`00`28R8P0Q8B408B4Q0020=kNgP80moOg00<0no_k0?ooo`3o
ool00P3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0
oooo0?ooo`020?Ogm`<0g]kN1@24Q8@30=kNgP80oooo1@3gmoL50?ooo`030?_kn`3gmoL0moOg00D0
moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`D0oooo0P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0
oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0
Q8B40P3Ng]h20?ooo`030?_kn`3gmoL0moOg00<0moOg1@3oool70?Ogm`040?_kn`3oool0oooo0?_k
n`@0moOg00<0no_k0?ooo`3oool00P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m
_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg0P3oool30?Ogm`L0oooo00<0no_k0?Og
m`3gmoL00P3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg
0080g]kN0`2<S8`00`28R8P0Q8B408B4Q0020=kNgP80moOg00<0no_k0?ooo`3oool00P3gmoL00`3k
no/0oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Og
m`<0g]kN1@24Q8@30=kNgP80oooo1@3gmoL50?ooo`030?_kn`3gmoL0moOg00D0moOg0P3oool00`3k
no/0moOg0?Ogm`030?Ogm`D0oooo0P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`020?oo
o`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h20?oo
o`030?_kn`3gmoL0moOg00<0moOg1@3oool70?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k
0?ooo`3oool00P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4
Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg0P3oool30?Ogm`L0oooo00<0no_k0?Ogm`3gmoL00P3gmoL0
0`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN0`2<S8`0
0`28R8P0Q8B408B4Q0020=kNgP80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`03
0?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24Q8@3
0=kNgP80oooo1@3gmoL50?ooo`030?_kn`3gmoL0moOg00D0moOg0P3oool00`3kno/0moOg0?Ogm`03
0?Ogm`D0oooo0P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0
moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h20?ooo`030?_kn`3gmoL0
moOg00<0moOg1@3oool70?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool00P3o
ool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0
g]kN0>o_kbD0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN7`3oool20?Ogm`<0g]kN1@24
Q8@30=kNgQh0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN6@3oool00`3kno/0moOg0?Og
m`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@05
0?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_9@3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3N
g]hO0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN7P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3N
g]hI0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgR40oooo0`3gmoL30=kNgP80Q8B41`3g
moL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=;BdP030<[:bP32`/80`/;200D0lo?c0P24Q8@0102a/K40g]kN0=kNgP3_knlU0?ooo`030?gmo@3k
no/0no_k0080inOW1P24Q8@20=kNgQl0oooo0P3kno/30>OWi`D0Q8B40`3Ng]hN0?ooo`030?gmo@3k
no/0no_k0080inOW1@24Q8@30=kNgQT0oooo00<0oOgm0?_kn`3kno/00`3WinL508B4Q080g]kN8@3o
ool30?_kn`<0inOW0P24Q8@70??cl`030=_Kf`32`/80`/;200<0c/k>0P3WinL00`3_knl0moOg0?Og
m`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl208B4Q0040;6a/@3Ng]h0
g]kN0>o_kbP0oooo0P3_knl608B4Q080g]kN8@3oool30>o_k`D0Q8B40`3Ng]hQ0?ooo`80kno_1@24
Q8@30=kNgQ`0oooo0`3_knl508B4Q080g]kN903oool30>o_k`80Q8B41`3_knl00`3Fe]H0_Kfm0;fm
_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0
a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3_knlX0?ooo`80kno_1P24Q8@20=kNgR40oooo0`3_
knl508B4Q0<0g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0kno_1@24Q8@20=kNgR@0oooo0`3_
knl208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0jn_[0P3g
moL<0?ooo`030;6a/@1SHf<0Hf=S0080Ng]k00<0_Kfm0?ooo`3oool03`3oool00`3kno/0moOg0?Og
m`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3_knl508B4Q0<0g]kN0P3g
moLO0?ooo`80g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool05`3oool30>o_k`D0Q8B40P3N
g]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm
_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0
_Kfm00D0moOg0P2<S8`0102e]KD0g]kN0=kNgP3[jn/20?Ogm``0oooo00<0/K6a06=SH`1SHf<00P1k
Ng/00`2m_Kd0oooo0?ooo`0?0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80moOg00<0
no_k0?ooo`3oool0703oool30>o_k`D0Q8B40`3Ng]h20?Ogmal0oooo0P3Ng]h508B4Q0<0g]kN0P3g
moL00`3kno/0oooo0?ooo`0G0?ooo`<0kno_1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool0703o
ool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30=kNgP80d];B00<0b<S80;fm_@2m_Kd01@3kno/208R8R0040;>c/`3Ng]h0
g]kN0>_[j`80moOg0P3kno/:0?ooo`030;jn_P1lO7`0O7al0080IfMW00<0/k>c0?ooo`3oool03`3o
ool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20??cl`030?Win@3oool0oooo01X0oooo0P3k
no/30>OWi`D0Q8B40`3Jf]X20?Ogma`0oooo00<0oOgm0?_kn`3kno/00P3Ng]h308B4Q080P8200`3N
g]h20?Ogm`030?_kn`3oool0oooo01@0oooo00<0oOgm0?_kn`3kno/00`3WinL508B4Q080f][J0P3g
moL00`3kno/0oooo0?ooo`0L0?ooo`<0no_k0`3WinL20820P0L0no_k00<0gmoO0<;2`P32`/800`3B
d]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@05
0?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL:0?ooo`030<[:bP2DU9@0U9BD0080DU9B00<0
ZJVY0?ooo`3oool03`3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030?Ogm`3o
ool0oooo01X0oooo0P3gmoL30=kNgPD0Q8B40`3Fe]H20?Ogma`0oooo00<0no_k0?Ogm`3gmoL00P3N
g]h308B4Q080Ng]k0`3Ng]h20?Ogm`030?_kn`3oool0oooo01@0oooo00<0no_k0?Ogm`3gmoL00`3N
g]h508B4Q080e]KF0P3gmoL00`3kno/0oooo0?ooo`0O0?ooo`<0kno_0P1kNg/70?ooo`030>?Sh`36
a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K6
0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg2P3oool00`3:b/X0U9BD09BD
U002059BDP030:VYZ@3oool0oooo00l0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_
knl00`3gmoL0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0e]KF0P3gmoLL0?ooo`030?_kn`3g
moL0moOg0080g]kN0`24Q8@207]kN`<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3g
moL0moOg00<0g]kN1@24Q8@20=KFeP80moOg00<0no_k0?ooo`3oool07`3oool30>o_k`80Ng]k1`3o
ool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL20?Ogm`T0oooo00@0
c/k>09bLW02LW9`0CTi>100000000`0410@020P800P820020<K6aP030>?Sh`3oool0oooo00<0oooo
0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80moOg
00<0no_k0?ooo`3oool00P3gmoL0102i^KT0Ng]k07]kN`0n?Sh200000080:BTY00<07AdM010@400@
41000P0000000`1OGel0_Kfm0;fm_@050?ooo`030?_kn`3gmoL0moOg0080moOg0`3Ng]h508B4Q0<0
g]kN103gmoL00`3kno/0oooo0?ooo`0:0000000303Hf=P1[Jf/0Jf][00D0oooo0`3gmoL20?ooo`03
0?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool00P0Y:BT00`0E5AD0
00000000000:0000000301DE5@0Y:BT0:BTY00D0moOg0`3Ng]h508B4Q080g]kN1@3gmoL30?ooo`80
moOg00<0no_k0?ooo`3oool00P3oool00`2i^KT0Lg=c07=cL`0502TY:@0304i>CP1cLg<0Lg=c0080
moOg00<0no_k0?ooo`3oool00P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0
e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd0
1@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWi`80moOg2@3oool0103>c/h0W9bL09bLW01>CTh40000
000300@4100820P020P80080a/K600<0hn?S0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo
0080oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`020?Og
m`040;Vi^@1kNg/0Ng]k03hn?P8000000P0Y:BT00`0M7Ad0410@010@40020000000305mOG`2m_Kd0
_Kfm00D0oooo00<0no_k0?Ogm`3gmoL00P3gmoL30=kNgPD0Q8B40`3Ng]h40?Ogm`030?_kn`3oool0
oooo00X0000000<0=SHf06][J`1[Jf/01@3oool30?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h5
08B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0202TY:@0301DE5@000000000000X0000000<05ADE
02TY:@0Y:BT01@3gmoL30=kNgPD0Q8B40P3Ng]h50?Ogm`<0oooo0P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`030;Vi^@1cLg<0Lg=c00D0:BTY00<0CTi>07=cL`1cLg<00P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kN
gP3Ng]h0inOW0P3_knl50?Ogm`80oooo0P3gmoL0101lO7`000000000001SHf<20<K6aP80000000<0
EeMG0:f][@2][Jd00P0820P00`24Q8@0oooo0?ooo`030?Ogm`L0oooo00<0moOg0>o_k`3_knl00P3N
g]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`020?ooo`040820P0000000000007QhN080kno_
0P1[Jf/00`1WIfL0Hf=S06=SH`0209bLW00306m_K`12@T80@T9200D0oooo00<0no_k0?Ogm`3gmoL0
0P3_knl30=kNgPD0Q8B40`3Ng]h20?Ogm`L0oooo00@0no_k0?Ogm`3gmoL0O7al0P0000020?Ogm`03
0?_kn`3oool0oooo00D0oooo203gmoL20=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo0080
S8b<00<0Fe]K02TY:@0Y:BT00P3oool0103kno/0moOg0?Ogm`3kno/20?ooo`80:BTY00<0Fe]K08b<
S02<S8`00P3gmoL00`3clo<0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo
00D0oooo00<0no_k0?Ogm`3gmoL00P1cLg<00`16ATH061PH01PH60050:f][@0306=SH`0H61P061PH
0080Jf][00<0/K6a0?Ogm`3gmoL00P3oool30>o_k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm
_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0
a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl50?Ogm`80oooo0P3gmoL0101l
O7`000000000001SHf<20<K6aP80000000<0EeMG0:f][@2][Jd00P0820P00`24Q8@0oooo0?ooo`03
0?Ogm`L0oooo00<0moOg0>o_k`3_knl00P3Ng]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`02
0?ooo`040820P0000000000007QhN080kno_0P1[Jf/00`1WIfL0Hf=S06=SH`0209bLW00306m_K`12
@T80@T9200D0oooo00<0no_k0?Ogm`3gmoL00P3_knl30=kNgPD0Q8B40`3Ng]h20?Ogm`L0oooo00@0
no_k0?Ogm`3gmoL0O7al0P0000020?Ogm`030?_kn`3oool0oooo00D0oooo203gmoL20=kNgPD0Q8B4
0`3Ng]h20?Ogm`030?_kn`3oool0oooo0080S8b<00<0Fe]K02TY:@0Y:BT00P3oool0103kno/0moOg
0?Ogm`3kno/20?ooo`80:BTY00<0Fe]K08b<S02<S8`00P3gmoL00`3clo<0kno_0>o_k`030=kNgPD0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P1cLg<00`16ATH0
61PH01PH60050:f][@0306=SH`0H61P061PH0080Jf][00<0/K6a0?Ogm`3gmoL00P3oool30>o_k`<0
g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
inOW0P3_knl50?Ogm`80oooo0P3gmoL0101lO7`000000000001SHf<20<K6aP80000000<0EeMG0:f]
[@2][Jd00P0820P00`24Q8@0oooo0?ooo`030?Ogm`L0oooo00<0moOg0>o_k`3_knl00P3Ng]h608B4
Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`020?ooo`040820P0000000000007QhN080kno_0P1[Jf/0
0`1WIfL0Hf=S06=SH`0209bLW00306m_K`12@T80@T9200D0oooo00<0no_k0?Ogm`3gmoL00P3_knl3
0=kNgPD0Q8B40`3Ng]h20?Ogm`L0oooo00@0no_k0?Ogm`3gmoL0O7al0P0000020?Ogm`030?_kn`3o
ool0oooo00D0oooo203gmoL20=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo0080S8b<00<0
Fe]K02TY:@0Y:BT00P3oool0103kno/0moOg0?Ogm`3kno/20?ooo`80:BTY00<0Fe]K08b<S02<S8`0
0P3gmoL00`3clo<0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00D0oooo
00<0no_k0?Ogm`3gmoL00P1cLg<00`16ATH061PH01PH60050:f][@0306=SH`0H61P061PH0080Jf][
00<0/K6a0?Ogm`3gmoL00P3oool30>o_k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd0
0`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3<c<`0a/K60<K6
aP050??cl`80Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<20?Ogm`L0no_k00@0VIVI03Hf=P0f=SH0
N7Qh0P2j^[X201DE5@0305eMG@2UYJD0YJFU00808B4Q00<0O7al0=KFeP3Fe]H01@3kno/00`3moOd0
oooo0?ooo`020?_kn`030?Ogm`3clo<0lo?c0080g]kN1P24Q8@20=[JfPD0moOg0P3kno/0101nOWh0
00000000001jNWX20??cl`80WIfM00<0KVi^03hn?P0n?Sh00P3:b/X00`1fMWH08B4Q024Q8@030?oo
o`80no_k00<0nOWi0?Ogm`3gmoL00P3clo<30=[JfP80Q8B40`20P8030=kNgP80lo?c1`3kno/0103i
nOT0moOg0?Ogm`1lO7`2000000D0no_k0P3oool00`3moOd0no_k0?_kn`050?_kn`030?Ogm`3clo<0
lo?c0080g]kN0`20P80208R8R0<0g]kN0P3clo<00`3gmoL0no_k0?_kn`020<K6aP03071`L00I6AT0
6ATI0080g]kN00@0kNg]0?_kn`3kno/0lO7a0P3WinL201TI6@0306i^KP32`/80`/;20080moOk00<0
mOGg0??cl`3clo<00`3Jf]X208B4Q0<0P8200P3Ng]h20??cl`030?Ogm`3kno/0no_k00D0no_k00<0
nOWi0?Ogm`3gmoL00P0n?Sh00`1IFET0Lg=c07=cL`020=;BdP040=CDe03Fe]H0e]KF0:FUY@80Lg=c
0P0j>SX00`2KVi/0no_k0?_kn`020?_kn`<0lo?c0`3Jf]X208R8R0D0lo?c0P3gmoL00`3MgMd0`/;2
0<;2`P030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36
a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`<0oooo0P3gmoL20?ooo`040;Fe
]@1[Jf/0Jf][08b<S080[Jf]0P0Y:BT00`1SHf<0W9bL09bLW00203Ti>@0307=cL`2][Jd0[Jf]00<0
oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`80g]kN1P24Q8@20=KFeP80oooo00<0no_k0?Ogm`3g
moL00P3gmoL0101lO7`000000000001lO7`20?Ogm`80c/k>00<0Lg=c01PH600H61P00P3gmoL00`1l
O7`00000000000030?ooo`L0moOg0`3Fe]H208B4Q0<0Ng]k0`3Ng]h20>o_k`X0moOg00<0O7al0000
000000000P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00D0oooo00<0moOg0>o_
k`3_knl00P3Ng]h307]kN`80S8b<0`3Ng]h20>o_k`030??cl`3gmoL0moOg0080oooo00<0Q8B400P8
200820P00P2m_Kd0103Ng]h0oooo0?ooo`3WinL20<k>cP8020P800<0P8200?Ogm`3gmoL00P3gmol0
0`3gmo/0moOg0?Ogm`030=KFeP80Q8B40`1kNg/20=kNgP80kno_00<0lo?c0?Ogm`3gmoL0203gmoL2
00P8200306][J`3>c/h0c/k>0080moOg00@0no_k0?ooo`3oool0inOW0P3>c/h200P8200308B4Q03o
ool0oooo00D0moOg0`3Fe]H208b<S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0/K6a
0=kNgP3Ng]h0jn_[103gmoL30?ooo`80moOg0P3oool0102e]KD0Jf][06][J`2<S8`20:f][@80:BTY
00<0Hf=S09bLW02LW9`00P0i>CT00`1cLg<0[Jf]0:f][@030?ooo`80moOg00<0no_k0?ooo`3oool0
1@3gmoL20=kNgPH0Q8B40P3Fe]H20?ooo`030?_kn`3gmoL0moOg0080moOg00@0O7al000000000000
O7al0P3gmoL20<k>cP0307=cL`0H61P061PH0080moOg00<0O7al0000000000000`3oool70?Ogm`<0
e]KF0P24Q8@307]kN`<0g]kN0P3_knl:0?Ogm`0307alO000000000000080oooo00<0no_k0?Ogm`3g
moL00P3oool00`3kno/0moOg0?Ogm`050?ooo`030?Ogm`3_knl0kno_0080g]kN0`1kNg/208b<S0<0
g]kN0P3_knl00`3clo<0moOg0?Ogm`020?ooo`0308B4Q00820P020P80080_Kfm00@0g]kN0?ooo`3o
ool0inOW0P3>c/h200P820030820P03gmoL0moOg0080moOo00<0moOk0?Ogm`3gmoL00`3Fe]H208B4
Q0<0Ng]k0P3Ng]h20>o_k`030??cl`3gmoL0moOg00P0moOg0P0820P00`1[Jf/0c/k>0<k>cP020?Og
m`040?_kn`3oool0oooo0>OWi`80c/k>0P0820P00`24Q8@0oooo0?ooo`050?Ogm`<0e]KF0P2<S8`7
0?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_
k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_303gmoL0
0`1lO7`000000000000206][J`0306=SH`1JFUX0FUYJ0080S8b<00<0U9BD09bLW02LW9`03@3gmoL2
0=KFePH0Q8B40P3Fe]H20>o_k`030??cl`3gmoL0moOg0080moOg00@0V9RH03Ti>@0i>CT0Jf][0P2L
W9`20?Ogm`030?_kn`3oool0oooo0080moOg00<0O7al0000000000001@3gmoL00`3kno/0oooo0?oo
o`020>o_k`<0e]KF1@24Q8@30=KFeP80kno_2P3gmoL00`1lO7`000000000000:0?Ogm`<0oooo0P3g
moL00`3clo<0kno_0>o_k`020=kNgPD0Q8B40`3Ng]h70?Ogm`030<;2`P2<S8`0S8b<0080BTY:00@0
XJ6Q0?Ogm`3gmoL0XJ6Q0P1:BTX207]kN`030;Vi^@3gmoL0moOg0080oooo00<0moOg0>o_k`3_knl0
0`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`080?Ogm`80000000<0O7al0?Ogm`3gmoL0
1@0000000`1lO7`0moOg0?Ogm`020000000307alO03gmoL0moOg00D0moOg0`3Fe]H208B4Q0L0oooo
00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3F
e]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl<0?Ogm`0307al
O000000000000080Jf][00<0Hf=S05YJFP1JFUX00P2<S8`00`2DU9@0W9bL09bLW00=0?Ogm`80e]KF
1P24Q8@20=KFeP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL0102HV9P0>CTi03Ti>@1[Jf/209bLW080
moOg00<0no_k0?ooo`3oool00P3gmoL00`1lO7`00000000000050?Ogm`030?_kn`3oool0oooo0080
kno_0`3Fe]H508B4Q0<0e]KF0P3_knl:0?Ogm`0307alO0000000000000X0moOg0`3oool20?Ogm`03
0??cl`3_knl0kno_0080g]kN1@24Q8@30=kNgPL0moOg00<0`/;208b<S02<S8`00P1:BTX0102QXJ40
moOg0?Ogm`2QXJ4204Y:BP80Ng]k00<0^KVi0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`030=KF
ePD0Q8B40P3Fe]H20>o_k`030??cl`3gmoL0moOg00P0moOg0P0000000`1lO7`0moOg0?Ogm`050000
000307alO03gmoL0moOg0080000000<0O7al0?Ogm`3gmoL01@3gmoL30=KFeP80Q8B41`3oool00`3N
g]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP03
0<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80moOg0`3_knl20?Og
m`80kno_00@0lo?c0?Ogm`3gmoL0V9RH0P0i>CT20:f][@0306=SH`0H61P061PH0080c/k>00<0IfMW
0000000000002P3gmoL00`3clo<0kno_0>o_k`020=KFePH0Q8B40P3Ng]h20=KFeP030>OWi`3gmoL0
moOg0080kno_00@0b/[:0:FUY@2UYJD0IfMW0P0Y:BT70?Ogm`0307alO0000000000000P0moOg0P3_
knl30=KFePD0Q8B40`3Fe]H20>o_k`80moOg00<0lo?c0>o_k`3_knl01@3gmoL00`1lO7`000000000
00050?Ogm`80000000<0O7al0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`020=KFeP<0Q8B40P1c
Lg<30=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`3[jn/0g]kN0=kNgP020000000406MWI`3>
c/h0c/k>06][J`8020P80P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_00<0e]KF
1@24Q8@20=KFeP80kno_00<0lo?c0?Ogm`3gmoL00`3_knl50?Ogm`8020P800<0Jf][0<k>cP3>c/h0
1@0000000`1WIfL0c/k>0<k>cP0200P820030820P03gmoL0moOg00D0kno_0`3Fe]H207=cL`L0moOg
00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>
c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?Ogm`<0kno_
0P3gmoL20>o_k`040??cl`3gmoL0moOg09RHV080>CTi0P2][Jd00`1SHf<061PH01PH60020<k>cP03
06MWI`000000000000X0moOg00<0lo?c0>o_k`3_knl00P3Fe]H608B4Q080g]kN0P3Fe]H00`3WinL0
moOg0?Ogm`020>o_k`040<[:bP2UYJD0YJFU06MWI`80:BTY1`3gmoL00`1lO7`00000000000080?Og
m`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?Ogm`030??cl`3_knl0kno_00D0moOg00<0O7al0000
000000001@3gmoL20000000307alO03gmoL0moOg00D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H308B4
Q080Lg=c0`3Ng]h20>o_k`030??cl`3gmoL0moOg0080moOg00<0jn_[0=kNgP3Ng]h00P000000101W
IfL0c/k>0<k>cP1[Jf/200P82080g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL00`3clo<0kno_0>o_k`03
0=KFePD0Q8B40P3Fe]H20>o_k`030??cl`3gmoL0moOg00<0kno_1@3gmoL200P8200306][J`3>c/h0
c/k>00D0000000<0IfMW0<k>cP3>c/h00P0820P00`20P800moOg0?Ogm`050>o_k`<0e]KF0P1cLg<7
0?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kN
gP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_0P3gmoL3
0>o_k`80moOg0P3_knl0103clo<0moOg0?Ogm`2HV9P203Ti>@80[Jf]00<0Hf=S01PH600H61P00P3>
c/h00`1WIfL000000000000:0?Ogm`030??cl`3_knl0kno_0080e]KF1P24Q8@20=kNgP80e]KF00<0
inOW0?Ogm`3gmoL00P3_knl0103:b/X0YJFU0:FUY@1WIfL202TY:@L0moOg00<0O7al000000000000
203gmoL20>o_k`<0e]KF1@24Q8@30=KFeP80kno_0P3gmoL00`3clo<0kno_0>o_k`050?Ogm`0307al
O0000000000000D0moOg0P0000000`1lO7`0moOg0?Ogm`050?Ogm`030??cl`3_knl0kno_0080e]KF
0`24Q8@207=cL`<0g]kN0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030>_[j`3Ng]h0g]kN00800000
00@0IfMW0<k>cP3>c/h0Jf][0P0820P20=kNgP030>_[j`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_
knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`030>o_k`D0moOg0P0820P00`1[Jf/0
c/k>0<k>cP050000000306MWI`3>c/h0c/k>008020P800<0P8200?Ogm`3gmoL01@3_knl30=KFeP80
Lg=c1`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102YZJT0c/k>
0<k>cP3Fe]H20=kNgPD0kno_103gmoL0103clo<0kno_0>o_k`3clo<40?Ogm`0307alO00000000000
0080g]kN00<0inOW0>o_k`3_knl00`3_knl50?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P3Fe]H608B4
Q080e]KF1@3_knl50?Ogm`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl00P3_knl00`3c
lo<0moOg0?Ogm`030?Ogm`D0kno_0P3Ng]h30=KFePD0Q8B40`3Fe]H20=kNgPD0moOg0P3_knl0103c
lo<0moOg0?Ogm`1lO7`200000080kno_00<0lo?c0?Ogm`3gmoL00P0000000`1hN7P0kno_0>o_k`08
0>o_k`80e]KF1@24Q8@30<k>cPD0moOg0P3_knl00`3clo<0moOg0?Ogm`0206][J`040492@P0H61P0
61PH03Ti>@80FUYJ0P3gmoL00`3clo<0kno_0>o_k`020>o_k`030>OWi`3Ng]h0g]kN00<0e]KF1@24
Q8@20=KFeP80g]kN00<0jn_[0?Ogm`3gmoL00`3gmoL20>o_k`030??cl`3gmoL0moOg0080Jf][00<0
@T9201PH600H61P00P2UYJD0102YZJT0[Jf]0:f][@1SHf<201PH6080Jf][00<0[Jf]0>o_k`3_knl0
1@3_knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>
0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3g
moL00`3clo<0kno_0>o_k`0208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN1@3_knl40?Ogm`040??c
l`3_knl0kno_0??cl`@0moOg00<0O7al0000000000000P3Ng]h00`3WinL0kno_0>o_k`030>o_k`D0
moOg0P3_knl00`3WinL0g]kN0=kNgP020=KFePH0Q8B40P3Fe]H50>o_k`D0moOg00<0lo?c0>o_k`3_
knl00P3gmoL00`3clo<0kno_0>o_k`020>o_k`030??cl`3gmoL0moOg00<0moOg1@3_knl20=kNgP<0
e]KF1@24Q8@30=KFeP80g]kN1@3gmoL20>o_k`040??cl`3gmoL0moOg07alO08000000P3_knl00`3c
lo<0moOg0?Ogm`020000000307QhN03_knl0kno_00P0kno_0P3Fe]H508B4Q0<0c/k>1@3gmoL20>o_
k`030??cl`3gmoL0moOg0080Jf][00@0@T9201PH600H61P0>CTi0P1JFUX20?Ogm`030??cl`3_knl0
kno_0080kno_00<0inOW0=kNgP3Ng]h00`3Fe]H508B4Q080e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`03
0?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P1[Jf/00`12@T8061PH01PH60020:FUY@040:VYZ@2][Jd0
[Jf]06=SH`8061PH0P1[Jf/00`2][Jd0kno_0>o_k`050>o_k`<0g]kN0P24Q8@20>o_k`030??cl`3g
moL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J103N
g]h30>o_k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP020>o_k`0308b<S00Y:BT0:BTY0080U9BD00<0
`/;20>o_k`3_knl02P3_knl00`3WinL0g]kN0=kNgP020=kNgP<0Ng]k00<0P82008B4Q024Q8@0103F
e]H00`3Jf]X0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`@0kno_00<0inOW0=kNgP3Ng]h0
0P3_knl00`3WinL0g]kN0=kNgP080>o_k`80g]kN0`3Fe]H207]kN`<0Q8B41@3Fe]H20=kNgP030>OW
i`3_knl0kno_00l0000000<0N7Qh0>o_k`3_knl00`3_knl20?Ogm`030>_[j`3Ng]h0g]kN0080e]KF
0`1kNg/208B4Q0D0e]KF00<0f][J0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP020=KFeP0406][
J`000000000005mOG`80_Kfm0P3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00<0
e]KF0P1kNg/308B4Q0@0e]KF00<0f][J0=kNgP3Ng]h00`3_knl20=kNgP030>OWi`3_knl0kno_0080
kno_00<0ZJVY06=SH`1SHf<01@0Y:BT00`1:BTX0Jf][06][J`020>o_k`030??cl`3gmoL0moOg0080
kno_0`3Ng]h30=KFeP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102][Jd0e]KF
0=KFeP3Jf]X40=kNgP<0kno_0P3Ng]h50>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0S8b<02TY:@0Y
:BT00P2DU9@00`32`/80kno_0>o_k`0:0>o_k`030>OWi`3Ng]h0g]kN0080g]kN0`1kNg/00`20P800
Q8B408B4Q0040=KFeP030=[JfP3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW103_knl00`3W
inL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00P0kno_0P3Ng]h30=KFeP80Ng]k0`24Q8@50=KF
eP80g]kN00<0inOW0>o_k`3_knl03`0000000`1hN7P0kno_0>o_k`030>o_k`80moOg00<0jn_[0=kN
gP3Ng]h00P3Fe]H307]kN`80Q8B41@3Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN
0080e]KF00@0Jf][000000000000GemO0P2m_Kd20>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW
0=kNgP3Ng]h00`3Fe]H207]kN`<0Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP030>o_k`80g]kN00<0inOW
0>o_k`3_knl00P3_knl00`2YZJT0Hf=S06=SH`0502TY:@0304Y:BP1[Jf/0Jf][0080kno_00<0lo?c
0?Ogm`3gmoL00P3_knl30=kNgP<0e]KF0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>00<0b<S80<;2`P32`/801@3kno/208B4
Q0040:^[Z`3Bd]80d];B0=SHf0@0g]kN0`3WinL20=kNgP80kno_00@0jn_[0>OWi`3WinL0hn?S0P3N
g]h20>o_k`0309^KV`16ATH0ATI60080Lg=c00<0[Jf]0>OWi`3WinL00`3_knl20>OWi`030>g]k@3c
lo<0lo?c0080inOW00<0hn?S0=kNgP3Ng]h00P3Fe]H30820P00308:2PP24Q8@0Q8B40080d];B0P3J
f]X00`3Lg=`0g]kN0=kNgP020>OWi`040>?Sh`3Ng]h0g]kN0>OWi`80kno_0P3WinL00`3Shn<0g]kN
0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0inOW00<0jn_[0>o_k`3_knl00P3Ng]h30=;BdP80P820
0`24Q8@30=;BdP80f][J0P3Ng]h00`3Shn<0inOW0>OWi`0206m_K`0407AdM01hN7P0N7Qh07AdM0@0
Kfm_00<0M7Ad07QhN01hN7P00P1_Kfl00`2[Zj/0inOW0>OWi`030>OWi`80lo?c00<0jNWY0=kNgP3N
g]h00P3Bd]830820P080Q8B40`3Bd]820=[JfP030=cLg03Ng]h0g]kN0080inOW00<0hn?S0=kNgP3N
g]h00P3Shn<0102YZJT0Kfm_06m_K`2OWil20<k>cP80lo?c00<0jNWY0=kNgP3Ng]h00P3WinL00`3S
hn<0g]kN0=kNgP030=;BdP80P8200`24Q8@20=;BdP80f][J00<0g=cL0=kNgP3Ng]h00`3WinL20=kN
gP030>OWi`3_knl0kno_0080inOW00<0a<C40:6QX@2QXJ400P2<S8`01028R8P0Q8B408B4Q02EUID2
0:FUY@80inOW00<0kNg]0??cl`3clo<00P3WinL30=kNgP<0d];B0P20P8070?_kn`030=oOg`32`/80
`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm
_@2m_Kd01@3oool208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kNgP03
0=kNgP80kno_00<0ZJVY06=SH`1SHf<00P1BDU800`2HV9P0g]kN0=kNgP030>o_k`80g]kN00<0jn_[
0?Ogm`3gmoL01@3Ng]h20<k>cPH0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl0
0`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3>c/h508B4Q0<0c/k>2@3Ng]h0
103WinL0kno_0>o_k`3WinL40=kNgP030>OWi`3_knl0kno_00P0g]kN0P3_knl00`3WinL0g]kN0=kN
gP020<k>cPD0Q8B40`3>c/h:0=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20?Ogm`030>_[j`3N
g]h0g]kN00D0g]kN0`3>c/h508B4Q080c/k>2P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0
inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0c/k>0P24Q8@70?ooo`030=kNgP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K6
0;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kN
gP030=kNgP80kno_00<0ZJVY06=SH`1SHf<00P1BDU800`2HV9P0g]kN0=kNgP030>o_k`80g]kN00<0
jn_[0?Ogm`3gmoL01@3Ng]h20<k>cPH0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_
knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3>c/h508B4Q0<0c/k>2@3N
g]h0103WinL0kno_0>o_k`3WinL40=kNgP030>OWi`3_knl0kno_00P0g]kN0P3_knl00`3WinL0g]kN
0=kNgP020<k>cPD0Q8B40`3>c/h:0=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20?Ogm`030>_[
j`3Ng]h0g]kN00D0g]kN0`3>c/h508B4Q080c/k>2P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_
00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0c/k>0P24Q8@70?ooo`030=kN
gP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>00<0
b<S80<;2`P32`/801@3kno/208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Jf]X50=kNgP80inOW
00@0hn?S0=kNgP3Ng]h0g=cL0P3Jf]X20>?Sh`030<;2`P2QXJ40XJ6Q0080U9BD00<0^KVi0=kNgP3N
g]h00`3WinL20=kNgP030>GUi@3[jn/0jn_[00D0f][J0P3>c/h608B4Q080c/k>0P3Ng]h00`3Lg=`0
f][J0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[JfP3Jf]X00P3Shn<00`3QhN40
g]kN0=kNgP050=[JfP030>7Qh@3WinL0inOW0080f][J0`3>c/h508B4Q0<0c/k>0P3Ng]h20=[JfP03
0=cLg03Ng]h0g]kN0080g]kN00@0hn?S0>OWi`3WinL0hn?S0P3Ng]h20=[JfP030=oOg`3Shn<0hn?S
0080g]kN00<0g=cL0=[JfP3Jf]X00`3Ng]h20>OWi`030>7Qh@3Jf]X0f][J0080c/k>1@24Q8@30<k>
cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h20>OWi`040>?Sh`3Ng]h0g]kN0=cLg080f][J0P3WinL0
0`3QhN40f][J0=[JfP050=[JfP<0c/k>1@24Q8@20<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h0
0`3Shn<0inOW0>OWi`020=kNgP030=cLg03Jf]X0f][J0080hn?S00@0hN7Q0=kNgP3Ng]h0g=cL0P3J
f]X20=kNgP030>?Sh`3WinL0inOW0080g]kN0`3Jf]X30<k>cP80Q8B41`3kno/00`3Lg=`0_Kfm0;fm
_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0
a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h00`3Jf]X0e]KF0=KF
eP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80c/k>1P24
Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3N
g]h0g]kN00D0e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H30<k>cPD0Q8B40`3>c/h20=kNgP80e]KF00<0
f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3Fe]H01@3Ng]h00`3Jf]X0e]KF0=KF
eP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H02P3F
e]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Jf]X0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36
a/H0a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h00`3Jf]X0e]KF
0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80c/k>
1P24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[J
fP3Ng]h0g]kN00D0e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H30<k>cPD0Q8B40`3>c/h20=kNgP80e]KF
00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3Fe]H01@3Ng]h00`3Jf]X0e]KF
0=KFeP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H0
2P3Fe]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H0
0P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Jf]X0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0kno_0P1kNg/0102][Jd0g]kN0=kNgP3[jn/N0?Ogm`80oooo00<0no_k0?Ogm`3g
moL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Q8B400<0P82007]kN`1kNg/00P3Ng]hO0?Ogm`80
kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]hN0?Ogm`030??cl`3_knl0kno_0080g]kN0`24Q8@207]kN`<0
g]kN6@3gmoL00`3clo<0kno_0>o_k`030=kNgP80Q8B40`1kNg/20=kNgQl0moOg0P3oool30>o_k`<0
g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Ng]k00@0[Jf]0=kNgP3Ng]h0
jn_[7P3gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q003
0820P01kNg/0Ng]k0080g]kN7`3gmoL20>o_k`<0g]kN0P24Q8@307]kN`<0g]kN7P3gmoL00`3clo<0
kno_0>o_k`020=kNgP<0Q8B40P1kNg/30=kNgQT0moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0
Ng]k0P3Ng]hO0?Ogm`80oooo0`3_knl30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0
c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b<S80;fm_@2m_Kd0
0P3gmoL00`3emOD0lo?c0??cl`020820P0040;Jf]P3[jn/0jn_[0??clah0no_k0P3oool00`3moOd0
no_k0?_kn`020?ooo`030?_kn`3gmoL0moOg0080kno_0`24Q8@00`22PX80P8200820P0020>OWial0
no_k0P3gmoL30>o_k`80Q8B40`20P8030>OWiah0no_k00<0nOWi0?Ogm`3gmoL00P3_knl308B4Q080
P8200`3WinLI0?_kn`030?Win@3gmoL0moOg00<0kno_0P24Q8@30820P080inOW7`3kno/20?ooo`<0
moOg0`3_knl208B4Q0D0lo?c0P3gmoL00`3MgMd0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL0
0P24Q8@0102n_[h0moOg0?Ogm`3kno/Z0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0
Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?ooo`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo
00<0no_k0?Ogm`3gmoL00P24Q8@0102n_[h0moOg0?Ogm`3kno/Z0?ooo`H0Q8B40P3_knlT0?ooo`D0
Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?ooo`80Q8B41`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:
bP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`0208b<S0<0Q8B40P1kNg/208B4Q00408R8
R02<S8`0S8b<08R8R0`0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@308b<S003
08R8R024Q8@0Q8B40080Q8B40P1kNg/00`24Q8@0S8b<08b<S00208B4Q0040820P01kNg/0Ng]k0820
P140Q8B400<0P82007]kN`1kNg/00P24Q8@308b<S0P0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4
Q024Q8@04024Q8@207]kN`0308B4Q02<S8`0S8b<00L0Q8B40`2<S8`207]kN`030820P024Q8@0Q8B4
0080Q8B400<0O7al07=cL`1cLg<04P24Q8@308b<S0L0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4
Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k07]kN`0208b<S0P0Q8B41`3oool00`3N
g]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP03
0<[:bP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`0208b<S0<0Q8B40P1kNg/208B4Q004
08R8R02<S8`0S8b<08R8R0`0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@308b<
S00308R8R024Q8@0Q8B40080Q8B40P1kNg/00`24Q8@0S8b<08b<S00208B4Q0040820P01kNg/0Ng]k
0820P140Q8B400<0P82007]kN`1kNg/00P24Q8@308b<S0P0Q8B40P1kNg/508B4Q080Ng]k00<0P820
08B4Q024Q8@04024Q8@207]kN`0308B4Q02<S8`0S8b<00L0Q8B40`2<S8`207]kN`030820P024Q8@0
Q8B40080Q8B400<0O7al07=cL`1cLg<04P24Q8@308b<S0L0Q8B40P1kNg/00`20P800Q8B408B4Q003
08B4Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k07]kN`0208b<S0P0Q8B41`3oool0
0`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;B
dP030<S8b02m_Kd0_Kfm00D0no_k0P20P8001022PX80Q8B408B4Q022PX820820P0D0Q8B41020P800
1024Q8@0R8R808R8R026QXH708B4Q080P82000<0PX:208B4Q024Q8@01@20P8000`22PX80Q8B408B4
Q0050820P080Q8B40`28R8P00`24Q8@0P8200820P00208B4Q080P82000<0PX:208B4Q024Q8@00P24
Q8@00`22PX80P8200820P0030820P0X0Q8B40`20P80208B4Q00308:2PP20P800P8200080P8200`28
R8P208B4Q0<0P8200`24Q8@40820P00308:2PP24Q8@0Q8B400D0P82000<0PX:208B4Q024Q8@01`24
Q8@00`22PX80P8200820P00308B4Q080P82000<0PX:208B4Q024Q8@01@24Q8@20820P0<0R8R81@20
P80208B4Q0030820P01lO7`0O7al0080P82000<0PX:208B4Q024Q8@02024Q8@50820P0<0R8R80P24
Q8@30820P080Q8B41@20P80308B4Q0D0P8202P24Q8@00`22PX80P8200820P00208B4Q00308:2PP20
P800P8200080Q8B40`20P80508B4Q0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Ng]k00<0P820
08B4Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k00<0P820
08B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/01@24Q8@0
0`20P800Ng]k07]kN`0408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/02P24Q8@3
07]kN`D0Q8B40P1kNg/508B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P820
07]kN`1kNg/0P8202@24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1k
Ng/508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q0D0Ng]k1@24
Q8@307]kN`@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q0030820P01k
Ng/0Ng]k00D0Q8B41@1kNg/508B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Ng]k00<0P820
08B4Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k00<0P820
08B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/01@24Q8@0
0`20P800Ng]k07]kN`0408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/02P24Q8@3
07]kN`D0Q8B40P1kNg/508B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P820
07]kN`1kNg/0P8202@24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1k
Ng/508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q0D0Ng]k1@24
Q8@307]kN`@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q0030820P01k
Ng/0Ng]k00D0Q8B41@1kNg/508B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a
0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3g
moL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h70?Ogm`030?_kn`3o
ool0oooo00<0oooo1`3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg0`3N
g]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_kn`3gmoL0moOg00D0moOg0P3oool00`3kno/0moOg0?Og
m`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN1@3gmoL70?ooo`030?_kn`3g
moL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0oooo1`3g
moL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0L0kno_
00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_k
n`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg
0?Ogm`020=kNgPH0Q8B40P3Ng]h70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo
0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_k
n`3gmoL0moOg00D0moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P3Ng]h508B4Q0<0g]kN1@3gmoL70?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool0
1@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`03
0?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B4
00@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3o
ool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h70?Ogm`03
0?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo0080
moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_kn`3gmoL0moOg00D0moOg0P3oool00`3kno/0
moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN1@3gmoL70?ooo`03
0?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0
oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4
Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0kno_9@3oool00`3k
no/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]hO0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN7P3oool00`3k
no/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]hI0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kN
gR40oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102e]KD0
g]kN0=kNgP3_knlU0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgQl0oooo0P3gmoL30=kN
gPD0Q8B40`3Ng]hN0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0no_k0?Og
m`3gmoL00`3Ng]h508B4Q080g]kN8@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b<S80;fm_@2m
_Kd01@3kno/208R8R0040;>c/`3Ng]h0g]kN0>o_kbD0oooo00<0oOgm0?_kn`3kno/00P3WinL608B4
Q080g]kN7`3oool20?_kn`<0inOW1@24Q8@30=kNgQh0oooo00<0oOgm0?_kn`3kno/00P3[jn/508B4
Q0<0g]kN6@3oool00`3moOd0no_k0?_kn`030>OWi`D0Q8B40P3Ng]hQ0?ooo`<0no_k0`3WinL208B4
Q0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_:03oool20>o_
k`H0Q8B40P3Ng]hQ0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3gmoL508B4Q0<0g]kN703oool30>o_
k`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q004
0;6a/@3Ng]h0g]kN0>o_kbP0oooo0P3_knl608B4Q080g]kN8@3oool30>o_k`D0Q8B40`3Ng]hQ0?oo
o`80moOg1@24Q8@30=kNgQ`0oooo0`3_knl508B4Q080g]kN903oool30>o_k`80Q8B41`3oool00`3S
hn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Og
m`3gmoL00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4
Q0<0g]kN303oool00`2HV9P0<C4a034a<@020;Fe]@030=[JfP3oool0oooo00d0oooo0P3Ng]h508B4
Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`050?ooo`80U9BD00@0Q8B407=cL`1cLg<0^KVi2@3oool0
0`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h:0?ooo`030:VYZ@1BDU80DU9B0080U9BD00<0b/[:
0?ooo`3oool00P3_knl01028R8P08B4Q024Q8@0A4A4200000080Lg=c00<0^KVi0?ooo`3oool00P3o
ool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Og
m`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0
g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3o
ool0oooo01X0oooo0P3gmoL30=kNgPD0Q8B40`3Ng]h<0?ooo`0309RHV00a<C40<C4a0080]KFe00<0
f][J0?ooo`3oool03@3oool20=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo00D0oooo0P2D
U9@01024Q8@0Lg=c07=cL`2i^KT90?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgPX0oooo
00<0ZJVY059BDP1BDU800P2DU9@00`3:b/X0oooo0?ooo`020>o_k`0408R8R00Q8B408B4Q014A4@80
00000P1cLg<00`2i^KT0oooo0?ooo`020?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m
_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;2
0<;2`P050??cl`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080
g]kN1P24Q8@20=kNgP80lo?c00<0nOWi0?ooo`3oool06P3oool20?Ogm`<0g]kN1@24Q8@30=kNgP80
no_k2P3oool00`2MWId0>SXj03Xj>P020:6QX@030=3@d03oool0oooo00X0oooo00<0oOgm0?_kn`3k
no/00P3Ng]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`050?ooo`80[Jf]00@0OWin04i>CP1>
CTh0YjNW2@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?_kn`030?gmo@3oool0oooo
00D0oooo00<0e=CD0:VYZ@2YZJT00P1[Jf/00`2MWId0c/k>0<k>cP020<K6aP0407IfMP0U9BD09BDU
05=CD`80P8200P2i^KT00`3Lg=`0oooo0?ooo`020?ooo`<0moOg0`3Ng]h208B4Q0D0lo?c0P3gmoL0
0`3Jf]X0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>
cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k
0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_knl00`3gmoL0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h5
08B4Q0<0g]kN0P3gmoL:0?ooo`030:6QX@12@T80@T920080S8b<00<0a/K60?ooo`3oool02P3oool0
0`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo00D0oooo0P36a/H0
101hN7P0:BTY02TY:@2DU9@90?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgP80moOg00<0
no_k0?ooo`3oool0203oool20492@P0306m_K`2LW9`0W9bL0080W9bL00@0Hf=S02TY:@0Y:BT0U9BD
2@3oool30?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0
/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80kno_
00<0moOg0?ooo`3oool06P3oool20?Ogm`<0g]kN1@24Q8@30=kNgP80moOg2P3oool00`2QXJ40@T92
0492@P0208b<S0030<K6aP3oool0oooo00X0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN
0P3gmoL00`3kno/0oooo0?ooo`050?ooo`80a/K600@0N7Qh02TY:@0Y:BT0U9BD2@3oool00`3kno/0
moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00P0oooo0P12@T800`1_Kfl0
W9bL09bLW00209bLW00406=SH`0Y:BT0:BTY09BDU0T0oooo0`3gmoL30=kNgP80Q8B41@3_knl20?Og
m`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg0`3oool20?Og
m`80oooo00@0e]KF0:f][@2][Jd0Fe]K0P0820P20000000301DE5@0Y:BT0:BTY0080a/K600<0hn?S
0?ooo`3oool0203oool50?Ogm`80g]kN1P24Q8@20=kNgPD0oooo0P3gmoL00`3kno/0oooo0?ooo`03
0?ooo`8061PH00<030`<0000000000000P1:BTX00`2@T900e]KF0=KFeP030?ooo`80moOg00<0no_k
0?ooo`3oool00P3gmoL30=kNgP80Q8B40`1kNg/30=kNgP@0moOg00<0no_k0?ooo`3oool00P3oool0
102m_Kd0Ng]k07]kN`0n?Sh40000000301DE5@0Y:BT0:BTY0080kno_00<0lo?c0?Ogm`3gmoL01@3o
ool00`3gmoL0kno_0>o_k`020=kNgP<0Ng]k0P2<S8`30=kNgPD0moOg0P3oool00`36a/H0S8b<08b<
S00200P8200400@410000000000001DE5@80:BTY0P3_knl00`3gmoL0oooo0?ooo`020?ooo`030?_k
n`3gmoL0moOg00<0g]kN0P24Q8@307]kN`80g]kN1@3gmoL80?ooo`80kno_00<0R8R8024Q8@0Q8B40
0P12@T80101KFe/0Lg=c07=cL`2i^KT70?ooo`D0moOg0`3Ng]h208b<S0L0moOg00<0gmoO0<K6aP36
a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K6
0<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL30?ooo`80moOg0P3oool0103Fe]H0
[Jf]0:f][@1KFe/200P82080000000<05ADE02TY:@0Y:BT00P36a/H00`3Shn<0oooo0?ooo`080?oo
o`D0moOg0P3Ng]h608B4Q080g]kN1@3oool20?Ogm`030?_kn`3oool0oooo00<0oooo0P0H61P00`0<
30`000000000000204Y:BP03092@T03Fe]H0e]KF00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?Og
m`<0g]kN0P24Q8@307]kN`<0g]kN103gmoL00`3kno/0oooo0?ooo`020?ooo`040;fm_@1kNg/0Ng]k
03hn?P@0000000<05ADE02TY:@0Y:BT00P3_knl00`3clo<0moOg0?Ogm`050?ooo`030?Ogm`3_knl0
kno_0080g]kN0`1kNg/208b<S0<0g]kN1@3gmoL20?ooo`030<K6aP2<S8`0S8b<008020P800@010@4
0000000000005ADE0P0Y:BT20>o_k`030?Ogm`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL00`3N
g]h208B4Q0<0Ng]k0P3Ng]h50?Ogm`P0oooo0P3_knl00`28R8P08B4Q024Q8@020492@P0405]KF`1c
Lg<0Lg=c0;Vi^@L0oooo1@3gmoL30=kNgP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24
Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg1@3oool20?Ogm`040820P00820P020P8059BDP80
W9bL0P3oool00`2i^KT0Lg=c07=cL`0202TY:@0309BDU03oool0oooo00X0moOg00<0no_k0?ooo`3o
ool00P3Fe]H608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`080?ooo`8020P800<0Lg=c0=kNgP3N
g]h00P2m_Kd00`20P800@T920492@P050?Ogm`030?_kn`3oool0oooo0080kno_0`3Ng]h508B4Q0<0
g]kN0P3gmoL70?ooo`040820P0000000000003hn?P80Ng]k0P0i>CT00`1FEUH0Lg=c07=cL`0203Ti
>@0309RHV03gmoL0moOg00<0oooo1@3gmoL20=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo
0080oooo00<0P8200000000000000P2DU9@0101OGel0:BTY02TY:@1:BTX206][J`80BTY:00<0XJ6Q
0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0
oooo00X0oooo00<0kno_0=kNgP3Ng]h00P0820P0101BDU80W9bL09bLW03:b/X20?Ogm`80oooo00<0
no_k0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0
102a/K40g]kN0=kNgP3WinL20>o_k`80moOg1@3oool20?Ogm`040820P00820P020P8059BDP80W9bL
0P3oool00`2i^KT0Lg=c07=cL`0202TY:@0309BDU03oool0oooo00X0moOg00<0no_k0?ooo`3oool0
0P3Fe]H608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`080?ooo`8020P800<0Lg=c0=kNgP3Ng]h0
0P2m_Kd00`20P800@T920492@P050?Ogm`030?_kn`3oool0oooo0080kno_0`3Ng]h508B4Q0<0g]kN
0P3gmoL70?ooo`040820P0000000000003hn?P80Ng]k0P0i>CT00`1FEUH0Lg=c07=cL`0203Ti>@03
09RHV03gmoL0moOg00<0oooo1@3gmoL20=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo0080
oooo00<0P8200000000000000P2DU9@0101OGel0:BTY02TY:@1:BTX206][J`80BTY:00<0XJ6Q0?Og
m`3gmoL00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo
00X0oooo00<0kno_0=kNgP3Ng]h00P0820P0101BDU80W9bL09bLW03:b/X20?Ogm`80oooo00<0no_k
0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a
/K40g]kN0=kNgP3WinL20>o_k`80moOg1@3oool20?Ogm`040820P00820P020P8059BDP80W9bL0P3o
ool00`2i^KT0Lg=c07=cL`0202TY:@0309BDU03oool0oooo00X0moOg00<0no_k0?ooo`3oool00P3F
e]H608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`080?ooo`8020P800<0Lg=c0=kNgP3Ng]h00P2m
_Kd00`20P800@T920492@P050?Ogm`030?_kn`3oool0oooo0080kno_0`3Ng]h508B4Q0<0g]kN0P3g
moL70?ooo`040820P0000000000003hn?P80Ng]k0P0i>CT00`1FEUH0Lg=c07=cL`0203Ti>@0309RH
V03gmoL0moOg00<0oooo1@3gmoL20=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo0080oooo
00<0P8200000000000000P2DU9@0101OGel0:BTY02TY:@1:BTX206][J`80BTY:00<0XJ6Q0?Ogm`3g
moL00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00X0
oooo00<0kno_0=kNgP3Ng]h00P0820P0101BDU80W9bL09bLW03:b/X20?Ogm`80oooo00<0no_k0?Og
m`3gmoL01@3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102a/K40
g]kN0=kNgP3YjNT20??cl`80moOg0`3kno/20?ooo`80moOg00@0OWin00@4100410@0IfMW0P3:b/X2
0?_kn`030=[JfP2i^KT0^KVi00805ADE00<0R8R80?_kn`3kno/00`3kno/20?Ogm`030?Win@3kno/0
no_k00D0no_k0P3Jf]X608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`080?_kn`80<C4a00<0Lg=c
0;Fe]@2e]KD00P3Ng]h00`2n_[h0WIfM09fMW@030?Ogm`D0no_k0P3clo<30=kNgPD0Q8B40`3Jf]X2
0?Ogm`L0no_k00@0OWin000000000000EeMG0P2][Jd201dM7@0306UYJ@2e]KD0]KFe00807AdM00<0
S8b<0?_kn`3kno/00`3kno/20?Ogm`030?Gem@3clo<0lo?c0080f][J1@24Q8@30=kNgP80lo?c00<0
moOg0?_kn`3kno/00P3oool00`20P8000000000000020<K6aP0407QhN00Y:BT0:BTY05]KF`80S8b<
0P0U9BD00`2@T900no_k0?_kn`020?_kn`030?Ogm`3clo<0lo?c00<0g]kN1@24Q8@20=[JfP80moOg
00<0nOWi0?_kn`3kno/02P3kno/00`3emOD0kno_0>o_k`0200P8200403Hf=P1SHf<0Hf=S0:^[Z`80
lo?c1@3kno/20?Ogm`<0lo?c0`3Ng]h208B4Q0L0no_k00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B4
00@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL20?ooo`80moOg00@0O7al000000000000O7al103gmoL00`3k
no/0oooo0?ooo`020000000307alO03gmoL0moOg00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?oo
o`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL0203gmoL205YJ
FP0307=cL`2<S8`0S8b<0080oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg
0080moOg0`3Ng]h508B4Q0<0e]KF2@3gmoL0101lO7`000000000001_Kfl20=kNgP80000000<0O7al
0?Ogm`3gmoL00P0000000`20P800oooo0?ooo`050?Ogm`030??cl`3_knl0kno_0080e]KF1@24Q8@3
0=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3oool00`20P8000000000000020?Ogm`04092@T00Y:BT0
:BTY06][J`80[Jf]0P0000000`20P800oooo0?ooo`050?Ogm`<0g]kN1@24Q8@20=KFePl0moOg00<0
no_k0?ooo`3oool00P0820P0100I6AT0:BTY02TY:@2<S8`20>o_k`80moOg00<0no_k0?ooo`3oool0
0P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3N
g]h0g]kN0>_[j`L0moOg0P3oool20?Ogm`0407alO0000000000007alO0@0moOg00<0no_k0?ooo`3o
ool00P0000000`1lO7`0moOg0?Ogm`030?ooo`80moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0
moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg00P0moOg0P1JFUX00`1cLg<0
S8b<08b<S0020?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0
g]kN1@24Q8@30=KFePT0moOg00@0O7al000000000000Kfm_0P3Ng]h20000000307alO03gmoL0moOg
0080000000<0P8200?ooo`3oool01@3gmoL00`3clo<0kno_0>o_k`020=KFePD0Q8B40`3Ng]h20>o_
k`030??cl`3gmoL0moOg0080oooo00<0P8200000000000000P3gmoL0102@T900:BTY02TY:@1[Jf/2
0:f][@80000000<0P8200?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Fe]H?0?Ogm`030?_kn`3oool0
oooo008020P800@06ATI02TY:@0Y:BT0S8b<0P3_knl20?Ogm`030?_kn`3oool0oooo0080moOg0`3_
knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0
102][Jd0e]KF0=KFeP3Shn<20>o_k`T0moOg00@0T92@02TY:@0Y:BT0BTY:0P1[Jf/20?Ogm`030<[:
bP2LW9`0W9bL0080Hf=S00<0[Jf]0?Ogm`3gmoL02P3gmoL00`3clo<0kno_0>o_k`020=KFePH0Q8B4
0P3Ng]h20>o_k`030??cl`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL00`3gmoL20<K6aP0307Qh
N00Y:BT0:BTY00d0moOg0P3_knl30=KFePD0Q8B40`3Ng]h20>o_k`80oooo00<0no_k0?Ogm`3gmoL0
0P3gmoL0102MWId0@T920492@P1GEeL206][J`80>CTi00<0FUYJ07]kN`1kNg/00P0000000`1lO7`0
moOg0?Ogm`050?Ogm`030??cl`3_knl0kno_0080e]KF1@24Q8@30=KFePL0moOg00<0YJFU059BDP1B
DU800P2m_Kd0102DU9@0Jf][06][J`1SHf<205YJFP80000000<0O7al0?Ogm`3gmoL00P3gmoL00`3c
lo<0kno_0>o_k`030=KFePD0Q8B40P3Ng]h20>o_k`030?Ogm`3oool0oooo00D0moOg00<0no_k0?oo
o`3oool00P3gmoL00`3[jn/0g]kN0=kNgP020000000405MGE`2][Jd0[Jf]07=cL`80>CTi1`3gmoL3
0>o_k`<0g]kN0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h2
0>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Og
m`030??cl`3_knl0kno_0080Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl90?Ogm`04092@T00Y:BT0
:BTY04Y:BP80Jf][0P3gmoL00`3:b/X0W9bL09bLW00206=SH`030:f][@3gmoL0moOg00X0moOg00<0
lo?c0>o_k`3_knl00P3Fe]H608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`020?ooo`030?_kn`3g
moL0moOg00<0moOg0P36a/H00`1hN7P0:BTY02TY:@0=0?Ogm`80kno_0`3Fe]H508B4Q0<0g]kN0P3_
knl20?ooo`030?_kn`3gmoL0moOg0080moOg00@0WIfM0492@P12@T80EeMG0P1[Jf/203Ti>@0305YJ
FP1kNg/0Ng]k0080000000<0O7al0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`020=KFePD0Q8B4
0`3Fe]H70?Ogm`030:FUY@1BDU80DU9B0080_Kfm00@0U9BD06][J`1[Jf/0Hf=S0P1JFUX200000003
07alO03gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl00`3Fe]H508B4Q080g]kN0P3_knl00`3gmoL0
oooo0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg00<0jn_[0=kNgP3Ng]h00P000000101GEeL0
[Jf]0:f][@1cLg<203Ti>@L0moOg0`3_knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_
k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg0`3_knl20?Og
m`80kno_00@0inOW0=kNgP3Ng]h0S8b<0P0i>CT:000000d0moOg0P3Ng]h308B4Q0030820P01kNg/0
Ng]k0080e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`050?Ogm`0307alO0000000000000X000002P3gmoL3
0=KFeP80Ng]k0`24Q8@30=KFeP80kno_1@3gmoL20>o_k`040>OWi`3Ng]h0g]kN08b<S080>CTi1@00
000208b<S0030<;2`P3gmoL0moOg00D0oooo00<0moOg0>o_k`3_knl00P3Fe]H308B4Q080Ng]k0`3F
e]H20>o_k`030??cl`3gmoL0moOg0080moOg00<0jn_[0=kNgP3Ng]h00P1[Jf/0102MWId0c/k>0<k>
cP1WIfL200000080FUYJ00<0ZJVY0?Ogm`3gmoL01@3gmoL30=KFeP80Ng]k0`24Q8@20=KFeP80kno_
00<0lo?c0?Ogm`3gmoL00`3gmoL20>o_k`030??cl`3gmoL0moOg008061PH00<030`<000000000000
0P2<S8`01032`/80moOg0?Ogm`32`/8208b<S080BTY:00<0YJFU0?ooo`3oool01@3_knl30=KFeP80
Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`<0
kno_0P3gmoL20>o_k`040>OWi`3Ng]h0g]kN08b<S080>CTi2P00000=0?Ogm`80g]kN0`24Q8@00`20
P800Ng]k07]kN`020=KFeP80g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL00`1lO7`000000000000:0000
00X0moOg0`3Fe]H207]kN`<0Q8B40`3Fe]H20>o_k`D0moOg0P3_knl0103WinL0g]kN0=kNgP2<S8`2
03Ti>@D000000P2<S8`00`32`/80moOg0?Ogm`050?ooo`030?Ogm`3_knl0kno_0080e]KF0`24Q8@2
07]kN`<0e]KF0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030>_[j`3Ng]h0g]kN0080Jf][00@0WIfM
0<k>cP3>c/h0IfMW0P00000205YJFP030:VYZ@3gmoL0moOg00D0moOg0`3Fe]H207]kN`<0Q8B40P3F
e]H20>o_k`030??cl`3gmoL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`0201PH600300`<3000
000000000080S8b<00@0`/;20?Ogm`3gmoL0`/;20P2<S8`204Y:BP030:FUY@3oool0oooo00D0kno_
0`3Fe]H207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0inOW0P3>c/h00`38b<P0`/;20<;2`P050?_kn`80P82000@0[Jf]0=[JfP3Jf]X0hn?S
0P3[jn/50??cl`80moOg0P3_knl0103[jn/0inOW0>OWi`2n_[h209BDU0X0N7Qh203gmoL50??cl`80
f][J0`24Q8@00`22PX80P8200820P0020=KFeP80g]kN00<0jNWY0??cl`3clo<01@3clo<00`2f][H0
N7Qh07QhN00507QhN0D0O7al0`3gmoL70??cl`<0f][J0P20P80308B4Q0<0e]KF0P3_knl70??cl`04
0>g]k@3WinL0inOW0;jn_P80U9BD0P16ATH00`0b<S807AdM01dM7@020<;2`P030=_Kf`3clo<0lo?c
00D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H308B4Q080P8200`3Fe]H20>OWi`030>g]k@3clo<0lo?c
0080moOg00<0kno_0>OWi`3WinL00P2][Jd01038b<P0hn?S0>?Sh`2`/;0207alO080ZJVY00<0c/k>
0??cl`3clo<01@3clo<30=[JfP80P8200`24Q8@20=KFeP80kno_00<0lO7a0??cl`3clo<0203clo<2
08B4Q0030820P01lO7`0O7al0080`/;200@0gMgM0?Ogm`3gmoL0fm_K0P2n_[h209fMW@030<[:bP3g
moL0moOg0080kno_0`3clo<30=[JfP80P8201`3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0
102YZJT0e]KF0=KFeP3Jf]X20=kNgP80kno_1@3gmoLB0>o_k`P0moOg1@3_knl20=KFePH0Q8B40P3F
e]H20=kNgP030>OWi`3_knl0kno_00d0kno_203gmoL70>o_k`<0g]kN1@24Q8@30=KFePL0kno_0P3g
moL00`3clo<0kno_0>o_k`030>o_k`80S8b<00<0Hf=S03Ti>@0i>CT00P3gmoL00`3clo<0kno_0>o_
k`080>o_k`80e]KF1@24Q8@30=KFeP80g]kN00<0inOW0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_
k`020>o_k`030??cl`3gmoL0moOg00D0moOg00<0lo?c0>o_k`3_knl01@3_knl30=kNgPD0Q8B40P3F
e]H80>o_k`80moOg00<0lo?c0>o_k`3_knl00P3_knl00`3clo<0moOg0?Ogm`050?Ogm`030??cl`3_
knl0kno_00L0kno_0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0
102YZJT0e]KF0=KFeP3Jf]X20=kNgP80kno_1@3gmoLB0>o_k`P0moOg1@3_knl20=KFePH0Q8B40P3F
e]H20=kNgP030>OWi`3_knl0kno_00d0kno_203gmoL70>o_k`<0g]kN1@24Q8@30=KFePL0kno_0P3g
moL00`3clo<0kno_0>o_k`030>o_k`80S8b<00<0Hf=S03Ti>@0i>CT00P3gmoL00`3clo<0kno_0>o_
k`080>o_k`80e]KF1@24Q8@30=KFeP80g]kN00<0inOW0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_
k`020>o_k`030??cl`3gmoL0moOg00D0moOg00<0lo?c0>o_k`3_knl01@3_knl30=kNgPD0Q8B40P3F
e]H80>o_k`80moOg00<0lo?c0>o_k`3_knl00P3_knl00`3clo<0moOg0?Ogm`050?Ogm`030??cl`3_
knl0kno_00L0kno_0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0
0`2][Jd0e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3_knl0
0`3WinL0g]kN0=kNgP020?Ogm`030??cl`3_knl0kno_00X0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H3
07]kN`030820P024Q8@0Q8B400@0e]KF00<0f][J0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3W
inL20>o_k`80moOg00<0jn_[0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP080>o_k`80g]kN0`3F
e]H207]kN`<0Q8B41@3Fe]H20=kNgP030>OWi`3_knl0kno_0080g]kN00@0jn_[0?Ogm`3gmoL0lo?c
0P3_knl209bLW00306=SH`0Y:BT0:BTY0080g]kN00<0inOW0>o_k`3_knl01@3_knl00`3WinL0g]kN
0=kNgP020=KFeP<0Ng]k0P24Q8@50=KFeP030=[JfP3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0
1@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>?Sh`3Fe]H0e]KF0080kno_00<0inOW0=kNgP3Ng]h0
0`3Fe]H207]kN`<0Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP030>o_k`80g]kN00<0jn_[0?Ogm`3gmoL0
0P3_knl00`3WinL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`T0kno_0`3Ng]h30=KFeP80
Ng]k1`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@00`2][Jd0e]KF0=KFeP030=KFeP80g]kN
0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP020?Ogm`030??c
l`3_knl0kno_00X0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`030820P024Q8@0Q8B400@0e]KF
00<0f][J0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80moOg00<0jn_[0=kNgP3N
g]h00P3_knl00`3WinL0g]kN0=kNgP080>o_k`80g]kN0`3Fe]H207]kN`<0Q8B41@3Fe]H20=kNgP03
0>OWi`3_knl0kno_0080g]kN00@0jn_[0?Ogm`3gmoL0lo?c0P3_knl209bLW00306=SH`0Y:BT0:BTY
0080g]kN00<0inOW0>o_k`3_knl01@3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k0P24Q8@50=KF
eP030=[JfP3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3WinL0g]kN0=kNgP020>o_
k`030>?Sh`3Fe]H0e]KF0080kno_00<0inOW0=kNgP3Ng]h00`3Fe]H207]kN`<0Q8B4103Fe]H00`3J
f]X0g]kN0=kNgP030>o_k`80g]kN00<0jn_[0?Ogm`3gmoL00P3_knl00`3WinL0g]kN0=kNgP020>o_
k`040>OWi`3Ng]h0g]kN0>OWi`T0kno_0`3Ng]h30=KFeP80Ng]k1`3gmoL00`3Jf]X0_Kfm0;fm_@03
0=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;2
00D0lo?c0P24Q8@0102[Zj/0d];B0=;BdP3Fe]H20=[JfP80g]kN0`3WinL20=kNgP80kno_00@0jn_[
0>OWi`3WinL0hn?S0P3Ng]h20??cl`030>WYj@3Ng]h0g]kN0080jn_[00<0jNWY0>OWi`3WinL00`3_
knl20>OWi`030>_[j`3_knl0kno_0080inOW00<0hn?S0=kNgP3Ng]h00P3Bd]830820P00308:2PP24
Q8@0Q8B40080d];B0P3Jf]X00`3Lg=`0g]kN0=kNgP020>OWi`040>?Sh`3Ng]h0g]kN0>OWi`80kno_
0P3[jn/00`3UiND0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0inOW00<0jn_[0>o_k`3_knl0
0P3Ng]h30=;BdP80P8200`24Q8@30=;BdP80f][J0P3Ng]h00`3Shn<0inOW0>OWi`020=kNgP040>WY
j@3clo<0lo?c0>g]k@80inOW0P2e]KD00`1UIFD05ADE01DE5@020=kNgP030>?Sh`3WinL0inOW00<0
inOW0P3_knl00`3WinL0g]kN0=kNgP020=;BdP<0P8200P24Q8@30=;BdP80f][J00<0g=cL0=kNgP3N
g]h00P3WinL00`3Shn<0g]kN0=kNgP020>o_k`040>_[j`3WinL0inOW0>?Sh`80g]kN0P3_knl00`3U
iND0f][J0=[JfP020>OWi`030>?Sh`3Ng]h0g]kN00<0d];B0P20P80308B4Q080d];B0P3Jf]X00`3L
g=`0g]kN0=kNgP030>OWi`80g]kN00<0jNWY0??cl`3clo<00P3WinL00`3Shn<0g]kN0=kNgP020>o_
k`040>OWi`3Ng]h0g]kN0>?Sh`@0inOW00<0jn_[0>o_k`3_knl00P3WinL30=kNgP<0d];B0P20P805
0??cl`80moOg00<0f][J0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h2
0>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3gmoL00`3[jn/0g]kN0=kNgP050=kNgP<0kno_0P3Ng]h0
0`3WinL0kno_0>o_k`050=kNgP80c/k>1P24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl01@3Ng]h2
0>o_k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl00P3Ng]h30<k>cPD0Q8B40`3>c/h9
0=kNgP040>OWi`3_knl0kno_0>OWi`80g]kN0P3>c/h00`1WIfL00000000000080=kNgP80kno_00<0
inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>2P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_
knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl01@3N
g]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41@3_
knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_
knl00`3WinL0g]kN0=kNgP030=kNgP80moOg00<0jn_[0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0
inOW0>o_k`3_knl01@3Ng]h20<k>cPH0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_
knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3>c/h508B4Q0<0c/k>2@3N
g]h0103WinL0kno_0>o_k`3WinL20=kNgP80c/k>00<0IfMW000000000000203Ng]h20>o_k`030>OW
i`3Ng]h0g]kN0080c/k>1@24Q8@30<k>cPX0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_
00<0inOW0=kNgP3Ng]h01@3Ng]h30<k>cPD0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN
0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q0D0kno_
0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=;BdP030<S8b02m_Kd0_Kfm0080moOg00<0mOGe0??cl`3clo<00P24Q8@0102YZJT0c/k>0<k>
cP3Fe]H20=kNgP80f][J1@3Ng]h20>OWi`040>?Sh`3Ng]h0g]kN0=cLg080f][J0P3WinL00`3Shn<0
g]kN0=kNgP020=[JfP030=cLg03Ng]h0g]kN00<0inOW0P3Ng]h00`3Shn<0inOW0>OWi`050=[JfP80
c/k>1P24Q8@20<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h00`3Shn<0inOW0>OWi`020=kNgP03
0=cLg03Jf]X0f][J0080hn?S00<0hN7Q0=kNgP3Ng]h00`3Jf]X20=kNgP030>?Sh`3WinL0inOW0080
f][J0`3>c/h508B4Q0<0c/k>0P3Ng]h20=[JfP030=cLg03Ng]h0g]kN0080g]kN00@0hn?S0>OWi`3W
inL0hn?S0P3Ng]h20=;BdP0309nOW`1[Jf/0Jf][0080g]kN00<0g=cL0=[JfP3Jf]X00`3Ng]h20>OW
i`030>7Qh@3Jf]X0f][J0080c/k>1@24Q8@30<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h20>OW
i`040>?Sh`3Ng]h0g]kN0=cLg080f][J0P3Shn<00`3QhN40g]kN0=kNgP050=[JfP<0c/k>1@24Q8@2
0<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h00`3Shn<0inOW0>OWi`020=kNgP030=cLg03Jf]X0
f][J0080hn?S00@0hN7Q0=kNgP3Ng]h0g=cL0P3Jf]X20=kNgP030>?Sh`3WinL0inOW0080g]kN0`3J
f]X30<k>cP80Q8B41@3clo<20?Ogm`030=gMg@32`/80`/;200<0c/k>0P3WinL00`3_knl0moOg0?Og
m`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Ogm`02
08B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0
f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3>c/h608B4Q080c/k>0P3N
g]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3F
e]H50=kNgP80e]KF0`3>c/h508B4Q0<0c/k>0P3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3F
e]H20=kNgP030=[JfP3Fe]H0e]KF00D0g]kN00<0f][J0=KFeP3Fe]H00P3>c/h508B4Q0<0c/k>0P3N
g]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h01@3F
e]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Ogml0a/K6
0<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m
_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF
2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0
203Ng]h50=KFeP80c/k>1P24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF
0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00<0e]KF1@3Ng]h20=KFeP<0c/k>1@24Q8@30<k>cP80g]kN
0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3Ng]h00`3Jf]X0e]KF0=KFeP050=kNgP030=[J
fP3Fe]H0e]KF0080c/k>1@24Q8@30<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF
0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00D0e]KF0`3>c/h508B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF
0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00@0f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0
e]KF0`3>c/h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3Ng]h0
jn_[0P3gmoL20?ooo`L0moOg00@0no_k0?ooo`3oool0no_k3`3gmoL20?ooo`030?_kn`3gmoL0moOg
0080oooo00<0moOg0>o_k`3_knl00P3Ng]h308b<S00308B4Q01kNg/0Ng]k0080g]kN0P3gmoL00`3k
no/0oooo0?ooo`0J0?Ogm`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]h20?oooal0moOg0P3Ng]h308B4
Q080Ng]k0`3Ng]hI0?Ogm`030??cl`3_knl0kno_00<0g]kN0P24Q8@307]kN`80g]kN0P3oool00`3k
no/0moOg0?Ogm`0J0?Ogm`80oooo0`3_knl30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0
oooo0P1kNg/0102][Jd0g]kN0=kNgP3[jn/20?Ogm`80oooo1`3gmoL0103kno/0oooo0?ooo`3kno/?
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0S8b<00<0Q8B4
07]kN`1kNg/00P3Ng]h20?Ogm`030?_kn`3oool0oooo01X0moOg0P3_knl30=kNgP80Q8B40`1kNg/3
0=kNgP80oooo7`3gmoL20=kNgP<0Q8B40P1kNg/30=kNgQT0moOg00<0lo?c0>o_k`3_knl00`3Ng]h2
08B4Q0<0Ng]k0P3Ng]h20?ooo`030?_kn`3gmoL0moOg01X0moOg0P3oool30>o_k`<0g]kN0P24Q8@7
0?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OW
i`80d];B00<0b<S80;fm_@2m_Kd01@3kno/20820P0040;Bd]03WinL0inOW0?7al@80no_k0P3oool7
0?_kn`040?gmo@3oool0oooo0?gmo@l0no_k0P3oool00`3moOd0no_k0?_kn`020?ooo`030?_kn`3g
moL0moOg0080kno_0`28R8P00`24Q8@0P8200820P0020>OWi`80no_k00<0oOgm0?ooo`3oool06P3k
no/20?Ogm`<0kno_0P24Q8@30820P0<0inOW0P3ooolO0?_kn`80kno_0`24Q8@20820P0<0inOW6@3k
no/00`3inOT0moOg0?Ogm`030>o_k`80Q8B40`20P8020>OWi`80oooo00<0oOgm0?_kn`3kno/06P3k
no/20?ooo`<0moOg0`3_knl208B4Q0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0^[Zj
0>o_k`3_knl0moOg:P3oool608B4Q080kno_903oool508B4Q0<0kno_8`3oool508B4Q0<0kno_7`3o
ool508B4Q080kno_9`3oool208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0^[Zj
0>o_k`3_knl0moOg:P3oool608B4Q080kno_903oool508B4Q0<0kno_8`3oool508B4Q0<0kno_7`3o
ool508B4Q080kno_9`3oool208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`D0Q8B400<0P820
07]kN`1kNg/01@24Q8@207]kN`X0Q8B400<0R8R808b<S02<S8`01@24Q8@307]kN`D0Q8B40P1kNg/0
0`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`24
Q8@208b<S0l0Q8B400<0O7al07=cL`1cLg<03@24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4
Q00@08B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080S8b<00<0
Q8B407]kN`1kNg/07024Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4
Q00?08B4Q0030820P01kNg/0Ng]k00X0Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_1@24Q8@0
0`20P800Ng]k07]kN`0508B4Q080Ng]k2P24Q8@00`28R8P0S8b<08b<S00508B4Q0<0Ng]k1@24Q8@2
07]kN`030820P024Q8@0Q8B400X0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0
Ng]k08B4Q080S8b<3`24Q8@00`1lO7`0Lg=c07=cL`0=08B4Q080Ng]k1@24Q8@207]kN`030820P024
Q8@0Q8B40100Q8B40P1kNg/00`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P2<
S8`00`24Q8@0Ng]k07]kN`0L08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024
Q8@0Q8B400l0Q8B400<0P82007]kN`1kNg/02P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c<c<0<;2`P32`/801@3clo<2
0820P00408:2PP24Q8@0Q8B408:2PP@0P8200`24Q8@40820P00308:2PP24Q8@0Q8B400D0Q8B400<0
QXJ608R8R028R8P00P20P8000`22PX80Q8B408B4Q0050820P00308:2PP24Q8@0Q8B40080Q8B400<0
PX:20820P020P8001@24Q8@00`22PX80P8200820P00208B4Q0D0P8200P24Q8@01022PX80P8200820
P022PX8<08B4Q0<0P8200P28R8P00`22PX80O7al07alO0020820P0D0Q8B40`1lO7`308B4Q0@0P820
00<0PX:208B4Q024Q8@01@20P8000`22PX80Q8B408B4Q00708B4Q00308:2PP20P800P82000<0Q8B4
1@20P80508B4Q080P8200`24Q8@50820P080R8R800<0Q8B40820P020P8000P20P8000`22PX80Q8B4
08B4Q00508B4Q00308J6QP28R8P0R8R800D0P8201@24Q8@307alO080Q8B41@20P80308B4Q0D0P820
2P24Q8@00`22PX80P8200820P00208B4Q00308:2PP20P800P82000D0P8201@24Q8@70??cl`030=SH
f02m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0
b/[:0;fm_@2m_Kd01@3gmoL207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0
P82008B4Q024Q8@02024Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4
Q00208b<S00308B4Q01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01024Q8@00`20P800Ng]k07]k
N`0508B4Q0030820P01kNg/0Ng]k00X0Q8B40`1kNg/208b<S00308R8R024Q8@0Q8B40080Ng]k1@24
Q8@307=cL`D0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k0820P0T0Q8B4
00<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k1@24Q8@00`20P800Ng]k
07]kN`0508B4Q080Ng]k00<0P82008B4Q024Q8@01@24Q8@00`28R8P0S8b<08b<S00507]kN`D0Q8B4
0`1cLg<408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/02P24Q8@00`20P800Ng]k
07]kN`0508B4Q0D0Ng]k1@24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL207]kN`030820P024
Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`030820P024
Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00208b<S00308B4Q01kNg/0Ng]k00D0Q8B400<0
P82007]kN`1kNg/01024Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B40`1k
Ng/208b<S00308R8R024Q8@0Q8B40080Ng]k1@24Q8@307=cL`D0Q8B40P1kNg/00`20P800Q8B408B4
Q00208B4Q0040820P01kNg/0Ng]k0820P0T0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k
07]kN`0508B4Q080Ng]k1@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k00<0P82008B4Q024Q8@0
1@24Q8@00`28R8P0S8b<08b<S00507]kN`D0Q8B40`1cLg<408B4Q0030820P01kNg/0Ng]k00D0Q8B4
00<0P82007]kN`1kNg/02P24Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24Q8@70?Ogm`030=[J
fP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0
a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg1`3oool00`3kno/0moOg
0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`D0moOg1@3oool50?Ogm`030?_k
n`3oool0oooo0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_kn`3gmoL0moOg0080oooo
00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg0080moOg
00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0oooo0P3gmoL00`3kno/0oooo
0?ooo`020?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool00P3gmoL30?ooo`<0
g]kN0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0
moOg1`3oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool50?Ogm`80
oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`D0
moOg1@3oool50?Ogm`030?_kn`3oool0oooo0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`03
0?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`030?Ogm`80
oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`050?ooo`03
0?_kn`3gmoL0moOg0080moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0
oooo0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?oo
o`3oool00P3gmoL30?ooo`<0g]kN0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q004
0;6a/@3Ng]h0g]kN0>_[j`@0moOg1`3oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo
00D0moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3k
no/0oooo0?ooo`030?ooo`D0moOg1@3oool50?Ogm`030?_kn`3oool0oooo0080moOg0`3Ng]h508B4
Q0<0g]kN1`3gmoL50?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL00P3oool00`3k
no/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN1`3gmoL00`3k
no/0oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg0080moOg00<0no_k0?ooo`3oool01@3gmoL30=kN
gPD0Q8B40P3Ng]h80?Ogm`D0oooo0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`040?_kn`3oool0oooo
0?_kn`@0moOg00<0no_k0?ooo`3oool00P3gmoL30?ooo`<0g]kN0P24Q8@70?ooo`030>?Sh`36a/H0
a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm
_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_kbD0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h6
08B4Q080g]kN7`3oool20?Ogm`<0g]kN1@24Q8@30=kNgQh0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h5
08B4Q0<0g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3Ng]h2
08B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_9@3oool0
0`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]hO0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN7P3oool0
0`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]hI0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@2
0=kNgR40oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;200D0lo?c0P24Q8@0102a
/K40g]kN0=kNgP3_knlU0?ooo`030?gmo@3kno/0no_k0080inOW1P24Q8@20=kNgQl0oooo0P3kno/3
0>OWi`D0Q8B40`3Ng]hN0?ooo`030?gmo@3kno/0no_k0080inOW1@24Q8@30=kNgQT0oooo00<0oOgm
0?_kn`3kno/00`3WinL508B4Q080g]kN8@3oool30?_kn`<0inOW0P24Q8@50??cl`80moOg00<0f][J
0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:
b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0kno_:03oool20>o_k`H0Q8B40P3Ng]hQ
0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3_knl508B4Q0<0g]kN703oool30>o_k`D0Q8B40P3Ng]hT
0?ooo`<0kno_0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kN
gP3Ng]h0kno_:03oool20>o_k`H0Q8B40P3Ng]hQ0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3_knl5
08B4Q0<0g]kN703oool30>o_k`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@50>o_k`80moOg00<0f][J
0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>
c/h0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_2@3oool2010@400406][J`36a/H0
a/K60>?ShaT0oooo0P3_knl608B4Q080g]kN8@3oool30=kNgP80Q8B40`1kNg/50?Ogm`X0oooo00<0
T92@024Q8@0Q8B401@00000209BDU0030<[:bP3oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P3N
g]h307]kN`80S8b<0`3Ng]h20?Ogm`030?_kn`3oool0oooo01L0oooo0`3Ng]h208B4Q0<0Ng]k103g
moL00`3kno/0oooo0?ooo`050?ooo`0308B4Q00820P020P80080a/K600<0hn?S0?ooo`3oool04P3o
ool30=kNgP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_
knl90?ooo`80410@00@0Jf][0<K6aP36a/H0hn?S6@3oool20>o_k`H0Q8B40P3Ng]hQ0?ooo`<0g]kN
0P24Q8@307]kN`D0moOg2P3oool00`2@T9008B4Q024Q8@0500000080U9BD00<0b/[:0?ooo`3oool0
1@3oool00`3kno/0moOg0?Ogm`020=kNgP<0Ng]k0P2<S8`30=kNgP80moOg00<0no_k0?ooo`3oool0
5`3oool30=kNgP80Q8B40`1kNg/40?Ogm`030?_kn`3oool0oooo00D0oooo00<0Q8B400P8200820P0
0P36a/H00`3Shn<0oooo0?ooo`0B0?ooo`<0g]kN0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80e]KF00<0c<c<0<;2`P32`/801@3k
no/208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg1`3oool203Xj>P0406i^KP2QXJ40XJ6Q0=3@d1T0
oooo0P3WinL608B4Q080g]kN0P3kno/00`3moOd0oooo0?ooo`0J0?ooo`80no_k0`3Ng]h208B4Q0<0
P8200`3[jn/20?Ogm`X0oooo00<0b<S8092@T02@T9000P20P8000`1/K6`0EeMG05MGE`0204Y:BP03
0:FUY@3oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P3WinL30820P080R8R80`3Ng]h20?Ogm`03
0?_kn`3oool0oooo01@0oooo00<0oOgm0?_kn`3kno/00`3Ng]h208B4Q0<0P8200P3[jn/20?Ogm`03
0?_kn`3oool0oooo00D0oooo00<0TY:B02DU9@0U9BD00P2][Jd00`3Fe]H0oooo0?ooo`0B0?ooo`<0
g]kN0P28R8P70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80
kno_1`3oool206=SH`0406m_K`1kNg/0Ng]k0;fm_AT0oooo0P3Ng]h608B4Q080g]kN0P3gmoL00`3k
no/0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3gmoL?0?ooo`030=KFeP2][Jd0[Jf]
0080000000<0P8200?ooo`3oool01@3oool00`3kno/0moOg0?Ogm`020>o_k`D0Q8B40`3Ng]h20?Og
m`030?_kn`3oool0oooo01@0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN0P3gmoL00`3k
no/0oooo0?ooo`050?ooo`030:6QX@12@T80@T920080U9BD00<0b/[:0?ooo`3oool04P3oool30=kN
gP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_
k`L0oooo0P1SHf<0101_Kfl0Ng]k07]kN`2m_KdI0?ooo`80g]kN1P24Q8@20=kNgP80moOg00<0no_k
0?ooo`3oool06P3oool20?Ogm`<0g]kN1@24Q8@30=kNgP80moOg3`3oool00`3Fe]H0[Jf]0:f][@02
000000030820P03oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P3_knl508B4Q0<0g]kN0P3gmoL0
0`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgP80moOg00<0no_k
0?ooo`3oool01@3oool00`2QXJ40@T920492@P0209BDU0030<[:bP3oool0oooo0180oooo0`3Ng]h2
08B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL5
0?ooo`80U9BD00<0BTY:0000000000000`00000200P8200305]KF`2][Jd0[Jf]00D000002P3oool0
0`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo0080oooo00@0no_k
0?Ogm`3gmoL0no_k103oool00`20P8000000000000020<K6aP030>?Sh`3oool0oooo00P0oooo0P3g
moL30=kNgPD0Q8B40`3Fe]H70?Ogm`80oooo00@0a/K608b<S02<S8`0BTY:0P0820P500000080S8b<
00<0a/K60?ooo`3oool01@3oool00`3gmoL0kno_0>o_k`020=kNgPD0Q8B40`3Ng]h50?Ogm`80DU9B
00<0Hf=S07=cL`1cLg<0203oool208b<S00306m_K`1BDU80DU9B0080oooo00<0no_k0?Ogm`3gmoL0
0`3Ng]h508B4Q080e]KF203gmoL20?ooo`030;fm_@1kNg/0Ng]k0080Hf=S00<0ATI602TY:@0Y:BT0
0P000000100Q8B40@T920492@P2IVIT20>o_k`L0oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`D0oooo0P2DU9@00`1:BTX0
0000000000030000008020P800<0Fe]K0:f][@2][Jd01@00000:0?ooo`030?_kn`3gmoL0moOg0080
g]kN1P24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool00P3oool0103kno/0moOg0?Ogm`3kno/40?oo
o`030820P000000000000080a/K600<0hn?S0?ooo`3oool0203oool20?Ogm`<0g]kN1@24Q8@30=KF
ePL0moOg0P3oool01036a/H0S8b<08b<S01:BTX200P820D000000P2<S8`00`36a/H0oooo0?ooo`05
0?ooo`030?Ogm`3_knl0kno_0080g]kN1@24Q8@30=kNgPD0moOg0P1BDU800`1SHf<0Lg=c07=cL`08
0?ooo`80S8b<00<0Kfm_059BDP1BDU800P3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Fe]H8
0?Ogm`80oooo00<0_Kfm07]kN`1kNg/00P1SHf<00`16ATH0:BTY02TY:@0200000004024Q8@12@T80
@T9209VIV@80kno_1`3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL0
0`3clo<0kno_0>o_k`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_0P3oool30?Ogm`@0oooo00@0
P820000000000000Jf][0P3Fe]H20>o_k`030;jn_P2<S8`0S8b<0080000000<0Jf][0=KFeP3Fe]H0
1@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030??cl`3_knl0kno_0080e]KF1P24Q8@20=kNgPD0moOg
1@3oool00`3kno/0moOg0?Ogm`020?ooo`0309BDU00Y:BT0:BTY0080>CTi00<0V9RH0?Ogm`3gmoL0
0`3oool50?Ogm`80kno_0`3Ng]h508B4Q0<0g]kN0P3_knl50?ooo`80moOg00@0O7al000000000000
CTi>0P2LW9`50?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20=kNgPD0Q8B40`3Ng]h50?ooo`80
moOg00<0`/;208b<S02<S8`00P1BDU800`2UYJD0moOg0?Ogm`030?Ogm`80000000<0IfMW0<k>cP3>
c/h00P3gmoL00`3clo<0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20>o_k`030?Ogm`3oool0oooo00<0
oooo0P3gmoL00`3Bd]80[Jf]0:f][@0200P8200306][J`3>c/h0c/k>0080moOg00@0]KFe07=cL`1c
Lg<0EUIF0P0i>CT50?Ogm`80oooo0`3_knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_
k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040;6a/@3Ng]h0g]kN0>OW
i`80kno_0P3oool30?Ogm`@0oooo00@0P820000000000000Jf][0P3Fe]H20>o_k`030;jn_P2<S8`0
S8b<0080000000<0Jf][0=KFeP3Fe]H01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030??cl`3_knl0
kno_0080e]KF1P24Q8@20=kNgPD0moOg1@3oool00`3kno/0moOg0?Ogm`020?ooo`0309BDU00Y:BT0
:BTY0080>CTi00<0V9RH0?Ogm`3gmoL00`3oool50?Ogm`80kno_0`3Ng]h508B4Q0<0g]kN0P3_knl5
0?ooo`80moOg00@0O7al000000000000CTi>0P2LW9`50?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203g
moL20=kNgPD0Q8B40`3Ng]h50?ooo`80moOg00<0`/;208b<S02<S8`00P1BDU800`2UYJD0moOg0?Og
m`030?Ogm`80000000<0IfMW0<k>cP3>c/h00P3gmoL00`3clo<0kno_0>o_k`030=kNgPD0Q8B40P3N
g]h20>o_k`030?Ogm`3oool0oooo00<0oooo0P3gmoL00`3Bd]80[Jf]0:f][@0200P8200306][J`3>
c/h0c/k>0080moOg00@0]KFe07=cL`1cLg<0EUIF0P0i>CT50?Ogm`80oooo0`3_knl30=kNgP80Q8B4
0P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_
k`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_0P3oool30?Ogm`@0oooo00@0P820000000000000
Jf][0P3Fe]H20>o_k`030;jn_P2<S8`0S8b<0080000000<0Jf][0=KFeP3Fe]H01@3gmoL00`3kno/0
oooo0?ooo`020?Ogm`030??cl`3_knl0kno_0080e]KF1P24Q8@20=kNgPD0moOg1@3oool00`3kno/0
moOg0?Ogm`020?ooo`0309BDU00Y:BT0:BTY0080>CTi00<0V9RH0?Ogm`3gmoL00`3oool50?Ogm`80
kno_0`3Ng]h508B4Q0<0g]kN0P3_knl50?ooo`80moOg00@0O7al000000000000CTi>0P2LW9`50?Og
m`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20=kNgPD0Q8B40`3Ng]h50?ooo`80moOg00<0`/;208b<
S02<S8`00P1BDU800`2UYJD0moOg0?Ogm`030?Ogm`80000000<0IfMW0<k>cP3>c/h00P3gmoL00`3c
lo<0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h20>o_k`030?Ogm`3oool0oooo00<0oooo0P3gmoL00`3B
d]80[Jf]0:f][@0200P8200306][J`3>c/h0c/k>0080moOg00@0]KFe07=cL`1cLg<0EUIF0P0i>CT5
0?Ogm`80oooo0`3_knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0
_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b/[:0<;2
`P32`/800P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg0P3kno/3
0?Ogm`@0no_k00@0S8b<01dM7@0M7Ad0Jf][0P2i^KT20??cl`030=_Kf`32`/80`/;200808B4Q00<0
JFUY0;6a/@2a/K400`3gmoL50?_kn`80moOg00<0mOGe0??cl`3clo<00P3Jf]X608B4Q080g]kN0P3c
lo<00`3emOD0moOg0?Ogm`020?ooo`040?gmo@3kno/0no_k0?Win@80moOg0P3Fe]H00`2<S8`0@T92
0492@P0206=SH`0308b<S02e]KD0]KFe00<0no_k0P3gmoL00`3inOT0no_k0?_kn`020?Ogm`<0g]kN
1@24Q8@30=[JfP80kno_0P3oool00`3moOd0no_k0?_kn`020?Ogm`0407alO0000000000005mOG`80
_Kfm1@3gmoL20?_kn`030?Win@3gmoL0moOg00D0no_k00<0moOg0??cl`3clo<00P3Jf]X308B4Q080
P8200`3Ng]h50?_kn`80moOg00<0gmoO0<K6aP36a/H00P1>CTh01028R8P0`/;20<;2`P3MgMd20?Og
m`80000000<0LW9b0>?Sh`3Shn<00P3kno/00`3inOT0moOg0?Ogm`030=kNgPD0Q8B40P3Jf]X20>o_
k`030?Ogm`3oool0oooo00<0no_k0P3gmoL00`3WinL0e]KF0=KFeP0200@4100307AdM03Shn<0hn?S
0080no_k00@0f=SH0;Fe]@2e]KD0JFUY0P0M7Ad70?_kn`<0kno_0`3Ng]h20820P080lo?c00<0mOGe
0?Ogm`3gmoL00P3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knl2
0?ooo`T0moOg00@0V9RH03Ti>@0i>CT0Jf][0P2LW9`50?Ogm`80@T9200<0IfMW08b<S02<S8`00`3g
moL20?ooo`030?_kn`3gmoL0moOg00D0moOg0P3Ng]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Og
m`020?ooo`030?_kn`3gmoL0moOg00<0moOg0P2][Jd00`24Q8@0FUYJ05YJFP0208b<S0030820P01c
Lg<0Lg=c00D0moOg00<0no_k0?ooo`3oool00P3oool30=kNgPD0Q8B40`3Fe]H20>o_k`80oooo00<0
no_k0?Ogm`3gmoL00P3gmoL0101lO7`000000000001_Kfl20=kNgPX0moOg1@3oool00`3gmoL0kno_
0>o_k`020=KFeP<0Q8B40P1kNg/30=kNgPL0moOg00<0no_k0?ooo`3oool00P1:BTX0101[Jf/0S8b<
08b<S032`/820?Ogm`80000000<0O7al0?Ogm`3gmoL01@3oool30=kNgPD0Q8B40P3Fe]H20>o_k`03
0?Ogm`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P0000000`1lO7`0moOg0?Ogm`020?ooo`04
0?_kn`3gmoL0moOg07alO08000001@3oool20?Ogm`<0kno_0`3Ng]h207]kN`L0moOg00<0gmoO0<K6
aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0
a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_0P3oool90?Ogm`0409RHV00i>CT0>CTi
06][J`80W9bL1@3gmoL20492@P0306MWI`2<S8`0S8b<00<0moOg0P3oool00`3kno/0moOg0?Ogm`05
0?Ogm`80g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`03
0?Ogm`80[Jf]00<0Q8B405YJFP1JFUX00P2<S8`00`20P800Lg=c07=cL`050?Ogm`030?_kn`3oool0
oooo0080oooo0`3Ng]h508B4Q0<0e]KF0P3_knl20?ooo`030?_kn`3gmoL0moOg0080moOg00@0O7al
000000000000Kfm_0P3Ng]h:0?Ogm`D0oooo00<0moOg0>o_k`3_knl00P3Fe]H308B4Q080Ng]k0`3N
g]h70?Ogm`030?_kn`3oool0oooo0080BTY:00@0Jf][08b<S02<S8`0`/;20P3gmoL20000000307al
O03gmoL0moOg00D0oooo0`3Ng]h508B4Q080e]KF0P3_knl00`3gmoL0oooo0?ooo`050?Ogm`030?_k
n`3oool0oooo0080000000<0O7al0?Ogm`3gmoL00P3oool0103kno/0moOg0?Ogm`1lO7`2000000D0
oooo0P3gmoL30>o_k`<0g]kN0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]kN`040:VY
Z@3Fe]H0e]KF0>?Sh`80kno_1@3gmoL20?ooo`80moOg00@0^KVi07]kN`1kNg/0Hf=S0P1:BTX50?Og
m`80S8b<00<0Jf][04Y:BP1:BTX01@3oool00`3kno/0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_
0080e]KF1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL0203gmoL202TY:@0307alO03>c/h0c/k>
0080moOg00<0R8R801PH600H61P00`2m_Kd50?Ogm`80kno_0`3Ng]h508B4Q0<0e]KF103_knl00`3c
lo<0moOg0?Ogm`020?Ogm`040<;2`P2<S8`0S8b<06=SH`80>CTi0P3Fe]H00`3[jn/0oooo0?ooo`0:
0?Ogm`030??cl`3_knl0kno_0080e]KF1@24Q8@30=kNgP80kno_00<0lo?c0?Ogm`3gmoL01@3gmoL2
0<k>cP0407=cL`0H61P061PH08b<S080oooo0P0000000`1lO7`0moOg0?Ogm`020?Ogm`030??cl`3_
knl0kno_00<0g]kN1@24Q8@20=KFePD0kno_203gmoL203Ti>@0305YJFP1kNg/0Ng]k0080oooo00@0
c/k>09bLW02LW9`0CTi>0P00000:0?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3o
ool207]kN`040:VYZ@3Fe]H0e]KF0>?Sh`80kno_1@3gmoL20?ooo`80moOg00@0^KVi07]kN`1kNg/0
Hf=S0P1:BTX50?Ogm`80S8b<00<0Jf][04Y:BP1:BTX01@3oool00`3kno/0moOg0?Ogm`020?Ogm`03
0??cl`3_knl0kno_0080e]KF1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL0203gmoL202TY:@03
07alO03>c/h0c/k>0080moOg00<0R8R801PH600H61P00`2m_Kd50?Ogm`80kno_0`3Ng]h508B4Q0<0
e]KF103_knl00`3clo<0moOg0?Ogm`020?Ogm`040<;2`P2<S8`0S8b<06=SH`80>CTi0P3Fe]H00`3[
jn/0oooo0?ooo`0:0?Ogm`030??cl`3_knl0kno_0080e]KF1@24Q8@30=kNgP80kno_00<0lo?c0?Og
m`3gmoL01@3gmoL20<k>cP0407=cL`0H61P061PH08b<S080oooo0P0000000`1lO7`0moOg0?Ogm`02
0?Ogm`030??cl`3_knl0kno_00<0g]kN1@24Q8@20=KFePD0kno_203gmoL203Ti>@0305YJFP1kNg/0
Ng]k0080oooo00@0c/k>09bLW02LW9`0CTi>0P00000:0?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:
0<K6aP36a/H01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_1`3gmoL20>o_k`040=oOg`3>
c/h0c/k>06][J`8020P81@3gmoL20=KFeP0306m_K`0820P020P800X0moOg00<0lo?c0>o_k`3_knl0
0P3Ng]h307]kN`030820P024Q8@0Q8B40080e]KF0P3_knl00`3clo<0moOg0?Ogm`020>o_k`040??c
l`3gmoL0moOg0:VYZ@80FUYJ0P2e]KD00`3Fe]H0moOg0?Ogm`020?Ogm`030=;BdP2][Jd0[Jf]00<0
61PH0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`<0e]KF0P24Q8@307]kN`<0e]KF103_knl00`3clo<0
moOg0?Ogm`020>o_k`040?Ogm`3oool0oooo0<K6aP80S8b<1@00000:0?Ogm`030??cl`3_knl0kno_
0080e]KF0`1kNg/208B4Q0D0g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000?0000
000307alO03gmoL0moOg00<0e]KF0P24Q8@307]kN`80e]KF1@3_knl30?Ogm`80kno_00<0moOg0?oo
o`3oool00P3Ng]h00`24Q8@0:BTY02TY:@020000000400@4100820P020P804i>CP80U9BD0P3_knl0
0`3clo<0moOg0?Ogm`050>o_k`<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4
Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_1`3gmoL20>o_k`040=oOg`3>c/h0c/k>06][J`8020P81@3g
moL20=KFeP0306m_K`0820P020P800X0moOg00<0lo?c0>o_k`3_knl00P3Ng]h307]kN`030820P024
Q8@0Q8B40080e]KF0P3_knl00`3clo<0moOg0?Ogm`020>o_k`040??cl`3gmoL0moOg0:VYZ@80FUYJ
0P2e]KD00`3Fe]H0moOg0?Ogm`020?Ogm`030=;BdP2][Jd0[Jf]00<061PH0P3gmoL00`3clo<0kno_
0>o_k`020?Ogm`<0e]KF0P24Q8@307]kN`<0e]KF103_knl00`3clo<0moOg0?Ogm`020>o_k`040?Og
m`3oool0oooo0<K6aP80S8b<1@00000:0?Ogm`030??cl`3_knl0kno_0080e]KF0`1kNg/208B4Q0D0
g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000?0000000307alO03gmoL0moOg00<0
e]KF0P24Q8@307]kN`80e]KF1@3_knl30?Ogm`80kno_00<0moOg0?ooo`3oool00P3Ng]h00`24Q8@0
:BTY02TY:@020000000400@4100820P020P804i>CP80U9BD0P3_knl00`3clo<0moOg0?Ogm`050>o_
k`<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<20820P0040:^[Z`3Fe]H0e]KF0>?S
h`80kno_1@3clo<20?Ogm`80kno_00@0inOW0=oOg`3Ogml0[Zj^0P1lO7`50?Ogm`80hn?S00<0/;2`
07alO01lO7`01@3clo<00`3emOD0moOg0?Ogm`020??cl`030?7al@3_knl0kno_0080f][J0`20P800
0`22PX80Q8B408B4Q0020=KFeP80kno_00<0lO7a0??cl`3clo<00P3_knl0103clo<0moOg0?Ogm`3@
d=020:VYZ@80d];B00<0hn?S0??cl`3clo<00P3clo<00`3QhN40c/k>0<k>cP0308R8R080lo?c00<0
lO7a0>o_k`3_knl00P3clo<30=KFeP80Q8B40`20P8030=KFeP80inOW0P3_knl00`3clo<0moOg0?Og
m`020??cl`040?Gem@3gmoL0moOg09nOW`80ATI60P1KFe/00`1ZJVX0N7Qh07QhN0020?Ogm`030?Ge
m@3clo<0lo?c00D0lo?c00<0lO7a0>o_k`3_knl00P3Jf]X30820P080Q8B40`3Jf]X20>OWi`030>o_
k`3gmoL0moOg0080moOg00<0^;Rh07QhN01hN7P0201hN7P207alO00307YjNP1hN7P0N7Qh0080N7Qh
00<0][Jf0??cl`3clo<00`3Fe]H208B4Q0<0P8200P3Fe]H20>OWi`030>_[j`3_knl0kno_00<0moOg
0P3clo<00`3emOD0moOg0?Ogm`020>OWi`030;Zj^P2<S8`0S8b<0080N7Qh00@0O7al0820P020P800
XJ6Q0P32`/820>o_k`030?7al@3clo<0lo?c00D0kno_0`3Jf]X208B4Q0D0lo?c0P3gmoL00`3Jf]X0
_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0kno_0P1kNg/0102YZJT0e]KF0=KFeP3Shn<70>o_k`80moOg203_knl50?Ogm`X0
kno_00<0lo?c0?Ogm`3gmoL01@3_knl20=KFePH0Q8B40P3Fe]H70>o_k`030??cl`3gmoL0moOg00<0
moOg2P3_knl30?Ogm`L0kno_0`3Fe]H508B4Q0<0e]KF0P3Ng]h20>o_k`030??cl`3gmoL0moOg0080
moOg00@0lo?c0>o_k`3_knl0N7Qh0P0000020;Fe]@030=;BdP3_knl0kno_0080moOg00<0lo?c0>o_
k`3_knl0203_knl20=kNgPD0Q8B40`3Fe]H20>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c0>o_
k`3_knl0203_knl20?Ogm`030??cl`3_knl0kno_00D0kno_0`3Fe]H508B4Q080e]KF0P3Ng]h00`3W
inL0kno_0>o_k`050?Ogm`030??cl`3_knl0kno_00L0kno_00@0lo?c0?Ogm`3gmoL0lo?c303_knl3
0=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3_knl207]kN`040:VYZ@3Fe]H0e]KF
0>?Sh`L0kno_0P3gmoL80>o_k`D0moOg2P3_knl00`3clo<0moOg0?Ogm`050>o_k`80e]KF1P24Q8@2
0=KFePL0kno_00<0lo?c0?Ogm`3gmoL00`3gmoL:0>o_k`<0moOg1`3_knl30=KFePD0Q8B40`3Fe]H2
0=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL0103clo<0kno_0>o_k`1hN7P200000080]KFe00<0
d];B0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80g]kN1@24Q8@30=KFeP80kno_00<0
lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80moOg00<0lo?c0>o_k`3_knl01@3_
knl30=KFePD0Q8B40P3Fe]H20=kNgP030>OWi`3_knl0kno_00D0moOg00<0lo?c0>o_k`3_knl01`3_
knl0103clo<0moOg0?Ogm`3clo<<0>o_k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm
_@020?ooo`030?_kn`3gmoL0moOg0080Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0kno_0P3N
g]h50>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0203_knl20?Ogm`030??cl`3_
knl0kno_0080kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`030820P024Q8@0Q8B400@0e]KF00<0
f][J0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL40>o_k`030>OWi`3Ng]h0g]kN0080kno_
00<0inOW0=kNgP3Ng]h01@3_knl00`3clo<0moOg0?Ogm`020=kNgP<0e]KF0P1cLg<308B4Q0D0e]KF
0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP040>OWi`3_knl0kno_07alO08020P80P1cLg<00`2e]KD0
moOg0?Ogm`020=kNgP030>OWi`3_knl0kno_00<0moOg0P3_knl00`3WinL0g]kN0=kNgP020=KFeP<0
Ng]k0P24Q8@50=KFeP030=[JfP3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3WinL0
g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN0080moOg00<0jn_[0=kNgP3Ng]h00`3Fe]H207=cL`<0
Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP030>o_k`80g]kN00<0inOW0>o_k`3_knl00P3_knl00`3WinL0
g]kN0=kNgP020?Ogm`040>_[j`3Ng]h0g]kN0>OWi`80kno_0P3gmoL00`3clo<0kno_0>o_k`020>o_
k`<0g]kN0`3Fe]H207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080
Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0kno_0P3Ng]h50>o_k`030>OWi`3Ng]h0g]kN0080
kno_00<0inOW0=kNgP3Ng]h0203_knl20?Ogm`030??cl`3_knl0kno_0080kno_00<0inOW0=kNgP3N
g]h00P3Fe]H307]kN`030820P024Q8@0Q8B400@0e]KF00<0f][J0=kNgP3Ng]h00P3_knl0103WinL0
g]kN0=kNgP3WinL40>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3c
lo<0moOg0?Ogm`020=kNgP<0e]KF0P1cLg<308B4Q0D0e]KF0P3Ng]h00`3WinL0kno_0>o_k`020=kN
gP040>OWi`3_knl0kno_07alO08020P80P1cLg<00`2e]KD0moOg0?Ogm`020=kNgP030>OWi`3_knl0
kno_00<0moOg0P3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k0P24Q8@50=KFeP030=[JfP3Ng]h0
g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0
g]kN0080moOg00<0jn_[0=kNgP3Ng]h00`3Fe]H207=cL`<0Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP03
0>o_k`80g]kN00<0inOW0>o_k`3_knl00P3_knl00`3WinL0g]kN0=kNgP020?Ogm`040>_[j`3Ng]h0
g]kN0>OWi`80kno_0P3gmoL00`3clo<0kno_0>o_k`020>o_k`<0g]kN0`3Fe]H207]kN`L0moOg00<0
gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3Bd]80
0`38b<P0_Kfm0;fm_@020?ooo`030?gmo@3kno/0no_k0080Q8B400@0Zj^[0=;BdP3Bd]80e]KF0P3J
f]X20=kNgP<0inOW0P3Ng]h20>o_k`040>_[j`3WinL0inOW0>?Sh`80g]kN0P3_knl00`3WinL0g]kN
0=kNgP050>OWi`<0kno_0P3[jn/00`3]kNd0kno_0>o_k`020>OWi`030>?Sh`3Ng]h0g]kN0080d];B
1P24Q8@20=;BdP80f][J00<0g=cL0=kNgP3Ng]h00P3WinL0103Shn<0g]kN0=kNgP3WinL20>o_k`80
inOW00<0hn?S0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>OWi`030>g]k@3clo<0lo?c0080
g]kN0`3Fe]H207alO0<0Q8B40`3Bd]820=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h0103WinL0
kno_0>o_k`2UYJD205]KF`80EUIF00<0JFUY07alO01lO7`00P1_Kfl00`26QXH0WIfM09fMW@030>_[
j`80kno_00<0inOW0=kNgP3Ng]h00P3Bd]830820P080Q8B40`3Fe]H20=[JfP030=cLg03Ng]h0g]kN
0080inOW00<0hn?S0=kNgP3Ng]h00P3_knl0103[jn/0inOW0>OWi`3Shn<20=kNgP80kno_00<0inOW
0=kNgP3Ng]h00P3[jn/00`3UiND0g]kN0=kNgP030=KFeP80O7al0`24Q8@20=;BdP80f][J00<0g=cL
0=kNgP3Ng]h00`3WinL20=kNgP030>OWi`3_knl0kno_0080inOW00<0hn?S0=kNgP3Ng]h00P3clo<0
103YjNT0g]kN0=kNgP3Shn<20>OWi`80jn_[00<0kNg]0>o_k`3_knl00P3WinL30=kNgP<0d];B0P20
P8070?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_
knl00`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0
inOW0>o_k`3_knl01@3Ng]h20<k>cP<0S8b<00<0R8R808B4Q024Q8@00P3>c/h:0=kNgP030>OWi`3_
knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3F
e]H508B4Q0<0c/k>2@3Ng]h0103WinL0kno_0>o_k`3>c/h20:f][@80>CTi00<07AdM000000000000
0P0000000`0U9BD0BTY:04Y:BP030=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0e]KF
2P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0e]KF
1@24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN
00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24
Q8@0102YZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20>o_k`030>OW
i`3Ng]h0g]kN00D0g]kN0`3_knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h308b<S00308R8
R024Q8@0Q8B40080c/k>2P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h00`3WinL0kno_0>o_k`020=kNgP<0e]KF1@24Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0
c/k>0P2][Jd203Ti>@0301dM7@00000000000080000000<09BDU04Y:BP1:BTX00`3Ng]h20>o_k`03
0>OWi`3Ng]h0g]kN0080c/k>1@24Q8@30=KFePX0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80
kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30=KFePD0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0
g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q0L0
oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW
0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=[JfPD0
g]kN0P3WinL0103Shn<0g]kN0=kNgP3Lg=`20=[JfP80hn?S00<0hN7Q0=kNgP3Ng]h00P3Jf]X00`3L
g=`0g]kN0=kNgP030>OWi`80g]kN00<0hn?S0>OWi`3WinL01@3Jf]X20<k>cP<0R8R800<0QXJ608B4
Q024Q8@00P3>c/h20=kNgP030=cLg03Jf]X0f][J00D0g]kN00<0hn?S0>OWi`3WinL00P3Ng]h00`3L
g=`0f][J0=[JfP020>?Sh`030>7Qh@3Ng]h0g]kN00<0f][J0P3Ng]h00`3Shn<0inOW0>OWi`020=[J
fP<0d];B1@24Q8@30<k>cP80g]kN0P3Jf]X00`3Lg=`0g]kN0=kNgP020=kNgP040>?Sh`3WinL0inOW
0=OGe`80a/K60P28R8P00`1jNWX0Jf][06][J`0206m_K`030820P02@T900T92@00<0g]kN0P3WinL0
0`3QhN40f][J0=[JfP020<k>cPD0Q8B40`3Bd]820=kNgP030=cLg03Jf]X0f][J00D0g]kN0P3WinL0
103Shn<0g]kN0=kNgP3Lg=`20=[JfP80hn?S00<0hN7Q0=kNgP3Ng]h01@3Jf]X30=;BdPD0Q8B40P3>
c/h20=kNgP030=cLg03Jf]X0f][J00D0g]kN00<0hn?S0>OWi`3WinL00P3Ng]h00`3Lg=`0f][J0=[J
fP020>?Sh`040>7Qh@3Ng]h0g]kN0=cLg080f][J0P3Ng]h00`3Shn<0inOW0>OWi`020=kNgP<0f][J
0`3>c/h208B4Q0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF
0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[J
fP3Ng]h0g]kN00P0g]kN1@3Fe]H20<k>cPH0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN
00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP030=KFePD0g]kN0P3Fe]H30<k>cPD0Q8B4
0`3>c/h20=kNgP80e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3Fe]H0
1@3Ng]h00`3Jf]X0e]KF0=KFeP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN
00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP050=KFeP<0c/k>1@24Q8@20<k>cP80g]kN
00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80
e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040:VY
Z@3>c/h0c/k>0=KFeP80g]kN0P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3N
g]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3>c/h608B4Q080c/k>0P3Ng]h00`3Jf]X0
e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H50=kNgP80
e]KF0`3>c/h508B4Q0<0c/k>0P3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3Fe]H20=kNgP03
0=[JfP3Fe]H0e]KF00D0g]kN00<0f][J0=KFeP3Fe]H00P3>c/h508B4Q0<0c/k>0P3Ng]h00`3Jf]X0
e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h01@3Fe]H30<k>cPD0
Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0
g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0
kno_0P1kNg/0102][Jd0g]kN0=kNgP3[jn/C0?Ogm`030?_kn`3oool0oooo00P0moOg0P3oool00`3k
no/0moOg0?Ogm`020?ooo`030?Ogm`3_knl0kno_0080g]kN0`24Q8@00`20P800Ng]k07]kN`020=kN
gPX0moOg00<0no_k0?ooo`3oool04P3gmoL20>o_k`<0g]kN0P24Q8@307]kN`<0g]kN1`3gmoL20?oo
o`030?_kn`3gmoL0moOg0180moOg00<0lo?c0>o_k`3_knl00P3Ng]h308B4Q080Ng]k0`3Ng]h50?Og
m`80oooo00<0no_k0?Ogm`3gmoL03`3gmoL00`3clo<0kno_0>o_k`030=kNgP80Q8B40`1kNg/20=kN
gPP0moOg0P3oool00`3kno/0moOg0?Ogm`0B0?Ogm`80oooo0`3_knl30=kNgP80Q8B41`3_knl00`3F
e]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<k>cP36a/H0a/K600D0kno_0P1kNg/0102][Jd0g]kN0=kNgP3[jn/C0?Ogm`030?_kn`3oool0oooo
00P0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?Ogm`3_knl0kno_0080g]kN0`24Q8@00`20
P800Ng]k07]kN`020=kNgPX0moOg00<0no_k0?ooo`3oool04P3gmoL20>o_k`<0g]kN0P24Q8@307]k
N`<0g]kN1`3gmoL20?ooo`030?_kn`3gmoL0moOg0180moOg00<0lo?c0>o_k`3_knl00P3Ng]h308B4
Q080Ng]k0`3Ng]h50?Ogm`80oooo00<0no_k0?Ogm`3gmoL03`3gmoL00`3clo<0kno_0>o_k`030=kN
gP80Q8B40`1kNg/20=kNgPP0moOg0P3oool00`3kno/0moOg0?Ogm`0B0?Ogm`80oooo0`3_knl30=kN
gP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<c<c032`/80`/;200D0lo?c0P24Q8@0102f][H0inOW0>OWi`3alO4C0?_k
n`030?gmo@3oool0oooo00P0no_k0P3oool00`3moOd0no_k0?_kn`020?ooo`030?_kn`3gmoL0moOg
0080kno_0`24Q8@00`22PX80P8200820P0020>OWi`X0no_k00<0oOgm0?ooo`3oool04P3kno/20?Og
m`<0kno_0P24Q8@30820P0<0inOW1`3kno/20?ooo`030?gmo@3kno/0no_k0180no_k00<0nOWi0?Og
m`3gmoL00P3_knl308B4Q080P8200`3[jn/50?_kn`80oooo00<0oOgm0?_kn`3kno/03`3kno/00`3i
nOT0moOg0?Ogm`030>o_k`80Q8B40`20P8020>OWi`P0no_k0P3oool00`3moOd0no_k0?_kn`0B0?_k
n`80oooo0`3gmoL30>o_k`80Q8B41`3clo<00`3Hf=P0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102n_[h0
kno_0>o_k`3gmoLZ0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3gmoLO0?oo
o`D0Q8B40P3_knlW0?ooo`80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102n_[h0
kno_0>o_k`3gmoLZ0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3gmoLO0?oo
o`D0Q8B40P3_knlW0?ooo`80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800
Ng]k07]kN`0508B4Q080Ng]k4P24Q8@307]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00:08B4Q080
Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`20P80708B4Q080S8b<00<0R8R808B4
Q024Q8@01@24Q8@00`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207=cL`0307alO024Q8@0Q8B4
00<0Q8B40P2<S8`00`28R8P0Q8B408B4Q00808B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]k
N`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/00P24Q8@01028R8P0S8b<08b<S028R8PF
08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207=cL`0307alO024Q8@0Q8B40080Q8B400<0R8R8
08b<S02<S8`02P24Q8@00`20P800Ng]k07]kN`0:08B4Q0L0oooo00<0hn?S0<K6aP36a/H00`3>c/h2
0=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?oo
o`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4
Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8201`24Q8@2
08b<S00308R8R024Q8@0Q8B400D0Q8B400<0P82007]kN`1kNg/03@24Q8@207]kN`D0Q8B40P1cLg<0
0`1lO7`0Q8B408B4Q00308B4Q080S8b<00<0R8R808B4Q024Q8@02024Q8@207]kN`030820P024Q8@0
Q8B400X0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0030820P01kNg/0Ng]k0080Q8B400@0R8R8
08b<S02<S8`0R8R85P24Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1cLg<00`1lO7`0Q8B408B4
Q00208B4Q00308R8R02<S8`0S8b<00X0Q8B400<0P82007]kN`1kNg/02P24Q8@70?ooo`030>?Sh`36
a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b<S8
0;fm_@2m_Kd01@3kno/20820P00408:2PP24Q8@0Q8B408:2PP@0P8200`24Q8@40820P00308:2PP24
Q8@0Q8B400P0Q8B40P20P8000`22PX80Q8B408B4Q0050820P00308:2PP24Q8@0Q8B400D0P8201@24
Q8@00`22PX80P8200820P00208B4Q0D0P8200P24Q8@00`22PX80P8200820P0030820P0D0Q8B40P28
R8P00`26QXH0Q8B408B4Q0030820P080Q8B400<0PX:20820P020P8000P20P80508B4Q0<0P8200`24
Q8@40820P00308:2PP24Q8@0Q8B40080O7al00@0OWin0820P020P800PX:20P24Q8@208R8R00308J6
QP24Q8@0Q8B40080Q8B400<0PX:20820P020P8000`24Q8@50820P0D0Q8B40P20P80308B4Q0D0P820
0P24Q8@00`22PX80P8200820P0020820P00408B4Q028R8P0R8R808J6QPL0Q8B41@20P80508B4Q0<0
P8200P24Q8@50820P0<0Q8B40P1lO7`00`1nOWh0P8200820P00208B4Q00308J6QP28R8P0R8R800D0
Q8B400<0PX:20820P020P8000P24Q8@00`22PX80P8200820P0050820P0D0Q8B41`3kno/00`3Ogml0
`/;20<;2`P030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0moOg0P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`030820
P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@0
0P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00@0Q8B400<0P82007]kN`1kNg/0
1@24Q8@00`20P800Ng]k07]kN`0:08B4Q0<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/508B4Q080Ng]k
00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`20P80908B4Q0030820P01kNg/0Ng]k00D0
Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`03
0820P024Q8@0Q8B400P0Q8B41@1kNg/508B4Q0<0Ng]k1024Q8@00`20P800Ng]k07]kN`0508B4Q003
0820P01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/01@24Q8@507]kN`D0Q8B41`3gmoL00`3Jf]X0
_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0moOg0P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`030820
P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@0
0P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00@0Q8B400<0P82007]kN`1kNg/0
1@24Q8@00`20P800Ng]k07]kN`0:08B4Q0<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/508B4Q080Ng]k
00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`20P80908B4Q0030820P01kNg/0Ng]k00D0
Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`03
0820P024Q8@0Q8B400P0Q8B41@1kNg/508B4Q0<0Ng]k1024Q8@00`20P800Ng]k07]kN`0508B4Q003
0820P01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/01@24Q8@507]kN`D0Q8B41`3gmoL00`3Jf]X0
_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:
bP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Ogm`@0oooo00<0no_k0?Ogm`3g
moL00`3gmoL50?ooo`D0moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080
g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0
oooo0?ooo`020?Ogm`<0g]kN1@24Q8@30=kNgP@0moOg00<0no_k0?ooo`3oool01@3oool00`3kno/0
moOg0?Ogm`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080
g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`020?ooo`03
0?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h50?Ogm`P0
oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4
Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Og
m`@0oooo00<0no_k0?Ogm`3gmoL00`3gmoL50?ooo`D0moOg0`3oool50?Ogm`80oooo00<0no_k0?Og
m`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg00<0no_k0?oo
o`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24Q8@30=kNgP@0moOg00<0no_k0?oo
o`3oool01@3oool00`3kno/0moOg0?Ogm`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?oo
o`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool00P3gmoL00`3k
no/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30=kN
gPD0Q8B40P3Ng]h50?Ogm`P0oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0
oooo00D0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102a
/K40g]kN0=kNgP3[jn/70?Ogm`@0oooo00<0no_k0?Ogm`3gmoL00`3gmoL50?ooo`D0moOg0`3oool5
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`03
0?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24Q8@3
0=kNgP@0moOg00<0no_k0?ooo`3oool01@3oool00`3kno/0moOg0?Ogm`050?Ogm`80oooo00<0no_k
0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k
0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k
0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h50?Ogm`P0oooo1`3gmoL0103kno/0oooo0?ooo`3k
no/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm
_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0
a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knlU0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24
Q8@20=kNgQl0oooo0P3gmoL30=kNgPD0Q8B40`3Ng]hN0?ooo`030?_kn`3gmoL0moOg0080g]kN0`24
Q8@208b<S0<0g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3N
g]h208b<S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_9@3o
ool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]hO0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN7P3o
ool00`3kno/0moOg0?Ogm`020=kNgP<0Q8B40P2<S8`30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3N
g]h508B4Q080g]kN8@3oool30?Ogm`<0g]kN0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80e]KF00<0c<c<0<;2`P32`/801@3kno/2
08B4Q0040;6a/@3Ng]h0g]kN0>o_kbD0oooo00<0oOgm0?_kn`3kno/00P3WinL608B4Q080g]kN7`3o
ool20?_kn`<0inOW1@24Q8@30=kNgQh0oooo00<0oOgm0?_kn`3kno/00P3WinL308B4Q080R8R80`3N
g]hI0?ooo`030?gmo@3kno/0no_k00<0inOW1@24Q8@20=kNgR40oooo0`3kno/30>OWi`80R8R81`3k
no/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl2
0=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3_knlX0?ooo`80kno_1P24
Q8@20=kNgR40oooo0`3_knl508B4Q0<0g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0kno_1@24
Q8@20=kNgR@0oooo0`3_knl208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a
0=kNgP3Ng]h0kno_:03oool20>o_k`H0Q8B40P3Ng]hQ0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3_
knl508B4Q0<0g]kN703oool30>o_k`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@70?ooo`030=kNgP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K6
0;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg1`3oool20>o_k`040:6QX@1B
DU80DU9B02TY:@@0000000<020P8010@400@41000P2<S8`00`36a/H0oooo0?ooo`0:0?ooo`030?_k
n`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool03@3oool20000000306][
J`3Fe]H0e]KF00X0oooo0`3Ng]h508B4Q0<0e]KF0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN
1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool05`3oool30=kNgPD0Q8B40P3Fe]H20?Ogm`030?_k
n`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24
Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`L0oooo0P3_knl0102QXJ40DU9B059BDP0Y:BT400000003
00P8200@4100410@0080S8b<00<0a/K60?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`020=kNgPH0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00d0oooo0P0000000`1[Jf/0e]KF0=KFeP0:0?ooo`<0
g]kN1@24Q8@30=KFeP80moOg703oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20?Ogm`03
0?_kn`3oool0oooo01L0oooo0`3Ng]h508B4Q080e]KF0P3gmoL00`3kno/0oooo0?ooo`0L0?ooo`<0
moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm_@020?Ogm`030?Gem@3clo<0lo?c0080Q8B4
00@0/K6a0=kNgP3Ng]h0jNWY0P3clo<70?ooo`80VIVI00@0R8R807MgM`1gMgL0O7al1020P8000`1[
Jf/0EUIF05IFEP0204I6AP030:>SX`3oool0oooo00X0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4
Q080g]kN0P3gmoL00`3inOT0no_k0?_kn`0=0?ooo`805ADE00<0K6a/0<;2`P32`/80203oool20?_k
n`<0g]kN1@24Q8@30=[JfP80lo?c703oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20?_k
n`030?gmo@3oool0oooo01@0oooo00<0oOgm0?_kn`3kno/00`3Ng]h508B4Q080f][J0P3clo<00`3i
nOT0oooo0?ooo`0L0?ooo`<0moOg0`3WinL208B4Q080lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3H
f=P0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_
k`L0oooo0P12@T80101_Kfl0W9bL09bLW03>c/h40?ooo`030<k>cP2LW9`0W9bL0080000000<0P820
0?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h50?Ogm`d0oooo0P0Y:BT0
0`1[Jf/0[Jf]0:f][@080?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3_knlL0?ooo`030?_kn`3gmoL0
moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN0P3_knl0
0`3gmoL0oooo0?ooo`0L0?ooo`<0moOg0`3_knl208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl0
0`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KF
eP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102a/K40g]kN0=kNgP3WinL2
0>o_k`L0oooo0P12@T80101_Kfl0W9bL09bLW03>c/h40?ooo`030<k>cP2LW9`0W9bL0080000000<0
P8200?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h50?Ogm`d0oooo0P0Y
:BT00`1[Jf/0[Jf]0:f][@080?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3_knlL0?ooo`030?_kn`3g
moL0moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN0P3_
knl00`3gmoL0oooo0?ooo`0L0?ooo`<0moOg0`3_knl208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_
knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knl20?ooo`D0moOg0P3o
ool20?Ogm`040<;2`P2<S8`0S8b<04Y:BP8020P80P0000000`0410@020P800P8200208b<S0030<K6
aP3oool0oooo00X0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_knl00`3gmoL0oooo
0?ooo`050?ooo`0308B4Q00820P020P80080a/K600<0hn?S0?ooo`3oool01@1cLg<:0?ooo`<0g]kN
1@24Q8@30=kNgP80moOg1@3oool20;fm_@0407=cL`0Y:BT0:BTY01DE5@@0000000<0:BTY059BDP1B
DU800P3_knl00`3gmoL0oooo0?ooo`050?ooo`030?Ogm`3_knl0kno_0080g]kN0`24Q8@207]kN`<0
g]kN0P3gmoL00`3kno/0oooo0?ooo`0500000080oooo00@0c/k>09bLW02LW9`0CTi>100000000`20
P800oooo0?ooo`050?ooo`<0g]kN1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool00`3oool20?Og
m`0307alO000000000000080000000<0CTi>09bLW02LW9`00P3oool0103[jn/0e]KF0=KFeP20P802
02TY:@80000000<0P8200?ooo`3oool00P3oool30>o_k`<0g]kN0P1kNg/70?Ogm`030=oOg`36a/H0
a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6
aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3gmoL20?ooo`80moOg00@0`/;2
08b<S02<S8`0BTY:0P0820P20000000300@4100820P020P80080S8b<00<0a/K60?ooo`3oool02P3o
ool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030?Ogm`3oool0oooo00D0oooo00<0
Q8B400P8200820P00P36a/H00`3Shn<0oooo0?ooo`0507=cL`X0oooo0`3Ng]h508B4Q0<0g]kN0P3g
moL50?ooo`80_Kfm00@0Lg=c02TY:@0Y:BT05ADE100000000`0Y:BT0DU9B059BDP020>o_k`030?Og
m`3oool0oooo00D0oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q080Ng]k0`3Ng]h20?Ogm`030?_k
n`3oool0oooo00D000000P3oool0103>c/h0W9bL09bLW01>CTh4000000030820P03oool0oooo00D0
oooo0`3Ng]h508B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0O7al00000000
00000P0000000`1>CTh0W9bL09bLW0020?ooo`040>_[j`3Fe]H0e]KF0820P080:BTY0P0000000`20
P800oooo0?ooo`020?ooo`<0kno_0`3Ng]h207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80
Ng]k00@0[Jf]0=kNgP3Ng]h0inOW0P3_knl90?ooo`040820P0000000000003hn?P80Ng]k0P3_knl0
0`3gmoL0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo00P0oooo1@3gmoL20=kNgPH0Q8B40P3Ng]h2
0>o_k`030??cl`3gmoL0moOg0080moOg00@0no_k0?ooo`3oool0/K6a0P1SHf<207]kN`030;fm_@3o
ool0oooo0080W9bL00<0Kfm_0492@P12@T800`3oool20?Ogm`030?_kn`3oool0oooo0080kno_0`3N
g]h508B4Q0<0g]kN103gmoL00`3kno/0oooo0?ooo`0202TY:@0404Y:BP1[Jf/0Jf][0;6a/@80moOg
0P3_knl00`2e]KD0Ng]k07]kN`0202TY:@0308B4Q03Ng]h0g]kN00<0oooo1@3gmoL20=kNgPD0Q8B4
0`3Ng]h20>o_k`030?Ogm`3oool0oooo0080oooo00<0S8b<01PH600H61P00P2][Jd0101KFe/020P8
00P8201lO7`20>o_k`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0
Q8B40P3Ng]h50?Ogm`D0oooo00<0no_k0?Ogm`3gmoL00P3>c/h00`1cLg<061PH01PH60020=KFeP04
08b<S012@T80@T9205MGE`80Jf][0P3oool00`3kno/0moOg0?Ogm`020?ooo`<0moOg0`3Ng]h208B4
Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3Ng]h0inOW0P3_knl90?oo
o`040820P0000000000003hn?P80Ng]k0P3_knl00`3gmoL0oooo0?ooo`020?Ogm`030?_kn`3oool0
oooo00P0oooo1@3gmoL20=kNgPH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080moOg00@0no_k
0?ooo`3oool0/K6a0P1SHf<207]kN`030;fm_@3oool0oooo0080W9bL00<0Kfm_0492@P12@T800`3o
ool20?Ogm`030?_kn`3oool0oooo0080kno_0`3Ng]h508B4Q0<0g]kN103gmoL00`3kno/0oooo0?oo
o`0202TY:@0404Y:BP1[Jf/0Jf][0;6a/@80moOg0P3_knl00`2e]KD0Ng]k07]kN`0202TY:@0308B4
Q03Ng]h0g]kN00<0oooo1@3gmoL20=kNgPD0Q8B40`3Ng]h20>o_k`030?Ogm`3oool0oooo0080oooo
00<0S8b<01PH600H61P00P2][Jd0101KFe/020P800P8201lO7`20>o_k`80oooo00<0no_k0?Ogm`3g
moL00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0Q8B40P3Ng]h50?Ogm`D0oooo00<0no_k0?Ogm`3g
moL00P3>c/h00`1cLg<061PH01PH60020=KFeP0408b<S012@T80@T9205MGE`80Jf][0P3oool00`3k
no/0moOg0?Ogm`020?ooo`<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80
Ng]k00@0[Jf]0=kNgP3Ng]h0inOW0P3_knl90?ooo`040820P0000000000003hn?P80Ng]k0P3_knl0
0`3gmoL0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo00P0oooo1@3gmoL20=kNgPH0Q8B40P3Ng]h2
0>o_k`030??cl`3gmoL0moOg0080moOg00@0no_k0?ooo`3oool0/K6a0P1SHf<207]kN`030;fm_@3o
ool0oooo0080W9bL00<0Kfm_0492@P12@T800`3oool20?Ogm`030?_kn`3oool0oooo0080kno_0`3N
g]h508B4Q0<0g]kN103gmoL00`3kno/0oooo0?ooo`0202TY:@0404Y:BP1[Jf/0Jf][0;6a/@80moOg
0P3_knl00`2e]KD0Ng]k07]kN`0202TY:@0308B4Q03Ng]h0g]kN00<0oooo1@3gmoL20=kNgPD0Q8B4
0`3Ng]h20>o_k`030?Ogm`3oool0oooo0080oooo00<0S8b<01PH600H61P00P2][Jd0101KFe/020P8
00P8201lO7`20>o_k`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`030=kNgPD0
Q8B40P3Ng]h50?Ogm`D0oooo00<0no_k0?Ogm`3gmoL00P3>c/h00`1cLg<061PH01PH60020=KFeP04
08b<S012@T80@T9205MGE`80Jf][0P3oool00`3kno/0moOg0?Ogm`020?ooo`<0moOg0`3Ng]h208B4
Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW2`3gmoL01020
P80020P800P82020P8070?Ogm`80oooo00<0no_k0?Ogm`3gmoL02P3gmoL00`3clo<0kno_0>o_k`02
0=kNgPH0Q8B40P3Fe]H20>o_k`030?Ogm`3oool0oooo00D0moOg00<0b/[:09bLW02LW9`00P0Y:BT0
0`2@T900moOg0?Ogm`020;fm_@0306=SH`0820P020P800<0moOg0P3oool00`3kno/0moOg0?Ogm`02
0?Ogm`<0e]KF1@24Q8@30=kNgPL0moOg0P0000001020P800oooo0?ooo`3kno/70?Ogm`80S8b<00<0
Jf][04Y:BP1:BTX00`3gmoL20?ooo`030?Ogm`3_knl0kno_0080g]kN1@24Q8@30=kNgP80kno_00<0
lo?c0?Ogm`3gmoL00P3gmoL00`2UYJD0DU9B059BDP020000000403Hf=P1[Jf/0Jf][0;6a/@@0moOg
00<0no_k0?ooo`3oool01@3gmoL30=KFePD0Q8B40P3Ng]h:0?Ogm`030?_kn`3oool0oooo0080moOg
00<0d];B0:f][@2][Jd00P1:BTX0100U9BD000000000001WIfL20<k>cP80moOg00<0no_k0?ooo`3o
ool00P3gmoL30>o_k`<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040:f]
[@3Fe]H0e]KF0>OWi`/0moOg00@0P82000P8200820P0P8201`3gmoL20?ooo`030?_kn`3gmoL0moOg
00X0moOg00<0lo?c0>o_k`3_knl00P3Ng]h608B4Q080e]KF0P3_knl00`3gmoL0oooo0?ooo`050?Og
m`030<[:bP2LW9`0W9bL0080:BTY00<0T92@0?Ogm`3gmoL00P2m_Kd00`1SHf<020P800P820030?Og
m`80oooo00<0no_k0?Ogm`3gmoL00P3gmoL30=KFePD0Q8B40`3Ng]h70?Ogm`80000000@0P8200?oo
o`3oool0no_k1`3gmoL208b<S00306][J`1:BTX0BTY:00<0moOg0P3oool00`3gmoL0kno_0>o_k`02
0=kNgPD0Q8B40`3Ng]h20>o_k`030??cl`3gmoL0moOg0080moOg00<0YJFU059BDP1BDU800P000000
100f=SH0Jf][06][J`2a/K440?Ogm`030?_kn`3oool0oooo00D0moOg0`3Fe]H508B4Q080g]kN2P3g
moL00`3kno/0oooo0?ooo`020?Ogm`030=;BdP2][Jd0[Jf]0080BTY:00@09BDU000000000000IfMW
0P3>c/h20?Ogm`030?_kn`3oool0oooo0080moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36
a/H0a/K600D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL;0?Ogm`040820P00820P020P80820P0L0
moOg0P3oool00`3kno/0moOg0?Ogm`0:0?Ogm`030??cl`3_knl0kno_0080g]kN1P24Q8@20=KFeP80
kno_00<0moOg0?ooo`3oool01@3gmoL00`3:b/X0W9bL09bLW00202TY:@03092@T03gmoL0moOg0080
_Kfm00<0Hf=S00P8200820P00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080moOg0`3Fe]H508B4Q0<0
g]kN1`3gmoL2000000040820P03oool0oooo0?_kn`L0moOg0P2<S8`00`1[Jf/0BTY:04Y:BP030?Og
m`80oooo00<0moOg0>o_k`3_knl00P3Ng]h508B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`020?Og
m`030:FUY@1BDU80DU9B0080000000@0=SHf06][J`1[Jf/0/K6a103gmoL00`3kno/0oooo0?ooo`05
0?Ogm`<0e]KF1@24Q8@20=kNgPX0moOg00<0no_k0?ooo`3oool00P3gmoL00`3Bd]80[Jf]0:f][@02
04Y:BP0402DU9@000000000006MWI`80c/k>0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0kno_0`3F
e]H208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_
knl90?Ogm`040:6QX@1:BTX0BTY:07alO080[Jf]0P3gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030?_k
n`3oool0oooo0080moOg00<0lo?c0>o_k`3_knl00P3Fe]H608B4Q080g]kN0P3_knl00`3clo<0moOg
0?Ogm`050?Ogm`030??cl`3_knl0kno_0080000000<0?Shn07]kN`1kNg/00P3gmoL00`1lO7`00000
000000030?ooo`D0moOg0P3_knl30=KFePD0Q8B40`3Ng]h20>o_k`D0moOg4P0000050?Ogm`030??c
l`3_knl0kno_0080g]kN1@24Q8@30=KFeP80kno_00<0lo?c0?Ogm`3gmoL00P3oool00`36a/H0S8b<
08b<S00201PH6004034a<@1:BTX0BTY:09BDU080g]kN0P3oool00`3kno/0moOg0?Ogm`020?Ogm`03
0??cl`3_knl0kno_00<0e]KF1@24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00`3gmoL20?ooo`03
0?_kn`3gmoL0moOg00D0moOg0P0Y:BT0100E5AD000000000001lO7`90?Ogm`<0kno_0`3Ng]h208B4
Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_
k`T0moOg00@0XJ6Q04Y:BP1:BTX0O7al0P2][Jd20?Ogm`030?_kn`3oool0oooo00X0moOg00<0no_k
0?ooo`3oool00P3gmoL00`3clo<0kno_0>o_k`020=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0
moOg00D0moOg00<0lo?c0>o_k`3_knl00P0000000`0n?Sh0Ng]k07]kN`020?Ogm`0307alO0000000
000000<0oooo1@3gmoL20>o_k`<0e]KF1@24Q8@30=kNgP80kno_1@3gmoLB000000D0moOg00<0lo?c
0>o_k`3_knl00P3Ng]h508B4Q0<0e]KF0P3_knl00`3clo<0moOg0?Ogm`020?ooo`030<K6aP2<S8`0
S8b<008061PH00@0<C4a04Y:BP1:BTX0U9BD0P3Ng]h20?ooo`030?_kn`3gmoL0moOg0080moOg00<0
lo?c0>o_k`3_knl00`3Fe]H508B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`030?Ogm`80oooo00<0
no_k0?Ogm`3gmoL01@3gmoL202TY:@0401DE5@000000000007alO0T0moOg0`3_knl30=kNgP80Q8B4
1@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Ogm`0208B4Q0040;6a/@3N
g]h0g]kN0>OWi`@0kno_1`3gmoL0103Shn<0c/k>0<k>cP2<S8`204Y:BQL0moOg0P3Fe]H307]kN`03
0820P024Q8@0Q8B40080e]KF0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`040:VYZ@1JFUX0FUYJ02d]
;@8000000P0H61P00`1JFUX0W9bL09bLW0020000000300`<300H61P061PH00P0moOg0P3_knl30=KF
eP80Q8B40`1kNg/30=KFeP80kno_0P3gmoL00`3clo<0kno_0>o_k`0205YJFP0406][J`1kNg/0Ng]k
0;Vi^@T0moOg00<0O7al0000000000000`3gmoL50>o_k`80e]KF0`1kNg/208B4Q0<0g]kN0P3_knl0
0`3clo<0moOg0?Ogm`020?Ogm`0307alO000000000000080:BTY00@0Q8B40=kNgP3Ng]h0W9bL0P1J
FUX20000000307alO03gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl00`3Fe]H208B4Q0<0Ng]k0P3F
e]H20>o_k`030??cl`3gmoL0moOg00<0kno_0P3gmoL00`3clo<0kno_0>o_k`050?Ogm`80[Jf]00@0
EeMG000000000000O7al1`3gmoL50>o_k`<0e]KF0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3o
ool00`3kno/0moOg0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`@0kno_1`3gmoL0103Shn<0c/k>
0<k>cP2<S8`204Y:BQL0moOg0P3Fe]H307]kN`030820P024Q8@0Q8B40080e]KF0P3_knl00`3clo<0
moOg0?Ogm`020?Ogm`040:VYZ@1JFUX0FUYJ02d];@8000000P0H61P00`1JFUX0W9bL09bLW0020000
000300`<300H61P061PH00P0moOg0P3_knl30=KFeP80Q8B40`1kNg/30=KFeP80kno_0P3gmoL00`3c
lo<0kno_0>o_k`0205YJFP0406][J`1kNg/0Ng]k0;Vi^@T0moOg00<0O7al0000000000000`3gmoL5
0>o_k`80e]KF0`1kNg/208B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`0307alO0000000
00000080:BTY00@0Q8B40=kNgP3Ng]h0W9bL0P1JFUX20000000307alO03gmoL0moOg0080moOg00<0
lo?c0>o_k`3_knl00`3Fe]H208B4Q0<0Ng]k0P3Fe]H20>o_k`030??cl`3gmoL0moOg00<0kno_0P3g
moL00`3clo<0kno_0>o_k`050?Ogm`80[Jf]00@0EeMG000000000000O7al1`3gmoL50>o_k`<0e]KF
0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30>OWi`80d];B00<0b<S80;fm_@2m_Kd00P3oool00`3moOd0no_k0?_kn`0208B4Q0040:n_[`3J
f]X0f][J0>GUi@80kno_0P3clo<50?Ogm`80lo?c00@0jn_[0>?Sh`3Shn<0WinO0P1KFe/209RHV003
08Z:RP1lO7`0O7al0080O7al00<0WIfM0;jn_P2n_[h00`3gmoL:0??cl`80f][J1P24Q8@20=KFeP80
inOW00<0kno_0?Ogm`3gmoL00P3clo<0103>c/h0ZJVY0:VYZ@2ATI4207QhN080Q8B400<0YJFU0<K6
aP36a/H00P1lO7`00`20P800Q8B408B4Q0080??cl`80kno_0`3Jf]X208B4Q0<0P8200`3Bd]820>OW
i`D0lo?c0P2HV9P0101_Kfl0ATI604I6AP1nOWh20;Fe]@80jn_[00<0kno_0??cl`3clo<00P2a/K40
0`1SHf<05ADE01DE5@080??cl`80f][J1@20P8030=[JfP80kno_00<0lo?c0?Ogm`3gmoL00P3clo<0
0`2h^;P0O7al07alO00208b<S0040;bl_03[jn/0jn_[0<S8b080YJFU0P1hN7P00`2f][H0lo?c0??c
l`020??cl`030?7al@3_knl0kno_00<0f][J0P24Q8@30820P080d];B0P3WinL00`3]kNd0lo?c0??c
l`0:0??cl`030?Gem@3gmoL0moOg0080`/;200@0HF5Q000000000000NWYj103clo<00`3emOD0moOg
0?Ogm`020??cl`<0kno_0`3Fe]H20820P0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0
[Jf]0=KFeP3Fe]H0hn?S0P3_knl70?Ogm`80kno_00@0lo?c0?Ogm`3gmoL0/K6a0P1[Jf/203Ti>@03
01dM7@00000000000080000000<0@T9208B4Q024Q8@00`3gmoL:0>o_k`80g]kN0`2<S8`00`28R8P0
Q8B408B4Q0020=KFeP80g]kN00<0jn_[0?Ogm`3gmoL00P3_knl0103clo<0moOg0?Ogm`3clo<70>o_
k`80moOg00<0lo?c0>o_k`3_knl02P3_knl30=kNgPD0Q8B40`3>c/h20=kNgP80kno_00<0lo?c0?Og
m`3gmoL00P3Fe]H0101cLg<0410@010@4012@T8207=cL`80g]kN00<0inOW0>o_k`3_knl00P1[Jf/0
0`1:BTX0:BTY02TY:@030>o_k`D0moOg0P3Ng]h308B4Q080Ng]k0`3Fe]H20>o_k`030??cl`3gmoL0
moOg0080kno_00<0lo?c0?Ogm`3gmoL00P3_knl0103clo<0moOg0?Ogm`3clo<<0>o_k`<0g]kN1@24
Q8@20<k>cP80g]kN00<0inOW0>o_k`3_knl00`3gmoL20>o_k`030??cl`3gmoL0moOg0080kno_00<0
lo?c0?Ogm`3gmoL00P3Fe]H0101[Jf/000000000001hN7P40>o_k`030??cl`3gmoL0moOg0080moOg
0`3_knl30=KFeP80Ng]k1`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0e]KF0=KF
eP3Shn<20>o_k`L0moOg0P3_knl0103clo<0moOg0?Ogm`2a/K4206][J`80>CTi00<07AdM00000000
00000P0000000`12@T80Q8B408B4Q0030?Ogm`X0kno_0P3Ng]h308b<S00308R8R024Q8@0Q8B40080
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`020>o_k`040??cl`3gmoL0moOg0??cl`L0kno_0P3gmoL00`3c
lo<0kno_0>o_k`0:0>o_k`<0g]kN1@24Q8@30<k>cP80g]kN0P3_knl00`3clo<0moOg0?Ogm`020=KF
eP0407=cL`0@4100410@0492@P80Lg=c0P3Ng]h00`3WinL0kno_0>o_k`0206][J`0304Y:BP0Y:BT0
:BTY00<0kno_1@3gmoL20=kNgP<0Q8B40P1kNg/30=KFeP80kno_00<0lo?c0?Ogm`3gmoL00P3_knl0
0`3clo<0moOg0?Ogm`020>o_k`040??cl`3gmoL0moOg0??cl``0kno_0`3Ng]h508B4Q080c/k>0P3N
g]h00`3WinL0kno_0>o_k`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Og
m`020=KFeP0406][J`000000000007QhN0@0kno_00<0lo?c0?Ogm`3gmoL00P3gmoL30>o_k`<0e]KF
0P1kNg/70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0030:f][@3Fe]H0e]KF00<0e]KF0P3N
g]h30>o_k`80g]kN1@3_knl00`2QXJ40DU9B059BDP0203Ti>@0307=cL`2][Jd0[Jf]0080]KFe00<0
Fe]K0000000000002P3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k00<0P82008B4Q024Q8@0103F
e]H00`3Jf]X0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`@0kno_00<0inOW0=kNgP3Ng]h0
0P3_knl00`3WinL0g]kN0=kNgP080>o_k`80g]kN0`3Fe]H207]kN`<0Q8B41@3Fe]H20=kNgP030>OW
i`3_knl0kno_0080g]kN00@0f][J0=KFeP3Fe]H0T92@0P1:BTX500000080:BTY00<0P8200=KFeP3F
e]H01@3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k0P24Q8@50=KFeP030=[JfP3Ng]h0g]kN0080
kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN0080
kno_00<0inOW0=kNgP3Ng]h00`3Fe]H207]kN`<0Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP030>o_k`80
g]kN00<0inOW0>o_k`3_knl00P3_knl00`3WinL0g]kN0=kNgP0206][J`0405]KF`1:BTX0BTY:09fM
W@T0kno_0`3Ng]h30=KFeP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@00`2][Jd0
e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0XJ6Q059BDP1BDU800P0i>CT00`1cLg<0
[Jf]0:f][@020;Fe]@0305]KF`000000000000X0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`03
0820P024Q8@0Q8B400@0e]KF00<0f][J0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL40>o_
k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0203_knl20=kNgP<0e]KF0P1kNg/308B4
Q0D0e]KF0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP040=[JfP3Fe]H0e]KF092@T080BTY:1@000002
02TY:@030820P03Fe]H0e]KF00D0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`80Q8B41@3Fe]H0
0`3Jf]X0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0kno_00<0inOW0=kNgP3Ng]h00P3_knl0
0`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00<0e]KF0P1kNg/308B4Q0@0e]KF00<0f][J
0=kNgP3Ng]h00`3_knl20=kNgP030>OWi`3_knl0kno_0080kno_00<0inOW0=kNgP3Ng]h00P1[Jf/0
101KFe/0BTY:04Y:BP2MWId90>o_k`<0g]kN0`3Fe]H207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P05
0??cl`80Q8B400@0Zj^[0=;BdP3Bd]80e]KF0P3Jf]X20=kNgP<0inOW0P3Ng]h20>o_k`040>_[j`3W
inL0inOW0<30`080V9RH0P28R8P00`22PX80O7al07alO00205]KF`0303@d=00<30`030`<00<0kno_
0P3WinL00`3[jn/0kno_0>o_k`020>OWi`030>?Sh`3Ng]h0g]kN0080d];B0`20P8000`22PX80Q8B4
08B4Q0020=;BdP80f][J00<0g=cL0=kNgP3Ng]h00P3WinL0103Shn<0g]kN0=kNgP3YjNT20??cl`80
inOW00<0hn?S0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>OWi`030>_[j`3_knl0kno_0080
g]kN0`3Bd]820820P0<0Q8B40`3Bd]820=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h0103QhN40
hn?S0>?Sh`2l_;`209BDU080Kfm_00<0M7Ad07QhN01hN7P00P24Q8@00`2_[jl0f][J0=[JfP030>OW
i`80kno_00<0inOW0=kNgP3Ng]h00P3Bd]830820P080Q8B40`3Bd]820=[JfP030=cLg03Ng]h0g]kN
0080inOW00<0hn?S0=kNgP3Ng]h00P3_knl0103[jn/0inOW0>OWi`3Shn<20=kNgP80kno_00<0inOW
0=kNgP3Ng]h00P3WinL00`3Shn<0g]kN0=kNgP030=;BdP80P8200`24Q8@20=;BdP80f][J00<0g=cL
0=kNgP3Ng]h00`3WinL20=kNgP030>OWi`3_knl0kno_0080inOW00<0Zj^[06m_K`1_Kfl00P1BDU80
101_Kfl0S8b<08b<S02j^[X40>OWi`030>_[j`3_knl0kno_0080inOW0`3Ng]h30=;BdP80P8201`3c
lo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0
inOW0=kNgP3Ng]h00`3Ng]h20=KFeP03092@T01:BTX0BTY:0080000000<030`<01PH600H61P00`3_
knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h608B4Q080c/k>2P3Ng]h00`3[jn/0moOg0?Og
m`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP<0c/k>1@24
Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0inOW103Ng]h00`3WinL0kno_0>o_k`080=kNgP80kno_
00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>2P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN
0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl0
0P3Ng]h00`1_Kfl000000000000203Ti>@0408B4Q03>c/h0c/k>0=KFeP@0g]kN00<0inOW0>o_k`3_
knl01@3Ng]h30<k>cP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102YZJT0c/k>
0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20=KFeP03092@T01:BTX0BTY:0080
000000<030`<01PH600H61P00`3_knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h608B4Q080
c/k>2P3Ng]h00`3[jn/0moOg0?Ogm`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0
kno_0>o_k`020=kNgP<0c/k>1@24Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0inOW103Ng]h00`3W
inL0kno_0>o_k`080=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>2P3Ng]h20>o_
k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20<k>
cPX0g]kN00<0inOW0>o_k`3_knl00P3Ng]h00`1_Kfl000000000000203Ti>@0408B4Q03>c/h0c/k>
0=KFeP@0g]kN00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@03
0<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<c<c032`/80`/;2
00D0lo?c0P28R8P0102[Zj/0c/k>0<k>cP3Fe]H20=kNgP80f][J1@3Ng]h20>OWi`040>?Sh`3Ng]h0
g]kN0=cLg080f][J0P3Fe]H00`2e]KD0U9BD09BDU00206][J`0307=cL`1kNg/0Ng]k00<0inOW0P3N
g]h00`3Shn<0inOW0>OWi`050=[JfP80c/k>1P24Q8@20<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3N
g]h00`3UiND0jn_[0>_[j`020=kNgP030=cLg03Jf]X0f][J0080hn?S00<0hN7Q0=kNgP3Ng]h00`3J
f]X20=kNgP030>?Sh`3WinL0inOW0080f][J0`3>c/h508B4Q0<0c/k>0P3Ng]h20=[JfP030=cLg03N
g]h0g]kN0080g]kN00@0hn?S0>OWi`3WinL0hn?S0P3Ng]h20=[JfP030=oOg`3Shn<0hn?S0080g]kN
00<0g=cL0=[JfP3Jf]X00`3Ng]h20>OWi`030>7Qh@3Jf]X0f][J0080c/k>1@24Q8@30<k>cP80g]kN
00<0g=cL0=[JfP3Jf]X01@3Ng]h20>OWi`040>?Sh`3Ng]h0g]kN0=cLg080f][J0P3Shn<00`3QhN40
g]kN0=kNgP050=[JfP<0c/k>1@24Q8@20<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h00`3Shn<0
inOW0>OWi`020=kNgP030:FUY@1[Jf/0Jf][0080R8R800@0[jn_0=KFeP3Fe]H0f=SH0P3Jf]X20=kN
gP030>?Sh`3WinL0inOW0080g]kN0`3Jf]X30<k>cP80Q8B41`3clo<00`3Hf=P0_Kfm0;fm_@030=;B
dP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P2<S8`0102][Jd0c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KF
eP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80c/k>1P24Q8@20<k>
cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN
00<0e]KF1@3Ng]h20=KFeP<0c/k>1@24Q8@30<k>cP80g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kN
gPD0e]KF0P3Ng]h00`3Jf]X0e]KF0=KFeP050=kNgP030=[JfP3Fe]H0e]KF0080c/k>1@24Q8@30<k>
cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN
00D0e]KF0`3>c/h508B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF
0080e]KF00@0f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4Q0L0moOg00<0f][J
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:
b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0[Jf]0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0f][J
0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3Fe]H2
0<k>cPH0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0
0`3Jf]X0g]kN0=kNgP030=KFePD0g]kN0P3Fe]H30<k>cPD0Q8B40`3>c/h20=kNgP80e]KF00<0f][J
0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3Fe]H01@3Ng]h00`3Jf]X0e]KF0=KFeP02
0<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0
0`3Jf]X0g]kN0=kNgP050=KFeP<0c/k>1@24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h0
0`3Jf]X0e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24
Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN0>_[j`@0moOg0`3o
oolD0?Ogm`D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Q8B400<0
P82007]kN`1kNg/00P3Ng]hB0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20>o_k`<0g]kN0P24
Q8@307]kN`<0g]kN3`3gmoL20?ooo`030?_kn`3gmoL0moOg00X0moOg00<0lo?c0>o_k`3_knl00P3N
g]h308B4Q080Ng]k0`3Ng]h<0?Ogm`040?_kn`3oool0oooo0?_kn`T0moOg00<0lo?c0>o_k`3_knl0
0`3Ng]h208B4Q0<0Ng]k0P3Ng]h?0?Ogm`030?_kn`3oool0oooo00d0moOg0P3oool30?Ogm`<0g]kN
0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN0>_[j`@0moOg
0`3ooolD0?Ogm`D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Q8B4
00<0P82007]kN`1kNg/00P3Ng]hB0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20>o_k`<0g]kN
0P24Q8@307]kN`<0g]kN3`3gmoL20?ooo`030?_kn`3gmoL0moOg00X0moOg00<0lo?c0>o_k`3_knl0
0P3Ng]h308B4Q080Ng]k0`3Ng]h<0?Ogm`040?_kn`3oool0oooo0?_kn`T0moOg00<0lo?c0>o_k`3_
knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]h?0?Ogm`030?_kn`3oool0oooo00d0moOg0P3oool30?Ogm`<0
g]kN0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80d];B00<0b<S80;fm_@2m_Kd01@3kno/20820P0040;Jf]P3[jn/0jn_[0??cl`@0
no_k0`3ooolD0?_kn`D0oooo00<0oOgm0?_kn`3kno/00P3oool00`3kno/0moOg0?Ogm`020>o_k`<0
Q8B400<0PX:20820P020P8000P3WinLB0?_kn`80oooo00<0oOgm0?_kn`3kno/0203kno/20?Ogm`<0
kno_0P24Q8@30820P0<0inOW3`3kno/20?ooo`030?gmo@3kno/0no_k00X0no_k00<0nOWi0?Ogm`3g
moL00P3_knl308B4Q080P8200`3WinL<0?_kn`040?gmo@3oool0oooo0?gmo@T0no_k00<0nOWi0?Og
m`3gmoL00`3_knl208B4Q0<0P8200P3WinL?0?_kn`030?gmo@3oool0oooo00d0no_k0P3oool30?_k
n`<0kno_0P24Q8@70?_kn`030=oOg`32`/80`/;200<0d];B0P3WinL00`3_knl0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040;jn_P3gmoL0moOg0?_k
nbX0oooo1P24Q8@20>o_kb@0oooo1@24Q8@30>o_kb<0oooo1@24Q8@30>o_kal0oooo1@24Q8@20>o_
kbL0oooo0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040;jn_P3gmoL0moOg0?_k
nbX0oooo1P24Q8@20>o_kb@0oooo1@24Q8@30>o_kb<0oooo1@24Q8@30>o_kal0oooo1@24Q8@20>o_
kbL0oooo0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3_knl508B4Q0030820P01kNg/0Ng]k00D0
Q8B40P1kNg/B08B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400X0Q8B40P1kNg/00`20P800
Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k0820P140Q8B400<0P82007]kN`1kNg/03@24Q8@207]k
N`D0Q8B40P1kNg/00`20P800Q8B408B4Q00@08B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]k
N`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/07024Q8@207]kN`030820P024Q8@0Q8B4
00<0Q8B40P1kNg/00`20P800Q8B408B4Q00?08B4Q0030820P01kNg/0Ng]k00X0Q8B41@3_knl20?Og
m`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0b/[:0<K6aP36a/H01@3_knl508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0<0
Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400X0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q004
0820P01kNg/0Ng]k0820P140Q8B400<0P82007]kN`1kNg/03@24Q8@207]kN`D0Q8B40P1kNg/00`20
P800Q8B408B4Q00@08B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B4
0080Q8B400<0P82007]kN`1kNg/07024Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20
P800Q8B408B4Q00?08B4Q0030820P01kNg/0Ng]k00X0Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm
00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0c<c<0<K6aP36
a/H01@3clo<20820P00408:2PP24Q8@0Q8B408:2PP@0P8200`24Q8@40820P00308:2PP24Q8@0Q8B4
00P0Q8B40P20P8000`22PX80Q8B408B4Q0050820P00308:2PP24Q8@0Q8B400D0P8201@24Q8@00`22
PX80P8200820P00408B4Q00308:2PP20P800P8200080Q8B400<0PX:20820P020P8000`20P80:08B4
Q0<0P8200P24Q8@00`22PX80P8200820P00207alO0D0Q8B40`20P80308R8R0@0P82000<0PX:208B4
Q024Q8@01@20P8000`22PX80Q8B408B4Q00708B4Q00308:2PP20P800P82000<0Q8B41@20P80508B4
Q080P8200`24Q8@50820P080Q8B400<0PX:20820P020P8000P20P8000`22PX80Q8B408B4Q00808B4
Q080P82000<0OWin07alO01lO7`01@24Q8@30820P080R8R81@20P80308B4Q0D0P8202P24Q8@00`22
PX80P8200820P00208B4Q00308:2PP20P800P82000D0P8200`24Q8@208R8R0D0lo?c0P3gmoL00`3M
gMd0`/;20<;2`P030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<k>cP36a/H0a/K600D0moOg0P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`03
0820P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024
Q8@00P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k0080Q8B40P2<S8`00`24Q8@0
Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B40`1kNg/508B4Q080Lg=c1@24Q8@307]kN`<0
S8b<0P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8202@24Q8@00`20
P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/508B4Q0030820P01kNg/0Ng]k
00D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k00<0MgMg07=cL`1cLg<01@24Q8@307]k
N`80S8b<0P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B400<0P82007]k
N`1kNg/01@24Q8@507]kN`<0Q8B40P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL207]kN`03
0820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`03
0820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0030820P01kNg/0Ng]k00D0
Q8B400<0P82007]kN`1kNg/00P24Q8@208b<S00308B4Q01kNg/0Ng]k00D0Q8B400<0P82007]kN`1k
Ng/02P24Q8@307]kN`D0Q8B40P1cLg<508B4Q0<0Ng]k0`2<S8`208B4Q080Ng]k00<0P82008B4Q024
Q8@00P24Q8@01020P800Ng]k07]kN`20P80908B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]k
N`1kNg/01@24Q8@207]kN`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`030820P024Q8@0Q8B4
00P0Q8B40P1kNg/00`1gMgL0Lg=c07=cL`0508B4Q0<0Ng]k0P2<S8`208B4Q0030820P01kNg/0Ng]k
00D0Q8B400<0P82007]kN`1kNg/02P24Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k0`24Q8@208b<
S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?oo
o`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`030?oo
o`D0moOg1@3oool20=kNgPH0Q8B40P3Ng]h70?Ogm`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3k
no/0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3gmoL30=kN
gPD0Q8B40`3Ng]h70?Ogm`P0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg00D0oooo00<0no_k0?Og
m`3gmoL00P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg
00D0moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h80?Og
m`L0oooo00<0no_k0?Ogm`3gmoL00P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`D0oooo1@3gmoL3
0=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/7
0?Ogm`@0oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0
oooo00<0oooo1@3gmoL50?ooo`80g]kN1P24Q8@20=kNgPL0moOg00<0no_k0?ooo`3oool00`3oool2
0?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`02
0?Ogm`<0g]kN1@24Q8@30=kNgPL0moOg203oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3oool0
0`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h70?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k
0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@2
0=kNgPP0moOg1`3oool00`3kno/0moOg0?Ogm`020?Ogm`040?_kn`3oool0oooo0?_kn`80moOg1@3o
ool50?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0
g]kN0>_[j`L0moOg103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo0080moOg00<0
no_k0?ooo`3oool00`3oool50?Ogm`D0oooo0P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?oo
o`030?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3o
ool0oooo0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL80?ooo`D0moOg0P3oool00`3kno/0moOg0?Og
m`050?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgPL0moOg00<0no_k0?ooo`3oool00P3o
ool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL00`3N
g]h508B4Q080g]kN203gmoL70?ooo`030?_kn`3gmoL0moOg0080moOg00@0no_k0?ooo`3oool0no_k
0P3gmoL50?ooo`D0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0
/K6a0=kNgP3Ng]h0kno_9@3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]hO0?ooo`80moOg
0`3Ng]h508B4Q0<0e]KF7P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]hI0?ooo`030?_k
n`3gmoL0moOg00<0g]kN1@24Q8@20=KFeR40oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m
_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knlU0?ooo`030?_kn`3gmoL0moOg0080g]kN
1P24Q8@20=kNgQl0oooo0P3gmoL30=kNgPD0Q8B40`3Fe]HN0?ooo`030?_kn`3gmoL0moOg0080g]kN
1@24Q8@30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080e]KF8@3oool30?Ogm`<0g]kN
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80d];B00<0b<S80;fm_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040;6a/@3N
g]h0g]kN0>o_kbD0oooo00<0oOgm0?_kn`3kno/00P3WinL608B4Q080g]kN7`3oool20?_kn`<0inOW
1@24Q8@30=[JfQh0oooo00<0oOgm0?_kn`3kno/00P3WinL508B4Q0<0g]kN6@3oool00`3moOd0no_k
0?_kn`030>OWi`D0Q8B40P3Jf]XQ0?ooo`<0no_k0`3WinL208B4Q080lo?c00<0mOGe0?Ogm`3gmoL0
0P3clo<00`3Hf=P0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102a/K40g]kN0=kN
gP3_knlX0?ooo`80kno_1P24Q8@20=kNgR40oooo0`3_knl508B4Q0<0g]kN8@3oool20>o_k`D0Q8B4
0`3Ng]hL0?ooo`<0kno_1@24Q8@20=kNgR@0oooo0`3_knl208B4Q080kno_00<0lo?c0?Ogm`3gmoL0
0P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102a/K40g]kN0=kN
gP3_knlX0?ooo`80kno_1P24Q8@20=kNgR40oooo0`3_knl508B4Q0<0g]kN8@3oool20>o_k`D0Q8B4
0`3Ng]hL0?ooo`<0kno_1@24Q8@20=kNgR@0oooo0`3_knl208B4Q080kno_00<0lo?c0?Ogm`3gmoL0
0P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102j^[X0kno_0>o_k`3gmoLX0?ooo`80g]kN
1P24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool00P3oool01020P800000000000020P80F0?ooo`<0
g]kN1@24Q8@30=kNgP80moOg2P3oool00`2@T9008B4Q024Q8@020000000305=CD`2UYJD0YJFU00X0
oooo00<0no_k0?Ogm`3gmoL00P3Ng]h308B4Q080Ng]k0`3Ng]hL0?ooo`<0g]kN1@24Q8@20=kNgP80
moOg00<0no_k0?ooo`3oool0703oool30?Ogm`<0g]kN0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H0
1@3gmoL208B4Q0040;Zj^P3_knl0kno_0?OgmbP0oooo0P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0
oooo0?ooo`020?ooo`040820P000000000000820P1H0oooo0`3Ng]h508B4Q0<0g]kN0P3gmoL:0?oo
o`03092@T00Q8B408B4Q0080000000<0De=C0:FUY@2UYJD02P3oool00`3kno/0moOg0?Ogm`020=kN
gP<0Q8B40P1kNg/30=kNgQ`0oooo0`3Ng]h508B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`0L0?oo
o`<0moOg0`3Ng]h207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3N
g]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80moOg00<0no_k0?oo
o`3oool00P3oool0102DU9@0:BTY02TY:@1_Kfl20;Fe]A80oooo0P3gmoL30=kNgPD0Q8B40`3Ng]h4
0?Ogm`030?_kn`3oool0oooo00D0oooo00<0P8200000000000000P2][Jd00`1OGel0410@010@400:
0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80kno_00<0moOg0?ooo`3oool0503oool0
0`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h50?Ogma`0oooo0`3gmoL30>o_k`80Q8B41`3oool0
0`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>
cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k
0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`0409BDU00Y:BT0
:BTY06m_K`80]KFe4P3oool20?Ogm`<0g]kN1@24Q8@30=kNgP@0moOg00<0no_k0?ooo`3oool01@3o
ool00`20P8000000000000020:f][@0305mOG`0@4100410@00X0oooo00<0no_k0?Ogm`3gmoL00P3N
g]h508B4Q0<0g]kN0P3_knl00`3gmoL0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24
Q8@20=kNgPD0moOg703oool30?Ogm`<0kno_0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool2
07]kN`040:f][@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3N
g]h20?Ogm`030?_kn`3oool0oooo0080oooo00@0U9BD02TY:@0Y:BT0Kfm_0P2e]KDB0?ooo`80moOg
0`3Ng]h508B4Q0<0g]kN103gmoL00`3kno/0oooo0?ooo`050?ooo`030820P000000000000080[Jf]
00<0GemO010@400@41002P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20>o_k`030?Og
m`3oool0oooo01@0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN1@3gmoLL0?ooo`<0moOg
0`3_knl208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[
103gmoL50?ooo`80W9bL00@0CTi>00000000000010@40P0820P208b<S00308B4Q01kNg/0Ng]k0080
000000<0P8200?ooo`3oool00`3gmoL70?ooo`030?Ogm`3_knl0kno_0080g]kN1P24Q8@20=kNgP80
moOg00<0no_k0?ooo`3oool00P3gmoL0102a/K40Jf][06][J`1_Kfl207=cL`8020P800<010@40000
000000000P0820P00`1WIfL0a/K60<K6aP050?ooo`030?_kn`3gmoL0moOg0080moOg0`3Ng]h508B4
Q0<0g]kN103gmoL00`3kno/0oooo0?ooo`050?ooo`030:VYZ@1BDU80DU9B0080W9bL00<0CTi>0000
000000001@3oool30?Ogm`80oooo00<0moOg0>o_k`3_knl00P3Ng]h508B4Q0<0g]kN0P3_knl00`3g
moL0oooo0?ooo`020?ooo`030<[:bP2DU9@0U9BD00D0000000<0ATI608b<S02<S8`01@3oool50?Og
m`<0g]kN1@24Q8@20=kNgPD0moOg203oool20<K6aP0306MWI`0820P020P80080000000@010@400P8
200820P0=SHf0P1SHf<20?Ogm`030?_kn`3oool0oooo0080moOg0`3_knl30=kNgP80Q8B41`3gmoL0
0`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>
cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`D0oooo0P2LW9`0
101>CTh000000000000410@200P82080S8b<00<0Q8B407]kN`1kNg/00P0000000`20P800oooo0?oo
o`030?Ogm`L0oooo00<0moOg0>o_k`3_knl00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?oo
o`020?Ogm`040;6a/@1[Jf/0Jf][06m_K`80Lg=c0P0820P00`0410@000000000000200P8200306MW
I`36a/H0a/K600D0oooo00<0no_k0?Ogm`3gmoL00P3gmoL30=kNgPD0Q8B40`3Ng]h40?Ogm`030?_k
n`3oool0oooo00D0oooo00<0ZJVY059BDP1BDU800P2LW9`00`1>CTh00000000000050?ooo`<0moOg
0P3oool00`3gmoL0kno_0>o_k`020=kNgPD0Q8B40`3Ng]h20>o_k`030?Ogm`3oool0oooo0080oooo
00<0b/[:09BDU02DU9@01@0000000`16ATH0S8b<08b<S0050?ooo`D0moOg0`3Ng]h508B4Q080g]kN
1@3gmoL80?ooo`80a/K600<0IfMW00P8200820P00P000000100410@020P800P8200f=SH206=SH`80
moOg00<0no_k0?ooo`3oool00P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd0
1@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg1@3oool20000000405mOG`2m_Kd0_Kfm0=KF
eP80kno_0P0i>CT00`0Y:BT061PH01PH60020?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?oo
o`3oool00P3gmoL00`3clo<0kno_0>o_k`020=kNgPH0Q8B40P3Ng]h50?Ogm`80oooo00@0c/k>09bL
W02LW9`0Kfm_0P12@T820?Ogm`030?_kn`3oool0oooo0080Lg=c00<0?Shn00P8200820P00`3oool7
0?Ogm`<0g]kN1@24Q8@30=kNgP80kno_0P3oool00`3kno/0moOg0?Ogm`020?ooo`040?_kn`3gmoL0
moOg0??cl`80kno_0P12@T800`0];Bd061PH01PH60020?ooo`030?_kn`3gmoL0moOg00<0moOg0P3o
ool00`3gmoL0kno_0>o_k`020=kNgPD0Q8B40`3Ng]h50?Ogm`80oooo00<0P8200000000000000P2]
[Jd0103>c/h0kno_0>o_k`2DU9@203Ti>@80S8b<00<0`/;20?Ogm`3gmoL01@3gmoL30=kNgPD0Q8B4
0P3Ng]h20>o_k`030?Ogm`3oool0oooo00<0moOg0P3oool00`3kno/0moOg0?Ogm`0200P8200305]K
F`2][Jd0[Jf]0080moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0
g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
jn_[103gmoL50?ooo`80000000@0GemO0;fm_@2m_Kd0e]KF0P3_knl203Ti>@0302TY:@0H61P061PH
0080moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030??cl`3_knl0kno_
0080g]kN1P24Q8@20=kNgPD0moOg0P3oool0103>c/h0W9bL09bLW01_Kfl20492@P80moOg00<0no_k
0?ooo`3oool00P1cLg<00`0n?Sh020P800P820030?ooo`L0moOg0`3Ng]h508B4Q0<0g]kN0P3_knl2
0?ooo`030?_kn`3gmoL0moOg0080oooo00@0no_k0?Ogm`3gmoL0lo?c0P3_knl20492@P0302d];@0H
61P061PH0080oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?Ogm`3_knl0kno_0080g]kN1@24
Q8@30=kNgPD0moOg0P3oool00`20P8000000000000020:f][@040<k>cP3_knl0kno_09BDU080>CTi
0P2<S8`00`32`/80moOg0?Ogm`050?Ogm`<0g]kN1@24Q8@20=kNgP80kno_00<0moOg0?ooo`3oool0
0`3gmoL20?ooo`030?_kn`3gmoL0moOg008020P800<0Fe]K0:f][@2][Jd00P3gmoL0103kno/0oooo
0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0
_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`D0oooo0P000000101OGel0
_Kfm0;fm_@3Fe]H20>o_k`80>CTi00<0:BTY01PH600H61P00P3gmoL00`3kno/0oooo0?ooo`050?Og
m`030?_kn`3oool0oooo0080moOg00<0lo?c0>o_k`3_knl00P3Ng]h608B4Q080g]kN1@3gmoL20?oo
o`040<k>cP2LW9`0W9bL06m_K`80@T920P3gmoL00`3kno/0oooo0?ooo`0207=cL`0303hn?P0820P0
20P800<0oooo1`3gmoL30=kNgPD0Q8B40`3Ng]h20>o_k`80oooo00<0no_k0?Ogm`3gmoL00P3oool0
103kno/0moOg0?Ogm`3clo<20>o_k`80@T9200<0;Bd]01PH600H61P00P3oool00`3kno/0moOg0?Og
m`030?Ogm`80oooo00<0moOg0>o_k`3_knl00P3Ng]h508B4Q0<0g]kN1@3gmoL20?ooo`030820P000
000000000080[Jf]00@0c/k>0>o_k`3_knl0U9BD0P0i>CT208b<S0030<;2`P3gmoL0moOg00D0moOg
0`3Ng]h508B4Q080g]kN0P3_knl00`3gmoL0oooo0?ooo`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P0820P00`1KFe/0[Jf]0:f][@020?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3o
ool01@3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg
0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_1`3gmoL2000000040820P03oool0oooo0?_k
n`@0moOg00<0T92@02TY:@0Y:BT00P3gmoL00`3kno/0oooo0?ooo`030?Ogm`D0oooo1@3gmoL20=KF
eP<0Ng]k00<0P82008B4Q024Q8@00P3Fe]H20>o_k`030?Ogm`3oool0oooo0080moOg00@0hn?S0<k>
cP3>c/h0IfMW0P0000020?Ogm`030?_kn`3oool0oooo0080moOg00<0O7al0000000000000`3oool5
0?Ogm`80kno_0`3Fe]H208B4Q0<0Ng]k0`3Ng]h<0?Ogm`030?_kn`3oool0oooo0080FUYJ00<0>CTi
01PH600H61P00P3_knl00`3clo<0moOg0?Ogm`030?ooo`80moOg00<0lo?c0>o_k`3_knl00P3Ng]h3
07]kN`80Q8B40`3Ng]h20>o_k`030??cl`3gmoL0moOg0080oooo00<0P8200000000000001@3gmoL0
0`3WinL0e]KF0=KFeP0200P820030820P03gmoL0moOg0080oooo00<0moOg0>o_k`3_knl00`3Fe]H2
08B4Q0<0Ng]k0P3Ng]h=0?Ogm`d000000P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0kno_0`3Fe]H2
08B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080Q8B400@0/K6a0=kN
gP3Ng]h0inOW0P3_knl70?Ogm`80000000@0P8200?ooo`3oool0no_k103gmoL00`2@T900:BTY02TY
:@020?Ogm`030?_kn`3oool0oooo00<0moOg1@3oool50?Ogm`80e]KF0`1kNg/00`20P800Q8B408B4
Q0020=KFeP80kno_00<0moOg0?ooo`3oool00P3gmoL0103Shn<0c/k>0<k>cP1WIfL200000080moOg
00<0no_k0?ooo`3oool00P3gmoL00`1lO7`00000000000030?ooo`D0moOg0P3_knl30=KFeP80Q8B4
0`1kNg/30=kNgP`0moOg00<0no_k0?ooo`3oool00P1JFUX00`0i>CT061PH01PH60020>o_k`030??c
l`3gmoL0moOg00<0oooo0P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Ng]k0P24Q8@30=kNgP80kno_
00<0lo?c0?Ogm`3gmoL00P3oool00`20P8000000000000050?Ogm`030>OWi`3Fe]H0e]KF008020P8
00<0P8200?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`030=KFeP80Q8B40`1kNg/20=kNgPd0moOg
3@0000020?ooo`030?_kn`3gmoL0moOg0080moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Ogml0a/K6
0<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m
_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`L0moOg
0P0000001020P800oooo0?ooo`3kno/40?Ogm`03092@T00Y:BT0:BTY0080moOg00<0no_k0?ooo`3o
ool00`3gmoL50?ooo`D0moOg0P3Fe]H307]kN`030820P024Q8@0Q8B40080e]KF0P3_knl00`3gmoL0
oooo0?ooo`020?Ogm`040>?Sh`3>c/h0c/k>06MWI`8000000P3gmoL00`3kno/0oooo0?ooo`020?Og
m`0307alO0000000000000<0oooo1@3gmoL20>o_k`<0e]KF0P24Q8@307]kN`<0g]kN303gmoL00`3k
no/0oooo0?ooo`0205YJFP0303Ti>@0H61P061PH0080kno_00<0lo?c0?Ogm`3gmoL00`3oool20?Og
m`030??cl`3_knl0kno_0080g]kN0`1kNg/208B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`020?oo
o`030820P0000000000000D0moOg00<0inOW0=KFeP3Fe]H00P0820P00`20P800moOg0?Ogm`020?oo
o`030?Ogm`3_knl0kno_00<0e]KF0P24Q8@307]kN`80g]kN3@3gmoL=00000080oooo00<0no_k0?Og
m`3gmoL00P3gmoL30>o_k`<0e]KF0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q004
0:f][@3Fe]H0e]KF0>OWi`80moOg0P3oool50?Ogm`80BTY:00@0Fe]K06][J`1[Jf/0/K6a0P3gmoL2
07]kN`030492@P0820P020P80080c/k>00<0hn?S0?Ogm`3gmoL00`3oool70?Ogm`030??cl`3_knl0
kno_0080g]kN0`2<S8`00`28R8P0Q8B408B4Q0020=kNgP80kno_00<0moOg0?ooo`3oool01@3gmoL0
0`1lO7`00000000000020<k>cP030>?Sh`3gmoL0moOg0080Lg=c00<0CTi>02TY:@0Y:BT02P3gmoL3
0=kNgPD0Q8B40`3Fe]H<0?Ogm`030>_[j`3Ng]h0g]kN008020P800<0Jf][0<k>cP3>c/h00P1:BTX0
0`2DU9@0g]kN0=kNgP030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0e]KF0P3_knl0
0`3clo<0moOg0?Ogm`020?Ogm`0309BDU00a<C40<C4a0080_Kfm00@0g]kN0?ooo`3oool0no_k0P3g
moL20000000307alO03gmoL0moOg00D0moOg0`3Ng]h508B4Q080e]KF3@3gmoL203Ti>@0305IFEP1c
Lg<0Lg=c0080g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`020?ooo`<0moOg0`3F
e]H208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW0P3g
moL20?ooo`D0moOg0P1:BTX0101KFe/0Jf][06][J`2a/K420?Ogm`80Ng]k00<0@T9200P8200820P0
0P3>c/h00`3Shn<0moOg0?Ogm`030?ooo`L0moOg00<0lo?c0>o_k`3_knl00P3Ng]h308b<S00308R8
R024Q8@0Q8B40080g]kN0P3_knl00`3gmoL0oooo0?ooo`050?Ogm`0307alO000000000000080c/k>
00<0hn?S0?Ogm`3gmoL00P1cLg<00`1>CTh0:BTY02TY:@0:0?Ogm`<0g]kN1@24Q8@30=KFeP`0moOg
00<0jn_[0=kNgP3Ng]h00P0820P00`1[Jf/0c/k>0<k>cP0204Y:BP0309BDU03Ng]h0g]kN00<0moOg
0P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Fe]H20>o_k`030??cl`3gmoL0moOg0080moOg
00<0U9BD034a<@0a<C400P2m_Kd0103Ng]h0oooo0?ooo`3kno/20?Ogm`80000000<0O7al0?Ogm`3g
moL01@3gmoL30=kNgPD0Q8B40P3Fe]H=0?Ogm`80>CTi00<0EUIF07=cL`1cLg<00P3Ng]h00`3[jn/0
moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo0080oooo0`3gmoL30=KFeP80Q8B41`3oool00`3Ng]h0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80moOg0`3_knl20?Ogm`80
g]kN00@0Q8B402TY:@0Y:BT05ADE0P00000202TY:@0306MWI`2UYJD0YJFU0080:BTY00<0T92@0?Og
m`3gmoL02P3gmoL00`3clo<0kno_0>o_k`020=KFeP<0Ng]k00<0P82008B4Q024Q8@00P3Fe]H50>o_
k`D0moOg00<0T92@02TY:@0Y:BT00P2<S8`00`16ATH000000000000201PH600307]kN`3Ng]h0g]kN
00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020>o_k`<0e]KF1@24Q8@50=kNgPD0moOg0P3_knl0103O
gml0c/k>0<k>cP1lO7`202TY:@80_Kfm00<0f][J0?Ogm`3gmoL00P2e]KD00`1_Kfl0:BTY02TY:@03
0=kNgP80moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0e]KF0P3_knl00`3clo<0moOg0?Ogm`02
0>o_k`030>OWi`3Ng]h0g]kN0080BTY:00@0U9BD0=kNgP3Ng]h0a/K60P2][Jd201PH600308R8R03g
moL0moOg00D0kno_0`3Fe]H508B4Q0@0g]kN00<0jn_[0?Ogm`3gmoL00`3gmoL20>o_k`030??cl`3g
moL0moOg0080g]kN00<0U9BD04Y:BP1:BTX01@0000000`0M7Ad0>CTi03Ti>@020>o_k`030??cl`3g
moL0moOg00D0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]
0=KFeP3Fe]H0hn?S0P3_knl20?Ogm`<0kno_0P3gmoL20=kNgP0408B4Q00Y:BT0:BTY01DE5@800000
0P0Y:BT00`1WIfL0YJFU0:FUY@0202TY:@03092@T03gmoL0moOg00X0moOg00<0lo?c0>o_k`3_knl0
0P3Fe]H307]kN`030820P024Q8@0Q8B40080e]KF1@3_knl50?Ogm`03092@T00Y:BT0:BTY0080S8b<
00<0ATI60000000000000P0H61P00`1kNg/0g]kN0=kNgP030>o_k`80moOg00<0lo?c0>o_k`3_knl0
0P3_knl30=KFePD0Q8B41@3Ng]h50?Ogm`80kno_00@0gmoO0<k>cP3>c/h0O7al0P0Y:BT20;fm_@03
0=[JfP3gmoL0moOg0080]KFe00<0Kfm_02TY:@0Y:BT00`3Ng]h20?Ogm`030??cl`3_knl0kno_0080
e]KF1@24Q8@30=KFeP80kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3WinL0g]kN0=kNgP0204Y:BP04
09BDU03Ng]h0g]kN0<K6aP80[Jf]0P0H61P00`28R8P0moOg0?Ogm`050>o_k`<0e]KF1@24Q8@40=kN
gP030>_[j`3gmoL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`020=kNgP0309BDU01:BTX0BTY:
00D0000000<07AdM03Ti>@0i>CT00P3_knl00`3clo<0moOg0?Ogm`050>o_k`<0e]KF0P24Q8@70?Og
m`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
d];B00<0b/[:0<;2`P32`/801@3clo<208B4Q0040:f][@3Fe]H0e]KF0=oOg`80inOW1`3clo<20>_[
j`040;bl_02<S8`0S8b<08:2PP80N7Qh0P2@T9000`2_[jl0c/k>0<k>cP0208b<S0030<;2`P3gmoL0
moOg00D0lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3alO40kno_0>o_k`020=KFeP<0P82000<0PX:2
08B4Q024Q8@00P3Fe]H50>o_k`80lo?c00@0mOGe0?Ogm`3gmoL0Xj>S0P1>CTh207=cL`0307QhN01l
O7`0O7al0080CTi>00<0MGEe09bLW02LW9`01@3clo<00`3alO40kno_0>o_k`020>o_k`<0e]KF1@24
Q8@30=[JfP80g]kN0P3clo<00`3emOD0moOg0?Ogm`020:FUY@0409VIV@2<S8`0S8b<08B4Q080O7al
0P3Fe]H00`3UiND0lo?c0??cl`020=KFeP030:^[Z`20P800P82000<0V9RH0P3clo<00`3alO40kno_
0>o_k`020=[JfPD0Q8B40`3Fe]H20>OWi`030>o_k`3gmoL0moOg0080lo?c00<0kNg]0>OWi`3WinL0
0P2QXJ40102OWil0W9bL09bLW020P80206=SH`80Jf][00<0[jn_0??cl`3clo<01@3_knl30=KFePD0
Q8B40P3Jf]X20=kNgP030>WYj@3clo<0lo?c00<0moOg1@3clo<20>_[j`030<C4a02MWId0WIfM0080
N7Qh00@0NWYj07alO01lO7`0R8R80P2DU9@20>o_k`030?7al@3clo<0lo?c00D0kno_0`3Fe]H208B4
Q0L0lo?c00<0fm_K0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h20>o_
k`<0moOg0P3_knl20?Ogm`030??cl`3_knl0kno_00<0kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg
00D0kno_00<0lo?c0?Ogm`3gmoL01@3_knl20=KFePH0Q8B40P3Fe]H70>o_k`040??cl`3gmoL0moOg
0;Fe]@80Lg=c0P1JFUX00`2YZJT0moOg0?Ogm`0208B4Q00306m_K`1JFUX0FUYJ00<0moOg1`3_knl3
0=KFePD0Q8B40`3Fe]H20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P1JFUX0101BDU80BTY:04Y:BP2<
S8`20<k>cPD0kno_0P3gmoL00`3WinL0e]KF0=KFeP03059BDPD0kno_0P3Ng]h508B4Q0<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_0080moOg00@0ZJVY05YJFP1JFUX0>CTi
0P0H61P20;fm_@030=KFeP3_knl0kno_00D0kno_0`3Fe]H508B4Q080e]KF0P3Ng]h00`3WinL0kno_
0>o_k`050?Ogm`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl00P3_knl0103clo<0moOg
0?Ogm`3clo<<0>o_k`<0e]KF0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl208B4Q0040:f]
[@3Fe]H0e]KF0=[JfP80g]kN0P3_knl30?Ogm`80kno_0P3gmoL00`3clo<0kno_0>o_k`030>o_k`D0
moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg00D0kno_0P3Fe]H608B4Q080
e]KF1`3_knl0103clo<0moOg0?Ogm`2e]KD207=cL`80FUYJ00<0ZJVY0?Ogm`3gmoL00P24Q8@00`1_
Kfl0FUYJ05YJFP030?Ogm`L0kno_0`3Fe]H508B4Q0<0e]KF0P3Ng]h20>o_k`030??cl`3gmoL0moOg
0080FUYJ00@0DU9B04Y:BP1:BTX0S8b<0P3>c/h50>o_k`80moOg00<0inOW0=KFeP3Fe]H00`1BDU85
0>o_k`80g]kN1@24Q8@30=KFeP80g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL00`3clo<0kno_0>o_k`02
0?Ogm`040:VYZ@1JFUX0FUYJ03Ti>@8061PH0P2m_Kd00`3Fe]H0kno_0>o_k`050>o_k`<0e]KF1@24
Q8@20=KFeP80g]kN00<0inOW0>o_k`3_knl01@3gmoL00`3clo<0kno_0>o_k`020?Ogm`030??cl`3_
knl0kno_0080kno_00@0lo?c0?Ogm`3gmoL0lo?c303_knl30=KFeP80Q8B41`3_knl00`3Fe]H0_Kfm
0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m
_Kd0_Kfm00D0moOg0P2<S8`00`2a/K40e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgP80kno_00@0
lo?c0?Ogm`3gmoL0jn_[0P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00d0kno_0P3gmoL00`3[jn/0g]kN
0=kNgP020=KFeP<0Ng]k00<0P82008B4Q024Q8@0103Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`040>OW
i`3Ng]h0g]kN0=;BdP80a/K60P0000000`1OGel0_Kfm0;fm_@020<K6aP0306=SH`000000000000<0
kno_0P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0e]KF0P1kNg/308B4Q0D0e]KF0P3Ng]h00`3WinL0
kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP03
0>_[j`3gmoL0moOg00D0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307=cL`80Q8B41@3Fe]H00`3Jf]X0
g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN0080kno_00@0O7al00P8200820P0Fe]K0P2][Jd20>o_
k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00`3Fe]H207]kN`<0Q8B4103Fe]H00`3J
f]X0g]kN0=kNgP030>o_k`80g]kN00<0inOW0>o_k`3_knl00P3_knl00`3WinL0g]kN0=kNgP020>o_
k`040>OWi`3Ng]h0g]kN0>_[j`80moOg1`3_knl30=kNgP<0e]KF0P1kNg/70?Ogm`030=[JfP2m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm
_@2m_Kd01@3gmoL208b<S0030;6a/@3Fe]H0e]KF00<0e]KF0P3Ng]h30>o_k`80g]kN0P3_knl0103c
lo<0moOg0?Ogm`3[jn/20=kNgP80kno_00<0inOW0=kNgP3Ng]h03@3_knl20?Ogm`030>_[j`3Ng]h0
g]kN0080e]KF0`1kNg/00`20P800Q8B408B4Q0040=KFeP030=[JfP3Ng]h0g]kN0080kno_00@0inOW
0=kNgP3Ng]h0d];B0P36a/H20000000305mOG`2m_Kd0_Kfm0080a/K600<0Hf=S0000000000000`3_
knl20?Ogm`030??cl`3_knl0kno_0080g]kN0`3Fe]H207]kN`<0Q8B41@3Fe]H20=kNgP030>OWi`3_
knl0kno_0080g]kN00<0inOW0>o_k`3_knl00`3_knl20=kNgP030>OWi`3_knl0kno_0080g]kN00<0
jn_[0?Ogm`3gmoL01@3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Lg=c0P24Q8@50=KFeP030=[JfP3N
g]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00P3_knl0101lO7`020P800P8201KFe/20:f][@80kno_
00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP030=KFeP80Ng]k0`24Q8@40=KFeP030=[J
fP3Ng]h0g]kN00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`020>o_k`030>OWi`3Ng]h0g]kN0080kno_
00@0inOW0=kNgP3Ng]h0jn_[0P3gmoL70>o_k`<0g]kN0`3Fe]H207]kN`L0moOg00<0f][J0;fm_@2m
_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm
0;fm_@050?_kn`80R8R800@0[Jf]0=;BdP3Bd]80e]KF0P3Jf]X20=kNgP<0inOW0P3Ng]h20>o_k`04
0>g]k@3[jn/0jn_[0>GUi@80g]kN0P3_knl00`3WinL0g]kN0=kNgP050>OWi`<0lo?c0P3WinL00`3[
jn/0kno_0>o_k`020>_[j`030>GUi@3Ng]h0g]kN0080d];B0`20P8000`22PX80Q8B408B4Q0020=;B
dP80f][J00<0g=cL0=kNgP3Ng]h00P3WinL0103Shn<0g]kN0=kNgP3MgMd20=_Kf`80@T9200<0DE5A
05mOG`1OGel00P1SHf<00`1CDe<0@T920492@P030>OWi`80jn_[00<0kNg]0>o_k`3_knl00P3Ng]h3
0=;BdP80P8200`24Q8@30=;BdP80f][J0P3Ng]h00`3Shn<0inOW0>OWi`020=kNgP040>OWi`3_knl0
kno_0>_[j`80inOW0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP030>GUi@3[jn/0jn_[00<0inOW0P3_
knl00`3WinL0g]kN0=kNgP020=;BdP<0O7al0P24Q8@30=;BdP80f][J00<0g=cL0=kNgP3Ng]h00P3W
inL00`3Shn<0g]kN0=kNgP020>o_k`0409fMW@1:BTX0BTY:055AD@80EeMG0P1hN7P00`2[Zj/0g]kN
0=kNgP020>OWi`030>?Sh`3Ng]h0g]kN00<0d];B0P20P80308B4Q080d];B0P3Jf]X00`3Lg=`0g]kN
0=kNgP030>OWi`80g]kN00<0inOW0>o_k`3_knl00P3WinL00`3Shn<0g]kN0=kNgP020>o_k`040>OW
i`3Ng]h0g]kN0>GUi@80jn_[0P3WinL00`3[jn/0kno_0>o_k`020>OWi`<0g]kN0`3Bd]820820P0L0
no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h20>o_k`03
0>OWi`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0moOg0P3Ng]h00`3WinL0
kno_0>o_k`050=kNgP80c/k>1P24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl00P24Q8@00`12@T80
000000000002000000030492@P24Q8@0Q8B400D0g]kN00<0inOW0>o_k`3_knl00P3Ng]h30<k>cPD0
Q8B40`3>c/h90=kNgP040>OWi`3_knl0kno_0>OWi`@0g]kN00<0inOW0>o_k`3_knl0203Ng]h20>o_
k`030>OWi`3Ng]h0g]kN0080c/k>1@24Q8@30<k>cPX0g]kN0P3_knl0102n_[h0S8b<08b<S016ATH4
0000000306m_K`3Ng]h0g]kN00D0g]kN0`3>c/h508B4Q080c/k>2P3Ng]h00`3WinL0kno_0>o_k`05
0=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0c/k>0P24Q8@7
0?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kN
gP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl0
0`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30?Ogm`80g]kN00<0inOW
0>o_k`3_knl01@3Ng]h20<k>cPH0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_0080Q8B400<0@T92
0000000000000P0000000`12@T80Q8B408B4Q0050=kNgP030>OWi`3_knl0kno_0080g]kN0`3>c/h5
08B4Q0<0c/k>2@3Ng]h0103WinL0kno_0>o_k`3WinL40=kNgP030>OWi`3_knl0kno_00P0g]kN0P3_
knl00`3WinL0g]kN0=kNgP020<k>cPD0Q8B40`3>c/h:0=kNgP80kno_00@0_[jn08b<S02<S8`0ATI6
100000000`1_Kfl0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl0
1@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B4
1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80f][J
1@3Ng]h20>OWi`040>?Sh`3Ng]h0g]kN0=cLg080f][J0P3Shn<00`3QhN40g]kN0=kNgP020=[JfP03
0=cLg03Ng]h0g]kN00<0jn_[0P3Ng]h00`3Shn<0inOW0>OWi`050=[JfP80c/k>1P24Q8@20<k>cP80
g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h00`3Shn<0inOW0>OWi`020;6a/@0308j>SP1[Jf/0Jf][0080
Jf][00<0SXj>0;6a/@2a/K400`3Jf]X20=kNgP030>?Sh`3WinL0inOW0080f][J0`3>c/h508B4Q0<0
c/k>0P3Ng]h20=[JfP030=cLg03Ng]h0g]kN0080g]kN00@0hn?S0>OWi`3WinL0hn?S0P3Ng]h20=[J
fP030=oOg`3Shn<0hn?S0080g]kN00<0g=cL0=[JfP3Jf]X00`3Ng]h20>OWi`030>7Qh@3Jf]X0f][J
0080c/k>1@24Q8@30<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h20>OWi`040<k>cP2e]KD0]KFe
092@T0@0Jf][00<0YJFU0=kNgP3Ng]h01@3Jf]X30<k>cPD0Q8B40P3>c/h20=kNgP030=cLg03Jf]X0
f][J00D0g]kN00<0hn?S0>OWi`3WinL00P3Ng]h00`3Lg=`0f][J0=[JfP020>?Sh`040>7Qh@3Ng]h0
g]kN0=cLg080f][J0P3Ng]h00`3Shn<0inOW0>OWi`020=kNgP<0f][J0`3>c/h208B4Q0L0no_k00<0
gmoO0<;2`P32`/800`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H0
0`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0
f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3F
e]H20<k>cPH0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H00`3Jf]X0g]kN0=kNgP030=KFePD0g]kN0P3Fe]H30<k>cPD0Q8B40`3>c/h20=kNgP80e]KF00<0
f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3Fe]H01@3Ng]h00`3Jf]X0e]KF0=KF
eP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H00`3Jf]X0g]kN0=kNgP050=KFeP<0c/k>1@24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3N
g]h00`3Jf]X0e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN
0P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN
0=kNgP080=kNgPD0e]KF0P3>c/h608B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[J
fP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H50=kNgP80e]KF0`3>c/h508B4Q0<0c/k>
0P3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3Fe]H20=kNgP030=[JfP3Fe]H0e]KF00D0g]kN
00<0f][J0=KFeP3Fe]H00P3>c/h508B4Q0<0c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[J
fP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h01@3Fe]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[J
fP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0
g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P1kNg/0102][Jd0g]kN
0=kNgP3[jn/A0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3gmoL0moOg0080
oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q0030820P01kNg/0Ng]k0080g]kN1`3gmoL0103kno/0
oooo0?ooo`3kno/D0?Ogm`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]h40?Ogm`030?_kn`3oool0oooo
01L0moOg00<0lo?c0>o_k`3_knl00P3Ng]h308B4Q080Ng]k0`3Ng]h20?Ogm`030?_kn`3oool0oooo
01@0moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]h50?Ogm`<0oooo5`3gmoL20?oo
o`<0kno_0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P1kNg/0102][Jd0
g]kN0=kNgP3[jn/A0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3gmoL0moOg
0080oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q0030820P01kNg/0Ng]k0080g]kN1`3gmoL0103k
no/0oooo0?ooo`3kno/D0?Ogm`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]h40?Ogm`030?_kn`3oool0
oooo01L0moOg00<0lo?c0>o_k`3_knl00P3Ng]h308B4Q080Ng]k0`3Ng]h20?Ogm`030?_kn`3oool0
oooo01@0moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]h50?Ogm`<0oooo5`3gmoL2
0?ooo`<0kno_0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<c<c036a/H0a/K600D0lo?c0P20P800102d
];@0inOW0>OWi`3alO4A0?_kn`80oooo00<0oOgm0?_kn`3kno/0203kno/20?ooo`030?gmo@3kno/0
no_k0080oooo00<0no_k0?Ogm`3gmoL00P3_knl308B4Q00308:2PP20P800P8200080inOW1`3kno/0
103moOd0oooo0?ooo`3moOdD0?_kn`80moOg0`3_knl208B4Q0<0P8200`3[jn/40?_kn`030?gmo@3o
ool0oooo01L0no_k00<0nOWi0?Ogm`3gmoL00P3_knl508B4Q0<0inOW0P3kno/00`3moOd0oooo0?oo
o`0D0?_kn`030?Win@3gmoL0moOg00<0kno_0P24Q8@30820P080jn_[1@3kno/30?oooaL0no_k0P3o
ool30?Ogm`<0kno_0P28R8P50??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0^[Zj
0>o_k`3_knl0moOg:P3oool608B4Q080kno_903oool508B4Q0<0moOg8`3oool308B4Q080S8b<0`3_
knlO0?ooo`D0Q8B40P3gmoLW0?ooo`80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P24Q8@0
102j^[X0kno_0>o_k`3gmoLZ0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3gmoLS0?ooo`<0Q8B40P2<
S8`30>o_kal0oooo1@24Q8@20?OgmbL0oooo0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool2
08B4Q00408R8R02<S8`0S8b<08B4Q080Ng]k1@24Q8@207]kN`l0Q8B400<0R8R808b<S02<S8`00`1k
Ng/508B4Q080Ng]k00<0Q8B408b<S02<S8`02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0
P82007]kN`1kNg/0P8201024Q8@00`28R8P0S8b<08b<S00:08B4Q0030820P01kNg/0Ng]k00d0Q8B4
0P1kNg/508B4Q080Ng]k00@0P82008B4Q024Q8@0R8R80P2<S8`:08B4Q0<0S8b<0P1kNg/00`20P800
Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0208b<S003
08R8R024Q8@0Q8B400P0Q8B40P2<S8`00`28R8P0Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024
Q8@00`24Q8@207]kN`030820P024Q8@0Q8B40080S8b<00<0R8R808B4Q024Q8@02024Q8@208b<S003
08B4Q01kNg/0Ng]k00X0Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@01028R8P0S8b<
08b<S024Q8@207]kN`D0Q8B40P1kNg/?08B4Q00308R8R02<S8`0S8b<00<0Ng]k1@24Q8@207]kN`03
08B4Q02<S8`0S8b<00X0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k0820
P0@0Q8B400<0R8R808b<S02<S8`02P24Q8@00`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207]k
N`040820P024Q8@0Q8B408R8R080S8b<2P24Q8@308b<S080Ng]k00<0P82008B4Q024Q8@02P24Q8@2
07]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/00P2<S8`00`28R8P0Q8B408B4Q008
08B4Q080S8b<00<0R8R808B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/0
0`20P800Q8B408B4Q00208b<S00308R8R024Q8@0Q8B400P0Q8B40P2<S8`00`24Q8@0Ng]k07]kN`0:
08B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80@T9200@0A4A404I6AP16ATH0@T920P0n?Sh5
0492@P80?Shn3`12@T800`14A4@0ATI604I6AP0303hn?PD0@T920P0n?Sh00`12@T80ATI604I6AP0:
0492@P80?Shn00<0@4100492@P12@T800P12@T801010@400?Shn03hn?P10@4040492@P0304A4A016
ATH0ATI600X0@T9200<0@41003hn?P0n?Sh03@12@T8203hn?PD0@T920P0n?Sh01010@400@T920492
@P14A4@204I6APX0@T920`16ATH203hn?P030410@012@T80@T9200X0@T920P0n?Sh00`10@400@T92
0492@P020492@P030410@00n?Sh0?Shn0080ATI600<0A4A40492@P12@T802012@T8204I6AP0304A4
A012@T80@T9200X0@T920P0n?Sh00`10@400@T920492@P030492@P80?Shn00<0@4100492@P12@T80
0P16ATH00`14A4@0@T920492@P080492@P80ATI600<0@T9203hn?P0n?Sh02P12@T820820P0030;jn
_P3kno/0no_k0080no_k00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogmn00000000<0O7al0?Ogm`3gmoL00P3g
moL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0<k>cP030<K6aP2m_Kd0_Kfm00D0moOgh00000000`1lO7`0moOg0?Ogm`020?Ogm`030=[JfP2m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm
_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4
Q080Ng]k00@0P82008B4Q024Q8@0R8R80P2<S8`508B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@2
07]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`04
08B4Q0030820P01kNg/0Ng]k0080S8b<00@0R8R808B4Q024Q8@0P8200P1kNg/:08B4Q0<0Ng]k1@24
Q8@207]kN`D0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]k
N`20P80908B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`<0Q8B4
0P2<S8`00`24Q8@0Ng]k07]kN`0508B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@507]kN`D0Q8B4
0`1kNg/408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/02P24Q8@00`20P800Ng]k
07]kN`0508B4Q0D0Ng]k1@24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm
_@020?Ogm`030??cl`3_knl0kno_0080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`D0Q8B40P1k
Ng/01020P800Q8B408B4Q028R8P208b<S0D0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k
00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00@0Q8B4
00<0P82007]kN`1kNg/00P2<S8`01028R8P0Q8B408B4Q020P80207]kN`X0Q8B40`1kNg/508B4Q080
Ng]k1@24Q8@307]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k0820
P0T0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k0`24Q8@208b<
S00308B4Q01kNg/0Ng]k00D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q0D0Ng]k1@24Q8@307]k
N`@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q0030820P01kNg/0Ng]k
00D0Q8B41@1kNg/508B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>
cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080
moOg00<0lo?c0>o_k`3_knl00P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`04
0820P024Q8@0Q8B408R8R080S8b<1@24Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20
P800Q8B408B4Q00208B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01024Q8@00`20
P800Ng]k07]kN`0208b<S00408R8R024Q8@0Q8B40820P080Ng]k2P24Q8@307]kN`D0Q8B40P1kNg/5
08B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8202@24
Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/308B4Q080S8b<00<0
Q8B407]kN`1kNg/01@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B41@1kNg/508B4Q0<0Ng]k1024
Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/01@24
Q8@507]kN`D0Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL2
08B4Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3gmoL40?ooo`030?_kn`3gmoL0moOg00D0moOg00<0
no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3N
g]h70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3o
ool0oooo0080oooo0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_kn`3gmoL0moOg00D0moOg0P3o
ool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN1`3g
moL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool00P3g
moL00`3kno/0oooo0?ooo`030=kNgPD0Q8B40P3Ng]h80?Ogm`D0oooo1`3gmoL0103kno/0oooo0?oo
o`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H0
0`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6
aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_0P3oool50?Ogm`@0oooo00<0no_k0?Ogm`3gmoL0
1@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN
1P24Q8@20=kNgPL0moOg00<0no_k0?ooo`3oool00`3oool70?Ogm`030?_kn`3oool0oooo00D0moOg
00<0no_k0?ooo`3oool00P3oool30=kNgPD0Q8B40`3Ng]h70?Ogm`D0oooo00<0no_k0?Ogm`3gmoL0
1@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B4
0`3Ng]h70?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo
0?ooo`020?Ogm`030?_kn`3oool0oooo00<0g]kN1@24Q8@20=kNgPP0moOg1@3oool70?Ogm`040?_k
n`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20<k>cP030<S8
b032`/80`/;200D0no_k0P24Q8@0102a/K40g]kN0=kNgP3_knl20?ooo`D0no_k103oool00`3moOd0
no_k0?_kn`050?_kn`030?gmo@3oool0oooo00D0no_k0`3oool50?_kn`80oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN1`3kno/00`3moOd0oooo0?ooo`030?ooo`L0no_k00<0oOgm0?ooo`3o
ool01@3kno/00`3moOd0oooo0?ooo`020?_kn`<0g]kN1@24Q8@30=kNgPL0no_k1@3oool00`3moOd0
no_k0?_kn`050?_kn`80oooo00<0oOgm0?_kn`3kno/00`3kno/20?ooo`030?_kn`3gmoL0moOg0080
g]kN1@24Q8@30=kNgPL0no_k00<0oOgm0?ooo`3oool00P3oool00`3moOd0no_k0?_kn`050?_kn`03
0?gmo@3oool0oooo00D0no_k0`3Ng]h508B4Q080g]kN203kno/50?ooo`L0no_k00@0oOgm0?ooo`3o
ool0oOgm103kno/00`3moOd0oooo0?ooo`020?_kn`<0moOg0`3Ng]h208B4Q0L0no_k00<0gmoO0<;2
`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0
_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_9@3oool00`3kno/0moOg0?Ogm`020=kN
gPH0Q8B40P3Ng]hO0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN7P3oool00`3kno/0moOg0?Ogm`020=kN
gPD0Q8B40`3Ng]hI0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgR40oooo0`3gmoL30=kN
gP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3_knlU0?oo
o`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgQl0oooo0P3gmoL30=kNgPD0Q8B40`3Ng]hN0?oo
o`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4
Q080g]kN8@3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q004
0;6a/@3Ng]h0g]kN0>o_kbP0oooo0P3_knl608B4Q080g]kN8@3oool30>o_k`D0Q8B40`3Ng]hQ0?oo
o`80kno_1@24Q8@30=kNgQ`0oooo0`3_knl508B4Q080g]kN903oool30>o_k`80Q8B41`3gmoL00`3J
f]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP03
0<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knlX0?ooo`80kno_1P24Q8@20=kN
gR40oooo0`3_knl508B4Q0<0g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0kno_1@24Q8@20=kN
gR@0oooo0`3_knl208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3N
g]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80moOg00<0no_k0?oo
o`3oool0703oool30=kNgPD0Q8B40`3Ng]h20?Ogma`0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4
Q0<0g]kN2P3oool20;Fe]@0407alO012@T80@T9203Hf=P80:BTY0P12@T800`1hN7P0[Jf]0:f][@05
0?ooo`<0g]kN1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool07`3oool30>o_k`80Q8B41@3_knl2
0?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kN
gP80e]KF00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3oool0
0`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3Ng]h5
08B4Q0<0g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgPX0oooo0P2e]KD0
101lO7`0@T920492@P0f=SH202TY:@80@T9200<0N7Qh0:f][@2][Jd01@3oool30=kNgPD0Q8B40P3N
g]h20?Ogm`030?_kn`3oool0oooo01l0oooo0`3_knl208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm
_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0
_Kfm00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Ogm`3gmoL00P3N
g]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`0L0?ooo`<0g]kN1@24Q8@30=kNgP80moOg703o
ool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h:0?ooo`80]KFe00@0O7al0492@P12@T80=SHf
0P0Y:BT20492@P0307QhN02][Jd0[Jf]00D0oooo0`3Ng]h508B4Q080g]kN0P3gmoL00`3kno/0oooo
0?ooo`0O0?ooo`<0kno_0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??c
l`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3g
moL0moOg0080Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoLQ0?ooo`030?_kn`3gmoL0moOg0080g]kN
0`1kNg/00`20P800Q8B408B4Q0020=KFeP80moOg00<0no_k0?ooo`3oool06P3oool20?Ogm`<0g]kN
0P24Q8@307]kN`<0g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN0`1kNg/208B4Q0<0g]kN
0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030<k>cP2LW9`0W9bL0080000000@0ATI608b<S02<S8`0
WIfM0P2][Jd209BDU00304Y:BP00000000000080W9bL00<0b/[:0?Ogm`3gmoL00`3Ng]h208B4Q0<0
Ng]k0P3Ng]h20?Ogm`030?_kn`3oool0oooo00D0oooo00<0P8200000000000003@3oool200000003
0820P03oool0oooo00D0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_k
n`3gmoL0moOg0080Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoLQ0?ooo`030?_kn`3gmoL0moOg0080
g]kN0`1kNg/00`20P800Q8B408B4Q0020=KFeP80moOg00<0no_k0?ooo`3oool06P3oool20?Ogm`<0
g]kN0P24Q8@307]kN`<0g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN0`1kNg/208B4Q0<0
g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030<k>cP2LW9`0W9bL0080000000@0ATI608b<S02<
S8`0WIfM0P2][Jd209BDU00304Y:BP00000000000080W9bL00<0b/[:0?Ogm`3gmoL00`3Ng]h208B4
Q0<0Ng]k0P3Ng]h20?Ogm`030?_kn`3oool0oooo00D0oooo00<0P8200000000000003@3oool20000
00030820P03oool0oooo00D0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80
Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN0`2<S8`00`28
R8P0Q8B408B4Q0020=kNgP80moOg00<0no_k0?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`0=0?oo
o`80moOg0`3Ng]h508B4Q0<0g]kN303oool00`3kno/0moOg0?Ogm`0B0?ooo`80g]kN1@24Q8@30=kN
gP80moOg00<0no_k0?ooo`3oool00P3oool00`28R8P0410@010@400208b<S0030<K6aP3oool0oooo
00D0oooo00<0a/K608b<S02<S8`00P0H61P00`28R8P0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h:0?oo
o`030820P0000000000000d0oooo0P0000000`20P800oooo0?ooo`020?ooo`<0moOg0`3Ng]h208B4
Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?oo
o`030?_kn`3gmoL0moOg0080g]kN0`2<S8`00`28R8P0Q8B408B4Q0020=kNgP80moOg00<0no_k0?oo
o`3oool02P3oool00`3kno/0moOg0?Ogm`0=0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN303oool00`3k
no/0moOg0?Ogm`0B0?ooo`80g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool00P3oool00`28
R8P0410@010@400208b<S0030<K6aP3oool0oooo00D0oooo00<0a/K608b<S02<S8`00P0H61P00`28
R8P0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h:0?ooo`030820P0000000000000d0oooo0P0000000`20
P800oooo0?ooo`020?ooo`<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80
Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN0`2<S8`00`28
R8P0Q8B408B4Q0020=kNgP80moOg00<0no_k0?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`0=0?oo
o`80moOg0`3Ng]h508B4Q0<0g]kN303oool00`3kno/0moOg0?Ogm`0B0?ooo`80g]kN1@24Q8@30=kN
gP80moOg00<0no_k0?ooo`3oool00P3oool00`28R8P0410@010@400208b<S0030<K6aP3oool0oooo
00D0oooo00<0a/K608b<S02<S8`00P0H61P00`28R8P0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h:0?oo
o`030820P0000000000000d0oooo0P0000000`20P800oooo0?ooo`020?ooo`<0moOg0`3Ng]h208B4
Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?oo
o`040?_kn`3gmoL0moOg0?_kn`@0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`05
0?ooo`030?_kn`3gmoL0moOg0080oooo00<0moOg0>o_k`3_knl00P3_knl608B4Q080g]kN1@3gmoL2
0?ooo`0408b<S00H61P061PH05YJFP80W9bL1`3oool00`3>c/h0W9bL09bLW00301PH6080oooo00<0
no_k0?Ogm`3gmoL00P3gmoL30=kNgPD0Q8B40`3Ng]h20>o_k`80moOg00<0no_k0?ooo`3oool00P3g
moL0103kno/0oooo0?ooo`3Fe]H20:f][@80000000<0EeMG0:f][@2][Jd00P3gmoL00`3kno/0oooo
0?ooo`030?Ogm`80oooo00<0moOg0>o_k`3_knl00P3Ng]h508B4Q0<0e]KF1`3gmoL00`1lO7`00000
000000020>o_k`030?Ogm`3oool0oooo00<0oooo0P3gmoL00`3clo<0kno_0>o_k`020000000307al
O03gmoL0moOg00<0g]kN1@24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00`3oool20?Ogm`0307al
O0000000000000L0oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool2000000030820P03oool0oooo0080
moOg0`3_knl30=kNgP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN
0=kNgP3[jn/70?Ogm`@0oooo00@0no_k0?Ogm`3gmoL0no_k103oool00`3kno/0moOg0?Ogm`020?oo
o`030?_kn`3gmoL0moOg00D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020>o_
k`H0Q8B40P3Ng]h50?Ogm`80oooo00@0S8b<01PH600H61P0FUYJ0P2LW9`70?ooo`030<k>cP2LW9`0
W9bL00<061PH0P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0g]kN1@24Q8@30=kNgP80kno_0P3gmoL0
0`3kno/0oooo0?ooo`020?Ogm`040?_kn`3oool0oooo0=KFeP80[Jf]0P0000000`1GEeL0[Jf]0:f]
[@020?Ogm`030?_kn`3oool0oooo00<0moOg0P3oool00`3gmoL0kno_0>o_k`020=kNgPD0Q8B40`3F
e]H70?Ogm`0307alO000000000000080kno_00<0moOg0?ooo`3oool00`3oool20?Ogm`030??cl`3_
knl0kno_0080000000<0O7al0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN0P3_knl00`3clo<0moOg0?Og
m`030?ooo`80moOg00<0O7al0000000000001`3oool0103kno/0moOg0?Ogm`3kno/20?ooo`800000
00<0P8200?ooo`3oool00P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3g
moL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg103oool0103kno/0moOg0?Ogm`3kno/40?ooo`03
0?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`020?ooo`03
0?Ogm`3_knl0kno_0080kno_1P24Q8@20=kNgPD0moOg0P3oool0102<S8`061PH01PH601JFUX209bL
W0L0oooo00<0c/k>09bLW02LW9`00`0H61P20?ooo`030?_kn`3gmoL0moOg0080moOg0`3Ng]h508B4
Q0<0g]kN0P3_knl20?Ogm`030?_kn`3oool0oooo0080moOg00@0no_k0?ooo`3oool0e]KF0P2][Jd2
0000000305MGE`2][Jd0[Jf]0080moOg00<0no_k0?ooo`3oool00`3gmoL20?ooo`030?Ogm`3_knl0
kno_0080g]kN1@24Q8@30=KFePL0moOg00<0O7al0000000000000P3_knl00`3gmoL0oooo0?ooo`03
0?ooo`80moOg00<0lo?c0>o_k`3_knl00P0000000`1lO7`0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h2
0>o_k`030??cl`3gmoL0moOg00<0oooo0P3gmoL00`1lO7`00000000000070?ooo`040?_kn`3gmoL0
moOg0?_kn`80oooo0P0000000`20P800oooo0?ooo`020?Ogm`<0kno_0`3Ng]h208B4Q0L0moOg00<0
gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H0
0`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl20?Ogm`<0oooo0P3g
moL20?ooo`030?_kn`3gmoL0moOg00<0moOg1@3oool2000000030820P03oool0oooo00D0moOg00<0
no_k0?ooo`3oool01@3gmoL20=kNgPH0Q8B40P3Ng]h70?Ogm`040<;2`P2<S8`0S8b<06m_K`80DU9B
0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`030:6QX@1:BTX0BTY:00<0S8b<1@3gmoL20>o_k`<0g]kN
1@24Q8@30=kNgP80kno_0P3gmoL00`3kno/0oooo0?ooo`020?ooo`040?_kn`3gmoL0moOg0:FUY@80
DU9B0P2][Jd00`1lO7`0BTY:04Y:BP020?ooo`030?_kn`3gmoL0moOg00<0oooo1@3gmoL20=kNgPD0
Q8B40`3Ng]h20>o_k`030?Ogm`3oool0oooo0080oooo00<0P8200000000000000P3oool00`3kno/0
moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P0000000`1hN7P0kno_0>o_k`030=kNgPD0
Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg00D0oooo00<0P8200000000000000P3oool00`3kno/0
moOg0?Ogm`020?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P0000000`1lO7`0moOg0?Ogm`050?Og
m`<0g]kN0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>OW
i`80kno_0P3gmoL30?ooo`80moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`D0oooo0P0000000`20
P800oooo0?ooo`050?Ogm`030?_kn`3oool0oooo00D0moOg0P3Ng]h608B4Q080g]kN1`3gmoL01032
`/80S8b<08b<S01_Kfl2059BDP80moOg00<0no_k0?ooo`3oool00P3gmoL00`2QXJ40BTY:04Y:BP03
08b<S0D0moOg0P3_knl30=kNgPD0Q8B40`3Ng]h20>o_k`80moOg00<0no_k0?ooo`3oool00P3oool0
103kno/0moOg0?Ogm`2UYJD2059BDP80[Jf]00<0O7al04Y:BP1:BTX00P3oool00`3kno/0moOg0?Og
m`030?ooo`D0moOg0P3Ng]h508B4Q0<0g]kN0P3_knl00`3gmoL0oooo0?ooo`020?ooo`030820P000
000000000080oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080000000<0
N7Qh0>o_k`3_knl00`3Ng]h508B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`050?ooo`030820P000
000000000080oooo00<0no_k0?Ogm`3gmoL00P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`800000
00<0O7al0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_
00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<
S8`0102a/K40e]KF0=KFeP3WinL20?Ogm`80oooo4P3gmoL20000000307alO03gmoL0moOg00<0oooo
1@3gmoL20?ooo`030?Ogm`3_knl0kno_0080g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL0
1@3gmoL00`1lO7`00000000000020=kNgP030>_[j`3gmoL0moOg0080g]kN00<0Kfm_000000000000
0`3gmoL20?ooo`030?_kn`3gmoL0moOg0080moOg0`3Ng]h508B4Q0<0e]KF2@3gmoL0103Shn<0c/k>
0<k>cP1cLg<201PH6080moOg00<0R8R801PH600H61P00P3>c/h00`3WinL0oooo0?ooo`080?Ogm`80
g]kN1@24Q8@30=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000:0?Ogm`03
0?_kn`3oool0oooo0080000000<0O7al0?Ogm`3gmoL00`3Ng]h508B4Q080e]KF2P3gmoL00`1lO7`0
00000000000:0?Ogm`030?_kn`3oool0oooo0080000000<0O7al0?Ogm`3gmoL00P3oool30>o_k`<0
g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;6a/@3Fe]H0e]KF0>OWi`80
moOg0P3ooolB0?Ogm`80000000<0O7al0?Ogm`3gmoL00`3oool50?Ogm`80oooo00<0moOg0>o_k`3_
knl00P3Ng]h608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`0307alO000000000000080
g]kN00<0jn_[0?Ogm`3gmoL00P3Ng]h00`1_Kfl00000000000030?Ogm`80oooo00<0no_k0?Ogm`3g
moL00P3gmoL30=kNgPD0Q8B40`3Fe]H90?Ogm`040>?Sh`3>c/h0c/k>07=cL`8061PH0P3gmoL00`28
R8P061PH01PH60020<k>cP030>OWi`3oool0oooo00P0moOg0P3Ng]h508B4Q0<0g]kN0P3_knl00`3c
lo<0moOg0?Ogm`020?Ogm`0307alO0000000000000X0moOg00<0no_k0?ooo`3oool00P0000000`1l
O7`0moOg0?Ogm`030=kNgPD0Q8B40P3Fe]H:0?Ogm`0307alO0000000000000X0moOg00<0no_k0?oo
o`3oool00P0000000`1lO7`0moOg0?Ogm`020?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0
_Kfm0;fm_@050?_kn`80R8R800@0/K6a0=[JfP3Jf]X0inOW0P3clo<20?Ogm`<0no_k103gmoL00`2j
^[X0O7al07alO00807alO080000000<0O7al0?Ogm`3gmoL00`3oool50?Ogm`80no_k00<0mOGe0>o_
k`3_knl00P3Jf]X608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`0309NGU`0f=SH0=SHf
0080]KFe00<0e]KF0?Ogm`3gmoL00P2e]KD00`1fMWH0=SHf03Hf=P030?Ogm`80no_k00<0nOWi0?Og
m`3gmoL00P3clo<30=[JfPD0Q8B40`3Fe]H20??cl`L0moOg00@0b/[:09fMW@2MWId0N7Qh0P1BDU82
0?_kn`030:NWY`1BDU80DU9B0080WIfM00<0c<c<0?_kn`3kno/01@3gmoL00`3emOD0lo?c0??cl`02
0=[JfP<0Q8B40P20P8030=[JfP80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`0000000000002
0?Ogm`040?Win@3kno/0no_k0?Win@@0moOg00<0nOWi0?_kn`3kno/00P0000000`1jNWX0lo?c0??c
l`030=[JfPD0Q8B40P3Fe]H20??cl`030?Gem@3gmoL0moOg00D0moOg00<0O7al0000000000000P3g
moL00`3inOT0no_k0?_kn`050?Ogm`030?Win@3kno/0no_k0080000000<0O7al0?Ogm`3gmoL00P3g
moL30??cl`<0g]kN0P20P8070?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0
g]kN0>OWi`@0kno_0`3oool40?Ogm`0307alO0000000000000X0000000<0O7al0?Ogm`3gmoL00`3o
ool70?Ogm`030??cl`3_knl0kno_0080e]KF1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL01@3g
moL00`2a/K40Jf][06][J`0208b<S0030<;2`P3gmoL0moOg0080S8b<00<0O7al06][J`1[Jf/0203g
moL20>o_k`<0e]KF1@24Q8@30=KFeP80kno_1`3gmoL0102a/K40Jf][06][J`1lO7`208b<S080oooo
00<0a/K608b<S02<S8`00P1[Jf/00`2a/K40moOg0?Ogm`050?Ogm`030??cl`3_knl0kno_0080e]KF
0`24Q8@207]kN`<0e]KF0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`0307alO000000000000080moOg
00@0no_k0?ooo`3oool0no_k1`3gmoL20000000307QhN03_knl0kno_00<0e]KF1@24Q8@20=KFeP80
kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`1lO7`00000000000020?Ogm`030?_kn`3oool0oooo00P0
moOg0P0000000`1lO7`0moOg0?Ogm`020>o_k`<0moOg0`3Ng]h207]kN`L0oooo00<0hn?S0<K6aP36
a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm
0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0inOW103_knl30?ooo`@0moOg00<0O7al00000000
00002P0000000`1lO7`0moOg0?Ogm`030?ooo`L0moOg00<0lo?c0>o_k`3_knl00P3Fe]H608B4Q080
g]kN0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`030;6a/@1[Jf/0Jf][0080S8b<00<0`/;20?Ogm`3g
moL00P2<S8`00`1lO7`0Jf][06][J`080?Ogm`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl70?Ogm`04
0;6a/@1[Jf/0Jf][07alO080S8b<0P3oool00`36a/H0S8b<08b<S00206][J`030;6a/@3gmoL0moOg
00D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H308B4Q080Ng]k0`3Fe]H20>o_k`030??cl`3gmoL0moOg
0080moOg00<0O7al0000000000000P3gmoL0103kno/0oooo0?ooo`3kno/70?Ogm`80000000<0N7Qh
0>o_k`3_knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`0307alO0000000
00000080moOg00<0no_k0?ooo`3oool0203gmoL20000000307alO03gmoL0moOg0080kno_0`3gmoL3
0=kNgP80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<2
0>o_k`80moOg0`3_knl20?Ogm`80kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`08
0?Ogm`L0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H608B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`02
0>o_k`040??cl`3gmoL0moOg0=oOg`80a/K60P0H61P00`28R8P0moOg0?Ogm`0201PH600306m_K`36
a/H0a/K600<0kno_1@3gmoL20>o_k`<0g]kN1@24Q8@30=KFeP@0kno_00<0lo?c0?Ogm`3gmoL00P3_
knl0101hN7P000000000001_Kfl20=kNgP80moOg00<0inOW0=KFeP3Fe]H00P0000000`1lO7`0moOg
0?Ogm`030?Ogm`D0kno_0P3Fe]H508B4Q0D0g]kN00<0jn_[0?Ogm`3gmoL00P3_knl00`1hN7P00000
000000050?Ogm`030??cl`3_knl0kno_00D0moOg0P0000000`1hN7P0kno_0>o_k`030=kNgPD0Q8B4
0P3Fe]H50>o_k`<0moOg0P3_knl00`1hN7P00000000000050?Ogm`80kno_00<0lo?c0?Ogm`3gmoL0
0`3gmoL20000000307alO03gmoL0moOg0080moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm
0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m
_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80moOg0`3_knl20?Ogm`80kno_
00<0lo?c0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`080?Ogm`L0kno_00<0inOW0=kNgP3Ng]h0
0P3Fe]H608B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`020>o_k`040??cl`3gmoL0moOg0=oOg`80
a/K60P0H61P00`28R8P0moOg0?Ogm`0201PH600306m_K`36a/H0a/K600<0kno_1@3gmoL20>o_k`<0
g]kN1@24Q8@30=KFeP@0kno_00<0lo?c0?Ogm`3gmoL00P3_knl0101hN7P000000000001_Kfl20=kN
gP80moOg00<0inOW0=KFeP3Fe]H00P0000000`1lO7`0moOg0?Ogm`030?Ogm`D0kno_0P3Fe]H508B4
Q0D0g]kN00<0jn_[0?Ogm`3gmoL00P3_knl00`1hN7P00000000000050?Ogm`030??cl`3_knl0kno_
00D0moOg0P0000000`1hN7P0kno_0>o_k`030=kNgPD0Q8B40P3Fe]H50>o_k`<0moOg0P3_knl00`1h
N7P00000000000050?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00`3gmoL20000000307alO03gmoL0moOg
0080moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;200D0lo?c0P24Q8@0102[Zj/0
d];B0=;BdP3MgMd20>OWi`80lo?c0`3_knl20?Ogm`80kno_00<0lO7a0??cl`3clo<00`3clo<20?Og
m`030?Gem@3clo<0lo?c00P0lo?c1`3_knl00`3WinL0g]kN0=kNgP020=KFePH0Q8B40P3Fe]H20>OW
i`030>g]k@3clo<0lo?c0080kno_00@0lo?c0?Ogm`3gmoL0jn_[0P3Ogml2034a<@030820P03>c/h0
c/k>0080<C4a00<0QXJ60=_Kf`3Kfm/00`3_knl50??cl`80kno_0`3Jf]X508B4Q0<0d];B103_knl0
0`3clo<0moOg0?Ogm`020;jn_P04079bLP0U9BD09BDU08J6QP80inOW0P3clo<00`3]kNd0inOW0>OW
i`0202DU9@0307AdM032`/80`/;200<0lo?c1@3_knl20=KFeP<0Q8B40P20P8030=[JfP80inOW00<0
kno_0?Ogm`3gmoL00P3clo<00`1jNWX00000000000050??cl`030?7al@3_knl0kno_00D0lo?c0P00
00000`1hN7P0kno_0>o_k`030=[JfPD0Q8B40P3Bd]850>o_k`<0moOg0P3clo<00`1lO7`010@400@4
10020<K6aP030=gMg@3clo<0lo?c0080kno_00@0lO7a0??cl`3clo<0gmoO0P3:b/X200@4100307al
O03clo<0lo?c0080lo?c0`3_knl30=KFeP80P8201@3clo<20?Ogm`030=[JfP2m_Kd0_Kfm00<0d];B
0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3_
knl208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN1@3_knl20?Ogm`P0kno_1@3gmoL?0>o_k`030>OW
i`3Ng]h0g]kN0080e]KF1P24Q8@20=KFeP80g]kN00<0inOW0>o_k`3_knl00P3_knl00`3clo<0moOg
0?Ogm`030?Ogm`80BTY:00<0N7Qh0:FUY@2UYJD00P1:BTX00`2MWId0kno_0>o_k`0:0>o_k`<0e]KF
1@24Q8@30<k>cP@0kno_00<0lo?c0?Ogm`3gmoL00P2<S8`0101[Jf/0BTY:04Y:BP2MWId40>o_k`03
0??cl`3gmoL0moOg0080BTY:00<0Jf][08b<S02<S8`0203_knl20=KFeP<0Q8B40P1kNg/30=KFeP80
kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000=0>o_k`80000000<0N7Qh0>o_k`3_
knl00`3Fe]H508B4Q080c/k>1@3_knl50?Ogm`030820P00820P020P80080U9BD00<0`/;20>o_k`3_
knl01@3_knl00`36a/H0W9bL09bLW00200P8200307alO03_knl0kno_00D0kno_0`3Fe]H207]kN`D0
kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgPD0
kno_0P3gmoL80>o_k`D0moOg3`3_knl00`3WinL0g]kN0=kNgP020=KFePH0Q8B40P3Fe]H20=kNgP03
0>OWi`3_knl0kno_0080kno_00<0lo?c0?Ogm`3gmoL00`3gmoL204Y:BP0307QhN02UYJD0YJFU0080
BTY:00<0WIfM0>o_k`3_knl02P3_knl30=KFePD0Q8B40`3>c/h40>o_k`030??cl`3gmoL0moOg0080
S8b<00@0Jf][04Y:BP1:BTX0WIfM103_knl00`3clo<0moOg0?Ogm`0204Y:BP0306][J`2<S8`0S8b<
00P0kno_0P3Fe]H308B4Q080Ng]k0`3Fe]H20>o_k`030??cl`3gmoL0moOg0080moOg00<0O7al0000
000000003@3_knl20000000307QhN03_knl0kno_00<0e]KF1@24Q8@20<k>cPD0kno_1@3gmoL00`20
P80020P800P8200209BDU0030<;2`P3_knl0kno_00D0kno_00<0a/K609bLW02LW9`00P0820P00`1l
O7`0kno_0>o_k`050>o_k`<0e]KF0P1kNg/50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3<c<`0a/K60<K6aP050??cl`80
Q8B400@0Zj^[0=;BdP3Bd]80e]KF0P3Jf]X20>OWi`<0kno_0P3[jn/20??cl`040?7al@3_knl0kno_
0>_[j`80inOW0P3clo<00`3_knl0jn_[0>_[j`0?0>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`20P800
0`22PX80Q8B408B4Q0020=KFeP80f][J00<0hN7Q0>OWi`3WinL00P3_knl0103]kNd0jn_[0>_[j`3_
knl20??cl`80N7Qh00<0IVIV05=CD`1CDe<00P1hN7P00`2`/;00inOW0>OWi`080>o_k`80inOW0`3F
e]H20820P0<0Q8B40`3Bd]820>?Sh`80inOW00<0kNg]0??cl`3clo<00P1BDU80101QHF40Kfm_06m_
K`2_[jl20>o_k`80hn?S00<0jn_[0??cl`3clo<00P1[Jf/00`1OGel0DU9B059BDP050>o_k`030>_[
j`3WinL0inOW0080e]KF0`20P80208B4Q0<0e]KF0P3Shn<00`3WinL0jn_[0>_[j`020??cl`0307Yj
NP000000000000D0kno_00<0jn_[0>OWi`3WinL00P3_knl00`3[jn/0inOW0>OWi`020000000307Ad
M03WinL0inOW00<0e]KF0P20P80308B4Q080d];B0P3Shn<00`3UiND0inOW0>OWi`030??cl`80jn_[
00<0WIfM04i>CP1>CTh00P1:BTX00`22PX80^[Zj0;Zj^P020<[:bP040<;2`P2j^[X0^[Zj08B4Q0@0
CTi>00<0WinO0>o_k`3_knl00P3_knl30>OWi`<0e]KF0P1kNg/50??cl`80moOg00<0gMgM0<;2`P32
`/800`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K6
0<K6aP050?Ogm`80Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0kno_0P3Ng]h20?Ogm`040??c
l`3_knl0kno_0>OWi`80g]kN0P3_knl00`3WinL0g]kN0=kNgP0?0>o_k`030>OWi`3Ng]h0g]kN0080
e]KF0`1kNg/00`20P800Q8B408B4Q0040=KFeP030=[JfP3Ng]h0g]kN0080kno_00@0inOW0=kNgP3N
g]h0inOW0P3_knl20:FUY@0305=CD`00000000000080YJFU00<0`/;20=kNgP3Ng]h0203_knl20=kN
gP<0e]KF0P1kNg/308B4Q0D0e]KF0P3Ng]h00`3WinL0kno_0>o_k`0201PH600405IFEP2DU9@0U9BD
0<;2`P80kno_0P3Fe]H00`3Shn<0kno_0>o_k`0208b<S003059BDP0H61P061PH00D0kno_00<0inOW
0=kNgP3Ng]h00P3Fe]H307]kN`80S8b<1@3Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`0307QhN0000000
000000D0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP020000000306m_K`3Ng]h0
g]kN00<0e]KF0P1kNg/308B4Q0@0e]KF00<0f][J0=kNgP3Ng]h00`3_knl20=kNgP030;Vi^@2DU9@0
U9BD0080000000<0@T9208B4Q024Q8@00P2UYJD0102EUID0Q8B408B4Q012@T8200000080U9BD00<0
`/;20>o_k`3_knl00P3_knl30=kNgP<0e]KF0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL2
08B4Q0030:f][@3Fe]H0e]KF00<0e]KF0P3Ng]h30>o_k`80g]kN0P3gmoL0103clo<0kno_0>o_k`3W
inL20=kNgP80kno_00<0inOW0=kNgP3Ng]h03`3_knl00`3WinL0g]kN0=kNgP020=KFeP<0Ng]k00<0
P82008B4Q024Q8@0103Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`80kno_
0P2UYJD00`1CDe<00000000000020:FUY@030<;2`P3Ng]h0g]kN00P0kno_0P3Ng]h30=KFeP80Ng]k
0`24Q8@50=KFeP80g]kN00<0inOW0>o_k`3_knl00P0H61P0101FEUH0U9BD09BDU032`/820>o_k`80
e]KF00<0hn?S0>o_k`3_knl00P2<S8`00`1BDU8061PH01PH60050>o_k`030>OWi`3Ng]h0g]kN0080
e]KF0`1kNg/208b<S0D0e]KF00<0f][J0=kNgP3Ng]h00P3_knl00`1hN7P00000000000050>o_k`03
0>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00P0000000`1_Kfl0g]kN0=kNgP030=KFeP80
Ng]k0`24Q8@40=KFeP030=[JfP3Ng]h0g]kN00<0kno_0P3Ng]h00`2i^KT0U9BD09BDU00200000003
0492@P24Q8@0Q8B40080YJFU00@0UIFE08B4Q024Q8@0@T920P00000209BDU0030<;2`P3_knl0kno_
0080kno_0`3Ng]h30=KFeP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0
e]KF0=KFeP3Jf]X90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20>o_k`030>OWi`3Ng]h0g]kN
00D0g]kN0`3_knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h608B4Q080c/k>2P3Ng]h00`3W
inL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3[jn/0moOg0?Ogm`020=kN
gP<0c/k>1@24Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0inOW103Ng]h00`3WinL0kno_0>o_k`08
0=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>1`3Ng]h00`1_Kfl0000000000002
0?Ogm`030>_[j`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP020000000306m_K`3Ng]h0
g]kN00<0c/k>1@24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl00P2LW9`00`1[Jf/0>CTi03Ti>@05
02TY:@0305]KF`2<S8`0S8b<0080g]kN00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41`3oool0
0`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KF
eP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0e]KF0=KFeP3Jf]X90=kNgP80kno_00<0inOW
0=kNgP3Ng]h00`3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN0`3_knl20=kNgP030>OWi`3_knl0
kno_00D0g]kN0P3>c/h608B4Q080c/k>2P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW
0=kNgP3Ng]h01@3Ng]h00`3[jn/0moOg0?Ogm`020=kNgP<0c/k>1@24Q8@30<k>cPT0g]kN00@0inOW
0>o_k`3_knl0inOW103Ng]h00`3WinL0kno_0>o_k`080=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3>
c/h508B4Q0<0c/k>1`3Ng]h00`1_Kfl00000000000020?Ogm`030>_[j`3Ng]h0g]kN00<0g]kN0P3_
knl00`3WinL0g]kN0=kNgP020000000306m_K`3Ng]h0g]kN00<0c/k>1@24Q8@20<k>cPX0g]kN00<0
inOW0>o_k`3_knl00P2LW9`00`1[Jf/0>CTi03Ti>@0502TY:@0305]KF`2<S8`0S8b<0080g]kN00<0
inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0
102[Zj/0d];B0=;BdP3Hf=P20=kNgP80f][J1@3Ng]h20>?Sh`040>7Qh@3Ng]h0g]kN0=cLg080f][J
0P3Shn<00`3QhN40g]kN0=kNgP020=[JfP030=cLg03Ng]h0g]kN00<0inOW0P3Ng]h00`3Shn<0inOW
0>OWi`050=[JfP80c/k>1P24Q8@20<k>cPD0f][J1@3Ng]h00`3Shn<0inOW0>OWi`020=kNgP030=cL
g03Jf]X0f][J0080hn?S00<0hN7Q0=kNgP3Ng]h00`3Jf]X20=kNgP030>GUi@3[jn/0jn_[0080f][J
0`3>c/h508B4Q0<0c/k>0P3Ng]h20=[JfP030=cLg03Ng]h0g]kN0080g]kN00@0hn?S0>OWi`3WinL0
hn?S0P3Ng]h20=[JfP030=oOg`3Shn<0hn?S0080g]kN00<0g=cL0=[JfP3Jf]X00`3Ng]h20>OWi`03
0>7Qh@3Jf]X0f][J0080c/k>1@24Q8@30<k>cP80g]kN00<0g=cL0=[JfP3Jf]X00P3Ng]h00`2WYjL0
Kfm_06m_K`020>_[j`040>GUi@3Ng]h0g]kN0=cLg080f][J0P3Shn<00`3QhN40g]kN0=kNgP0206][
J`030:>SX`3Jf]X0f][J00<0c/k>1@24Q8@20<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h00`3S
hn<0inOW0>OWi`020;fm_@030:>SX`28R8P0R8R80080P82000@0PX:208B4Q024Q8@0Vi^K0P2a/K42
0=kNgP030>?Sh`3WinL0inOW0080g]kN0`3Jf]X30<k>cP80Q8B41`3kno/00`3Lg=`0_Kfm0;fm_@03
0=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm
00D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF1@3Ng]h20=KFeP040=[JfP3Ng]h0
g]kN0=[JfP@0e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3>
c/h608B4Q080c/k>1@3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3F
e]H50=kNgP80e]KF0`3>c/h508B4Q0<0c/k>0P3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3F
e]H20=kNgP030=[JfP3Fe]H0e]KF00D0g]kN00<0f][J0=KFeP3Fe]H00P3>c/h508B4Q0<0c/k>0P3N
g]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h01@3F
e]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Jf]X0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m
_Kd0_Kfm00D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF1@3Ng]h20=KFeP040=[J
fP3Ng]h0g]kN0=[JfP@0e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0
e]KF0P3>c/h608B4Q080c/k>1@3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3N
g]h00`3Fe]H50=kNgP80e]KF0`3>c/h508B4Q0<0c/k>0P3Ng]h20=KFeP030=[JfP3Ng]h0g]kN00P0
g]kN1@3Fe]H20=kNgP030=[JfP3Fe]H0e]KF00D0g]kN00<0f][J0=KFeP3Fe]H00P3>c/h508B4Q0<0
c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3N
g]h01@3Fe]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3F
e]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3J
f]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P1kNg/0102][Jd0g]kN0=kNgP3[jn/>0?Og
m`030?_kn`3oool0oooo00d0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?Ogm`3_knl0kno_
0080g]kN0`24Q8@00`20P800Ng]k07]kN`020=kNgPD0moOg0P3oool00`3kno/0moOg0?Ogm`0E0?Og
m`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]h20?Ogm`80oooo00<0no_k0?Ogm`3gmoL05`3gmoL00`3c
lo<0kno_0>o_k`020=kNgP<0Q8B40P1kNg/30=kNgP80oooo00<0no_k0?Ogm`3gmoL0503gmoL00`3c
lo<0kno_0>o_k`030=kNgP80Q8B40`1kNg/20=kNgP80moOg00<0no_k0?ooo`3oool06P3gmoL20?oo
o`<0kno_0`3Ng]h208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>
cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080
moOg00<0lo?c0>o_k`3_knl00P1kNg/0102][Jd0g]kN0=kNgP3[jn/>0?Ogm`030?_kn`3oool0oooo
00d0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?Ogm`3_knl0kno_0080g]kN0`24Q8@00`20
P800Ng]k07]kN`020=kNgPD0moOg0P3oool00`3kno/0moOg0?Ogm`0E0?Ogm`80kno_0`3Ng]h208B4
Q0<0Ng]k0`3Ng]h20?Ogm`80oooo00<0no_k0?Ogm`3gmoL05`3gmoL00`3clo<0kno_0>o_k`020=kN
gP<0Q8B40P1kNg/30=kNgP80oooo00<0no_k0?Ogm`3gmoL0503gmoL00`3clo<0kno_0>o_k`030=kN
gP80Q8B40`1kNg/20=kNgP80moOg00<0no_k0?ooo`3oool06P3gmoL20?ooo`<0kno_0`3Ng]h208B4
Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;20080moOg00<0mOGe0??cl`3c
lo<00P20P800102d];@0inOW0>OWi`3alO4>0?_kn`030?gmo@3oool0oooo00d0no_k0P3oool00`3m
oOd0no_k0?_kn`020?ooo`030?_kn`3gmoL0moOg0080kno_0`24Q8@00`22PX80P8200820P0020>OW
i`D0no_k0P3oool00`3moOd0no_k0?_kn`0E0?_kn`80moOg0`3_knl208B4Q0<0P8200`3WinL20?_k
n`80oooo00<0oOgm0?_kn`3kno/05`3kno/00`3inOT0moOg0?Ogm`020>o_k`<0Q8B40P20P8030>OW
i`80oooo00<0oOgm0?_kn`3kno/0503kno/00`3inOT0moOg0?Ogm`030>o_k`80Q8B40`20P8020>OW
i`80no_k00<0oOgm0?ooo`3oool06P3kno/20?ooo`<0moOg0`3_knl208B4Q080lo?c00<0mOGe0?Og
m`3gmoL00P3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102j^[X0kno_0>o_k`3gmoLZ0?oo
o`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?oo
o`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102j^[X0kno_0>o_k`3gmoLZ0?oo
o`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?oo
o`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`0508B4Q080
Ng]k4P24Q8@307]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024
Q8@00P24Q8@01020P800Ng]k07]kN`20P80A08B4Q0030820P01kNg/0Ng]k00d0Q8B40P1kNg/508B4
Q080Ng]k00<0P82008B4Q024Q8@04024Q8@207]kN`030820P024Q8@0Q8B400X0Q8B40P1kNg/00`20
P800Q8B408B4Q00208B4Q0030820P01kNg/0Ng]k01`0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4
Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k07]kN`0:08B4Q0L0oooo00<0g]kN0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0
_Kfm0;fm_@050?ooo`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/508B4Q080
Ng]k00<0P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1k
Ng/0P8204@24Q8@00`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B4
0100Q8B40P1kNg/00`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20
P800Ng]k07]kN`0L08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B4
00l0Q8B400<0P82007]kN`1kNg/02P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool508B4Q003
0820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400X0
Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k0820P140Q8B400<0P82007]k
N`1kNg/03@24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00@08B4Q080Ng]k00<0P82008B4
Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/07024Q8@207]k
N`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00?08B4Q0030820P01kNg/0Ng]k
00X0Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P1cLg<00`1lO7`0Q8B408B4Q00308B4Q080
Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080
Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00@0
Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0208b<S00308R8R024Q8@0Q8B400D0
Q8B40`1kNg/508B4Q080Ng]k1@24Q8@307]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q004
0820P01kNg/0Ng]k0820P0T0Q8B400<0O7al07=cL`1cLg<01@24Q8@00`20P800Ng]k07]kN`0508B4
Q080Ng]k1@24Q8@00`1lO7`0Lg=c07=cL`0208B4Q00308R8R02<S8`0S8b<0080Ng]k00<0P82008B4
Q024Q8@02024Q8@507]kN`D0Q8B40`1kNg/408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]k
N`1kNg/02P24Q8@00`1lO7`0Lg=c07=cL`0508B4Q0D0Ng]k1@24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36
a/H01@3gmoL207=cL`0307alO024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024
Q8@02024Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q003
0820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01024Q8@00`20P800Ng]k07]kN`0508B4Q003
0820P01kNg/0Ng]k0080S8b<00<0R8R808B4Q024Q8@01@24Q8@307]kN`D0Q8B40P1kNg/508B4Q0<0
Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8202@24Q8@00`1l
O7`0Lg=c07=cL`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/508B4Q00307alO01cLg<0Lg=c
0080Q8B400<0R8R808b<S02<S8`00P1kNg/00`20P800Q8B408B4Q00808B4Q0D0Ng]k1@24Q8@307]k
N`@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q00307alO01cLg<0Lg=c
00D0Q8B41@1kNg/508B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P050??cl`80O7al00@0UiNG0;6a/@2a
/K40^;Rh0P2n_[h20;Vi^@<0_[jn0P32`/820;fm_@P0_[jn00<0`<300<;2`P32`/800P2i^KT00`2l
_;`0_[jn0;jn_P030<;2`P80^KVi00<0_;bl0;jn_P2n_[h00P32`/800`2n_[h0^KVi0;Vi^@020;6a
/@<0Q8B400<0PX:20820P020P8000P2a/K420;jn_P030;bl_02i^KT0^KVi0080_[jn00@0`<300<;2
`P32`/80`<300P2m_Kd20<;2`P030<30`02n_[h0_[jn0080_[jn00<0`<300<;2`P32`/800`2i^KT2
0;jn_P030<30`032`/80`/;20080^KVi0`2a/K4208B4Q0<0P8200`2a/K420;jn_P80^KVi00<0_;bl
0;jn_P2n_[h00P32`/800`30`<00_Kfm0;fm_@080;jn_P80`/;200<0_;bl0;Fe]@2e]KD00`2n_[h2
0<;2`P030;jn_P2i^KT0^KVi0080/K6a0`24Q8@20820P0<0/K6a0P2n_[h00`2j^[X0]KFe0;Fe]@02
0;jn_P030<;2`P36a/H0a/K60080_Kfm202n_[h00`30`<00`/;20<;2`P050;Vi^@<0/K6a0P24Q8@3
0820P080/K6a0P2n_[h00`2l_;`0^KVi0;Vi^@030;jn_P80`/;200<0`<300;fm_@2m_Kd01`2n_[h0
1030`<00`/;20<;2`P2l_;`20;Fe]@80_[jn00<0`<300<;2`P32`/801@2i^KT30;6a/@80Q8B41@3c
lo<20?Ogm`030=[JfP2m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg103o
ool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool50?Ogm`80oooo00<0
no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN1`3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg00<0
no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0g]kN1@24Q8@30=kNgPL0moOg1@3o
ool00`3kno/0moOg0?Ogm`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3g
moL0moOg0080g]kN1@24Q8@30=kNgPL0moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Og
m`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h508B4Q080g]kN203gmoL50?ooo`L0moOg00@0
no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@50>o_k`80moOg
00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_k
n`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg
0?Ogm`020=kNgPH0Q8B40P3Ng]h70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo
0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL50?ooo`030?_k
n`3gmoL0moOg00D0moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P3Ng]h508B4Q0<0g]kN1`3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg
00<0no_k0?ooo`3oool01@3gmoL30=kNgPD0Q8B40P3Ng]h80?Ogm`D0oooo1`3gmoL0103kno/0oooo
0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0
_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kNgP3_knlU0?ooo`03
0?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgQl0oooo0P3gmoL30=kNgPD0Q8B40`3Ng]hN0?ooo`03
0?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080
g]kN8@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg
0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>o_kbD0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080
g]kN7`3oool20?Ogm`<0g]kN1@24Q8@30=kNgQh0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0
g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3Ng]h208B4Q0L0
moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_
0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_:03oool20>o_k`<0
S8b<00<0R8R808B4Q024Q8@00P3Ng]hQ0?ooo`<0moOg1@24Q8@30=kNgR40oooo0P3_knl508B4Q0<0
g]kN703oool30?Ogm`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd0
1@3oool208B4Q0040;6a/@3Ng]h0g]kN0>o_kbP0oooo0P3_knl308b<S00308R8R024Q8@0Q8B40080
g]kN8@3oool30?Ogm`D0Q8B40`3Ng]hQ0?ooo`80kno_1@24Q8@30=kNgQ`0oooo0`3gmoL508B4Q080
g]kN903oool30>o_k`80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN
0=kNgP3_knlX0?ooo`80kno_0`2<S8`00`28R8P0Q8B408B4Q0020=kNgR40oooo0`3gmoL508B4Q0<0
g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0moOg1@24Q8@20=kNgR@0oooo0`3_knl208B4Q0L0
oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`03
0?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgR40oooo0`3Ng]h508B4Q0<0kno_0P3gmoLL0?ooo`03
0?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool05`3oool30=kNgPD0
Q8B40P3_knl20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN8@3oool30=kNgPD0Q8B40`3_knl20?Ogma`0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0G0?ooo`<0g]kN1@24Q8@20>o_k`80
moOg00<0no_k0?ooo`3oool0703oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H0
1@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0
Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo00P0oooo0P0820P00`1_Kfl0e]KF0=KFeP0=0?ooo`80
moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80
moOg00<0no_k0?ooo`3oool0503oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]h20?Ogm`03
0?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80
kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_
0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080
g]kN0P3gmoL00`3kno/0oooo0?ooo`080?ooo`8020P800<0Kfm_0=KFeP3Fe]H03@3oool20?Ogm`<0
g]kN1@24Q8@30=kNgP80moOg703oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20?Ogm`03
0?_kn`3oool0oooo01@0oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN0P3gmoL00`3kno/0
oooo0?ooo`0L0?ooo`<0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B4
00@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80
moOg00<0no_k0?ooo`3oool0203oool200P8200306m_K`3Fe]H0e]KF00d0oooo0P3gmoL30=kNgPD0
Q8B40`3Ng]h20?Ogma`0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN0P3gmoL00`3kno/0
oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3o
ool0703oool30?Ogm`<0g]kN0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;Fe
]@3Ng]h0g]kN0>_[j`80moOg0P3oool30?Ogm`X0oooo0P3gmoL00`3kno/0oooo0?ooo`0?0?ooo`03
0?Ogm`3_knl0kno_0080g]kN1P24Q8@20=kNgP80moOg00<0no_k0?ooo`3oool00P3oool0103kno/0
moOg0?Ogm`3kno/20?ooo`80FUYJ00<0Jf][07]kN`1kNg/02P3oool00`3kno/0moOg0?Ogm`020?Og
m`<0g]kN1@24Q8@30=kNgPL0moOg0P3oool00`20P80000000000000:000000030820P03oool0oooo
00<0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h50?Ogm`80oooo00<0P8200000
000000002P0000000`20P800oooo0?ooo`050?Ogm`<0g]kN1@24Q8@20=kNgPP0moOg1@3oool20<K6
aP0307QhN00Y:BT0:BTY00P000000P3gmoL00`3kno/0oooo0?ooo`020?ooo`<0kno_0`3Ng]h208B4
Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0jn_[0P3gmoL20?oo
o`<0moOg2P3oool20?Ogm`030?_kn`3oool0oooo00l0oooo00<0moOg0>o_k`3_knl00P3Ng]h608B4
Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P1JFUX0
0`1[Jf/0Ng]k07]kN`0:0?ooo`030?_kn`3gmoL0moOg0080moOg0`3Ng]h508B4Q0<0g]kN1`3gmoL2
0?ooo`030820P0000000000000X0000000<0P8200?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0
moOg0080g]kN1@24Q8@30=kNgPD0moOg0P3oool00`20P80000000000000:000000030820P03oool0
oooo00D0moOg0`3Ng]h508B4Q080g]kN203gmoL50?ooo`80a/K600<0N7Qh02TY:@0Y:BT020000002
0?Ogm`030?_kn`3oool0oooo0080oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@03
0=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<S8b02m_Kd0_Kfm
00D0no_k0P28R8P0102c/k<0g]kN0=kNgP3YjNT20??cl`D0no_k0P3oool80820P080moOg00<0_;bl
0820P020P8001@20P8030?ooo`80no_k00<0oOgm0?ooo`3oool00P3oool00`3inOT0lo?c0??cl`02
0=kNgPH0Q8B40P3Ng]h20??cl`030?Ogm`3kno/0no_k0080oooo00@0no_k0?Ogm`3gmoL0_;bl0P20
P80202d];@0303Hf=P0n?Sh0?Shn00D0P8201@3oool00`3moOd0no_k0?_kn`020??cl`<0f][J1@24
Q8@30=[JfP80lo?c0P3kno/00`3inOT0moOg0?Ogm`020?ooo`040<30`020P800P82007inOP80O7al
0P20P8000`1/K6`0EeMG05MGE`0201DE5@0308Z:RP3oool0oooo00D0no_k00<0moOg0??cl`3clo<0
0P3Ng]h308B4Q080P8200`3Ng]h50?Ogm`80oooo00<0RXZ:01DE5@0E5AD00P1GEeL0101/K6`0P820
0820P01nOWh207alO080P82000<0`<300?ooo`3oool00P3kno/00`3gmoL0lo?c0??cl`030=[JfPD0
Q8B40P3Jf]X20??cl`030?Ogm`3kno/0no_k00<0moOg1@3oool207QhN00306EUI@1BDU80DU9B00D0
O7al00<0OWin0820P020P8001`3kno/30?Ogm`<0g]kN0P20P8070?_kn`030=oOg`32`/80`/;200<0
d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd0
1@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_0P3gmoL50?ooo`P000000P3gmoL00`1lO7`0
000000000005000000<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080
g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P3oool0103kno/0moOg0?Ogm`1lO7`<0000
00P0oooo0P3_knl30=KFePD0Q8B40`3Fe]H20>o_k`80oooo00<0no_k0?Ogm`3gmoL01@3oool00`3k
no/0moOg0?Ogm`020?ooo`030=KFeP2][Jd0[Jf]0080:BTY00<0U9BD0?ooo`3oool00`3oool20?Og
m`030??cl`3_knl0kno_0080g]kN0`24Q8@207]kN`<0g]kN1@3gmoL20?ooo`0309BDU00Y:BT0:BTY
0080[Jf]00@0e]KF0?ooo`3oool0no_k0P3gmoL70?ooo`030?Ogm`3_knl0kno_00<0e]KF1@24Q8@2
0=KFeP80kno_00<0moOg0?ooo`3oool00`3gmoL50?ooo`80:BTY00<0DU9B07]kN`1kNg/01@3gmoL0
0`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080moOg0`3oool30=kNgP80Ng]k1`3oool0
0`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>
cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg1@3oool8
00000080moOg00<0O7al0000000000001@0000030?ooo`80moOg00<0no_k0?ooo`3oool00P3oool0
0`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080oooo00@0no_k
0?Ogm`3gmoL0O7al300000080?ooo`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?ooo`030?_kn`3g
moL0moOg00D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3Fe]H0[Jf]0:f][@0202TY:@0309BDU03o
ool0oooo00<0oooo0P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Q8B40P1kNg/30=kNgPD0moOg0P3o
ool00`2DU9@0:BTY02TY:@020:f][@040=KFeP3oool0oooo0?_kn`80moOg1`3oool00`3gmoL0kno_
0>o_k`030=KFePD0Q8B40P3Fe]H20>o_k`030?Ogm`3oool0oooo00<0moOg1@3oool202TY:@03059B
DP1kNg/0Ng]k00D0moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0oooo
0`3Ng]h207]kN`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S
0P3_knl20?ooo`L0moOg00@0no_k0?ooo`3oool0no_k2@3gmoL00`3kno/0oooo0?ooo`0=0?Ogm`80
g]kN1P24Q8@20=kNgP80kno_00<0moOg0?ooo`3oool0203gmoL20=kNgP0307=cL`0820P020P80080
g]kN00<0jn_[0?Ogm`3gmoL02P3gmoL30=kNgPD0Q8B40`3Ng]h<0?Ogm`030=;BdP2][Jd0[Jf]0080
:BTY00<08B4Q01PH600H61P00P2<S8`00`32`/80moOg0?Ogm`080?Ogm`80g]kN1@24Q8@30=kNgP80
kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`32`/80S8b<08b<S002010@400401dM7@0Y:BT0:BTY06][
J`80[Jf]2P3gmoL30=kNgPD0Q8B40P3Ng]h=0?Ogm`d000001@3gmoL20?ooo`<0kno_0`3Ng]h208B4
Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?oo
o`L0moOg00@0no_k0?ooo`3oool0no_k2@3gmoL00`3kno/0oooo0?ooo`0=0?Ogm`80g]kN1P24Q8@2
0=kNgP80kno_00<0moOg0?ooo`3oool0203gmoL20=kNgP0307=cL`0820P020P80080g]kN00<0jn_[
0?Ogm`3gmoL02P3gmoL30=kNgPD0Q8B40`3Ng]h<0?Ogm`030=;BdP2][Jd0[Jf]0080:BTY00<08B4Q
01PH600H61P00P2<S8`00`32`/80moOg0?Ogm`080?Ogm`80g]kN1@24Q8@30=kNgP80kno_00<0lo?c
0?Ogm`3gmoL00P3gmoL00`32`/80S8b<08b<S002010@400401dM7@0Y:BT0:BTY06][J`80[Jf]2P3g
moL30=kNgPD0Q8B40P3Ng]h=0?Ogm`d000001@3gmoL20?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0
f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]80
0`3:b/X0`/;20<;2`P050??cl`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?_kn`D0moOg0P1l
O7`0101nOWh0P8200820P01nOWh207alO080no_k00<0_;bl07alO01lO7`00P1lO7`00`1nOWh0P820
0820P00:0?Ogm`030?Gem@3clo<0lo?c0080f][J1P24Q8@20=kNgP80kno_00<0mOGe0?_kn`3kno/0
0P3gmoL0103inOT0no_k0?_kn`2l_;`207alO080Kfm_00<0>SXj00@4100410@00P1_Kfl00`1fMWH0
O7al07alO0080?Ogm`80lo?c0`3Jf]X508B4Q0<0f][J0P3clo<20?Ogm`030?Win@3kno/0no_k0080
moOg00@0e=CD0;6a/@2a/K40Q8B40P1GEeL204Y:BP0306UYJ@28R8P0R8R80080`/;200<0gmoO0?_k
n`3kno/01@3gmoL00`3emOD0lo?c0??cl`020=[JfPD0Q8B40`3Jf]X20>o_k`030?Gem@3kno/0no_k
0080moOg00<0gMgM0<;2`P32`/800P24Q8@0101WIfL0BTY:04Y:BP1ADE4205MGE`80/K6a00<0e=CD
0?Ogm`3gmoL00P3gmoL00`3emOD0lo?c0??cl`030=[JfPD0Q8B40P3Jf]X20??cl`030?Gem@3gmoL0
moOg00<0no_k1@3gmoL201DE5@0302XZ:P0n?Sh0?Shn00P0O7al1@3gmoL20?_kn`<0kno_0`3Jf]X2
08B4Q0D0lo?c0P3gmoL00`3Jf]X0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102][Jd0e]KF0=KFeP3Shn<2
0>o_k`L0moOg200000020?ooo`030820P0000000000000D000002P3gmoL00`3clo<0kno_0>o_k`02
0=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080moOg00@0no_k0?ooo`3oool0P8203000
00080?Ogm`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?Ogm`030?_kn`3oool0oooo0080moOg00@0
/K6a06][J`1[Jf/0=SHf0P00000206][J`030;6a/@3gmoL0moOg0080moOg00<0no_k0?ooo`3oool0
1@3gmoL00`3clo<0kno_0>o_k`020=KFePD0Q8B40`3Fe]H20>o_k`030?Ogm`3oool0oooo00L0moOg
00@0/K6a06][J`1[Jf/0=SHf0P00000206][J`030;6a/@3gmoL0moOg0080moOg00<0lo?c0>o_k`3_
knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`030?ooo`D0moOg0P0Y:BT00`1BDU80
Ng]k07]kN`0?0?Ogm`<0kno_0`3Fe]H208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_
0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`L0moOg200000020?ooo`030820P0000000000000D0
00002P3gmoL00`3clo<0kno_0>o_k`020=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080
moOg00@0no_k0?ooo`3oool0P820300000080?Ogm`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?Og
m`030?_kn`3oool0oooo0080moOg00@0/K6a06][J`1[Jf/0=SHf0P00000206][J`030;6a/@3gmoL0
moOg0080moOg00<0no_k0?ooo`3oool01@3gmoL00`3clo<0kno_0>o_k`020=KFePD0Q8B40`3Fe]H2
0>o_k`030?Ogm`3oool0oooo00L0moOg00@0/K6a06][J`1[Jf/0=SHf0P00000206][J`030;6a/@3g
moL0moOg0080moOg00<0lo?c0>o_k`3_knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Og
m`030?ooo`D0moOg0P0Y:BT00`1BDU80Ng]k07]kN`0?0?Ogm`<0kno_0`3Fe]H208B4Q0D0kno_0P3g
moL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=KFeP030<k>cP36a/H0a/K600D0moOg0P1kNg/0102YZJT0e]KF0=KFeP3Shn<20>o_k`D0moOg0P3_
knl20?ooo`030?_kn`3gmoL0moOg01D0moOg1@3_knl20=kNgP<0Ng]k00<0P82008B4Q024Q8@00P3F
e]H50?Ogm`D0kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`2YZJT0FUYJ05YJFP0207=cL`030;Fe]@3g
moL0moOg00X0moOg0`3Fe]H208B4Q0<0Ng]k0`3Ng]h20>o_k`80moOg00<0lo?c0>o_k`3_knl01@3g
moL00`3Bd]80[Jf]0:f][@02024Q8@0301dM7@0H61P061PH0080S8b<00<0_[jn0>o_k`3_knl01@3g
moL00`3clo<0kno_0>o_k`020=kNgP<0Ng]k0P2<S8`30=KFeP80g]kN00<0jn_[0?Ogm`3gmoL00P3g
moL00`2n_[h0Q8B408B4Q00201PH600401dM7@0Q8B408B4Q06MWI`80[Jf]0P3oool00`3kno/0moOg
0?Ogm`050?Ogm`<0e]KF0P24Q8@307]kN`80g]kN0P3_knl00`3clo<0moOg0?Ogm`030>o_k`80moOg
00<0lo?c0>o_k`3_knl00P2m_Kd00`1_Kfl08B4Q024Q8@08000000D0moOg1@3_knl30=KFeP80S8b<
1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P1kNg/0102YZJT0e]KF0=KFeP3Shn<20>o_k`D0moOg
0P3_knl20?ooo`030?_kn`3gmoL0moOg01D0moOg1@3_knl20=kNgP<0Ng]k00<0P82008B4Q024Q8@0
0P3Fe]H50?Ogm`D0kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`2YZJT0FUYJ05YJFP0207=cL`030;Fe
]@3gmoL0moOg00X0moOg0`3Fe]H208B4Q0<0Ng]k0`3Ng]h20>o_k`80moOg00<0lo?c0>o_k`3_knl0
1@3gmoL00`3Bd]80[Jf]0:f][@02024Q8@0301dM7@0H61P061PH0080S8b<00<0_[jn0>o_k`3_knl0
1@3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Ng]k0P2<S8`30=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
0P3gmoL00`2n_[h0Q8B408B4Q00201PH600401dM7@0Q8B408B4Q06MWI`80[Jf]0P3oool00`3kno/0
moOg0?Ogm`050?Ogm`<0e]KF0P24Q8@307]kN`80g]kN0P3_knl00`3clo<0moOg0?Ogm`030>o_k`80
moOg00<0lo?c0>o_k`3_knl00P2m_Kd00`1_Kfl08B4Q024Q8@08000000D0moOg1@3_knl30=KFeP80
S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3WinL20=KFeP030<c<c032`/80`/;200D0no_k0P20P800102[Zj/0e]KF0=KFeP3Ogml20>OWi`80
lo?c0`3gmoL20>o_k`80moOg00@0mOGe0??cl`3clo<0mOGe0P3gmoL20??cl`030?Gem@3gmoL0moOg
0080lo?c00<0mOGe0?Ogm`3gmoL0203clo<20>o_k`030?7al@3clo<0lo?c0080f][J0`20P8000`22
PX80Q8B408B4Q0020=KFeP80jn_[00<0kno_0??cl`3clo<00P3clo<0103alO40kno_0>o_k`3clo<2
0?Ogm`80lo?c00<0_[jn08R8R028R8P00P16ATH00`2MWId0lo?c0??cl`050??cl`030?Gem@3gmoL0
moOg0080jn_[0`3Fe]H208B4Q0<0P8200`3Jf]X20>o_k`80moOg00<0lo?c0>o_k`3_knl00P3gmoL0
103emOD0lo?c0??cl`3Shn<20=;BdP80R8R800<0M7Ad05mOG`1OGel00P1KFe/00`2UYJD0kno_0>o_
k`030?Ogm`80lo?c00<0lO7a0>o_k`3_knl00P3Ng]h30820P080R8R80`3Fe]H20>OWi`030>g]k@3c
lo<0lo?c0080moOg00<0YjNW05MGE`1GEeL00P1SHf<0101fMWH0R8R808R8R02[Zj/20<k>cP80moOg
00<0mOGe0??cl`3clo<00P3gmoL00`3alO40jn_[0>_[j`030=KFeP80Q8B40`20P8020=[JfP80kno_
00<0lo?c0?Ogm`3gmoL00`3_knl20?Ogm`030??cl`3_knl0kno_0080f][J00<0/K6a08R8R028R8P0
201hN7P20?Ogm`030?Gem@3clo<0lo?c00D0kno_0`3Fe]H208R8R0L0no_k00<0gmoO0<;2`P32`/80
0`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm
_@050?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h20>o_k`<0moOg1`3_knl00`3clo<0moOg
0?Ogm`020>o_k`030??cl`3gmoL0moOg0080kno_00<0lo?c0?Ogm`3gmoL02P3_knl00`3clo<0moOg
0?Ogm`020=KFePH0Q8B40P3Fe]H20=kNgP030>OWi`3_knl0kno_0080moOg00@0lo?c0>o_k`3_knl0
lo?c0P3gmoL20>o_k`030=;BdP2e]KD0]KFe008061PH00<0Q8B40>o_k`3_knl01@3_knl00`3clo<0
moOg0?Ogm`020=kNgP<0e]KF1@24Q8@30=KFeP80kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`04
0??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3:b/X0YJFU0:FUY@0202TY:@0308b<S03_knl0kno_
00<0moOg1@3_knl20=kNgPD0Q8B40`3Fe]H50>o_k`80moOg00<0T92@02TY:@0Y:BT00P2][Jd00`3>
c/h0kno_0>o_k`080>o_k`80moOg00<0jn_[0=kNgP3Ng]h00`3Fe]H508B4Q080e]KF0P3_knl00`3c
lo<0moOg0?Ogm`030>o_k`80moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`080>o_
k`80moOg00<0lo?c0>o_k`3_knl01@3_knl30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0
oooo0P24Q8@0102][Jd0e]KF0=KFeP3Jf]X20=kNgP80kno_0`3gmoL70>o_k`030??cl`3gmoL0moOg
0080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`0:0>o_k`030??cl`3gmoL0moOg
0080e]KF1P24Q8@20=KFeP80g]kN00<0inOW0>o_k`3_knl00P3gmoL0103clo<0kno_0>o_k`3clo<2
0?Ogm`80kno_00<0d];B0;Fe]@2e]KD00P0H61P00`24Q8@0kno_0>o_k`050>o_k`030??cl`3gmoL0
moOg0080g]kN0`3Fe]H508B4Q0<0e]KF0P3_knl20?Ogm`030??cl`3_knl0kno_0080moOg00@0lo?c
0>o_k`3_knl0lo?c0P3gmoL20>o_k`030<[:bP2UYJD0YJFU0080:BTY00<0S8b<0>o_k`3_knl00`3g
moL50>o_k`80g]kN1@24Q8@30=KFePD0kno_0P3gmoL00`2@T900:BTY02TY:@020:f][@030<k>cP3_
knl0kno_00P0kno_0P3gmoL00`3[jn/0g]kN0=kNgP030=KFePD0Q8B40P3Fe]H20>o_k`030??cl`3g
moL0moOg00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00P0kno_0P3g
moL00`3clo<0kno_0>o_k`050>o_k`<0e]KF0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80d];B00<0b<S80;fm_@2m_Kd01@3kno/2
08B4Q0040:f][@3Fe]H0e]KF0=SHf080f][J0P3WinL30??cl`80inOW1@3_knl00`3]kNd0jn_[0>_[
j`020>o_k`030>g]k@3[jn/0jn_[0080kno_00<0lO7a0??cl`3clo<02P3_knl00`3]kNd0jn_[0>_[
j`020=KFeP<0P82000<0PX:208B4Q024Q8@00P3Fe]H20=[JfP030>7Qh@3WinL0inOW0080lo?c00@0
kNg]0>OWi`3WinL0kNg]0P3clo<20>o_k`030=gMg@3:b/X0b/[:0080Q8B400<0][Jf0>OWi`3WinL0
1@3_knl00`3alO40lo?c0??cl`020=kNgP<0e]KF0P20P80308B4Q0<0e]KF0P3Shn<20>_[j`030>g]
k@3_knl0kno_0080jn_[00@0kNg]0>o_k`3_knl0lO7a0P3clo<20>OWi`030=WIf@3:b/X0b/[:0080
Q8B400<0^[Zj0>o_k`3_knl00`3clo<20>o_k`030>_[j`3WinL0inOW0080f][J0`20P80208B4Q0<0
e]KF0P3Shn<00`3UiND0inOW0>OWi`020??cl`030;bl_024Q8@0Q8B40080c/k>00@0gmoO0>o_k`3_
knl0jn_[0P3WinL20>o_k`030>_[j`3WinL0inOW0080lo?c00<0jNWY0=kNgP3Ng]h00`3Fe]H20820
P0<0Q8B40P3Fe]H20>?Sh`030>OWi`3[jn/0jn_[00<0kno_0P3[jn/00`3]kNd0kno_0>o_k`020??c
l`030>g]k@3WinL0inOW0080kno_00@0jn_[0>OWi`3WinL0jn_[0P3_knl20??cl`030?7al@3_knl0
kno_0080kno_0`3WinL30=KFeP80O7al1`3kno/00`3Lg=`0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@00`2]
[Jd0e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3W
inL0g]kN0=kNgP0?0>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/00`20P800Q8B408B4Q0040=KF
eP030=[JfP3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW103_knl00`3WinL0g]kN0=kNgP02
0>o_k`030>OWi`3Ng]h0g]kN00P0kno_0P3Ng]h30=KFeP80Ng]k0`24Q8@50=KFeP80g]kN00<0inOW
0>o_k`3_knl00P3Ng]h00`3WinL0kno_0>o_k`030>o_k`80g]kN00<0inOW0>o_k`3_knl00P3Ng]h0
0`3WinL0kno_0>o_k`050>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/208B4Q0D0e]KF00<0f][J
0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW
0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP030=KFeP80Ng]k0`24Q8@40=KFeP030=[JfP3Ng]h0
g]kN00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`020>o_k`030>OWi`3Ng]h0g]kN0080kno_00@0inOW
0=kNgP3Ng]h0inOW2@3_knl30=kNgP<0e]KF0P1cLg<70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL2
08B4Q0030:f][@3Fe]H0e]KF00<0e]KF0P3Ng]h30>o_k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP02
0>o_k`030>OWi`3Ng]h0g]kN00l0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`030820P024Q8@0
Q8B400@0e]KF00<0f][J0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL40>o_k`030>OWi`3N
g]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0203_knl20=kNgP<0e]KF0P1kNg/308B4Q0D0e]KF0P3N
g]h00`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00<0kno_0P3Ng]h00`3WinL0kno_0>o_
k`020=kNgP030>OWi`3_knl0kno_00D0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`80Q8B41@3F
e]H00`3Jf]X0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0kno_00<0inOW0=kNgP3Ng]h00P3_
knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00<0e]KF0P1kNg/308B4Q0@0e]KF00<0
f][J0=kNgP3Ng]h00`3_knl20=kNgP030>OWi`3_knl0kno_0080kno_00<0inOW0=kNgP3Ng]h00P3_
knl0103WinL0g]kN0=kNgP3WinL90>o_k`<0g]kN0`3Fe]H207=cL`L0moOg00<0f][J0;fm_@2m_Kd0
0`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm
_@020?Ogm`030??cl`3_knl0kno_0080Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h20>o_k`030>OW
i`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0kno_0P3Ng]h00`3WinL0kno_
0>o_k`050=kNgP80c/k>1P24Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20>o_k`030>OW
i`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl00P3Ng]h30<k>cPD0Q8B40`3>c/h90=kNgP040>OW
i`3_knl0kno_0>OWi`@0g]kN00<0jn_[0?Ogm`3gmoL0203Ng]h20>o_k`030>OWi`3Ng]h0g]kN0080
c/k>1@24Q8@30<k>cPX0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3N
g]h01@3Ng]h30<k>cPD0Q8B40P3>c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3gmoL00`3[jn/0
g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q080kno_00<0lo?c0?Ogm`3g
moL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102YZJT0c/k>
0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0
g]kN0`3_knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h608B4Q080c/k>2P3Ng]h00`3WinL0
kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP<0
c/k>1@24Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0inOW103Ng]h00`3[jn/0moOg0?Ogm`080=kN
gP80kno_00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>2P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN
00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24Q8@20<k>cPX0g]kN00<0inOW0>o_
k`3_knl01@3Ng]h20?Ogm`030>_[j`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h30<k>
cP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3c
lo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/800P3gmoL00`3emOD0
lo?c0??cl`0208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Jf]X50=kNgP80inOW00@0hn?S0=kN
gP3Ng]h0g=cL0P3Jf]X20>?Sh`030>7Qh@3Ng]h0g]kN0080f][J00<0g=cL0=kNgP3Ng]h00`3WinL2
0=kNgP030>?Sh`3WinL0inOW00D0f][J0P3Bd]8608B4Q080c/k>0P3Ng]h00`3Lg=`0f][J0=[JfP05
0=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[JfP3Jf]X00P3Shn<00`3QhN40g]kN0=kNgP03
0=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h30<k>cPD0Q8B40`3>c/h20=kNgP80f][J00<0g=cL
0=kNgP3Ng]h00P3Ng]h0103Shn<0inOW0>OWi`3Shn<20=kNgP80f][J00<0hN7Q0>OWi`3WinL00P3N
g]h00`3Lg=`0f][J0=[JfP030=kNgP80inOW00<0hN7Q0=[JfP3Jf]X00P3>c/h508B4Q0<0c/k>0P3N
g]h00`3Lg=`0f][J0=[JfP050=kNgP80inOW00@0hn?S0=kNgP3Ng]h0g=cL0P3Jf]X20>?Sh`030>7Q
h@3Ng]h0g]kN0080f][J00<0g=cL0=kNgP3Ng]h00`3>c/h508B4Q080c/k>0P3Ng]h00`3Lg=`0f][J
0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[JfP3Jf]X00P3WinL0103Shn<0g]kN
0=kNgP3Lg=`20=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h30=[JfP<0c/k>0P24Q8@20??cl`03
0?Gem@3gmoL0moOg0080lo?c00<0fm_K0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0
e]KF0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP03
0=[JfP3Ng]h0g]kN00P0g]kN1`3Fe]H608B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP03
0=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H70=kNgP<0c/k>1@24Q8@30<k>cP80
g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3Ng]h00`3Jf]X0e]KF0=KFeP050=kNgP03
0=[JfP3Fe]H0e]KF0080c/k>1@24Q8@30<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0
e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h00`3>c/h508B4Q080
c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00@0f][J0=kNgP3N
g]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80
Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3J
f]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1`3Fe]H608B4Q080c/k>0P3Ng]h00`3J
f]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H70=kN
gP<0c/k>1@24Q8@30<k>cP80g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3Ng]h00`3J
f]X0e]KF0=KFeP050=kNgP030=[JfP3Fe]H0e]KF0080c/k>1@24Q8@30<k>cP80g]kN00<0f][J0=KF
eP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kN
gP3Ng]h00`3>c/h508B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF
0080e]KF00@0f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4Q0L0moOg00<0gmoO
0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36
a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3Ng]h0jn_[7P3gmoL20?ooo`030?_kn`3gmoL0
moOg0080oooo00<0moOg0>o_k`3_knl00P3Ng]h308B4Q0030820P01kNg/0Ng]k0080g]kN7`3gmoL2
0>o_k`<0g]kN0P24Q8@307]kN`<0g]kN7P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Q8B40P1kNg/3
0=kNgQT0moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]hO0?Ogm`80oooo0`3gmoL3
0=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3[jn/N
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Q8B400<0P820
07]kN`1kNg/00P3Ng]hO0?Ogm`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]hN0?Ogm`030??cl`3_knl0
kno_0080g]kN0`24Q8@207]kN`<0g]kN6@3gmoL00`3clo<0kno_0>o_k`030=kNgP80Q8B40`1kNg/2
0=kNgQl0moOg0P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>00<0b<S80<;2`P32`/801@3kno/20820
P0040;Bd]03WinL0inOW0?7alAh0no_k0P3oool00`3moOd0no_k0?_kn`020?ooo`030?_kn`3gmoL0
moOg0080kno_0`24Q8@00`22PX80P8200820P0020>OWial0no_k0P3gmoL30>o_k`80Q8B40`20P803
0>OWiah0no_k00<0nOWi0?Ogm`3gmoL00P3_knl308B4Q080P8200`3WinLI0?_kn`030?Win@3gmoL0
moOg00<0kno_0P24Q8@30820P080inOW7`3kno/20?ooo`<0no_k0`3_knl208B4Q0L0no_k00<0g=cL
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:
b/X0a/K60<K6aP050?Ogm`80Q8B400@0^[Zj0>o_k`3_knl0moOg:P3oool608B4Q080kno_903oool5
08B4Q0<0kno_8`3oool508B4Q0<0kno_7`3oool508B4Q080kno_9`3oool208B4Q0L0moOg00<0f][J
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:
b/X0a/K60<K6aP050?Ogm`80Q8B400@0^[Zj0>o_k`3_knl0moOg:P3oool608B4Q080kno_903oool5
08B4Q0<0kno_8`3oool508B4Q0<0kno_7`3oool508B4Q080kno_9`3oool208B4Q0L0moOg00<0f][J
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:
b/X0_Kfm0;fm_@050>o_k`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/508B4
Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]k
N`1kNg/0P8204@24Q8@00`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0
Q8B40100Q8B40P1kNg/00`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@0
0`20P800Ng]k07]kN`0L08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0
Q8B400l0Q8B400<0P82007]kN`1kNg/02P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h2
0>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_
k`D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4
Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8204@24Q8@0
0`20P800Ng]k07]kN`0=08B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40100Q8B40P1kNg/0
0`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0L
08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400l0Q8B400<0P820
07]kN`1kNg/02P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`D0Q8B400<0P82007]k
N`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]k
N`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0P8204@24Q8@00`20P800Ng]k07]kN`0=
08B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40100Q8B40P1kNg/00`20P800Q8B408B4Q00:
08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0L08B4Q080Ng]k00<0P820
08B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400l0Q8B400<0P82007]kN`1kNg/02P24Q8@5
0>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080Ng]k00<0P82008B4
Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k00<0P82008B4
Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400<0P82007]kN`1kNg/01@24Q8@00`1l
O7`0Lg=c07=cL`0408B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01`24Q8@00`28
R8P0S8b<08b<S00307]kN`D0Q8B40P1kNg/508B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B4
0080Q8B400@0P82007]kN`1kNg/0P8201024Q8@00`28R8P0S8b<08b<S00208B4Q0030820P01kNg/0
Ng]k00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`D0Q8B400<0P82007]kN`1kNg/01@24Q8@2
07]kN`040820P024Q8@0Q8B408R8R080S8b<1@24Q8@507]kN`D0Q8B40`1kNg/408B4Q0030820P01k
Ng/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01@24Q8@208b<S00408R8R024Q8@0Q8B40820P080Ng]k
1@24Q8@207]kN`<0Lg=c1@24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Og
m`0207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@02024
Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0030820P01k
Ng/0Ng]k00D0Q8B400<0O7al07=cL`1cLg<01024Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01k
Ng/0Ng]k00L0Q8B400<0R8R808b<S02<S8`00`1kNg/508B4Q080Ng]k1@24Q8@307]kN`D0Q8B40P1k
Ng/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k0820P0@0Q8B400<0R8R808b<S02<S8`0
0P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/508B4Q0030820
P01kNg/0Ng]k00D0Q8B40P1kNg/01020P800Q8B408B4Q028R8P208b<S0D0Q8B41@1kNg/508B4Q0<0
Ng]k1024Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P2<S8`01028R8P0
Q8B408B4Q020P80207]kN`D0Q8B40P1kNg/307=cL`D0Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0_Kfm0080
oooo00<0oOgm0?_kn`3kno/00P20P800102IVIT0/K6a0;6a/@2h^;P20;jn_P80_Kfm0`2n_[h20<;2
`P80_Kfm00@0`<300<;2`P32`/80`<30102n_[h00`30`<00`/;20<;2`P020;Vi^@030;bl_02n_[h0
_[jn00<0`/;20P2i^KT00`2l_;`0_[jn0;jn_P020<;2`P030;jn_P2i^KT0^KVi0080/K6a0`28R8P0
0`22PX80O7al07alO0020;6a/@<0_[jn0P2m_Kd20;jn_P040<30`032`/80`/;20<30`080_Kfm1`2n
_[h00`32`/80a/K60<K6aP030;Vi^@80_[jn00<0`<300<;2`P32`/800P2i^KT30;6a/@80Q8B40`20
P8030;6a/@80`/;20P2i^KT00`2l_;`0_[jn0;jn_P020<;2`P030<30`02m_Kd0_Kfm00D0_[jn00<0
`<300<;2`P32`/800P32`/800`2n_[h0^KVi0;Vi^@030;jn_P80`/;200<0`<300;fm_@2m_Kd00P2a
/K4308B4Q080P8200`2a/K420;jn_P030;bl_02i^KT0^KVi0080_[jn00<0`<300<;2`P32`/800P2m
_Kd30;jn_P030<30`032`/80`/;20080_[jn00<0`<300<;2`P32`/801@2i^KT30;6a/@80Q8B40`20
P8020;6a/@80`/;200<0_[jn0;Vi^@2i^KT00`2n_[h20<;2`P030<30`02m_Kd0_Kfm00D0_[jn1@32
`/800`2n_[h0^KVi0;Vi^@020;jn_P030<30`032`/80`/;20080_Kfm0`2e]KD30;6a/@80Q8B41`3k
no/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl2
0=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`80oooo0`3g
moL70?ooo`030?_kn`3gmoL0moOg0080moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3o
ool00`3kno/0moOg0?Ogm`020=kNgP<0S8b<00<0R8R808B4Q024Q8@00P3Ng]h20?Ogm`030?_kn`3o
ool0oooo0080moOg00<0no_k0?ooo`3oool00`3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0
no_k0?ooo`3oool00P3gmoL30=kNgPD0Q8B40`3Ng]h20?ooo`D0moOg1@3oool00`3kno/0moOg0?Og
m`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL50?ooo`80g]kN1@24Q8@30=kNgPL0moOg00<0
no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3N
g]h508B4Q080g]kN0P3oool00`3kno/0moOg0?Ogm`030?Ogm`D0oooo1`3gmoL0103kno/0oooo0?oo
o`3kno/40?Ogm`030?_kn`3oool0oooo0080oooo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m
_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`80oooo0`3gmoL70?ooo`030?_k
n`3gmoL0moOg0080moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg
0?Ogm`020=kNgP<0S8b<00<0R8R808B4Q024Q8@00P3Ng]h20?Ogm`030?_kn`3oool0oooo0080moOg
00<0no_k0?ooo`3oool00`3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool0
0P3gmoL30=kNgPD0Q8B40`3Ng]h20?ooo`D0moOg1@3oool00`3kno/0moOg0?Ogm`050?Ogm`80oooo
00<0no_k0?Ogm`3gmoL00`3gmoL50?ooo`80g]kN1@24Q8@30=kNgPL0moOg00<0no_k0?ooo`3oool0
0P3oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h508B4Q080g]kN
0P3oool00`3kno/0moOg0?Ogm`030?Ogm`D0oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`03
0?_kn`3oool0oooo0080oooo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg
0P24Q8@0102a/K40g]kN0=kNgP3_knlU0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgQl0
oooo0P3gmoL30=kNgPD0Q8B40`3Ng]hN0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgQT0
oooo00<0no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN8@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`03
0=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>
00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_kbD0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN7`3oool20?Ogm`<0g]kN1@24Q8@30=kNgQh0oooo00<0no_k0?Ogm`3g
moL00P3Ng]h508B4Q0<0g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0
moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
kno_:03oool20>o_k`H0Q8B40P3Ng]hQ0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3_knl508B4Q0<0
g]kN703oool30>o_k`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0
c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H0
1@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>o_kbP0oooo0P3_knl608B4Q080g]kN8@3oool30>o_k`D0
Q8B40`3Ng]hQ0?ooo`80kno_1@24Q8@30=kNgQ`0oooo0`3_knl508B4Q080g]kN903oool30>o_k`80
Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3_knlX0?ooo`80
kno_1P24Q8@20=kNgR40oooo0`3_knl508B4Q0<0g]kN8@3oool20>o_k`D0Q8B40`3Ng]hL0?ooo`<0
kno_1@24Q8@20=kNgR@0oooo0`3_knl208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<
00@0]KFe0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80
moOg00<0no_k0?ooo`3oool0703oool30>o_k`D0Q8B40`3Ng]h20?Ogmal0oooo0P3Ng]h508B4Q0<0
g]kN0P3gmoL00`3kno/0oooo0?ooo`0G0?ooo`<0kno_1@24Q8@20=kNgP80moOg00<0no_k0?ooo`3o
ool0703oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;Fe
]@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20?Ogm`03
0?_kn`3oool0oooo01`0oooo0`3_knl508B4Q0<0g]kN0P3gmoLO0?ooo`80g]kN1@24Q8@30=kNgP80
moOg00<0no_k0?ooo`3oool05`3oool30>o_k`D0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0
oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN
0=kNgP3[jn/40?Ogmb40oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_knl00`3gmoL0
oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0e]KF0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080
g]kN0`24Q8@207]kN`<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0
g]kN1@24Q8@20=KFeP80moOg00<0no_k0?ooo`3oool07`3oool30>o_k`80Ng]k1`3oool00`3Shn<0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogmb40oooo00<0no_k0?Ogm`3g
moL00P3Ng]h608B4Q080g]kN0P3_knl00`3gmoL0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0
e]KF0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080g]kN0`24Q8@207]kN`<0g]kN0P3gmoL00`3kno/0
oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=KFeP80moOg00<0no_k0?ooo`3o
ool07`3oool30>o_k`80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN
0=kNgP3[jn/40?Ogmb40oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_knl00`3gmoL0
oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0e]KF0P3gmoLL0?ooo`030?_kn`3gmoL0moOg0080
g]kN0`24Q8@207]kN`<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0
g]kN1@24Q8@20=KFeP80moOg00<0no_k0?ooo`3oool07`3oool30>o_k`80Ng]k1`3oool00`3Shn<0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL20?Ogm`T0oooo00@0ZJVY059BDP1B
DU80XJ6Q0P3_knl20?ooo`030>o_k`3Ng]h0g]kN0080DU9B00<0ZJVY0?ooo`3oool00`3oool20?Og
m`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3gmoL00`3k
no/0oooo0?ooo`020?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P3oool00`2DU9@0:BTY02TY:@02
0?ooo`030?_kn`3gmoL0moOg00D0oooo00<0no_k0?Ogm`3gmoL00P3gmoL30=kNgPD0Q8B40`3Ng]h4
0?Ogm`030?_kn`3oool0oooo0080moOg00<0lo?c0>o_k`3_knl00`3_knl20?ooo`030>o_k`3Ng]h0
g]kN0080kno_00<0moOg0?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@3
0=kNgP80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`050?ooo`030>o_k`3Ng]h0
g]kN008020P800<0Kfm_0=KFeP3Fe]H01@3gmoL30=kNgPD0Q8B40P3Ng]h50?Ogm`<0:BTY0P3gmoL0
0`3kno/0oooo0?ooo`050?ooo`80FUYJ00@0T92@0<K6aP36a/H0hn?S0P3oool20?Ogm`030?_kn`3o
ool0oooo0080oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0
102][Jd0e]KF0=KFeP3WinL20?Ogm`T0oooo00@0ZJVY059BDP1BDU80XJ6Q0P3_knl20?ooo`030>o_
k`3Ng]h0g]kN0080DU9B00<0ZJVY0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo0080oooo
00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`040?_k
n`3oool0oooo0?_kn`80moOg0P3oool00`2DU9@0:BTY02TY:@020?ooo`030?_kn`3gmoL0moOg00D0
oooo00<0no_k0?Ogm`3gmoL00P3gmoL30=kNgPD0Q8B40`3Ng]h40?Ogm`030?_kn`3oool0oooo0080
moOg00<0lo?c0>o_k`3_knl00`3_knl20?ooo`030>o_k`3Ng]h0g]kN0080kno_00<0moOg0?ooo`3o
ool00`3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3o
ool00P3gmoL00`3kno/0oooo0?ooo`050?ooo`030>o_k`3Ng]h0g]kN008020P800<0Kfm_0=KFeP3F
e]H01@3gmoL30=kNgPD0Q8B40P3Ng]h50?Ogm`<0:BTY0P3gmoL00`3kno/0oooo0?ooo`050?ooo`80
FUYJ00@0T92@0<K6aP36a/H0hn?S0P3oool20?Ogm`030?_kn`3oool0oooo0080oooo0`3_knl30=kN
gP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=;BdP030<[:bP32`/80`/;200D0lo?c0P24Q8@0102_[jl0f][J0=[JfP3WinL20??c
l`D0no_k0P3oool20?_kn`030<k>cP2QXJ40XJ6Q00<0XJ6Q0P3WinL00`30`<00V9RH09RHV00209RH
V0030<c<c03oool0oooo00D0no_k00<0oOgm0?ooo`3oool00P3oool00`3inOT0lo?c0??cl`020=kN
gPH0Q8B40P3Ng]h20??cl`030?Ogm`3kno/0no_k0080no_k00@0oOgm0?ooo`3oool0oOgm103kno/0
0`38b<P0U9BD09BDU0050?_kn`D0oooo00<0no_k0?Ogm`3gmoL00P3clo<30=kNgPD0Q8B40`3Ng]h2
0?Ogm`80no_k00<0oOgm0?ooo`3oool00P3kno/0103alO40inOW0>OWi`34a<@20:6QX@80inOW00<0
`<3009RHV02HV9P00P3_knl00`3gmoL0oooo0?ooo`030?Ogm`80no_k00<0nOWi0?Ogm`3gmoL00P3N
g]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`050?_kn`80oooo00@0oOgm0?_kn`3kno/0mOGe
0P3_knl204Y:BP03065QH@1gMgL0MgMg0080jn_[00<0kno_0??cl`3clo<00`3Ng]h508B4Q080g]kN
0P3gmoL00`3inOT0no_k0?_kn`0309BDU0D0no_k0P3oool00`3moOd0no_k0?_kn`020:FUY@0409nO
W`2IVIT0VIVI0<S8b0@0moOg00<0nOWi0?_kn`3kno/00P3oool30>o_k`<0g]kN0P24Q8@50??cl`80
moOg00<0f][J0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl50?Ogm`80
oooo0P3gmoL0103clo<0kno_0>o_k`2QXJ42059BDP80c/k>00<0T92@059BDP1BDU800P3Ng]h00`3_
knl0oooo0?ooo`030?Ogm`L0oooo00<0moOg0>o_k`3_knl00P3Ng]h608B4Q080g]kN0P3_knl00`3c
lo<0moOg0?Ogm`080?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`050?oo
o`030?_kn`3gmoL0moOg0080kno_0`3Ng]h508B4Q0<0g]kN0P3gmoL70?ooo`040>o_k`3Ng]h0g]kN
09RHV080DU9B0P3>c/h00`2@T900DU9B059BDP020>o_k`030?Ogm`3oool0oooo00P0moOg0P3Ng]h5
08B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080oooo00@0no_k
0?Ogm`3gmoL0no_k0P3oool208b<S003059BDP0H61P061PH0080g]kN00<0inOW0>o_k`3_knl00`3N
g]h508B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg0080oooo00<0
no_k0?Ogm`3gmoL00P3_knl0102][Jd0Jf][06][J`2][Jd20>o_k`D0moOg0P3oool30>o_k`<0g]kN
0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW
0P3_knl50?Ogm`80oooo0P3gmoL0103clo<0kno_0>o_k`2QXJ42059BDP80c/k>00<0T92@059BDP1B
DU800P3Ng]h00`3_knl0oooo0?ooo`030?Ogm`L0oooo00<0moOg0>o_k`3_knl00P3Ng]h608B4Q080
g]kN0P3_knl00`3clo<0moOg0?Ogm`080?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0
oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg0080kno_0`3Ng]h508B4Q0<0g]kN0P3gmoL70?ooo`04
0>o_k`3Ng]h0g]kN09RHV080DU9B0P3>c/h00`2@T900DU9B059BDP020>o_k`030?Ogm`3oool0oooo
00P0moOg0P3Ng]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg
0080oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool208b<S003059BDP0H61P061PH0080g]kN00<0inOW
0>o_k`3_knl00`3Ng]h508B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`050?ooo`030?_kn`3gmoL0
moOg0080oooo00<0no_k0?Ogm`3gmoL00P3_knl0102][Jd0Jf][06][J`2][Jd20>o_k`D0moOg0P3o
ool30>o_k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0/K6a
0=kNgP3Ng]h0jn_[103gmoL30?ooo`80moOg0P3oool0103kno/0moOg0?Ogm`3Shn<20<k>cP800000
00<0Jf][0=KFeP3Fe]H00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool0
1@3gmoL20=kNgPH0Q8B40P3Fe]H20?ooo`030?_kn`3gmoL0moOg00D0moOg00<0O7al000000000000
2P0000030?ooo`L0moOg0`3Fe]H208B4Q0<0Ng]k0`3Ng]h20>o_k`X0moOg00<0inOW0=KFeP3Fe]H0
0P0000000`1WIfL0c/k>0<k>cP020?ooo`030?_kn`3gmoL0moOg00D0oooo00<0moOg0>o_k`3_knl0
0P3Ng]h307]kN`80S8b<0`3Ng]h20>o_k`0307QhN00000000000018000000P0Y:BT00`2@T900moOg
0?Ogm`030=KFeP80Q8B40`1kNg/20=kNgP80kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`1lO7`00000
0000000:0000000301DE5@0Y:BT0:BTY0080moOg00<0no_k0?ooo`3oool01@3gmoL30=KFeP80S8b<
1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`<0oooo
0P3gmoL20?ooo`040?_kn`3gmoL0moOg0>?Sh`80c/k>0P0000000`1[Jf/0e]KF0=KFeP020?Ogm`03
0?_kn`3oool0oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`80g]kN1P24Q8@20=KFeP80
oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`1lO7`000000000000:000000<0oooo1`3gmoL30=KFeP80
Q8B40`1kNg/30=kNgP80kno_2P3gmoL00`3WinL0e]KF0=KFeP020000000306MWI`3>c/h0c/k>0080
oooo00<0no_k0?Ogm`3gmoL01@3oool00`3gmoL0kno_0>o_k`020=kNgP<0Ng]k0P2<S8`30=kNgP80
kno_00<0N7Qh0000000000004P00000202TY:@03092@T03gmoL0moOg00<0e]KF0P24Q8@307]kN`80
g]kN0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`0307alO0000000000000X0000000<05ADE02TY:@0Y
:BT00P3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0e]KF0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80e]KF00<0c<c<0<;2`P32`/80
1@3kno/208B4Q0040;6a/@3Ng]h0g]kN0>WYj@80lo?c0P3gmoL30?_kn`80moOg0P3kno/0103clo<0
jn_[0>_[j`2n_[h2092@T080IfMW00<0O7al092@T02@T9000P3[jn/00`3emOD0oooo0?ooo`030?_k
n`80moOg00<0nOWi0?_kn`3kno/01@3gmoL20=[JfPH0Q8B40P3Fe]H:0?Ogm`030;Zj^P1lO7`0O7al
0080O7al00<0OWin0820P020P8001@1lO7`30?_kn`80moOg00<0nOWi0?_kn`3kno/00P3clo<30=KF
eP80Q8B40`20P8030=[JfP80kno_1`3gmoL0103alO40jn_[0>_[j`2n_[h2092@T080IfMW00<0NWYj
08b<S02<S8`00P3_knl00`3clo<0moOg0?Ogm`030?ooo`80no_k00<0mOGe0>o_k`3_knl00P3Ng]h3
0820P080R8R80`3Ng]h20??cl`030;Rh^01lO7`0O7al00D0O7al0P20P8000`1nOWh0O7al07alO003
07alO080ATI600<08b<S0000000000000P1cLg<00`2c/k<0lo?c0??cl`030=KFeP80Q8B40`20P802
0=[JfP80kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`2j^[X0O7al07alO0020820P00307inOP1lO7`0
O7al0080Kfm_00@0CTi>02d];@0];Bd0D51@0P1cLg<50?_kn`D0moOg0`3Fe]H208R8R0L0no_k00<0
gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H0
0`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl90?Ogm`040>_[j`3N
g]h0g]kN09RHV080DU9B0P3>c/h00`2<S8`0BTY:04Y:BP020=kNgP030>o_k`3oool0oooo00d0moOg
0P3Fe]H608B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`0:0?Ogm`030?_kn`3oool0oooo00X0moOg
00<0no_k0?ooo`3oool00P3_knl30=KFePD0Q8B40`3Fe]H20>o_k`L0moOg00@0jn_[0=kNgP3Ng]h0
U9BD0P1:BTX20<k>cP0308b<S01:BTX0BTY:0080g]kN00<0jn_[0?Ogm`3gmoL00`3oool20?Ogm`03
0??cl`3_knl0kno_0080g]kN1@24Q8@30=kNgPX0moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80
S8b<00<0ATI60000000000000P2m_Kd00`3Fe]H0kno_0>o_k`030=KFePD0Q8B40P3Fe]H20>o_k`03
0??cl`3gmoL0moOg00P0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgP0409bLW01JFUX0FUYJ08b<
S080_Kfm0P3oool00`3kno/0moOg0?Ogm`050?Ogm`<0e]KF0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m
_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_2@3gmoL0103[jn/0g]kN0=kNgP2HV9P2
059BDP80c/k>00<0S8b<04Y:BP1:BTX00P3Ng]h00`3_knl0oooo0?ooo`0=0?Ogm`80e]KF1P24Q8@2
0=KFeP80kno_00<0lo?c0?Ogm`3gmoL02P3gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030?_kn`3oool0
oooo0080kno_0`3Fe]H508B4Q0<0e]KF0P3_knl70?Ogm`040>_[j`3Ng]h0g]kN09BDU080BTY:0P3>
c/h00`2<S8`0BTY:04Y:BP020=kNgP030>_[j`3gmoL0moOg00<0oooo0P3gmoL00`3clo<0kno_0>o_
k`020=kNgPD0Q8B40`3Ng]h:0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL208b<S00304I6AP00
000000000080_Kfm00<0e]KF0>o_k`3_knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Og
m`080?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3Ng]h0102LW9`0FUYJ05YJFP2<S8`20;fm_@80oooo
00<0no_k0?Ogm`3gmoL01@3gmoL30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24
Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80moOg0`3_knl20?Ogm`80kno_00@0WIfM04Y:BP1:BTX0
U9BD0P3Ng]h20?Ogm`030>_[j`3Ng]h0g]kN0080BTY:00<0XJ6Q0?Ogm`3gmoL02P3gmoL00`3clo<0
kno_0>o_k`020=KFePH0Q8B40P3Ng]h20=KFeP030>OWi`3gmoL0moOg00D0kno_00<0lo?c0?Ogm`3g
moL00P3gmoL00`2@T900:BTY02TY:@0=0?Ogm`80kno_0`3Fe]H508B4Q0<0e]KF0P3_knl20?Ogm`03
0??cl`3_knl0kno_0080moOg00<0jn_[0=kNgP3Ng]h00`3Ng]h20?Ogm`030>_[j`3Ng]h0g]kN0080
g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`020=KFeP<0Q8B40P1cLg<30=kNgP80
kno_00<0lo?c0?Ogm`3gmoL02P3gmoL00`3Shn<0c/k>0<k>cP0200P8200306=SH`2m_Kd0_Kfm0080
moOg00<0lo?c0>o_k`3_knl00`3Fe]H508B4Q080e]KF0P3_knl00`3clo<0moOg0?Ogm`0302TY:@X0
moOg0P1JFUX0102<S8`0_Kfm0;fm_@3Jf]X70?Ogm`D0kno_0`3Fe]H207=cL`L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0
_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?Ogm`<0kno_0P3gmoL20>o_
k`0409fMW@1:BTX0BTY:09BDU080g]kN0P3gmoL00`3[jn/0g]kN0=kNgP0204Y:BP030:6QX@3gmoL0
moOg00X0moOg00<0lo?c0>o_k`3_knl00P3Fe]H608B4Q080g]kN0P3Fe]H00`3WinL0moOg0?Ogm`05
0>o_k`030??cl`3gmoL0moOg0080moOg00<0T92@02TY:@0Y:BT03@3gmoL20>o_k`<0e]KF1@24Q8@3
0=KFeP80kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030>_[j`3Ng]h0g]kN00<0g]kN0P3gmoL0
0`3[jn/0g]kN0=kNgP020=kNgP030>_[j`3gmoL0moOg00D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H3
08B4Q080Lg=c0`3Ng]h20>o_k`030??cl`3gmoL0moOg00X0moOg00<0hn?S0<k>cP3>c/h00P0820P0
0`1SHf<0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_00<0e]KF1@24Q8@20=KFeP80kno_00<0lo?c
0?Ogm`3gmoL00`0Y:BT:0?Ogm`80FUYJ00@0S8b<0;fm_@2m_Kd0f][J1`3gmoL50>o_k`<0e]KF0P1c
Lg<70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80d];B00<0b<S80;fm_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040:^[Z`3Bd]80
d];B0=gMg@80inOW0P3clo<30>o_k`80moOg0P3clo<01038b<P0WIfM09fMW@34a<@20>_[j`80moOg
00<0kno_0>OWi`3WinL00P2QXJ400`3:b/X0lo?c0??cl`030??cl`D0moOg0P3clo<00`3]kNd0inOW
0>OWi`020=KFePH0Q8B40P3Jf]X20>?Sh`030>_[j`3clo<0lo?c00P0lo?c0P3gmoL00`32`/80S8b<
08b<S0020??cl`030?Gem@3gmoL0moOg00<0moOg1@3clo<20>OWi`<0e]KF1@24Q8@30=KFeP80inOW
0P3gmoL00`3emOD0lo?c0??cl`020??cl`040>o_k`3[jn/0jn_[0>WYj@80inOW0P3clo<00`3_knl0
jn_[0>_[j`020>_[j`030>o_k`3clo<0lo?c00D0lo?c00<0lO7a0>o_k`3_knl00P3Fe]H308B4Q080
O7al0`3Fe]H20??cl`030?Gem@3gmoL0moOg0080lo?c00<0mOGe0?Ogm`3gmoL01@3clo<00`3[jn/0
hn?S0>?Sh`020820P0030:^[Z`3Fe]H0e]KF0080lo?c00<0kNg]0>OWi`3WinL00`3Fe]H508B4Q080
e]KF0P3WinL00`3_knl0moOg0?Ogm`03092@T080lo?c00<0mOGe0?Ogm`3gmoL01@3clo<20:VYZ@04
0<;2`P3Jf]X0f][J0>OWi`L0lo?c1@3_knl30=[JfP80O7al0P3clo<00`3emOD0moOg0?Ogm`020??c
l`030=SHf02m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040:VYZ@3>c/h0c/k>0=KF
eP80g]kN1@3_knl40?Ogm`040??cl`3_knl0kno_0??cl`@0moOg00<0lo?c0>o_k`3_knl00P3gmoL0
0`3clo<0kno_0>o_k`030>o_k`D0moOg0P3_knl00`3WinL0g]kN0=kNgP020=KFePH0Q8B40P3Fe]H5
0>o_k`D0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`020>o_k`030??cl`3gmoL0
moOg00<0moOg1@3_knl20=kNgP<0e]KF1@24Q8@30=KFeP80g]kN1@3gmoL20>o_k`040??cl`3gmoL0
moOg0??cl`@0kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80e]KF1@24
Q8@30<k>cPD0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg0080moOg00<0
lo?c0>o_k`3_knl00P3_knl00`3WinL0g]kN0=kNgP030=KFePD0Q8B40P3Fe]H20=kNgP030>_[j`3g
moL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`D0moOg00<0lo?c0>o_k`3_knl02P3_
knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL0
0`3clo<0kno_0>o_k`0208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN1@3_knl40?Ogm`040??cl`3_
knl0kno_0??cl`@0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`030>o_k`D0moOg
0P3_knl00`3WinL0g]kN0=kNgP020=KFePH0Q8B40P3Fe]H50>o_k`D0moOg00<0lo?c0>o_k`3_knl0
0P3gmoL00`3clo<0kno_0>o_k`020>o_k`030??cl`3gmoL0moOg00<0moOg1@3_knl20=kNgP<0e]KF
1@24Q8@30=KFeP80g]kN1@3gmoL20>o_k`040??cl`3gmoL0moOg0??cl`@0kno_00<0lo?c0?Ogm`3g
moL00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80e]KF1@24Q8@30<k>cPD0moOg0P3_knl00`3clo<0
moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl00P3_knl00`3WinL0
g]kN0=kNgP030=KFePD0Q8B40P3Fe]H20=kNgP030>_[j`3gmoL0moOg00<0moOg0P3_knl00`3clo<0
moOg0?Ogm`050>o_k`D0moOg00<0lo?c0>o_k`3_knl02P3_knl30=kNgP80Q8B40P3_knl00`3clo<0
moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/800P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040:^[
Z`3Bd]80d];B0=SHf080g]kN0P3WinL30>o_k`80jn_[0P3clo<0103alO40kno_0>o_k`3]kNd20>_[
j`80lo?c00<0kNg]0>OWi`3WinL00P3clo<00`3alO40kno_0>o_k`030>o_k`D0lo?c0P3_knl00`3W
inL0g]kN0=kNgP020=[JfP<0P82000<0PX:208B4Q024Q8@00P3Fe]H20>?Sh`030>GUi@3WinL0inOW
0080lo?c00@0kno_0>_[j`3[jn/0kNg]0P3_knl20??cl`030>g]k@3WinL0inOW0080kno_00<0kNg]
0>_[j`3[jn/00`3clo<50>o_k`80g]kN0`3Fe]H20820P0<0Q8B40`3Fe]H20=[JfP80jn_[00<0kno_
0??cl`3clo<00P3WinL0103]kNd0lo?c0??cl`3alO420>o_k`80inOW00<0kNg]0??cl`3clo<00P3[
jn/00`3]kNd0kno_0>o_k`030>o_k`80lo?c00<0kNg]0>OWi`3WinL00P3Fe]H30820P080Q8B40`3B
d]820>OWi`030>WYj@3[jn/0jn_[0080kno_00<0kNg]0>_[j`3[jn/01@3_knl00`3]kNd0jn_[0>_[
j`020??cl`030>g]k@3WinL0inOW0080kno_00<0inOW0=kNgP3Ng]h00`3Fe]H20820P0<0Q8B40P3F
e]H20=[JfP030>?Sh`3[jn/0jn_[00<0lo?c0P3WinL00`3]kNd0lo?c0??cl`020>o_k`030>_[j`3W
inL0inOW0080lo?c00@0kno_0>_[j`3[jn/0kNg]103_knl00`3alO40lo?c0??cl`020>o_k`<0inOW
0`3Jf]X20820P080lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW
00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24
Q8@0102][Jd0e]KF0=KFeP3Jf]X40=kNgP<0kno_0P3Ng]h50>o_k`030>OWi`3Ng]h0g]kN0080kno_
00<0inOW0=kNgP3Ng]h03`3_knl00`3WinL0g]kN0=kNgP020=kNgP<0Ng]k00<0P82008B4Q024Q8@0
103Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`@0kno_00<0inOW0=kNgP3N
g]h00P3_knl00`3WinL0g]kN0=kNgP080>o_k`80g]kN0`3Fe]H207]kN`<0Q8B41@3Fe]H20=kNgP03
0>OWi`3_knl0kno_0080g]kN00<0inOW0>o_k`3_knl00`3_knl20=kNgP030>OWi`3_knl0kno_0080
g]kN00<0inOW0>o_k`3_knl00`3_knl20?Ogm`030>_[j`3Ng]h0g]kN0080e]KF0`1kNg/208B4Q0D0
e]KF00<0f][J0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>o_k`030>OWi`3Ng]h0g]kN0080
kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP030=KFeP80Ng]k0`24Q8@40=KFeP03
0=[JfP3Ng]h0g]kN00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`020>o_k`030>OWi`3Ng]h0g]kN0080
kno_00@0inOW0=kNgP3Ng]h0inOW103_knl00`3clo<0moOg0?Ogm`020>o_k`<0g]kN0`3Fe]H207]k
N`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J103Ng]h30>o_
k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00l0kno_00<0inOW0=kN
gP3Ng]h00P3Ng]h307]kN`030820P024Q8@0Q8B400@0e]KF00<0f][J0=kNgP3Ng]h00P3_knl0103W
inL0g]kN0=kNgP3WinL40>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0203_knl2
0=kNgP<0e]KF0P1kNg/308B4Q0D0e]KF0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0
kno_00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00<0kno_0P3gmoL0
0`3[jn/0g]kN0=kNgP020=KFeP<0Ng]k0P24Q8@50=KFeP030=[JfP3Ng]h0g]kN0080kno_00<0inOW
0=kNgP3Ng]h01@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW
0=kNgP3Ng]h00`3Fe]H207]kN`<0Q8B4103Fe]H00`3Jf]X0g]kN0=kNgP030>o_k`80g]kN00<0inOW
0>o_k`3_knl00P3_knl00`3WinL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`@0kno_00<0
lo?c0?Ogm`3gmoL00P3_knl30=kNgP<0e]KF0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool2
08B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_00<0
inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0jn_[0?Ogm`3gmoL01@3Ng]h20<k>cPH0Q8B40P3>
c/h:0=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_
knl0kno_0080g]kN0`3>c/h508B4Q0<0c/k>2@3Ng]h0103WinL0kno_0>o_k`3WinL40=kNgP030>OW
i`3_knl0kno_00P0g]kN0P3_knl00`3WinL0g]kN0=kNgP020<k>cPD0Q8B40`3>c/h:0=kNgP80kno_
00<0inOW0=kNgP3Ng]h00`3Ng]h20?Ogm`030>_[j`3Ng]h0g]kN00D0g]kN0`3>c/h508B4Q080c/k>
2P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_
0>o_k`050=kNgP<0c/k>0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>
c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h30>o_k`80g]kN00<0jn_[0?Ogm`3gmoL01@3Ng]h20<k>cPH0Q8B40P3>c/h:0=kNgP030>OW
i`3_knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN
0`3>c/h508B4Q0<0c/k>2@3Ng]h0103WinL0kno_0>o_k`3WinL40=kNgP030>OWi`3_knl0kno_00P0
g]kN0P3_knl00`3WinL0g]kN0=kNgP020<k>cPD0Q8B40`3>c/h:0=kNgP80kno_00<0inOW0=kNgP3N
g]h00`3Ng]h20?Ogm`030>_[j`3Ng]h0g]kN00D0g]kN0`3>c/h508B4Q080c/k>2P3Ng]h00`3WinL0
kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0
c/k>0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30>OWi`80c/k>00<0b<S80<;2`P32`/801@3kno/208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80
g]kN0P3Jf]X50=kNgP80inOW00@0hn?S0=kNgP3Ng]h0g=cL0P3Jf]X20>?Sh`030>7Qh@3Ng]h0g]kN
0080f][J00<0g=cL0=kNgP3Ng]h00`3WinL20=kNgP030>GUi@3[jn/0jn_[00D0f][J0P3>c/h608B4
Q080c/k>0P3Ng]h00`3Lg=`0f][J0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[J
fP3Jf]X00P3Shn<00`3QhN40g]kN0=kNgP050=[JfP030>7Qh@3WinL0inOW0080f][J0`3>c/h508B4
Q0<0c/k>0P3Ng]h20=[JfP030=cLg03Ng]h0g]kN0080g]kN00@0hn?S0>OWi`3WinL0hn?S0P3Ng]h2
0=[JfP030=oOg`3Shn<0hn?S0080g]kN00<0g=cL0=[JfP3Jf]X00`3Ng]h20>OWi`030>7Qh@3Jf]X0
f][J0080c/k>1@24Q8@30<k>cP80g]kN00<0g=cL0=[JfP3Jf]X01@3Ng]h20>OWi`040>?Sh`3Ng]h0
g]kN0=cLg080f][J0P3WinL00`3QhN40f][J0=[JfP050=[JfP<0c/k>1@24Q8@20<k>cP80g]kN00<0
g=cL0=[JfP3Jf]X01@3Ng]h00`3Shn<0inOW0>OWi`020=kNgP030=cLg03Jf]X0f][J0080hn?S00@0
hN7Q0=kNgP3Ng]h0g=cL0P3Jf]X20=kNgP030>?Sh`3WinL0inOW0080g]kN0`3Jf]X30<k>cP80Q8B4
1`3kno/00`3Lg=`0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF
2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0
203Ng]h50=KFeP80c/k>1P24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF
0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00D0e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H30<k>cPD0Q8B4
0`3>c/h20=kNgP80e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3Fe]H0
1@3Ng]h00`3Jf]X0e]KF0=KFeP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN
00<0f][J0=KFeP3Fe]H02P3Fe]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN
00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80
Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80
e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3N
g]h0203Ng]h50=KFeP80c/k>1P24Q8@20<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0
e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00D0e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H30<k>cPD0
Q8B40`3>c/h20=kNgP80e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J0=KFeP3F
e]H01@3Ng]h00`3Jf]X0e]KF0=KFeP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0
g]kN00<0f][J0=KFeP3Fe]H02P3Fe]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0
g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>
cP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P1kNg/0102][Jd0g]kN0=kNgP3[jn/N0?Og
m`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Q8B400<0P82007]k
N`1kNg/00P3Ng]hO0?Ogm`80kno_0`3Ng]h208B4Q0<0Ng]k0`3Ng]hN0?Ogm`030??cl`3_knl0kno_
0080g]kN0`24Q8@207]kN`<0g]kN6@3gmoL00`3clo<0kno_0>o_k`030=kNgP80Q8B40`1kNg/20=kN
gQl0moOg0P3oool30>o_k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_
k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80
Ng]k00@0[Jf]0=kNgP3Ng]h0jn_[7P3gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo00<0moOg0>o_
k`3_knl00P3Ng]h308B4Q0030820P01kNg/0Ng]k0080g]kN7`3gmoL20>o_k`<0g]kN0P24Q8@307]k
N`<0g]kN7P3gmoL00`3clo<0kno_0>o_k`020=kNgP<0Q8B40P1kNg/30=kNgQT0moOg00<0lo?c0>o_
k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]hO0?Ogm`80oooo0`3_knl30=kNgP80Q8B41@3_knl20?Og
m`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
d];B00<0b<S80;fm_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`020820P0040;Jf]P3[jn/0jn_[0??c
lah0no_k0P3oool00`3moOd0no_k0?_kn`020?ooo`030?_kn`3gmoL0moOg0080kno_0`24Q8@00`22
PX80P8200820P0020>OWial0no_k0P3gmoL30>o_k`80Q8B40`20P8030>OWiah0no_k00<0nOWi0?Og
m`3gmoL00P3_knl308B4Q080P8200`3WinLI0?_kn`030?Win@3gmoL0moOg00<0kno_0P24Q8@30820
P080inOW7`3kno/20?ooo`<0moOg0`3_knl208B4Q0D0lo?c0P3gmoL00`3MgMd0`/;20<;2`P030<k>
cP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080
oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102n_[h0moOg0?Ogm`3kno/Z0?ooo`H0Q8B40P3_knlT0?oo
o`D0Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?ooo`80Q8B41`3gmoL00`3O
gml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP03
0<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102n_[h0moOg0?Ogm`3kno/Z0?oo
o`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW0?oo
o`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`0208b<S0<0
Q8B40P1kNg/208B4Q00408R8R02<S8`0S8b<08R8R0`0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4
Q024Q8@00P24Q8@308b<S00308R8R024Q8@0Q8B40080Q8B40P1kNg/00`24Q8@0S8b<08b<S00208B4
Q0040820P01kNg/0Ng]k0820P140Q8B400<0P82007]kN`1kNg/00P24Q8@308b<S0P0Q8B40P1kNg/5
08B4Q080Ng]k00<0P82008B4Q024Q8@04024Q8@207]kN`0308B4Q02<S8`0S8b<00L0Q8B40`2<S8`2
07]kN`030820P024Q8@0Q8B40080Q8B400<0O7al07=cL`1cLg<04P24Q8@308b<S0L0Q8B40P1kNg/0
0`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k07]kN`02
08b<S0P0Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`0208b<
S0<0Q8B40P1kNg/208B4Q00408R8R02<S8`0S8b<08R8R0`0Q8B40`1kNg/508B4Q080Ng]k00<0P820
08B4Q024Q8@00P24Q8@308b<S00308R8R024Q8@0Q8B40080Q8B40P1kNg/00`24Q8@0S8b<08b<S002
08B4Q0040820P01kNg/0Ng]k0820P140Q8B400<0P82007]kN`1kNg/00P24Q8@308b<S0P0Q8B40P1k
Ng/508B4Q080Ng]k00<0P82008B4Q024Q8@04024Q8@207]kN`0308B4Q02<S8`0S8b<00L0Q8B40`2<
S8`207]kN`030820P024Q8@0Q8B40080Q8B400<0O7al07=cL`1cLg<04P24Q8@308b<S0L0Q8B40P1k
Ng/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k07]k
N`0208b<S0P0Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`02
08b<S0<0Q8B40P1kNg/208B4Q00408R8R02<S8`0S8b<08R8R0`0Q8B40`1kNg/508B4Q080Ng]k00<0
P82008B4Q024Q8@00P24Q8@308b<S00308R8R024Q8@0Q8B40080Q8B40P1kNg/00`24Q8@0S8b<08b<
S00208B4Q0040820P01kNg/0Ng]k0820P140Q8B400<0P82007]kN`1kNg/00P24Q8@308b<S0P0Q8B4
0P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@04024Q8@207]kN`0308B4Q02<S8`0S8b<00L0Q8B4
0`2<S8`207]kN`030820P024Q8@0Q8B40080Q8B400<0O7al07=cL`1cLg<04P24Q8@308b<S0L0Q8B4
0P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k
07]kN`0208b<S0P0Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P1kNg/00`20P800Q8B408B4
Q00308B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800Q8B408B4
Q00308B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01k
Ng/0Ng]k00@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q0<0Ng]k1@24
Q8@207]kN`D0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]k
N`20P80908B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`D0Q8B4
00<0P82007]kN`1kNg/01@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B41@1kNg/508B4Q0<0Ng]k
1024Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/0
1@24Q8@507]kN`D0Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P1kNg/00`20P800Q8B408B4
Q00308B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800Q8B408B4
Q00308B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01k
Ng/0Ng]k00@0Q8B400<0P82007]kN`1kNg/01@24Q8@00`20P800Ng]k07]kN`0:08B4Q0<0Ng]k1@24
Q8@207]kN`D0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]k
N`20P80908B4Q0030820P01kNg/0Ng]k00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`D0Q8B4
00<0P82007]kN`1kNg/01@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B41@1kNg/508B4Q0<0Ng]k
1024Q8@00`20P800Ng]k07]kN`0508B4Q0030820P01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/0
1@24Q8@507]kN`D0Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;200D0lo?c0P20P800102IVIT0/K6a0;6a
/@2h^;P20;jn_P80^KVi0`2n_[h20<;2`P80_Kfm202n_[h00`30`<00`/;20<;2`P020;Vi^@030;bl
_02n_[h0_[jn00<0`/;20P2i^KT00`2l_;`0_[jn0;jn_P020<;2`P030;jn_P2i^KT0^KVi0080/K6a
0`24Q8@00`22PX80P8200820P0020;6a/@80_[jn00<0_;bl0;Vi^@2i^KT00P2n_[h01030`<00`/;2
0<;2`P30`<020;fm_@L0_[jn00<0`<300<;2`P32`/800`2i^KT20;jn_P030<30`032`/80`/;20080
^KVi0`2a/K4208B4Q0<0P8200`2a/K420;jn_P80^KVi00<0_;bl0;jn_P2n_[h00P32`/800`30`<00
_Kfm0;fm_@080;jn_P80`/;200<0_[jn0;Vi^@2i^KT00`2n_[h20<;2`P030;jn_P2i^KT0^KVi0080
/K6a0`24Q8@20820P0<0/K6a0P2n_[h00`2l_;`0^KVi0;Vi^@050<;2`P80_Kfm202n_[h00`30`<00
`/;20<;2`P050;Vi^@<0/K6a0P24Q8@30820P080/K6a0P2n_[h00`2l_;`0^KVi0;Vi^@030;jn_P80
`/;200<0`<300;fm_@2m_Kd01`2n_[h01030`<00`/;20<;2`P2n_[h20;Vi^@80_[jn00<0`<300<;2
`P32`/801@2i^KT30;6a/@80Q8B41`3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40
g]kN0=kNgP3[jn/70?Ogm`@0oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Og
m`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgPL0moOg00<0no_k0?oo
o`3oool00`3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3gmoL30=kN
gPD0Q8B40`3Ng]h70?Ogm`D0oooo00<0no_k0?Ogm`3gmoL01@3gmoL20?ooo`030?_kn`3gmoL0moOg
00<0moOg0P3oool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h50?Ogm`L0oooo00<0no_k0?Og
m`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN1@24Q8@20=kNgPP0moOg1@3oool70?Og
m`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41`3_knl0
0`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KF
eP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Ogm`@0oooo00<0no_k
0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0
moOg0080g]kN1P24Q8@20=kNgPL0moOg00<0no_k0?ooo`3oool00`3oool70?Ogm`030?_kn`3oool0
oooo00D0moOg00<0no_k0?ooo`3oool00P3gmoL30=kNgPD0Q8B40`3Ng]h70?Ogm`D0oooo00<0no_k
0?Ogm`3gmoL01@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`02
0=kNgPD0Q8B40`3Ng]h50?Ogm`L0oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`05
0?Ogm`<0g]kN1@24Q8@20=kNgPP0moOg1@3oool70?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0
no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0
102e]KD0g]kN0=kNgP3_knlU0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgQl0oooo0P3g
moL30=kNgPD0Q8B40`3Ng]hN0?ooo`030?_kn`3gmoL0moOg0080g]kN1@24Q8@30=kNgQT0oooo00<0
no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN8@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:
0;fm_@2m_Kd01@3gmoL208b<S0040;Fe]@3Ng]h0g]kN0>o_kbD0oooo00<0no_k0?Ogm`3gmoL00P3N
g]h608B4Q080g]kN7`3oool20?Ogm`<0g]kN1@24Q8@30=kNgQh0oooo00<0no_k0?Ogm`3gmoL00P3N
g]h508B4Q0<0g]kN6@3oool00`3kno/0moOg0?Ogm`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3N
g]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_:03o
ool20>o_k`H0Q8B40P3Ng]hQ0?ooo`<0kno_1@24Q8@30=kNgR40oooo0P3gmoL508B4Q0<0g]kN703o
ool30>o_k`D0Q8B40P3Ng]hT0?ooo`<0kno_0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool2
08B4Q0040;6a/@3Ng]h0g]kN0>o_kbP0oooo0P3_knl608B4Q080g]kN8@3oool30>o_k`D0Q8B40`3N
g]hQ0?ooo`80moOg1@24Q8@30=kNgQ`0oooo0`3_knl508B4Q080g]kN903oool30>o_k`80Q8B41`3o
ool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102a/K40g]kN0=kNgP3]kNd20?_knb<0oooo00<0
oOgm0?_kn`3kno/00P3WinL608B4Q080g]kN0P3kno/00`3moOd0oooo0?ooo`0J0?ooo`80no_k0`3W
inL508B4Q0<0g]kN8@3oool20>_[j`D0Q8B40`3Ng]h20?_kn`030?gmo@3oool0oooo01@0oooo00<0
oOgm0?_kn`3kno/00`3WinL508B4Q080g]kN8@3oool30?_kn`<0inOW0P24Q8@70?_kn`030=oOg`32
`/80`/;200<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:
0;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3oool00`3kno/0moOg0?Og
m`020=kNgPH0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01X0oooo0P3gmoL30=kNgPD0Q8B40`3N
g]hQ0?ooo`80g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool0503oool00`3kno/0moOg0?Og
m`030=kNgPD0Q8B40P3Ng]hQ0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3F
e]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@05
0?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24
Q8@20=kNgP80moOg00<0no_k0?ooo`3oool06P3oool20?Ogm`<0g]kN1@24Q8@30=kNgR40oooo0P3N
g]h508B4Q0<0g]kN0P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24
Q8@20=kNgR40oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0
102a/K40g]kN0=kNgP3[jn/20?Ogmb<0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h608B4Q080g]kN0P3_
knl00`3gmoL0oooo0?ooo`0J0?ooo`80moOg0`3Ng]h508B4Q0<0g]kN0P3gmoLL0?ooo`030?_kn`3g
moL0moOg0080g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3oool0503oool00`3kno/0moOg0?Og
m`030=kNgPD0Q8B40P3Ng]h20?Ogm`030?_kn`3oool0oooo01`0oooo0`3gmoL30=kNgP80Q8B41@3_
knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg8`3o
ool00`3kno/0moOg0?Ogm`020=kNgPH0Q8B40P3Ng]h20>o_k`030?Ogm`3oool0oooo01X0oooo0P3g
moL30=kNgPD0Q8B40`3Ng]h20?Ogma`0oooo00<0no_k0?Ogm`3gmoL00P3Ng]h508B4Q0<0g]kN0P3g
moL00`3kno/0oooo0?ooo`0D0?ooo`030?_kn`3gmoL0moOg00<0g]kN1@24Q8@20=kNgP80moOg00<0
no_k0?ooo`3oool0703oool30?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP05
0>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLS0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24
Q8@20=kNgP80kno_00<0moOg0?ooo`3oool06P3oool20?Ogm`<0g]kN1@24Q8@30=kNgP80moOg703o
ool00`3kno/0moOg0?Ogm`020=kNgPD0Q8B40`3Ng]h20?Ogm`030?_kn`3oool0oooo01@0oooo00<0
no_k0?Ogm`3gmoL00`3Ng]h508B4Q080g]kN0P3gmoL00`3kno/0oooo0?ooo`0L0?ooo`<0moOg0`3N
g]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[
jn/40?Ogm`<0oooo0P3gmoL2059BDP0406=SH`1cLg<0Lg=c0;Fe]@80moOg1@3oool208b<S00306m_
K`1BDU80DU9B00P0oooo1@3gmoL20=kNgPH0Q8B40P3Ng]h50?ooo`80g]kN00@0V9RH059BDP1BDU80
:BTY100000000`0410@020P800P8200209BDU0030<[:bP3oool0oooo00<0oooo0P3gmoL00`3kno/0
oooo0?ooo`020?Ogm`<0g]kN0P24Q8@307]kN`<0g]kN103gmoL00`3kno/0oooo0?ooo`020?ooo`03
0820P00000000000010000000P3oool00`3gmoL0kno_0>o_k`020=kNgP<0Ng]k0P2<S8`30=kNgPD0
moOg503oool00`3kno/0moOg0?Ogm`030=kNgP80Q8B40`1kNg/20=kNgPD0moOg6P3oool50?Ogm`<0
g]kN0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0
moOg0`3oool20?Ogm`80DU9B00@0Hf=S07=cL`1cLg<0]KFe0P3gmoL50?ooo`80S8b<00<0Kfm_059B
DP1BDU80203oool50?Ogm`80g]kN1P24Q8@20=kNgPD0oooo0P3Ng]h0102HV9P0DU9B059BDP0Y:BT4
0000000300@4100820P020P80080U9BD00<0b/[:0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0
oooo0080moOg0`3Ng]h208B4Q0<0Ng]k0`3Ng]h40?Ogm`030?_kn`3oool0oooo0080oooo00<0P820
000000000000400000020?ooo`030?Ogm`3_knl0kno_0080g]kN0`1kNg/208b<S0<0g]kN1@3gmoLD
0?ooo`030?_kn`3gmoL0moOg00<0g]kN0P24Q8@307]kN`80g]kN1@3gmoLJ0?ooo`D0moOg0`3Ng]h2
08b<S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0inOW0P3Fe]H00`3<c<`0`/;20<;2`P050?_kn`80Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<2
0?Ogm`<0oooo0P3kno/20:FUY@0409>CT`20P800P82009>CT`80YJFU1@3oool204I6AP0306e]K@2D
U9@0U9BD00P0no_k0P3gmoL00`3inOT0no_k0?_kn`020=[JfPH0Q8B40P3Ng]h20?Ogm`030?Win@3k
no/0no_k0080T92@00@0P82006m_K`1_Kfl0B4Q80P0Q8B4205MGE`0306i^KP24Q8@0Q8B40080a/K6
00<0hn?S0?ooo`3oool00`3kno/20?Ogm`030?_kn`3oool0oooo0080lo?c0`3Ng]h208B4Q0<0P820
0`3Ng]h20?Ogm`80no_k00<0oOgm0?ooo`3oool00P3oool00`30`<00P8200820P0030820P0800000
00<0@4100820P020P8000P0000000`0n?Sh0O7al07alO0030820P080no_k00<0moOg0??cl`3clo<0
0P3Ng]h30820P080R8R80`3Ng]h20?Ogm`030?Win@3kno/0no_k0080hn?S00<0];Bd08B4Q024Q8@0
0P20P800102:RXX0U9BD09BDU02e]KD20=KFeP80Q8B400<0PX:20820P020P8000P36a/H00`3MgMd0
lo?c0??cl`030=kNgP80Q8B40`20P8020=kNgP80moOg00<0nOWi0?_kn`3kno/02P3oool00`3moOd0
no_k0?_kn`020?ooo`030?gmo@3kno/0no_k00<0no_k0P3oool00`3moOd0no_k0?_kn`050?Ogm`<0
g]kN0P28R8P70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80
kno_0P3gmoL50?ooo`80moOg00@0`/;208b<S02<S8`0Kfm_0P1BDU850?ooo`80000000<0Jf][0=KF
eP3Fe]H02P3gmoL00`3kno/0oooo0?ooo`020=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg
0080@T9200@0IfMW08b<S02<S8`0IfMW0P12@T820:f][@030=KFeP3oool0oooo0080moOg00<0no_k
0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020>o_k`<0g]kN1@24Q8@30=kNgP80moOg3@3oool2
000000030820P03oool0oooo0080000000<0O7al0?Ogm`3gmoL00`3oool50?Ogm`80g]kN1@24Q8@3
0=kNgP80moOg00<0no_k0?ooo`3oool00P36a/H00`1WIfL020P800P820020000000401DE5@0Y:BT0
:BTY06][J`80[Jf]0P0820P00`0410@000000000000208b<S0030;jn_P3_knl0kno_00<0g]kN1@24
Q8@20=kNgP80moOg00<0no_k0?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3g
moL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`050?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:
0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_0P3gmoL50?ooo`80moOg00@0
`/;208b<S02<S8`0Kfm_0P1BDU850?ooo`80000000<0Jf][0=KFeP3Fe]H02P3gmoL00`3kno/0oooo
0?ooo`020=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080@T9200@0IfMW08b<S02<S8`0
IfMW0P12@T820:f][@030=KFeP3oool0oooo0080moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0
oooo0?ooo`020>o_k`<0g]kN1@24Q8@30=kNgP80moOg3@3oool2000000030820P03oool0oooo0080
000000<0O7al0?Ogm`3gmoL00`3oool50?Ogm`80g]kN1@24Q8@30=kNgP80moOg00<0no_k0?ooo`3o
ool00P36a/H00`1WIfL020P800P820020000000401DE5@0Y:BT0:BTY06][J`80[Jf]0P0820P00`04
10@000000000000208b<S0030;jn_P3_knl0kno_00<0g]kN1@24Q8@20=kNgP80moOg00<0no_k0?oo
o`3oool02P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3k
no/0moOg0?Ogm`050?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q004
0;6a/@3Ng]h0g]kN0>_[j`L0moOg0P3oool20?Ogm`040?_kn`3oool0oooo0:FUY@80BTY:0P2<S8`0
0`36a/H0oooo0?ooo`020000000307alO03gmoL0moOg00<0oooo0P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`030?_kn`3gmoL0moOg0080g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P1[Jf/0
102a/K40moOg0?Ogm`1lO7`90000000307alO03gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Og
m`020?Ogm`<0g]kN1@24Q8@30=KFePl0moOg0P0000000`1lO7`0moOg0?Ogm`02000000030820P03o
ool0oooo00D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Og
m`0200P8200304Y:BP2<S8`0S8b<0080moOg00@0`/;208b<S02<S8`0ATI60P0000020;fm_@030<;2
`P36a/H0a/K60080000000<0O7al0?Ogm`3gmoL00`3Ng]h508B4Q080e]KF3`3gmoL00`3kno/0oooo
0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL30>o_k`<0g]kN
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg
0P3oool20?Ogm`040?_kn`3oool0oooo0:FUY@80BTY:0P2<S8`00`36a/H0oooo0?ooo`0200000003
07alO03gmoL0moOg00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080
g]kN1P24Q8@20=kNgP80kno_00<0lo?c0?Ogm`3gmoL00P1[Jf/0102a/K40moOg0?Ogm`1lO7`90000
000307alO03gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0g]kN1@24Q8@30=KF
ePl0moOg0P0000000`1lO7`0moOg0?Ogm`02000000030820P03oool0oooo00D0moOg00<0lo?c0>o_
k`3_knl00P3Fe]H508B4Q0<0g]kN0P3_knl00`3clo<0moOg0?Ogm`0200P8200304Y:BP2<S8`0S8b<
0080moOg00@0`/;208b<S02<S8`0ATI60P0000020;fm_@030<;2`P36a/H0a/K60080000000<0O7al
0?Ogm`3gmoL00`3Ng]h508B4Q080e]KF3`3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0
oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b<S80;fm
_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040:n_[`3Jf]X0f][J0>OWi`80lo?c1@3gmoL2
0?_kn`80moOg00@0nOWi0?_kn`3kno/0a/K60P2@T902059BDP030:NWY`3kno/0no_k0080000000<0
O7al0?Ogm`3gmoL00`3kno/20?Ogm`030?Win@3kno/0no_k0080no_k00<0moOg0??cl`3clo<00P3J
f]X608B4Q080g]kN0P3_knl00`3clo<0moOg0?Ogm`02059BDP0408Z:RP32`/80`/;207AdM0809BDU
0P1>CTh00`1GEeL0GemO05mOG`0201DE5@0308J6QP3gmoL0moOg00<0moOg0P3kno/00`3inOT0moOg
0?Ogm`020??cl`<0f][J1@24Q8@30=[JfP80lo?c0P3kno/00`3inOT0moOg0?Ogm`020?Ogm`040?Wi
n@3kno/0no_k0?Win@80moOg0P0000000`1lO7`0moOg0?Ogm`020000000307inOP3kno/0no_k00D0
moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0f][J0P3clo<00`3emOD0moOg0?Ogm`0200P82003
04Y:BP2<S8`0S8b<0080moOg00@0`/;208b<S02<S8`0ATI60P0000020;fm_@030<30`032`/80`/;2
0080000000<0NWYj0??cl`3clo<00`3Jf]X508B4Q080f][J0P3clo<00`3gmoL0no_k0?_kn`050?Og
m`030?Win@3kno/0no_k0080moOg00<0nOWi0?_kn`3kno/01@3gmoL00`3inOT0no_k0?_kn`020?Og
m`030?Win@3kno/0no_k0080moOg0`3_knl30=kNgP80Q8B40P3clo<00`3emOD0moOg0?Ogm`020??c
l`030=SHf02m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040:f][@3Fe]H0e]KF0>?S
h`80kno_303gmoL00`3WinL0e]KF0=KFeP0201PH600308R8R03gmoL0moOg0080000000<0O7al0?Og
m`3gmoL02P3gmoL00`3clo<0kno_0>o_k`020=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg
0080>CTi00@0Hf=S08b<S02<S8`0Jf][0P1:BTX209bLW0030:f][@2m_Kd0_Kfm0080:BTY00<0T92@
0?Ogm`3gmoL0203gmoL20>o_k`<0e]KF1@24Q8@30=kNgP80kno_0P3oool00`3kno/0moOg0?Ogm`02
0?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P0000000`1lO7`0moOg0?Ogm`020000000307alO03g
moL0moOg00D0moOg00<0lo?c0>o_k`3_knl00P3Fe]H508B4Q0<0e]KF1@3gmoL200P8200304Y:BP2<
S8`0S8b<0080moOg00@0`/;208b<S02<S8`0ATI60P0000050;fm_@80000000<0N7Qh0>o_k`3_knl0
0`3Fe]H508B4Q080g]kN0P3_knl00`3gmoL0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo01@0moOg
0`3_knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>
0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3g
moL00`3clo<0kno_0>o_k`0208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_303gmoL00`3WinL0e]KF
0=KFeP0201PH600308R8R03gmoL0moOg0080000000<0O7al0?Ogm`3gmoL02P3gmoL00`3clo<0kno_
0>o_k`020=KFePH0Q8B40P3Ng]h20>o_k`030??cl`3gmoL0moOg0080>CTi00@0Hf=S08b<S02<S8`0
Jf][0P1:BTX209bLW0030:f][@2m_Kd0_Kfm0080:BTY00<0T92@0?Ogm`3gmoL0203gmoL20>o_k`<0
e]KF1@24Q8@30=kNgP80kno_0P3oool00`3kno/0moOg0?Ogm`020?Ogm`040?_kn`3oool0oooo0?_k
n`80moOg0P0000000`1lO7`0moOg0?Ogm`020000000307alO03gmoL0moOg00D0moOg00<0lo?c0>o_
k`3_knl00P3Fe]H508B4Q0<0e]KF1@3gmoL200P8200304Y:BP2<S8`0S8b<0080moOg00@0`/;208b<
S02<S8`0ATI60P0000050;fm_@80000000<0N7Qh0>o_k`3_knl00`3Fe]H508B4Q080g]kN0P3_knl0
0`3gmoL0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo01@0moOg0`3_knl30=kNgP80Q8B40P3_knl0
0`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN
0>_[j`@0moOg0`3_knl20?Ogm`80kno_00<0N7Qh0000000000004000000:0?Ogm`80g]kN0`24Q8@0
0`20P800Ng]k07]kN`020=KFeP80g]kN00<0jn_[0?Ogm`3gmoL00P3Ng]h0102DU9@0BTY:04Y:BP0U
9BD40000000301dM7@0i>CT0>CTi0080g]kN00<0jn_[0?Ogm`3gmoL02P3gmoL30=KFeP80Ng]k0`24
Q8@30=KFeP80kno_1@3gmoL20>o_k`0408b<S00Y:BT0:BTY01DE5@T0000000<0O7al0?Ogm`3gmoL0
1@3oool00`3gmoL0kno_0>o_k`020=KFeP<0Q8B40P1kNg/30=KFeP80kno_00<0lo?c0?Ogm`3gmoL0
0P2m_Kd00`1SHf<020P800P820020000000401DE5@0Y:BT0:BTY06][J`80[Jf]0P0820P00`0410@0
00000000000208b<S0030<;2`P3gmoL0moOg00<0e]KF0P1kNg/308B4Q080e]KF0P3_knl00`3clo<0
moOg0?Ogm`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`1lO7`000000000000200000003
07alO03gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3_knl30=KFeP80Ng]k1`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:
bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`<0kno_0P3gmoL20>o_k`03
07QhN00000000000010000002P3gmoL20=kNgP<0Q8B400<0P82007]kN`1kNg/00P3Fe]H20=kNgP03
0>_[j`3gmoL0moOg0080g]kN00@0U9BD04Y:BP1:BTX09BDU100000000`0M7Ad0>CTi03Ti>@020=kN
gP030>_[j`3gmoL0moOg00X0moOg0`3Fe]H207]kN`<0Q8B40`3Fe]H20>o_k`D0moOg0P3_knl0102<
S8`0:BTY02TY:@0E5AD90000000307alO03gmoL0moOg00D0oooo00<0moOg0>o_k`3_knl00P3Fe]H3
08B4Q080Ng]k0`3Fe]H20>o_k`030??cl`3gmoL0moOg0080_Kfm00<0Hf=S00P8200820P00P000000
100E5AD0:BTY02TY:@1[Jf/20:f][@8020P800<010@40000000000000P2<S8`00`32`/80moOg0?Og
m`030=KFeP80Ng]k0`24Q8@20=KFeP80kno_00<0lo?c0?Ogm`3gmoL00`3gmoL20>o_k`030??cl`3g
moL0moOg0080moOg00<0O7al0000000000000P0000000`1lO7`0moOg0?Ogm`050?Ogm`030?_kn`3o
ool0oooo00D0kno_0`3Fe]H207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3g
moL0moOg00Sooooo0006ooooo`<0inOW0P3>c/h00`38b<P0`/;20<;2`P050?_kn`80P82000@0[Jf]
0=[JfP3Jf]X0hn?S0P3[jn/50??cl`80moOg0P3_knl00`2d];@0N7Qh07QhN00=07QhN0<0O7al1@3g
moL50??cl`80f][J0`24Q8@00`22PX80P8200820P0020=KFeP80g]kN00<0jNWY0??cl`3clo<00P3W
inL01032`/80WIfM09fMW@2;Rh/407QhN00308J6QP2DU9@0U9BD0080jn_[00<0lO7a0?Ogm`3gmoL0
0`3gmoL70??cl`<0f][J0P20P80308B4Q0<0e]KF0P3_knl70??cl`040<30`02<S8`0S8b<08:2PP80
N7Qh1`1lO7`00`2h^;P0lo?c0??cl`050?Ogm`030??cl`3_knl0kno_0080e]KF0`24Q8@20820P0<0
e]KF0P3WinL00`3]kNd0lo?c0??cl`020=[JfP030:^[Z`1lO7`0O7al0080N7Qh00@0Q8B4092@T02@
T900/K6a0P3Bd]820820P00307alO01hN7P0N7Qh0080_[jn00<0fMWI0??cl`3clo<00`3Jf]X20820
P0<0Q8B40P3Fe]H20>o_k`030?7al@3clo<0lo?c00P0lo?c2P1lO7`00`2h^;P0lo?c0??cl`020??c
l`030?Gem@3gmoL0moOg0080kno_0`3clo<30=[JfP80P8201`3kno/00`3Ogml0`/;20<;2`P030=;B
dP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0
oooo0P1kNg/0102YZJT0e]KF0=KFeP3Jf]X20=kNgP80kno_1@3gmoLB0>o_k`P0moOg1@3_knl20=KF
ePH0Q8B40P3Fe]H20=kNgP030>OWi`3_knl0kno_00d0kno_203gmoL70>o_k`<0g]kN1@24Q8@30=KF
ePL0kno_0P3gmoL00`3clo<0kno_0>o_k`030>o_k`L0moOg00<0lo?c0>o_k`3_knl0203_knl20=KF
ePD0Q8B40`3Fe]H20=kNgP030>OWi`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl00P3_knl00`3c
lo<0moOg0?Ogm`050?Ogm`030??cl`3_knl0kno_00D0kno_0`3Ng]h508B4Q080e]KF203_knl20?Og
m`030??cl`3_knl0kno_0080000000<0O7al0?Ogm`3gmoL00P3gmoL0101lO7`000000000001hN7P9
0>o_k`<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0ZJVY0=KF
eP3Fe]H0f][J0P3Ng]h20>o_k`D0moOg4P3_knl80?Ogm`D0kno_0P3Fe]H608B4Q080e]KF0P3Ng]h0
0`3WinL0kno_0>o_k`0=0>o_k`P0moOg1`3_knl30=kNgPD0Q8B40`3Fe]H70>o_k`80moOg00<0lo?c
0>o_k`3_knl00`3_knl70?Ogm`030??cl`3_knl0kno_00P0kno_0P3Fe]H508B4Q0<0e]KF0P3Ng]h0
0`3WinL0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_0080kno_00<0lo?c0?Ogm`3gmoL01@3gmoL0
0`3clo<0kno_0>o_k`050>o_k`<0g]kN1@24Q8@20=KFePP0kno_0P3gmoL00`3clo<0kno_0>o_k`02
0000000307alO03gmoL0moOg0080moOg00@0O7al000000000000N7Qh2@3_knl30?Ogm`<0g]kN0P24
Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>OWi`80c/k>00<0b<S80<;2`P32`/801@3kno/20820P0040:^[Z`3Fe]H0e]KF0=SHf080f][J0P3W
inL30??cl`80jn_[1@3_knl00`3[jn/0inOW0>OWi`020>o_k`030>_[j`3WinL0inOW0080lo?c00<0
lO7a0>o_k`3_knl0203clo<20>o_k`030>_[j`3WinL0inOW0080e]KF0`20P8000`22PX80Q8B408B4
Q0020=KFeP80f][J00<0hN7Q0>OWi`3WinL00P3_knl0103[jn/0inOW0>OWi`3[jn/20>o_k`80lo?c
00<0kNg]0>OWi`3WinL00P3clo<00`3_knl0jn_[0>_[j`030??cl`D0kno_0P3WinL30=[JfP80P820
0`24Q8@30=KFeP80hn?S0P3WinL00`3[jn/0kno_0>o_k`020>_[j`040>o_k`3clo<0lo?c0?7al@80
kno_0P3[jn/00`3_knl0lo?c0??cl`020>_[j`030>g]k@3_knl0kno_00D0kno_00<0jn_[0>OWi`3W
inL00P3Fe]H30820P080Q8B40`3Fe]H20=[JfP030>7Qh@3WinL0inOW0080lo?c00<0kNg]0>OWi`3W
inL00P3_knl0103alO40lo?c0??cl`3_knl20>_[j`80lo?c00<0jn_[0>?Sh`3Shn<00P3_knl00`3[
jn/0inOW0>OWi`030=[JfP80P8200`24Q8@20=KFeP80hn?S00<0iNGU0>OWi`3WinL00`3_knl20>_[
j`030>o_k`3clo<0lo?c0080000000<0MWIf0>_[j`3[jn/00P3clo<0101jNWX000000000001hN7P9
0>o_k`<0jn_[0`3Jf]X20820P0L0no_k00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400<0[Jf]0=KF
eP3Fe]H00`3Fe]H20=kNgP<0kno_0P3Ng]h50>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kN
gP3Ng]h00P3gmoL00`3clo<0kno_0>o_k`0:0>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/00`20
P800Q8B408B4Q0040=KFeP030=[JfP3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW0P3_knl2
0?Ogm`030>_[j`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0203_knl20=kNgP<0e]KF0P1kNg/3
08B4Q0D0e]KF0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP040>_[j`3gmoL0moOg0??cl`80kno_0P3N
g]h00`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00D0kno_00<0inOW0=kNgP3Ng]h00P3F
e]H307]kN`80Q8B41@3Fe]H00`3Jf]X0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0kno_00<0
inOW0=kNgP3Ng]h00P3_knl00`3Shn<0e]KF0=KFeP020>o_k`030>OWi`3Ng]h0g]kN00<0e]KF0P1k
Ng/308B4Q0@0e]KF00<0f][J0=kNgP3Ng]h00`3_knl20=kNgP030>_[j`3gmoL0moOg0080000000<0
Kfm_0=kNgP3Ng]h00P3_knl0101hN7P000000000001hN7P90>o_k`<0g]kN0`3Fe]H207]kN`L0moOg
00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>
c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0kno_0P3N
g]h50>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00P3gmoL00`3clo<0kno_0>o_
k`0:0>o_k`030>OWi`3Ng]h0g]kN0080e]KF0`1kNg/00`20P800Q8B408B4Q0040=KFeP030=[JfP3N
g]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW0P3_knl20?Ogm`030>_[j`3Ng]h0g]kN0080kno_
00<0inOW0=kNgP3Ng]h0203_knl20=kNgP<0e]KF0P1kNg/308B4Q0D0e]KF0P3Ng]h00`3WinL0kno_
0>o_k`020=kNgP040>_[j`3gmoL0moOg0??cl`80kno_0P3Ng]h00`3WinL0kno_0>o_k`020=kNgP03
0>OWi`3_knl0kno_00D0kno_00<0inOW0=kNgP3Ng]h00P3Fe]H307]kN`80Q8B41@3Fe]H00`3Jf]X0
g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3Shn<0
e]KF0=KFeP020>o_k`030>OWi`3Ng]h0g]kN00<0e]KF0P1kNg/308B4Q0@0e]KF00<0f][J0=kNgP3N
g]h00`3_knl20=kNgP030>_[j`3gmoL0moOg0080000000<0Kfm_0=kNgP3Ng]h00P3_knl0101hN7P0
00000000001hN7P90>o_k`<0g]kN0`3Fe]H207]kN`L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80
Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3gmoL00`3[
jn/0g]kN0=kNgP050=kNgP<0kno_0P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80c/k>1P24Q8@20<k>
cPX0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_
k`3_knl00P3Ng]h30<k>cPD0Q8B40`3>c/h90=kNgP040>OWi`3_knl0kno_0>OWi`@0g]kN00<0Kfm_
000000000000203Ng]h20>o_k`030>OWi`3Ng]h0g]kN0080c/k>1@24Q8@30<k>cPX0g]kN0P3_knl0
0`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30<k>cPD0Q8B40P3>c/h:
0=kNgP030>OWi`3_knl0kno_0080g]kN00<0Kfm_0000000000000P0000000`1_Kfl0g]kN0=kNgP05
0=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@03
0<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm
00D0kno_0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h2
0?Ogm`030>_[j`3Ng]h0g]kN00D0g]kN0`3_knl20=kNgP030>OWi`3_knl0kno_00D0g]kN0P3>c/h6
08B4Q080c/k>2P3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h0
0`3WinL0kno_0>o_k`020=kNgP<0c/k>1@24Q8@30<k>cPT0g]kN00@0inOW0>o_k`3_knl0inOW103N
g]h00`1_Kfl00000000000080=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3>c/h508B4Q0<0c/k>2P3N
g]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP<0c/k>1@24
Q8@20<k>cPX0g]kN00<0inOW0>o_k`3_knl00P3Ng]h00`1_Kfl00000000000020000000306m_K`3N
g]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41@3_knl20?Ogm`030=[JfP2m
_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b<S8
0;fm_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3J
f]X50=kNgP80inOW00@0hn?S0=kNgP3Ng]h0g=cL0P3Jf]X20>OWi`030>?Sh`3Ng]h0g]kN0080f][J
00<0g=cL0=kNgP3Ng]h00`3WinL20=kNgP030>?Sh`3WinL0inOW00D0f][J0P3>c/h608B4Q080c/k>
0P3Ng]h00`3Lg=`0f][J0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0g=cL0=[JfP3Jf]X0
0P3Shn<00`3QhN40g]kN0=kNgP030=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Jf]X30<k>cPD0Q8B4
0`3>c/h20=kNgP80f][J00<0g=cL0=kNgP3Ng]h00P3Ng]h0103Shn<0inOW0>OWi`3Shn<20=kNgP80
f][J00<0Xj>S06][J`1[Jf/00P3Ng]h00`3Lg=`0f][J0=[JfP030=kNgP80inOW00<0hN7Q0=[JfP3J
f]X00P3>c/h508B4Q0<0c/k>0P3Ng]h00`3Lg=`0f][J0=[JfP050=kNgP80inOW00@0hn?S0=kNgP3N
g]h0g=cL0P3Jf]X20>?Sh`030>7Qh@3Ng]h0g]kN00D0f][J0`3>c/h508B4Q080c/k>0P3Ng]h00`3L
g=`0f][J0=[JfP050=kNgP030>?Sh`3WinL0inOW0080g]kN00<0YJFU06][J`1[Jf/00P1[Jf/0102U
YJD0g]kN0=kNgP3Lg=`20=[JfP80g]kN00<0hn?S0>OWi`3WinL00P3Ng]h30=[JfP<0c/k>0P24Q8@5
0??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080Q8B400@0ZJVY0<k>
cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP02
0=KFeP030=[JfP3Ng]h0g]kN00P0g]kN1@3Fe]H20<k>cPH0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0
e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP030=KFePD0g]kN0P3Fe]H3
0<k>cPD0Q8B40`3>c/h20=kNgP80e]KF00<0f][J0=kNgP3Ng]h0203Ng]h50=KFeP80g]kN00<0f][J
0=KFeP3Fe]H01@3Ng]h00`3Jf]X0e]KF0=KFeP020<k>cPD0Q8B40`3>c/h20=kNgP030=[JfP3Fe]H0
e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP050=KFeP<0c/k>1@24Q8@2
0<k>cP80g]kN00<0f][J0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP040=[JfP3Ng]h0
g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool0
0`3kno/0moOg0?Ogm`0208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Fe]H:0=kNgP030=[JfP3F
e]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgPD0e]KF0P3>
c/h608B4Q080c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0
f][J0=kNgP3Ng]h00`3Fe]H50=kNgP80e]KF0`3>c/h508B4Q0<0c/k>0P3Ng]h20=KFeP030=[JfP3N
g]h0g]kN00P0g]kN1@3Fe]H20=kNgP030=[JfP3Fe]H0e]KF00D0g]kN00<0f][J0=KFeP3Fe]H00P3>
c/h508B4Q0<0c/k>0P3Ng]h00`3Jf]X0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0
f][J0=kNgP3Ng]h01@3Fe]H30<k>cPD0Q8B40P3>c/h20=kNgP030=[JfP3Fe]H0e]KF00X0g]kN00<0
f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B4
1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_
knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3[jn/20?Ogm`80oooo
1`3gmoL0103kno/0oooo0?ooo`3kno/?0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3gmoL0
kno_0>o_k`020=kNgP<0S8b<00<0Q8B407]kN`1kNg/00P3Ng]h20?Ogm`030?_kn`3oool0oooo01X0
moOg0P3_knl30=kNgP80Q8B40`1kNg/30=kNgP80oooo7`3gmoL20=kNgP<0Q8B40P1kNg/30=kNgQT0
moOg00<0lo?c0>o_k`3_knl00`3Ng]h208B4Q0<0Ng]k0P3Ng]h20?ooo`030?_kn`3gmoL0moOg01X0
moOg0P3oool30>o_k`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool207]kN`040:f]
[@3Ng]h0g]kN0>_[j`80moOg0P3oool70?Ogm`040?_kn`3oool0oooo0?_kn`l0moOg0P3oool00`3k
no/0moOg0?Ogm`020?ooo`030?Ogm`3_knl0kno_0080g]kN0`2<S8`00`24Q8@0Ng]k07]kN`020=kN
gP80moOg00<0no_k0?ooo`3oool06P3gmoL20>o_k`<0g]kN0P24Q8@307]kN`<0g]kN0P3ooolO0?Og
m`80g]kN0`24Q8@207]kN`<0g]kN6@3gmoL00`3clo<0kno_0>o_k`030=kNgP80Q8B40`1kNg/20=kN
gP80oooo00<0no_k0?Ogm`3gmoL06P3gmoL20?ooo`<0kno_0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3Bd]800`38b<P0
_Kfm0;fm_@050?_kn`80P82000@0];Bd0>OWi`3WinL0lO7a0P3kno/20?ooo`L0no_k00@0oOgm0?oo
o`3oool0oOgm3`3kno/20?ooo`030?gmo@3kno/0no_k0080oooo00<0no_k0?Ogm`3gmoL00P3_knl3
08R8R00308B4Q020P800P8200080inOW0P3kno/00`3moOd0oooo0?ooo`0J0?_kn`80moOg0`3_knl2
08B4Q0<0P8200`3WinL20?oooal0no_k0P3_knl308B4Q080P8200`3WinLI0?_kn`030?Win@3gmoL0
moOg00<0kno_0P24Q8@30820P080inOW0P3oool00`3moOd0no_k0?_kn`0J0?_kn`80oooo0`3gmoL3
0>o_k`80Q8B41`3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102j^[X0kno_0>o_k`3gmoLZ
0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW
0?ooo`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102j^[X0kno_0>o_k`3gmoLZ
0?ooo`H0Q8B40P3_knlT0?ooo`D0Q8B40`3_knlS0?ooo`D0Q8B40`3_knlO0?ooo`D0Q8B40P3_knlW
0?ooo`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_1@24Q8@00`20P800Ng]k07]kN`0508B4
Q080Ng]k2P24Q8@00`28R8P0S8b<08b<S00508B4Q0<0Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B4
00X0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0040820P01kNg/0Ng]k08B4Q080S8b<3`24Q8@0
0`1lO7`0Lg=c07=cL`0=08B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40100Q8B40P1kNg/0
0`20P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P2<S8`00`24Q8@0Ng]k07]kN`0L
08B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400l0Q8B400<0P820
07]kN`1kNg/02P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl508B4Q0030820P01kNg/0Ng]k
00D0Q8B40P1kNg/:08B4Q00308R8R02<S8`0S8b<00D0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4
Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080Q8B400@0P82007]kN`1kNg/0Q8B40P2<S8`?
08B4Q00307alO01cLg<0Lg=c00d0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@04024Q8@2
07]kN`030820P024Q8@0Q8B400X0Q8B40P1kNg/00`20P800Q8B408B4Q00208b<S00308B4Q01kNg/0
Ng]k01`0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@0
0`20P800Ng]k07]kN`0:08B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`D0Q8B400<0P82007]k
N`1kNg/01@24Q8@207]kN`X0Q8B400<0R8R808b<S02<S8`01@24Q8@307]kN`D0Q8B40P1kNg/00`20
P800Q8B408B4Q00:08B4Q080Ng]k00<0P82008B4Q024Q8@00P24Q8@01020P800Ng]k07]kN`24Q8@2
08b<S0l0Q8B400<0O7al07=cL`1cLg<03@24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00@
08B4Q080Ng]k00<0P82008B4Q024Q8@02P24Q8@207]kN`030820P024Q8@0Q8B40080S8b<00<0Q8B4
07]kN`1kNg/07024Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00?
08B4Q0030820P01kNg/0Ng]k00X0Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOgh00000000`1l
O7`0moOg0?Ogm`020?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoOP0000000307alO03gmoL0moOg0080
moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80?Shn00<0@4100492@P12@T800`12@T8203hn?PD0@T92
0P0n?Sh00`10@400@T920492@P080492@P80?Shn00<0@4100492@P12@T800`16ATH203hn?P030410
@012@T80@T9200L0@T920`0n?Sh00`10@400@T920492@P020492@PD0?Shn1@12@T800`0n?Sh0>SXj
03Xj>P050492@P80ATI600<0A4A40492@P12@T800`0n?Sh50492@P80?Shn2`12@T8203hn?PD0@T92
0P0j>SX0100l?3`0?Shn03hn?P10@4020492@P80?Shn00<0@4100492@P12@T800P12@T800`1QHF40
P8200820P00303hn?PD0@T920P0n?Sh50492@P<0?Shn2P12@T8203hn?P040492@P16ATH0ATI604A4
A080@T920P0n?Sh00`10@400@T920492@P080492@P80?Shn1@12@T8503hn?PD0@T9200<0@41003hn
?P0n?Sh00P12@T800`14A4@0ATI604I6AP050492@P030410@00n?Sh0?Shn00D0@T921@0n?Sh50492
@P80P82000<0_[jn0?_kn`3kno/00P3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/00`20P800
Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/00`20P800
Q8B408B4Q00308b<S080Ng]k00<0P82008B4Q024Q8@01`24Q8@307]kN`030820P024Q8@0Q8B40080
Q8B41@1kNg/508B4Q00307alO01cLg<0Lg=c00D0Q8B40P2<S8`00`28R8P0Q8B408B4Q00307]kN`D0
Q8B40P1kNg/;08B4Q080Ng]k1@24Q8@207=cL`0407MgM`1kNg/0Ng]k0820P080Q8B40P1kNg/00`20
P800Q8B408B4Q00208B4Q0030<;2`P3oool0oooo00<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/:08B4
Q080Ng]k00@0Q8B408b<S02<S8`0R8R80P24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/5
08B4Q0D0Ng]k1@24Q8@00`20P800Ng]k07]kN`0208B4Q00308R8R02<S8`0S8b<00D0Q8B400<0P820
07]kN`1kNg/01@24Q8@507]kN`D0Q8B41`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/00`20
P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/00`20
P800Q8B408B4Q00308b<S080Ng]k00<0P82008B4Q024Q8@01`24Q8@307]kN`030820P024Q8@0Q8B4
0080Q8B41@1kNg/508B4Q00307alO01cLg<0Lg=c00D0Q8B40P2<S8`00`28R8P0Q8B408B4Q00307]k
N`D0Q8B40P1kNg/;08B4Q080Ng]k1@24Q8@207=cL`0407MgM`1kNg/0Ng]k0820P080Q8B40P1kNg/0
0`20P800Q8B408B4Q00208B4Q0030<;2`P3oool0oooo00<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/:
08B4Q080Ng]k00@0Q8B408b<S02<S8`0R8R80P24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1k
Ng/508B4Q0D0Ng]k1@24Q8@00`20P800Ng]k07]kN`0208B4Q00308R8R02<S8`0S8b<00D0Q8B400<0
P82007]kN`1kNg/01@24Q8@507]kN`D0Q8B41`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0
102a/K40g]kN0=kNgP3[jn/70?Ogm`@0oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?oo
o`050?Ogm`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo1P3gmoL20?ooo`L0moOg00<0
no_k0?ooo`3oool00`3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool01@3g
moL20?ooo`<0moOg0`3oool40?Ogm`030?_kn`3oool0oooo00X0moOg00<0jn_[0=kNgP3Ng]h00P24
Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL50?ooo`L0moOg00<0
no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3o
ool50?Ogm`80oooo203gmoL50?ooo`L0moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo
0?ooo`050?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3N
g]h0g]kN0>_[j`L0moOg103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg
0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool60?Ogm`80oooo1`3gmoL00`3kno/0oooo
0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`80oooo
0`3gmoL30?ooo`@0moOg00<0no_k0?ooo`3oool02P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;jn
_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`050?Ogm`D0oooo1`3gmoL00`3kno/0oooo
0?ooo`050?Ogm`030?_kn`3oool0oooo00D0moOg0P3oool00`3kno/0moOg0?Ogm`030?ooo`D0moOg
0P3oool80?Ogm`D0oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0
moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
kno_K@3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=kNgP03
0>o_k`3oool0oooo0540oooo0`3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H0
1@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>o_kfd0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q003
0;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`1A0?ooo`<0moOg0`3Ng]h208B4Q0D0
kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=;BdP030<c<c036a/H0a/K600D0lo?c0P24Q8@0102a/K40g]kN0=kNgP3_knm]0?ooo`80
no_k00<0lO7a0>OWi`3WinL00P24Q8@00`2l_;`0lo?c0??cl`0308B4Q080g]kN00<0kno_0?ooo`3o
ool0D@3oool30?_kn`<0inOW0P28R8P50??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B4
00@0/K6a0=kNgP3Ng]h0kno_K`3oool00`3gmoL0kno_0>o_k`0208B4Q0030;jn_P3gmoL0moOg00<0
Q8B40P3Ng]h00`3_knl0oooo0?ooo`1D0?ooo`<0kno_0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H0
1@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_kfl0oooo00<0moOg0>o_k`3_knl00P24Q8@00`2n_[h0
moOg0?Ogm`0308B4Q080g]kN00<0kno_0?ooo`3oool0E03oool30>o_k`80S8b<1`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:
bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmf/0oooo0P3gmoL00`3[jn/0
g]kN0=kNgP0207]kN`030;fm_@3oool0oooo00<0S8b<0P3Ng]h00`3[jn/0moOg0?Ogm`1D0?ooo`<0
g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80
moOgJ`3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool00`2<S8`20=kNgP03
0>_[j`3gmoL0moOg05@0oooo0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B4
00@0/K6a0=kNgP3Ng]h0jn_[0P3gmoM[0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P1kNg/00`2m_Kd0
oooo0?ooo`0308b<S080g]kN00<0jn_[0?Ogm`3gmoL0E03oool30=kNgP80Q8B41`3oool00`3Ng]h0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmfd0oooo00<0kno_0=kNgP3N
g]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0D@3oool30?Ogm`<0
g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80
moOgK@3oool00`3_knl0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0
moOg0?Ogm`1A0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm_@020?Ogm`030?Ge
m@3clo<0lo?c0080Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo=[0?ooo`80no_k00<0kNg]0=kNgP3N
g]h00P24Q8@00`2l_;`0lo?c0??cl`0308B4Q080f][J00<0jNWY0?Ogm`3gmoL0D@3oool30?Ogm`<0
inOW0P24Q8@20??cl`030?Gem@3gmoL0moOg0080lo?c00<0f=SH0;fm_@2m_Kd00`3Bd]820>OWi`03
0>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??c
l`3_knl0kno_0080Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knm[0?ooo`80moOg00<0jn_[0=kNgP3N
g]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080e]KF00<0inOW0?Ogm`3gmoL0D@3oool30?Ogm`<0
kno_0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??c
l`3_knl0kno_0080Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knm[0?ooo`80moOg00<0jn_[0=kNgP3N
g]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080e]KF00<0inOW0?Ogm`3gmoL0D@3oool30?Ogm`<0
kno_0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B4
00@0/K6a0=kNgP3Ng]h0kno_0P3oool50?Ogma@0oooo1@1cLg<00`2i^KT0oooo0?ooo`050?ooo`l0
00000P3oool00`20P80000000000000=000000D0oooo00<0^KVi07=cL`1cLg<00P1cLg<J0?ooo`80
moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_
knl00P3gmoM?0?ooo`<0moOg0`3Ng]h207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B4
00@0/K6a0=kNgP3Ng]h0kno_0P3oool50?Ogma@0oooo1@1cLg<00`2i^KT0oooo0?ooo`050?ooo`l0
00000P3oool00`20P80000000000000=000000D0oooo00<0^KVi07=cL`1cLg<00P1cLg<J0?ooo`80
moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_
knl00P3gmoM?0?ooo`<0moOg0`3Ng]h207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3>c/h00`38b<P0`/;20<;2`P050?_kn`80P820
00@0[jn_0=kNgP3Ng]h0kNg]1`3kno/D0?ooo`<0?Shn0P2UYJD00`3Bd]80oooo0?ooo`050?ooo`80
00002P20P8000`10@4000000000000020?ooo`040820P000000000000410@0T0P82000<0@4100000
000000001@3oool00`3Bd]80YJFU0:FUY@0203hn?Q@0oooo00@0oOgm0?_kn`3kno/0oOgm0P3oool2
0?Ogm`030>o_k`3WinL0inOW0080Q8B400<0`<300?_kn`3kno/00`24Q8@20=kNgP030>WYj@3clo<0
lo?c0080no_k703oool00`30`<00P8200820P0080820P0`0oooo2P20P8000`30`<00oooo0?ooo`0?
0?ooo`<0moOg0`3WinL20820P0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kN
gP3Ng]h0jn_[0P3gmoLI0?ooo`<020P80P3Fe]H00`3[jn/0oooo0?ooo`050?ooo`8000002P3oool0
0`20P8000000000000020?ooo`040820P000000000000820P0T0oooo00<0P8200000000000001@3o
ool00`3[jn/0e]KF0=KFeP0200P821@0oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030??c
l`3_knl0kno_0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[j`3gmoL0moOg01h0oooo
00<0P8200000000000002000000<0?ooo`X0000000<0P8200?ooo`3oool03`3oool30?Ogm`<0kno_
0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN0>_[j`80moOg
6@3oool300P82080e]KF00<0jn_[0?ooo`3oool01@3oool2000000X0oooo00<0P820000000000000
0P3oool01020P800000000000020P8090?ooo`030820P0000000000000D0oooo00<0jn_[0=KFeP3F
e]H00P0820PD0?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P3gmoL00`3clo<0kno_0>o_k`0208B4
Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`0N0?ooo`030820P00000000000
00P00000303oool:000000030820P03oool0oooo00l0oooo0`3gmoL30>o_k`80Q8B41`3oool00`3N
g]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP03
0<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`<0oooo103gmoL0103k
no/0oooo0?ooo`3kno/20?Ogm`L0oooo00<0c/k>09bLW02LW9`00`0i>CT:0?ooo`8000001P3oool2
0?Ogm`80oooo00<0P8200000000000000P3gmoL0101lO7`0000000000020P8070?ooo`80moOg00<0
O7al000000000000203oool20492@P<0W9bL2P3oool20?Ogm`030?_kn`3oool0oooo00P0oooo0P3_
knl00`3WinL0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Og
m`020?ooo`D0moOg0`3oool20?Ogm`030?_kn`3oool0oooo00L0oooo00@0no_k0?Ogm`3gmoL0no_k
103oool00`20P8000000000000020?Ogm`0307alO0000000000000D0oooo0`3gmoL40?ooo`030?_k
n`3gmoL0moOg00<0oooo0P0000000`20P800oooo0?ooo`020000000307alO03gmoL0moOg00P0oooo
0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd0
0`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6
aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL30?ooo`@0moOg00@0no_k0?ooo`3oool0
no_k0P3gmoL70?ooo`030<k>cP2LW9`0W9bL00<0>CTi2P3oool2000000H0oooo0P3gmoL20?ooo`03
0820P000000000000080moOg00@0O7al000000000000P8201`3oool20?Ogm`0307alO00000000000
00P0oooo0P12@T8309bLW0X0oooo0P3gmoL00`3kno/0oooo0?ooo`080?ooo`80kno_00<0inOW0=kN
gP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL00P3oool50?Og
m`<0oooo0P3gmoL00`3kno/0oooo0?ooo`070?ooo`040?_kn`3gmoL0moOg0?_kn`@0oooo00<0P820
0000000000000P3gmoL00`1lO7`00000000000050?ooo`<0moOg103oool00`3kno/0moOg0?Ogm`03
0?ooo`80000000<0P8200?ooo`3oool00P0000000`1lO7`0moOg0?Ogm`080?ooo`80moOg00<0no_k
0?ooo`3oool00P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<208B4
Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg0`3oool:0?_kn`L0oooo00<0`<300820P020P8000`1SHf<2
0?_kn`030?gmo@3oool0oooo00D0no_k0P0000060?ooo`80no_k0P3oool00`20P800000000000002
0?_kn`0407inOP00000000000820P0L0oooo0P3kno/00`1nOWh00000000000030?ooo`D0no_k0P1O
Gel30820P0P0oooo103kno/00`3moOd0oooo0?ooo`020?ooo`040?gmo@3kno/0no_k0?gmo@80oooo
0P3clo<00`3YjNT0g]kN0=kNgP0208B4Q0030;bl_03clo<0lo?c00<0Q8B40P3Ng]h00`3[jn/0moOg
0?Ogm`020?ooo`X0no_k00<0oOgm0?ooo`3oool01`3oool00`3moOd0no_k0?_kn`030?_kn`80oooo
00<0P8200000000000000P3gmoL00`1lO7`00000000000050?ooo`<0O7al1020P8000`1nOWh0O7al
07alO0030?ooo`80000000<0P8200?ooo`3oool00P0000000`1nOWh0no_k0?_kn`020?_kn`040?gm
o@3oool0oooo0?gmo@80no_k0P3gmoL00`3kno/0oooo0?ooo`020?_kn`<0lo?c0`3WinL208B4Q0D0
lo?c0P3gmoL00`3Jf]X0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`L0
oooo00@0no_k0?Ogm`3gmoL0no_k2@3oool00`2a/K40Hf=S06=SH`0308b<S080moOg00<0no_k0?oo
o`3oool01@3gmoL2000000X0oooo00<0P8200000000000000P3oool01020P800000000000020P809
0?ooo`030820P0000000000000<0oooo1@3gmoL207]kN`<0Hf=S203oool20?Ogm`L0oooo00@0no_k
0?Ogm`3gmoL0no_k0P3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24
Q8@20=kNgP030>_[j`3gmoL0moOg00L0oooo0`3gmoL?0?ooo`030?_kn`3gmoL0moOg0080oooo00<0
P8200000000000000P3gmoL00`1lO7`00000000000050?ooo`X000000`3oool2000000030820P03o
ool0oooo0080000000<0P8200?ooo`3oool00P3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_k
n`3oool0oooo0080oooo0`3gmoL30>o_k`80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>
0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3_
knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg1`3oool0103kno/0moOg0?Ogm`3kno/90?ooo`03
0;6a/@1SHf<0Hf=S00<0S8b<0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`8000002P3oool00`20P800
0000000000020?ooo`040820P000000000000820P0T0oooo00<0P8200000000000000`3oool50?Og
m`80Ng]k0`1SHf<80?ooo`80moOg1`3oool0103kno/0moOg0?Ogm`3kno/20?ooo`80moOg00<0jn_[
0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL01`3oool3
0?Ogm`l0oooo00<0no_k0?Ogm`3gmoL00P3oool00`20P8000000000000020?Ogm`0307alO0000000
000000D0oooo2P0000030?ooo`80000000<0P8200?ooo`3oool00P0000000`20P800oooo0?ooo`02
0?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool00P3oool30?Ogm`<0kno_0P24
Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm_@020?Ogm`030?Gem@3clo<0lo?c0080Q8B400@0/K6a
0=kNgP3Ng]h0jNWY0P3clo<20?Ogm`D0no_k0P3oool0103moOd0no_k0?_kn`3moOd20?ooo`80no_k
00<0oOgm0?ooo`3oool00P3kno/00`2MWId0?Shn03hn?P030;6a/@80no_k00<0oOgm0?ooo`3oool0
1@3kno/2000000<0no_k00<0oOgm0?ooo`3oool00P3kno/20?ooo`030820P000000000000080oooo
00@0P820000000000000P8200P3oool20?_kn`030?gmo@3oool0oooo0080oooo00<0P82000000000
00000`3oool50?_kn`80W9bL0`0n?Sh20?ooo`<0no_k0`3oool20?_kn`80oooo00<0oOgm0?_kn`3k
no/00P3oool0103kno/0moOg0?Ogm`3kno/20?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2l
_;`0lo?c0??cl`0308B4Q080g]kN00<0jNWY0??cl`3clo<01@3kno/20?ooo`<0no_k0P3oool00`3m
oOd0no_k0?_kn`020?ooo`030?gmo@3kno/0no_k00D0oooo00<0oOgm0?_kn`3kno/00P3oool00`20
P8000000000000020?_kn`0307inOP000000000000<0no_k0P3oool3000000@0P82000<0@4100000
000000000`3kno/20000000307inOP3kno/0no_k0080000000<0P8200?ooo`3oool00P3kno/0103m
oOd0oooo0?ooo`3moOd90?_kn`<0moOg0`3WinL208B4Q0D0lo?c0P3gmoL00`3MgMd0`/;20<;2`P03
0<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm
0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`L0moOg203oool2
0?Ogm`030?_kn`3oool0oooo0080moOg00<0R8R801PH600H61P00`3Fe]H:0?ooo`8000000`3gmoL0
0`3kno/0oooo0?ooo`020?Ogm`80oooo00<0P8200000000000000P3oool01020P800000000000020
P8020?ooo`80moOg00<0no_k0?ooo`3oool00P3oool00`20P8000000000000080?ooo`80_Kfm0`0H
61P20?ooo`<0moOg1`3oool00`3kno/0moOg0?Ogm`020?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo
0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_
0>o_k`050?Ogm`L0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`0:0?ooo`030820
P000000000000080oooo00<0P8200000000000000`3gmoL20?ooo`<00000103oool00`20P8000000
000000030?Ogm`80000000<0O7al0?Ogm`3gmoL00P0000000`20P800oooo0?ooo`0:0?ooo`030?_k
n`3gmoL0moOg00D0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3g
moL0moOg0080Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl70?Ogm`P0oooo0P3gmoL00`3kno/0oooo
0?ooo`020?Ogm`0308R8R00H61P061PH00<0e]KF2P3oool2000000<0moOg00<0no_k0?ooo`3oool0
0P3gmoL20?ooo`030820P000000000000080oooo00@0P820000000000000P8200P3oool20?Ogm`03
0?_kn`3oool0oooo0080oooo00<0P820000000000000203oool20;fm_@<061PH0P3oool30?Ogm`L0
oooo00<0no_k0?Ogm`3gmoL00P3oool0103kno/0moOg0?Ogm`3kno/20?ooo`80moOg00<0jn_[0=kN
gP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl01@3gmoL70?oo
o`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL02P3oool00`20P8000000000000020?oo
o`030820P0000000000000<0moOg0P3oool3000000@0oooo00<0P8200000000000000`3gmoL20000
000307alO03gmoL0moOg0080000000<0P8200?ooo`3oool02P3oool00`3kno/0moOg0?Ogm`050?Og
m`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[
j`80moOg1`3oool20?Ogm`030?_kn`3oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`20
P8000000000000050?ooo`030?_kn`3gmoL0moOg00D0moOg3`0000020?ooo`030820P00000000000
00d00000203gmoL20?ooo`<000001@3oool30?Ogm`L0oooo0P3gmoL0103kno/0oooo0?ooo`3kno/4
0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>o_k`3oool0
oooo0080oooo1@3gmoL30?ooo`l0000000<0P8200?ooo`3oool00P3gmoL00`1lO7`0000000000002
0?Ogm`0307alO0000000000000D0oooo0`0000020?Ogm`80oooo00<0P8200000000000000`3oool2
000000030820P03oool0oooo0080000000<0P8200?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`05
0?Ogm`030?_kn`3oool0oooo0080oooo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@03
0=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm
00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`L0oooo0P3gmoL00`3kno/0oooo0?ooo`05
0?ooo`030?_kn`3gmoL0moOg0080oooo00<0P8200000000000001@3oool00`3kno/0moOg0?Ogm`05
0?Ogm`l000000P3oool00`20P80000000000000=000000P0moOg0P3oool3000000D0oooo0`3gmoL7
0?ooo`80moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030<;2`P3o
ool0oooo00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`020?ooo`D0moOg0`3oool?000000030820P03o
ool0oooo0080moOg00<0O7al0000000000000P3gmoL00`1lO7`00000000000050?ooo`<000000P3g
moL20?ooo`030820P0000000000000<0oooo0P0000000`20P800oooo0?ooo`02000000030820P03o
ool0oooo0080oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`020?ooo`<0moOg0`3N
g]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80Q8B400@0[jn_0=[JfP3Jf]X0jNWY0P3g
moL<0?_kn`030?gmo@3oool0oooo0080no_k00<0nOWi0?Ogm`3gmoL00P3Ng]h00`1jNWX05ADE01DE
5@050?ooo`030?_kn`3gmoL0moOg0080no_k00<0nOWi0?Ogm`3gmoL00P20P80807alO080P82000<0
OWin07alO01lO7`00P3oool00`2n_[h0O7al07alO00:07alO00307inOP20P800P82000<0moOg0P3k
no/00`3inOT0moOg0?Ogm`020?ooo`<05ADE0P3Ng]h80?_kn`80oooo00<0oOgm0?_kn`3kno/00P3g
moL0103inOT0no_k0?_kn`3inOT40?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`<300?_kn`3kno/0
0`20P8020=kNgP030>_[j`3gmoL0moOg0080no_k0`3gmoL50?_kn`l0000000<0P8200?ooo`3oool0
0P3gmoL00`1lO7`00000000000020?Ogm`0307alO0000000000000D0no_k0`00000207alO080P820
00<0@4100000000000000`3kno/20000000307inOP3kno/0no_k0080000000<0P8200?ooo`3oool0
0P3oool0103kno/0moOg0?Ogm`3inOT20?_kn`80moOg00<0no_k0?ooo`3oool00P3kno/30??cl`<0
g]kN0P24Q8@70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWi`T0
moOg0P3oool0103kno/0moOg0?Ogm`3kno/20?ooo`D0moOg0P2m_Kd00`1cLg<0:BTY02TY:@050?oo
o`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL00P3oool80?Ogm`80oooo00<0no_k0?Og
m`3gmoL00P3oool00`3kno/0moOg0?Ogm`0:0?Ogm`030?_kn`3oool0oooo00<0moOg0P3oool00`3k
no/0moOg0?Ogm`020?ooo`<0:BTY0P2m_Kd30?Ogm`<0oooo0P3gmoL20?ooo`030?_kn`3gmoL0moOg
00X0moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0inOW0>o_
k`3_knl01@3gmoL20?ooo`<0moOg3`0000000`20P800oooo0?ooo`020?Ogm`0307alO00000000000
0080moOg00<0O7al0000000000001@3gmoL:000000<0moOg0P0000000`1lO7`0moOg0?Ogm`020000
00030820P03oool0oooo0080oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030?_kn`3oool0
oooo0080moOg0`3_knl30=kNgP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102]
[Jd0e]KF0=KFeP3WinL90?Ogm`80oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool50?Ogm`80_Kfm00<0
Lg=c02TY:@0Y:BT01@3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg0080oooo203g
moL20?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL02P3gmoL00`3kno/0oooo0?oo
o`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool302TY:@80_Kfm0`3gmoL30?ooo`80moOg0P3o
ool00`3kno/0moOg0?Ogm`0:0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`1k
Ng/20=kNgP030>OWi`3_knl0kno_00D0moOg0P3oool30?Ogm`l0000000<0P8200?ooo`3oool00P3g
moL00`1lO7`00000000000020?Ogm`0307alO0000000000000D0moOg2P0000030?Ogm`80000000<0
O7al0?Ogm`3gmoL00P0000000`20P800oooo0?ooo`020?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo
0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0kno_0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H0
0`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6
aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl20?Ogm`<0oooo0P3gmoL20?ooo`030?_k
n`3gmoL0moOg00<0moOg1@3oool20:f][@0306][J`0Y:BT0:BTY00D0moOg00<0no_k0?ooo`3oool0
2P3gmoL00`3kno/0oooo0?ooo`020?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0oooo
0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`L0moOg0`0Y:BT20:f][@<0moOg
0`3oool40?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL00`3gmoL20>o_k`030>OW
i`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=kNgP030>OWi`3_knl0kno_00D0moOg
0P3oool30?Ogm`l0000000<0O7al0?Ogm`3gmoL00P3oool00`20P8000000000000020?Ogm`0307al
O0000000000000<0moOg0P3oool:0?Ogm`<0oooo0P0000000`1lO7`0moOg0?Ogm`020000000307al
O03gmoL0moOg0080moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20?ooo`030?_kn`3gmoL0moOg00D0
moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
inOW0P3_knl20?Ogm`<0oooo0P3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg1@3oool20:f][@03
06][J`0Y:BT0:BTY00D0moOg00<0no_k0?ooo`3oool02P3gmoL00`3kno/0oooo0?ooo`020?Ogm`80
oooo00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3o
ool01@3gmoL30?ooo`L0moOg0`0Y:BT20:f][@<0moOg0`3oool40?Ogm`030?_kn`3oool0oooo0080
oooo00<0no_k0?Ogm`3gmoL00`3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_
knl00`24Q8@20=kNgP030>OWi`3_knl0kno_00D0moOg0P3oool30?Ogm`l0000000<0O7al0?Ogm`3g
moL00P3oool00`20P8000000000000020?Ogm`0307alO0000000000000<0moOg0P3oool:0?Ogm`<0
oooo0P0000000`1lO7`0moOg0?Ogm`020000000307alO03gmoL0moOg0080moOg00@0no_k0?ooo`3o
ool0no_k0P3gmoL20?ooo`030?_kn`3gmoL0moOg00D0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm
_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3<c<`0
`/;20<;2`P050??cl`80R8R800@0/K6a0=[JfP3Jf]X0inOW0P3clo<50?_kn`80moOg0P3kno/00`3i
nOT0moOg0?Ogm`030?Ogm`D0no_k0P2][Jd00`1[Jf/0:BTY02TY:@050?Ogm`030?Win@3kno/0no_k
0080no_k00<0nOWi0?Ogm`3gmoL00P3gmoL60?_kn`80moOg0P3kno/00`3inOT0moOg0?Ogm`020?Og
m`030?Win@3kno/0no_k00<0no_k0P3gmoL00`3inOT0no_k0?_kn`050?Ogm`D0no_k00<0nOWi0?Og
m`3gmoL00P3kno/302TY:@80[Jf]0`3gmoL30?_kn`@0moOg00<0nOWi0?_kn`3kno/00P3kno/00`3i
nOT0moOg0?Ogm`030?Ogm`80lo?c00<0inOW0=[JfP3Jf]X00P24Q8@00`2n_[h0moOg0?Ogm`0308B4
Q080g]kN00<0jNWY0??cl`3clo<01@3gmoL20?_kn`<0moOg3`0000000`1lO7`0moOg0?Ogm`020?_k
n`0307inOP00000000000080O7al00<0?Shn0000000000000`1lO7`20?_kn`X0moOg0`20P8020000
000303hn?P1lO7`0O7al0080000000<0OWin0?_kn`3kno/00P3gmoL00`3inOT0no_k0?_kn`050?_k
n`030?Win@3gmoL0moOg0080no_k0`3clo<30=kNgP80Q8B41`3clo<00`3Hf=P0_Kfm0;fm_@030=;B
dP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P2<S8`0102a/K40e]KF0=KFeP3WinL20?Ogm`80oooo4P3gmoL20:f][@0306][J`0Y:BT0:BTY
00P0moOg0P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0oooo00<0no_k0?Ogm`3gmoL0703gmoL20?oo
o`030?_kn`3gmoL0moOg0080oooo0`0Y:BT20:f][AL0moOg00<0inOW0=KFeP3Fe]H00P24Q8@00`32
`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL02P3gmoL?0000000307alO03gmoL0moOg
0080moOg00<0O7al0000000000002000000<0?Ogm`X0000000<0P8200?ooo`3oool01@3gmoL00`3k
no/0oooo0?ooo`050?Ogm`80oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P2<S8`0102a/K40e]KF0=KFeP3WinL20?Ogm`80oooo4P3gmoL20:f][@0306][J`0Y:BT0:BTY
00P0moOg0P3oool00`3kno/0moOg0?Ogm`020?Ogm`<0oooo00<0no_k0?Ogm`3gmoL0703gmoL20?oo
o`030?_kn`3gmoL0moOg0080oooo0`0Y:BT20:f][AL0moOg00<0inOW0=KFeP3Fe]H00P24Q8@00`32
`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL02P3gmoL?0000000307alO03gmoL0moOg
0080moOg00<0O7al0000000000002000000<0?Ogm`X0000000<0P8200?ooo`3oool01@3gmoL00`3k
no/0oooo0?ooo`050?Ogm`80oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0
oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg0`3oool?0?Ogm`80[Jf]00<0Jf][02TY
:@0Y:BT00`3oool?0?Ogm`030?_kn`3oool0oooo01@0moOg0P3oool00`3kno/0moOg0?Ogm`0:0?Og
m`<0:BTY0P2][Jd80?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030>o_k`3Ng]h0g]kN
0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=KFeP030>?Sh`3_knl0kno_00D0oooo1@3gmoL?0000
000307alO03gmoL0moOg00d0moOg1@3ooolA0?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?oo
o`3oool01`3gmoL30?ooo`<0g]kN0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q004
0;6a/@3Ng]h0g]kN0>OWi`80kno_0P3gmoL30?ooo`l0moOg0P2][Jd00`1[Jf/0:BTY02TY:@030?oo
o`l0moOg00<0no_k0?ooo`3oool0503gmoL20?ooo`030?_kn`3gmoL0moOg00X0moOg0`0Y:BT20:f]
[@P0moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32
`/80oooo0?ooo`0308B4Q080e]KF00<0hn?S0>o_k`3_knl01@3oool50?Ogm`l0000000<0O7al0?Og
m`3gmoL03@3gmoL50?oooa40moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`070?Og
m`<0oooo0`3Ng]h207]kN`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3N
g]h0inOW0P3_knl20?Ogm`<0oooo3`3gmoL20:f][@0306][J`0Y:BT0:BTY00<0oooo3`3gmoL00`3k
no/0oooo0?ooo`0D0?Ogm`80oooo00<0no_k0?Ogm`3gmoL02P3gmoL302TY:@80[Jf]203gmoL20?oo
o`030?_kn`3gmoL0moOg00P0moOg0P3oool00`3_knl0g]kN0=kNgP0208B4Q0030<;2`P3oool0oooo
00<0Q8B40P3Fe]H00`3Shn<0kno_0>o_k`050?ooo`D0moOg3`0000000`1lO7`0moOg0?Ogm`0=0?Og
m`D0oooo4@3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo00L0moOg0`3oool30=kN
gP80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_
k`80moOg0`3_knl<0?Ogm`030??cl`3_knl0kno_0080moOg00<0O7al0000000000003@3gmoL?0000
0080moOg00<0O7al0000000000003@00000:0?Ogm`<00000203gmoL20?ooo`d0moOg0P3_knl00`3S
hn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Fe]H00`3Shn<0kno_0>o_k`020>o_
k`P0moOg3`0000000`1lO7`0moOg0?Ogm`0D0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?oo
o`030?_kn`3gmoL0moOg00l0moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80moOg0`3_knl<0?Ogm`030??cl`3_knl0kno_
0080moOg00<0O7al0000000000003@3gmoL?00000080moOg00<0O7al0000000000003@00000:0?Og
m`<00000203gmoL20?ooo`d0moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg
00<0Ng]k0P3Fe]H00`3Shn<0kno_0>o_k`020>o_k`P0moOg3`0000000`1lO7`0moOg0?Ogm`0D0?Og
m`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3gmoL0moOg00l0moOg0`3_knl30=KF
eP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_
k`l0moOg0P3oool00`3kno/0moOg0?Ogm`020?Ogm`030820P00820P020P800<0]KFe2P3gmoL20000
00X0moOg00<0O7al0000000000000P3gmoL0101lO7`000000000001lO7`90?Ogm`0307alO0000000
000000P0moOg0P3>c/h301PH60`0moOg00<0no_k0?ooo`3oool0203gmoL20>o_k`030>OWi`3Ng]h0
g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=KFeP030>?Sh`3_knl0kno_00`0moOg00<0no_k
0?ooo`3oool01`3gmoL0103clo<0kno_0>o_k`3clo<K0?Ogm`<0oooo1`3gmoL00`3clo<0kno_0>o_
k`080?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL30>o_k`<0e]KF0P1kNg/50>o_k`80moOg00<0
f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h0
0`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl?0?Ogm`80oooo00<0
no_k0?Ogm`3gmoL00P3gmoL00`20P80020P800P820030;Fe]@X0moOg0P00000:0?Ogm`0307alO000
000000000080moOg00@0O7al000000000000O7al2@3gmoL00`1lO7`00000000000080?Ogm`80c/k>
0`0H61P<0?Ogm`030?_kn`3oool0oooo00P0moOg0P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;Zj
^P3_knl0kno_00<0Q8B40P3Fe]H00`3Shn<0kno_0>o_k`0<0?Ogm`030?_kn`3oool0oooo00L0moOg
00@0lo?c0>o_k`3_knl0lo?c6`3gmoL30?ooo`L0moOg00<0lo?c0>o_k`3_knl0203gmoL20>o_k`03
0??cl`3gmoL0moOg0080moOg0`3_knl30=KFeP80Ng]k1@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H0
1@3_knl208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_3`3gmoL20?ooo`030?_kn`3gmoL0moOg0080
moOg00<0P82000P8200820P00`2e]KD:0?Ogm`8000002P3gmoL00`1lO7`00000000000020?Ogm`04
07alO0000000000007alO0T0moOg00<0O7al000000000000203gmoL20<k>cP<061PH303gmoL00`3k
no/0oooo0?ooo`080?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4
Q080e]KF00<0hn?S0>o_k`3_knl0303gmoL00`3kno/0oooo0?ooo`070?Ogm`040??cl`3_knl0kno_
0??cla/0moOg0`3oool70?Ogm`030??cl`3_knl0kno_00P0moOg0P3_knl00`3clo<0moOg0?Ogm`02
0?Ogm`<0kno_0`3Fe]H207]kN`D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P1kNg/0102Y
ZJT0e]KF0=KFeP3Shn<20>o_k`D0moOg0P3_knl20?ooo`040?_kn`3gmoL0moOg0??cl`80kno_1@3g
moL20>o_k`030:FUY@1JFUX0FUYJ00<0Lg=c2P3gmoL2000000H0moOg0P3_knl20?ooo`030820P000
000000000080kno_00@0N7Qh000000000000O7al2@3gmoL00`1lO7`00000000000080?Ogm`80S8b<
0`1JFUX20?Ogm`<0kno_0`3oool40?Ogm`030??cl`3_knl0kno_0080moOg00@0lo?c0>o_k`3_knl0
lo?c0P3gmoL20>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP03
0>OWi`3_knl0kno_0080moOg0`3_knl20?ooo`<0moOg0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`03
0??cl`3_knl0kno_01L0moOg0`3_knl20?oooa@0moOg00@0no_k0?ooo`3oool0no_k1`3gmoL50>o_
k`<0e]KF0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL207]kN`040:VYZ@3Fe]H0e]KF0>?S
h`80kno_1@3gmoL20>o_k`80oooo00@0no_k0?Ogm`3gmoL0lo?c0P3_knl50?Ogm`80kno_00<0YJFU
05YJFP1JFUX00`1cLg<:0?Ogm`8000001P3gmoL20>o_k`80oooo00<0P8200000000000000P3_knl0
101hN7P000000000001lO7`90?Ogm`0307alO0000000000000P0moOg0P2<S8`305YJFP80moOg0`3_
knl30?ooo`@0moOg00<0lo?c0>o_k`3_knl00P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_
00<0hn?S0=KFeP3Fe]H00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl0
0P3gmoL30>o_k`80oooo0`3gmoL20>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl0
5`3gmoL30>o_k`80oooo503gmoL0103kno/0oooo0?ooo`3kno/70?Ogm`D0kno_0`3Fe]H208b<S0L0
moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_
0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h50?Ogm`@0
kno_00<0lo?c0?Ogm`3gmoL0203gmoL20>o_k`030<;2`P2DU9@0U9BD00<0>CTi1`3_knl00`3gmoL0
oooo0?ooo`02000000P0moOg0P3_knl00`1hN7P00000000000020?Ogm`0407alO0000000000007al
O0L0moOg0P3_knl00`1hN7P00000000000050>o_k`030?Ogm`3oool0oooo0080>CTi0`2LW9`20?Og
m`H0kno_2@3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P1kNg/0
0`2m_Kd0oooo0?ooo`0308b<S080e]KF00<0hn?S0>o_k`3_knl00P3gmoL50>o_k`X0moOg00<0lo?c
0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80oooo00<0moOg0>o_k`3_knl0203gmoL2
0>o_k`D0moOg0`3_knl70?Ogm`030??cl`3_knl0kno_00P0kno_0P3oool00`3gmoL0kno_0>o_k`05
0>o_k`<0e]KF0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF
0=[JfP80g]kN1@3gmoL40>o_k`030??cl`3gmoL0moOg00P0moOg0P3_knl00`32`/80U9BD09BDU003
03Ti>@L0kno_00<0moOg0?ooo`3oool00P0000080?Ogm`80kno_00<0N7Qh0000000000000P3gmoL0
101lO7`000000000001lO7`70?Ogm`80kno_00<0N7Qh0000000000001@3_knl00`3gmoL0oooo0?oo
o`0203Ti>@<0W9bL0P3gmoL60>o_k`T0moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030>OW
i`3Ng]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool00`2<S8`20=KFeP030>?Sh`3_knl0kno_0080moOg
1@3_knl:0?Ogm`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl0203_knl20?ooo`030?Og
m`3_knl0kno_00P0moOg0P3_knl50?Ogm`<0kno_1`3gmoL00`3clo<0kno_0>o_k`080>o_k`80oooo
00<0moOg0>o_k`3_knl01@3_knl30=KFeP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24
Q8@0102][Jd0e]KF0=KFeP3Ogml20>OWi`D0lo?c103_knl0103clo<0moOg0?Ogm`3emOD40??cl`03
0?Gem@3gmoL0moOg0080kno_00<0fm_K0<K6aP36a/H00`0Q8B420=_Kf`030>GUi@3_knl0kno_0080
lo?c00<0mOGe0?Ogm`3gmoL00P0000080??cl`80kno_00<0N7Qh0000000000000P3clo<0101jNWX0
00000000001lO7`20?Ogm`L0lo?c00<0NWYj0000000000000`3_knl20??cl`030>_[j`3Shn<0hn?S
00808B4Q0`36a/H20??cl`H0kno_0P3gmoL70??cl`040?7al@3_knl0kno_0?7al@80lo?c0P3_knl0
0`3UiND0f][J0=[JfP020820P0030;jn_P3kno/0no_k00<0R8R80P3Fe]H00`3Ogml0inOW0>OWi`02
0??cl`D0kno_0`3gmoL50??cl`80moOg00<0lo?c0>o_k`3_knl00P3gmoL0103emOD0lo?c0??cl`3a
lO440>o_k`030?7al@3clo<0lo?c0080moOg00<0lo?c0>o_k`3_knl01@3clo<30?Ogm`80kno_0P3g
moL00`3emOD0lo?c0??cl`030>o_k`D0lo?c0P3gmoL00`3emOD0lo?c0??cl`050>o_k`030?7al@3c
lo<0lo?c0080moOg00<0lo?c0>o_k`3_knl00P3_knl30>OWi`<0f][J0P1lO7`70?_kn`030=cLg02m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K6
0;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`/0kno_00@0lo?c0?Ogm`3gmoL0lo?c
103_knl00`3clo<0moOg0?Ogm`020>o_k`030??cl`3gmoL0moOg00<020P80P36a/H00`3Kfm/0kno_
0>o_k`020?Ogm`030??cl`3_knl0kno_008000002P3_knl00`1hN7P00000000000020>o_k`0407Qh
N0000000000007alO080moOg1@3_knl20?Ogm`0307alO0000000000000<0kno_0P3gmoL00`3Ogml0
a/K60<K6aP0200P820/0kno_0P3gmoL?0>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3g
moL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN00L0kno_0`3gmoL50>o_k`80moOg00<0lo?c0>o_k`3_
knl01@3gmoL00`3clo<0kno_0>o_k`020>o_k`030??cl`3gmoL0moOg00X0kno_0`3gmoL20>o_k`80
moOg00<0lo?c0>o_k`3_knl0203_knl50?Ogm`D0kno_00<0lo?c0?Ogm`3gmoL01`3_knl60=kNgP80
Lg=c1`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<;0>o_k`04
0??cl`3gmoL0moOg0??cl`@0kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`0300P8
2080a/K600<0fm_K0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`02000000X0kno_00<0N7Qh0000
000000000P3_knl0101hN7P000000000001lO7`20?Ogm`D0kno_0P3gmoL00`1lO7`0000000000003
0>o_k`80moOg00<0gmoO0<K6aP36a/H00P0820P;0>o_k`80moOg3`3_knl00`3Shn<0e]KF0=KFeP02
08B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Fe]H00`3Jf]X0g]kN0=kNgP070>o_k`<0moOg1@3_knl2
0?Ogm`030??cl`3_knl0kno_00D0moOg00<0lo?c0>o_k`3_knl00P3_knl00`3clo<0moOg0?Ogm`0:
0>o_k`<0moOg0P3_knl20?Ogm`030??cl`3_knl0kno_00P0kno_1@3gmoL50>o_k`030??cl`3gmoL0
moOg00L0kno_1P3Ng]h207=cL`L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_
0080Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h<0>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c
0>o_k`3_knl01@3gmoL506][J`030;6a/@3gmoL0moOg00D0kno_3`0000020?Ogm`0307alO0000000
000000d000000`3gmoL20>o_k`030:f][@1[Jf/0Jf][0080Jf][203_knl30?Ogm`80kno_0P3gmoL0
0`3clo<0kno_0>o_k`080>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P24Q8@00`2j^[X0kno_0>o_k`03
08B4Q080c/k>00<0gmoO0>o_k`3_knl02P3_knl50?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL0
103clo<0kno_0>o_k`3clo<20?Ogm`l0kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg00<0moOg0P3_
knl00`3clo<0moOg0?Ogm`050>o_k`80moOg00<0lo?c0>o_k`3_knl01@3_knl00`3WinL0g]kN0=kN
gP050>o_k`<0g]kN0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>
c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@02
0?Ogm`030??cl`3_knl0kno_0080Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h<0>o_k`030??cl`3g
moL0moOg0080moOg00<0lo?c0>o_k`3_knl01@3gmoL506][J`030;6a/@3gmoL0moOg00D0kno_3`00
00020?Ogm`0307alO0000000000000d000000`3gmoL20>o_k`030:f][@1[Jf/0Jf][0080Jf][203_
knl30?Ogm`80kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P24
Q8@00`2j^[X0kno_0>o_k`0308B4Q080c/k>00<0gmoO0>o_k`3_knl02P3_knl50?Ogm`80kno_00<0
lo?c0?Ogm`3gmoL00P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`l0kno_1@3gmoL20>o_k`030??c
l`3gmoL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`80moOg00<0lo?c0>o_k`3_knl0
1@3_knl00`3WinL0g]kN0=kNgP050>o_k`<0g]kN0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_
00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080Q8B400@0ZJVY0<k>cP3>c/h0e]KF
0P3Ng]h<0>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl01@3gmoL506][J`030;6a
/@3gmoL0moOg00D0kno_3`0000020?Ogm`0307alO0000000000000d000000`3gmoL20>o_k`030:f]
[@1[Jf/0Jf][0080Jf][203_knl30?Ogm`80kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80g]kN
00<0f][J0=KFeP3Fe]H00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080c/k>00<0gmoO0>o_k`3_knl0
2P3_knl50?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`l0
kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`80
moOg00<0lo?c0>o_k`3_knl01@3_knl00`3WinL0g]kN0=kNgP050>o_k`<0g]kN0P24Q8@20>o_k`03
0??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0
f][J103Ng]h30>o_k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN0180
kno_0P3gmoL60>o_k`80g]kN0P3_knl00`3WinL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OW
i`@0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP080>o_k`80moOg3`3_knl00`3W
inL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`80kno_0P3Ng]h00`3Jf]X0e]KF0=KFeP02
07]kN`030;Vi^@3gmoL0moOg00<0Q8B40P3Ng]h00`3Jf]X0e]KF0=KFeP020=kNgP<0kno_0P3Ng]h5
0>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h03`3_knl00`3clo<0moOg0?Ogm`08
0>o_k`80g]kN0P3_knl00`3WinL0g]kN0=kNgP030>o_k`80g]kN00<0inOW0>o_k`3_knl00P3_knl0
0`3WinL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`@0kno_00<0lo?c0?Ogm`3gmoL00P3_
knl30=kNgP<0e]KF0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040:f][@3Fe]H0
e]KF0=[JfP@0g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kN
gP0B0>o_k`80moOg1P3_knl20=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kN
gP3WinL40>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h0203_knl20?Ogm`l0kno_
00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80g]kN00<0f][J0=KFeP3F
e]H00P1kNg/00`2i^KT0moOg0?Ogm`0308B4Q080g]kN00<0f][J0=KFeP3Fe]H00P3Ng]h30>o_k`80
g]kN1@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00l0kno_00<0lo?c0?Ogm`3g
moL0203_knl20=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3_knl20=kNgP030>OWi`3_knl0kno_0080
kno_00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL40>o_k`030??cl`3gmoL0moOg
0080kno_0`3Ng]h30=KFeP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3WinL20<k>cP030<S8b032`/80`/;200D0no_k0P24Q8@0102[Zj/0
d];B0=;BdP3Hf=P40=kNgP<0inOW0P3Ng]h20>o_k`040>_[j`3WinL0inOW0>?Sh`80g]kN0P3_knl0
0`3WinL0g]kN0=kNgP050>OWi`<0kno_0P3WinL00`3]kNd0lo?c0??cl`050>OWi`80jn_[0`3_knl0
0`3[jn/0inOW0>OWi`020=kNgP80inO_00<0hn?W0=kNgP3Ng]h00P3WinL0103Shn<0g]kN0=kNgP3W
inL20>o_k`80inOW00<0hn?S0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>OWi`030>_[j`3_
knl0kno_0080jn_[0`3_knl80>OWi`80kno_0P3WinL00`3Shn<0g]kN0=kNgP020>OWk`040>?Si`3N
g]h0g]kN0>?Sh`80inOW0P3Ng]h00`3Hf=P0d];B0=;BdP020820P0030;jn_P3kno/0no_k00<0Q8B4
0P3Fe]H00`3Hf=P0f][J0=[JfP020=kNgP<0inOW0P3Ng]h30>o_k`80inOW00<0hn?S0=kNgP3Ng]h0
0P3_knl00`3WinL0g]kN0=kNgP050>OWi`030>_[j`3_knl0kno_0080inOW00<0jn_[0>o_k`3_knl0
0P3WinL00`3YjNT0jn_[0>_[j`030>OWi`80lo?c0`3WinL20=kNgP80inO_00<0hn?W0=kNgP3Ng]h0
0`3WinL20=kNgP030>OWi`3_knl0kno_0080inOW00<0hn?S0=kNgP3Ng]h00P3_knl0103WinL0g]kN
0=kNgP3Shn<40>OWi`030>g]k@3clo<0lo?c0080inOW0`3Ng]h30=;BdP80P8201`3kno/00`3Ogml0
`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6
aP2m_Kd0_Kfm00D0oooo0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3N
g]h00`3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN0`3_knl20=kNgP030>_[j`3gmoL0moOg00L0
g]kN0`3_knl00`3WinL0g]kN0=kNgP020=kNgP80g]k_00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0
kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP<0
kno_203Ng]h20>o_k`D0g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP030=KFeP3>c/h0c/k>0080
Q8B400<0`/;20?ooo`3oool00`24Q8@20<k>cP030=KFeP3Ng]h0g]kN00L0g]kN0`3_knl50=kNgP80
kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00P0
g]kN0P3gmoL50=kNgP80g]k_00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP80
kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0c/k>0P24Q8@70?ooo`03
0=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>
00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0
g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0jn_[0?Ogm`3g
moL01`3Ng]h30>o_k`030>OWi`3Ng]h0g]kN0080g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP03
0>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080
g]kN0`3_knl80=kNgP80kno_1@3Ng]h20=kNk`030=kNi`3Ng]h0g]kN00D0g]kN00<0e]KF0<k>cP3>
c/h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080c/k>00<0e]KF0=kNgP3Ng]h01`3Ng]h30>o_k`D0
g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN00<0inOW0>o_k`3_
knl0203Ng]h20?Ogm`D0g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0
g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q0L0
oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0
g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0
g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0
e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00D0e]KF00<0f][J0=kNgP3Ng]h01@3Ng]h20=KFePd0
g]kN0P3Ng]H0103Jf]H0e]KF0=KFeP3Jf]X20=kNgP80e]KF00<0d];B0<k>cP3>c/h00P24Q8@00`2n
_[h0moOg0?Ogm`0308B4Q080c/k>00<0e]KF0=kNgP3Ng]h00P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF
0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP050=kNgP030=[JfP3Fe]H0e]KF
0080e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h20=kNeP030=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KF
eP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL0
0`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>
cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h0
0`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h2
0=KFeP030=[JfP3Ng]h0g]kN00X0g]kN0P3Ng]H00`3Jf]H0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0
e]KF0080e]KF00<0f][J0=kNgP3Ng]h01@3Fe]H00`3Jf]X0g]kN0=kNgP050=kNgP80e]KF3@3Ng]h2
0=kNeP040=[JeP3Fe]H0e]KF0=[JfP80g]kN0P3Fe]H00`3Bd]80c/k>0<k>cP0208B4Q0030;jn_P3g
moL0moOg00<0Q8B40P3>c/h00`3Fe]H0g]kN0=kNgP020=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00D0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KF
eP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@70?Ogm`030=[J
fP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0
b/[:0<;2`P32`/801@3clo<20820P0040:^[Z`3Fe]H0e]KF0>7Qh@80jn_[0P3WinL:0>_[j`030>WY
j@3WinL0inOW0080inOW00<0jNWY0>_[j`3[jn/00P3WinL00`3YjNT0jn_[0>_[j`030>_[j`80kno_
00<0kNg]0>_[j`3[jn/03`3[jn/20>_[i`030>WYi`3WinL0inOW00X0jn_[00<0jNWY0>OWi`3WinL0
0P3WinL00`3YjNT0jn_[0>_[j`050>OWi`030>WYj@3[jn/0jn_[0080kno_4P3[jn/20>_[i`040>WY
i`3WinL0inOW0>WYj@80jn_[0P3Shn<00`3MgMd0e]KF0=KFeP0208B4Q0030;bl_03clo<0lo?c00<0
P8200P3Fe]H00`3QhN40jn_[0>_[j`020>OWi`X0jn_[00<0jNWY0>OWi`3WinL00P3WinL00`3YjNT0
jn_[0>_[j`020>OWi`030>WYj@3[jn/0jn_[00<0jn_[0P3_knl00`3[jn/0inOW0>OWi`0?0>_[j`80
jn_W00<0jNWW0>OWi`3WinL02P3[jn/00`3YjNT0inOW0>OWi`020>OWi`040>WYj@3[jn/0jn_[0>WY
j@80inOW1@3[jn/20>o_k`<0hn?S0`3Fe]H208B4Q0D0lo?c0P3gmoL00`3Jf]X0_Kfm0;fm_@030=;B
dP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
kno_0P1kNg/0102][Jd0g]kN0=kNgP3[jn/N0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3k
no/0moOg0?Ogm`0Y0?Ogm`80oooo0`3gmoL20?oooaD0moOg0P3_knl00`3WinL0g]kN0=kNgP0208B4
Q0030;Zj^P3_knl0kno_00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Ogm`0L0?Ogm`80oooo00<0no_k0?Og
m`3gmoL00P3oool00`3kno/0moOg0?Ogm`0Y0?Ogm`80oooo0`3_knl30=kNgP80Q8B41@3_knl20?Og
m`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
e]KF00<0b/[:0;fm_@2m_Kd01@3_knl207]kN`040:f][@3Ng]h0g]kN0>_[jah0moOg0P3oool00`3k
no/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg02T0moOg0P3oool30?Ogm`80oooo5@3gmoL20>o_
k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`1kNg/20=kNgP030>_[j`3gmoL0moOg
01`0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg02T0moOg0P3oool30>o_
k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080
Q8B400@0_[jn0?Ogm`3gmoL0no_kLP3oool208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3_knl00`3g
moL0oooo0?ooo`1G0?ooo`80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3g
moL00P24Q8@0102n_[h0moOg0?Ogm`3kno]b0?ooo`80Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20>o_
k`030?Ogm`3oool0oooo05L0oooo0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80d];B00<0b<S80;fm_@2m_Kd00P3oool00`3moOd0
no_k0?_kn`0208B4Q0040:6QX@2n_[h0_[jn0;jn_P80_Kfm0P36a/H30<;2`P80_Kfm0P32`/801034
a<@0a/K60<K6aP34a<@<0<;2`P<0_Kfm1@32`/820;fm_@030<30`032`/80`/;20080`/;20`36a/H0
0`34a<@0`/;20<;2`P020;fm_@80`/;200<0a<C40<K6aP36a/H00P32`/801030`<00_Kfm0;fm_@30
`<0A0<;2`P030<30`02m_Kd0_Kfm0080`/;20`36a/H20;fm_@H0`/;20P36a/H20<;2`P030<30`02m
_Kd0_Kfm00d0`/;20P24Q8@00`30`<00no_k0?_kn`0308B4Q080^[Zj00<0_;bl0;fm_@2m_Kd01@32
`/820;fm_@<0a/K63`32`/800`30`<00_Kfm0;fm_@050<;2`P80_Kfm00<0`<300<;2`P32`/800`36
a/H50<;2`P80_Kfm0P36a/H00`34a<@0`/;20<;2`P030<;2`P80_Kfm00<0`<300<;2`P32`/803`32
`/800`30`<00_Kfm0;fm_@020<K6aPH0`/;20P24Q8@70?_kn`030=oOg`32`/80`/;200<0d];B0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool5
08B4Q0030820P01kNg/0Ng]k0080S8b<0`24Q8@207]kN`80Q8B400@0R8R808b<S02<S8`0R8R83024
Q8@307]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00208B4Q0<0S8b<00<0R8R808B4Q024Q8@00P1k
Ng/208B4Q00308R8R02<S8`0S8b<0080Q8B400@0P82007]kN`1kNg/0P8204@24Q8@00`20P800Ng]k
07]kN`0208B4Q0<0S8b<0P1kNg/608B4Q080S8b<0P24Q8@00`20P800Ng]k07]kN`0?08B4Q0030<;2
`P3oool0oooo00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`<0S8b<3`24Q8@00`20P800Ng]k
07]kN`0508B4Q080Ng]k00<0P82008B4Q024Q8@00`2<S8`508B4Q080Ng]k0P2<S8`00`28R8P0Q8B4
08B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@03`24Q8@00`20P800Ng]k07]kN`0208b<S0P0Q8B4
1`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_
knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo1@24Q8@00`20P800Ng]k07]kN`0208b<S0<0Q8B40P1k
Ng/208B4Q00408R8R02<S8`0S8b<08R8R0`0Q8B40`1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@0
0P24Q8@308b<S00308R8R024Q8@0Q8B40080Ng]k0P24Q8@00`28R8P0S8b<08b<S00208B4Q0040820
P01kNg/0Ng]k0820P140Q8B400<0P82007]kN`1kNg/00P24Q8@308b<S080Ng]k1P24Q8@208b<S080
Q8B400<0P82007]kN`1kNg/03`24Q8@00`32`/80oooo0?ooo`0508B4Q0030820P01kNg/0Ng]k00D0
Q8B40P1kNg/308b<S0l0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kN`030820P024Q8@0Q8B400<0
S8b<1@24Q8@207]kN`80S8b<00<0R8R808B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400l0
Q8B400<0P82007]kN`1kNg/00P2<S8`808B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`D0_[jn
00<0_;bl0;Vi^@2i^KT00P32`/830;jn_P80^KVi0P2n_[h01030`<00`/;20<;2`P30`<0<0;jn_P<0
^KVi1@2n_[h20;Vi^@030;bl_02n_[h0_[jn0080_[jn0`32`/800`30`<00_[jn0;jn_P020;Vi^@80
_[jn00<0`<300<;2`P32`/800P2n_[h0102l_;`0^KVi0;Vi^@2l_;`A0;jn_P030;bl_02i^KT0^KVi
0080_[jn0`32`/820;Vi^@H0_[jn0P32`/820;jn_P030;bl_02i^KT0^KVi00l0_[jn00<0gMgM0?_k
n`3kno/01@2n_[h00`2l_;`0^KVi0;Vi^@050;jn_P80^KVi0`32`/8?0;jn_P030;bl_02i^KT0^KVi
00D0_[jn0P2i^KT00`2l_;`0_[jn0;jn_P030<;2`PD0_[jn0P2i^KT20<;2`P030<30`02n_[h0_[jn
00<0_[jn0P2i^KT00`2l_;`0_[jn0;jn_P0?0;jn_P030;bl_02i^KT0^KVi0080`/;2202n_[h70?_k
n`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0a/K60;fm_@2m_Kd0jP3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0>X0moOg00<0gmoO0<K6aP36a/H0
0`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6
aP050>o_k`80Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4
Q00508B4Q00308R8R02<S8`0S8b<0080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024
Q8@0Q8B400L0Q8B40`1kNg/00`20P800Q8B408B4Q00208B4Q0D0Ng]k1@24Q8@00`20P800Ng]k07]k
N`0:08B4Q0<0Ng]k1@24Q8@207]kN`/0Q8B40P1kNg/508B4Q0D0Ng]k00<0P82008B4Q024Q8@00P1k
Ng/00`20P800Q8B408B4Q00208B4Q0030;Zj^P3_knl0kno_00<0Lg=c1@24Q8@207]kN`D0Q8B40`1k
Ng/508B4Q080S8b<00<0R8R808B4Q024Q8@00P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0
P82008B4Q024Q8@02024Q8@207]kN`D0Q8B41@1kNg/308B4Q080S8b<00<0Q8B407]kN`1kNg/02P24
Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl2
07]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@01@24Q8@0
0`28R8P0S8b<08b<S00207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q007
08B4Q0<0Ng]k00<0P82008B4Q024Q8@00P24Q8@507]kN`D0Q8B400<0P82007]kN`1kNg/02P24Q8@3
07]kN`D0Q8B40P1kNg/;08B4Q080Ng]k1@24Q8@507]kN`030820P024Q8@0Q8B40080Ng]k00<0P820
08B4Q024Q8@00P24Q8@00`2j^[X0kno_0>o_k`0307=cL`D0Q8B40P1kNg/508B4Q0<0Ng]k1@24Q8@2
08b<S00308R8R024Q8@0Q8B40080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0
Q8B400P0Q8B40P1kNg/508B4Q0D0Ng]k0`24Q8@208b<S00308B4Q01kNg/0Ng]k00X0Q8B400<0P820
07]kN`1kNg/01@24Q8@507]kN`D0Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<c<c032`/80`/;200D0lo?c0P24Q8@0102K
Vi/0/K6a0;6a/@2h^;P20;jn_P80^KVi0`2n_[h20<;2`P80_Kfm202n_[h00`32`/80a/K60<K6aP02
0;Vi^@030;bl_02n_[h0_[jn00<0`/;20P2i^KT00`2l_;`0_[jn0;jn_P020<;2`P030<30`02n_[h0
_[jn0080`/;20`2i^KT00`2l_;`0_[jn0;jn_P020<;2`PD0^KVi0P2n_[h01030`<00`/;20<;2`P30
`<020;fm_@L0_[jn00<0`<300<;2`P32`/800`2i^KT50<;2`P80^KVi0`2n_[h20<;2`P<0_[jn0`32
`/820;Vi^@80_[jn00<0`<300<;2`P32`/801@2i^KT00`2l_;`0_[jn0;jn_P020;Vi^@030;Fe]@2a
/K40/K6a0080Q8B400<0_[jn0?Ogm`3gmoL00`1lO7`20;6a/@030;Rh^02n_[h0_[jn0080^KVi0`2n
_[h20<;2`P<0_Kfm1@2n_[h50<;2`P80^KVi00@0_;bl0;jn_P2n_[h0`<300P32`/820;Vi^@030;jn
_P32`/80`/;20080`/;200<0`<300;jn_P2n_[h00`32`/820;Vi^@<0_[jn0P32`/850;Vi^@<0_[jn
0P36a/H00`32`/80_Kfm0;fm_@070;jn_P040<30`032`/80`/;20<30`080_Kfm0P2n_[h00`30`<00
`/;20<;2`P050;Vi^@<0/K6a0P24Q8@70??cl`030=SHf02m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;Fe
]@3Ng]h0g]kN0>_[j`L0moOg103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0
moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool60?Ogm`80oooo1`3gmoL00`3kno/0
oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool00`3gmoL50?ooo`D0moOg0P3oool30?Ogm`<0
oooo103gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3o
ool00`24Q8@20=kNgP030>_[j`3gmoL0moOg00D0moOg1@3oool70?Ogm`030?_kn`3oool0oooo00D0
moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00<0
oooo1@3gmoL20?ooo`P0moOg1@3oool70?Ogm`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3kno/0
oooo0?ooo`050?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;Fe
]@3Ng]h0g]kN0>_[j`L0moOg103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0
moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool60?Ogm`80oooo1`3gmoL00`3kno/0
oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool00`3gmoL50?ooo`D0moOg0P3oool30?Ogm`<0
oooo103gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3o
ool00`24Q8@20=kNgP030>_[j`3gmoL0moOg00D0moOg1@3oool70?Ogm`030?_kn`3oool0oooo00D0
moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00<0
oooo1@3gmoL20?ooo`P0moOg1@3oool70?Ogm`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3kno/0
oooo0?ooo`050?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a
/@3Ng]h0g]kN0>o_kfl0oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080
g]kN00<0kno_0?ooo`3oool0E03oool30=kNgP80Q8B41`3oool00`3Shn<0a/K60<K6aP030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo
0P24Q8@0102a/K40g]kN0=kNgP3_knm_0?ooo`030>o_k`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3o
ool00`24Q8@20=kNgP030>o_k`3oool0oooo05@0oooo0`3Ng]h208B4Q0L0oooo00<0hn?S0<K6aP36
a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm
0;fm_@050?_kn`80Q8B400@0/K6a0=kNgP3Ng]h0kno_K`3oool00`3clo<0inOW0>OWi`0208B4Q003
0<30`03kno/0no_k00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`1D0?ooo`<0inOW0P24Q8@70?_kn`03
0=oOg`32`/80`/;200<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_kfl0oooo00<0moOg0>o_k`3_
knl00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0kno_0?ooo`3oool0E03oool30>o_k`80
Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knm_0?ooo`03
0?Ogm`3_knl0kno_0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>o_k`3oool0oooo05@0
oooo0`3_knl208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
jn_[0P3gmoM[0?ooo`80moOg00<0lo?c0>o_k`3_knl00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080
g]kN00<0jn_[0?Ogm`3gmoL0D@3oool30?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m
_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K6
0<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoM[0?ooo`80moOg00<0lo?c0>o_k`3_
knl00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0D@3oool30?Ogm`<0
g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0
jn_[0P3gmoM[0?ooo`80moOg00<0lo?c0>o_k`3_knl00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080
g]kN00<0jn_[0?Ogm`3gmoL0D@3oool30?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m
_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K6
0<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_5P3oool:000000030820P03oool0oooo00X0
000000<0P8200?ooo`3oool02@0000000`20P800oooo0?ooo`0c0?ooo`030>o_k`3Ng]h0g]kN0080
Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20>o_k`030??cl`3gmoL0moOg00L0oooo2P0000000`20P800
oooo0?ooo`0:000000030820P03oool0oooo00X00000:@3oool30=kNgP80S8b<1`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>
cP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knlF0?ooo`X0000000<0P8200?ooo`3o
ool02P0000000`20P800oooo0?ooo`09000000030820P03oool0oooo03<0oooo00<0kno_0=kNgP3N
g]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080kno_00<0lo?c0?Ogm`3gmoL01`3oool:00000003
0820P03oool0oooo00X0000000<0P8200?ooo`3oool02P00000Y0?ooo`<0g]kN0P2<S8`70?Ogm`03
0=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF
00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg503oool200000003
0820P03oool0oooo00<0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`8000001@3oool200000003
0820P03oool0oooo0340oooo0P3gmoL00`3[jn/0g]kN0=kNgP0207]kN`030;fm_@3oool0oooo00<0
S8b<0P3Ng]h00`3[jn/0moOg0?Ogm`070?ooo`<000001@3oool2000000030820P03oool0oooo00d0
oooo0P0000000`20P800oooo0?ooo`030?ooo`800000:@3oool30=kNgP80Q8B41`3oool00`3Ng]h0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:
bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogma@0oooo0P0000000`20P800
oooo0?ooo`030?ooo`80000000<0P8200?ooo`3oool03@3oool2000000D0oooo0P0000000`20P800
oooo0?ooo`0a0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P1kNg/00`2m_Kd0oooo0?ooo`0308b<S080
g]kN00<0jn_[0?Ogm`3gmoL01`3oool3000000D0oooo0P0000000`20P800oooo0?ooo`0=0?ooo`80
000000<0P8200?ooo`3oool00`3oool2000002T0oooo0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m
_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm
0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLD0?ooo`80000000<0P8200?ooo`3o
ool00`3oool2000000030820P03oool0oooo00d0oooo0P0000050?ooo`80000000<0P8200?ooo`3o
ool0<@3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool00`2<S8`20=kNgP03
0>_[j`3gmoL0moOg00L0oooo0`0000050?ooo`80000000<0P8200?ooo`3oool03@3oool200000003
0820P03oool0oooo00<0oooo0P00000Y0?ooo`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd0
1@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg503oool2000000030820P03oool0oooo00<0
oooo0P0000000`20P800oooo0?ooo`0:000000030820P03oool0oooo008000001@3oool200000003
0820P03oool0oooo03<0oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080
g]kN00<0jn_[0?Ogm`3gmoL01`3oool3000000D0oooo0P0000000`20P800oooo0?ooo`0:00000003
0820P03oool0oooo0080000000<0P8200?ooo`3oool00`3oool2000002H0oooo0`3gmoL30=kNgP80
Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogma@0
oooo0P0000000`20P800oooo0?ooo`030?ooo`80000000<0P8200?ooo`3oool02P0000000`20P800
oooo0?ooo`02000000D0oooo0P0000000`20P800oooo0?ooo`0c0?ooo`030>o_k`3Ng]h0g]kN0080
Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>_[j`3gmoL0moOg00L0oooo0`0000050?ooo`80
000000<0P8200?ooo`3oool02P0000000`20P800oooo0?ooo`02000000030820P03oool0oooo00<0
oooo0P00000V0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??c
l`3_knl0kno_0080Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knlD0?ooo`X0000000<0P8200?ooo`3o
ool03@3oool9000000030820P03oool0oooo0340oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q003
0;Zj^P3_knl0kno_00<0Q8B40P3Fe]H00`3WinL0moOg0?Ogm`070?ooo`X0000000<0P8200?ooo`3o
ool03@3oool:000002H0oooo0`3gmoL30>o_k`80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`03
0=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF
00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80
kno_503oool:000000030820P03oool0oooo00d0oooo2@0000000`20P800oooo0?ooo`0a0?ooo`80
moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080e]KF00<0inOW0?Ogm`3g
moL01`3oool:000000030820P03oool0oooo00d0oooo2P00000V0?ooo`<0moOg0`3_knl208B4Q080
kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;20080moOg00<0mOGe0??cl`3clo<0
0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`D0no_k3`3oool:0820P0030<30`03oool0oooo00d0
oooo2@20P8000`30`<00oooo0?ooo`0a0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2l_;`0
lo?c0??cl`0308B4Q080f][J00<0inOW0??cl`3clo<00P3kno/50?ooo`X0P82000<0`<300?ooo`3o
ool03@3oool:0820P2H0oooo0`3gmoL30>OWi`80P8200P3clo<00`3emOD0moOg0?Ogm`020??cl`03
0=_Kf`32`/80`/;200<0c/k>0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>
00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3gmoMV0?ooo`80
moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_
knl00P3gmoM?0?ooo`<0moOg0`3Ng]h207]kN`L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B4
00@0/K6a0=kNgP3Ng]h0kno_0P3oool50?OgmfH0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q003
0;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`020?Ogmdl0oooo0`3gmoL30=kNgP80
Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3[jn/20?Ogmf/0
oooo0P3gmoL00`3clo<0kno_0>o_k`0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3[jn/0
moOg0?Ogm`1A0?ooo`<0moOg0`3_knl208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k
00@0[Jf]0=kNgP3Ng]h0jn_[0P3gmoM[0?ooo`80moOg00<0lo?c0>o_k`3_knl00P24Q8@00`32`/80
oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0D@3oool30?Ogm`<0kno_0P24Q8@70?ooo`03
0=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>
00<0a/K60;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN0>_[j`80moOgJ`3oool20?Ogm`03
0??cl`3_knl0kno_0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[j`3gmoL0moOg0540
oooo0`3gmoL30>o_k`80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN
0=kNgP3[jn/40?OgmfT0oooo0P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0
Q8B40P3Ng]h00`3WinL0kno_0>o_k`020?ooo`<0moOgC03oool30?Ogm`<0g]kN0P24Q8@70?Ogm`03
0=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>
00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOgJ@3oool20>o_k`03
0>OWi`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_0080
oooo0`3gmoM<0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P050??cl`80Q8B4
00@0/K6a0=kNgP3Ng]h0jn_[0P3gmoL20?_knfT0oooo0P3clo<00`3YjNT0g]kN0=kNgP0208B4Q003
0;bl_03clo<0lo?c00<0Q8B40P3Ng]h00`3YjNT0lo?c0??cl`020?ooo`<0no_k@P3oool00`3moOd0
no_k0?_kn`070?ooo`<0moOg0`3Ng]h208B4Q0D0lo?c0P3gmoL00`3Jf]X0_Kfm0;fm_@030=;BdP80
inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_
0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmf/0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q003
0;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`170?ooo`030?_kn`3gmoL0moOg00L0
oooo0`3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q0040;6a
/@3Ng]h0g]kN0>_[j`80moOgJ`3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_
knl00`24Q8@20=kNgP030>_[j`3gmoL0moOg04L0oooo00<0no_k0?Ogm`3gmoL01`3oool30?Ogm`<0
g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080Q8B4
00@0/K6a0=kNgP3Ng]h0jn_[103gmoL30?ooo`80moOg3@3ooolS0000000407alO03gmoL0moOg0?_k
naH0oooo0`3gmoL20?ooo`<0moOg1`3oool00`3kno/0moOg0?Ogm`020?ooo`040?_kn`3gmoL0moOg
0?_kn`80oooo0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h0
0`3WinL0kno_0>o_k`020?ooo`<0moOg1@3oool70000000307alO03gmoL0moOg00d0oooo20000002
0?ooo`<0moOg8@3oool20?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h2
0=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?oo
o`030?_kn`3gmoL0moOg0080Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL30?ooo`80moOg3@3ooolS
0000000407alO03gmoL0moOg0?_knaH0oooo0`3gmoL20?ooo`<0moOg1`3oool00`3kno/0moOg0?Og
m`020?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn
_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`020?ooo`<0moOg1@3oool70000000307al
O03gmoL0moOg00d0oooo200000020?ooo`<0moOg8@3oool20?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg
00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3B
d]800`38b<P0_Kfm0;fm_@020?ooo`030?gmo@3kno/0no_k0080Q8B400@0/K6a0=kNgP3Ng]h0jn_[
0P3gmoL20?_kn`<0oooo103kno/00`3moOd0oooo0?ooo`080?ooo`80<S8b00<0?3`l04I6AP16ATH0
5`20P80207alO00307inOP20P800P8200080000000@0OWin0?_kn`3kno/0oOgm103oool00`3moOd0
no_k0?_kn`0?0?ooo`<0no_k0P3oool60?_kn`@0oooo00<0oOgm0?_kn`3kno/00P3oool00`3moOd0
no_k0?_kn`030?_kn`80lo?c00<0inOW0=[JfP3Jf]X00P24Q8@00`30`<00no_k0?_kn`0308B4Q080
g]kN00<0jn_[0?Ogm`3gmoL00P3oool50?_kn`<0oooo0P20P8000`10@4000000000000020820P003
0;jn_P3kno/0no_k0080no_k00<0oOgm0?ooo`3oool0203oool20820P0030410@0000000000000<0
P8200P3oool50?_kn`d0oooo0P3kno/00`3moOd0oooo0?ooo`0=0?ooo`80no_k0`3clo<30=[JfP80
Q8B41`3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`L0
oooo0P3gmoL00`3kno/0oooo0?ooo`080?ooo`80Hf=S00<0N7Qh08b<S02<S8`05`3oool20?Ogm`03
0?_kn`3oool0oooo0080000000<0P8200?ooo`3oool01@3oool00`3kno/0moOg0?Ogm`0G0?ooo`<0
moOg303oool00`3kno/0moOg0?Ogm`020?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3o
ool00`24Q8@20=kNgP030>o_k`3oool0oooo00D0oooo0P3gmoL50?ooo`030820P0000000000000D0
oooo0P3gmoL00`3kno/0oooo0?ooo`0:0?ooo`030820P0000000000000P0oooo0P3gmoL=0?ooo`80
moOg00<0no_k0?ooo`3oool03`3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd0
1@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg1`3oool20?Ogm`030?_kn`3oool0oooo00P0
oooo0P1SHf<00`1hN7P0S8b<08b<S00G0?ooo`80moOg00<0no_k0?ooo`3oool00P0000000`20P800
oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg01L0oooo0`3gmoL<0?ooo`030?_kn`3gmoL0moOg0080
moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0kno_0?ooo`3o
ool01@3oool20?Ogm`D0oooo00<0P8200000000000001@3oool20?Ogm`030?_kn`3oool0oooo00X0
oooo00<0P820000000000000203oool20?Ogm`d0oooo0P3gmoL00`3kno/0oooo0?ooo`0?0?ooo`<0
moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0
jn_[1`3gmoL40?ooo`040?_kn`3gmoL0moOg0?_kn`@0oooo00<0no_k0?Ogm`3gmoL00P3oool00`2Y
ZJT0DU9B059BDP0309bLW080oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`020?oo
o`H0moOg103oool00`3kno/0moOg0?Ogm`02000000040820P03oool0oooo0?_kn`80moOg2P3oool3
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool50?Ogm`H0oooo0P3gmoL50?ooo`X0moOg00<0lo?c
0>o_k`3_knl00P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0inOW0>o_k`3_knl01@3gmoL2
0?ooo`<0moOg0P3oool00`20P8000000000000020?Ogm`030?_kn`3oool0oooo00P0oooo0P3gmoL0
0`3kno/0oooo0?ooo`020?Ogm`0307alO0000000000000<0moOg1`3oool20?Ogm`030?_kn`3oool0
oooo00D0moOg00<0no_k0?ooo`3oool01`3oool0103kno/0moOg0?Ogm`3kno/20?ooo`80moOg00<0
no_k0?ooo`3oool00P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL2
08B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg103oool0103kno/0moOg0?Ogm`3kno/40?ooo`030?_k
n`3gmoL0moOg0080oooo00<0ZJVY059BDP1BDU800`2LW9`20?ooo`030?_kn`3gmoL0moOg0080oooo
00<0no_k0?Ogm`3gmoL00P3oool60?Ogm`@0oooo00<0no_k0?Ogm`3gmoL00P0000001020P800oooo
0?ooo`3kno/20?Ogm`X0oooo0`3gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo1@3gmoL60?ooo`80
moOg1@3oool:0?Ogm`030??cl`3_knl0kno_0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=kNgP03
0>OWi`3_knl0kno_00D0moOg0P3oool30?Ogm`80oooo00<0P8200000000000000P3gmoL00`3kno/0
oooo0?ooo`080?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL00`1lO7`00000000000030?Ogm`L0
oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo00L0oooo00@0no_k0?Ogm`3g
moL0no_k0P3oool20?Ogm`030?_kn`3oool0oooo0080moOg0`3_knl30=kNgP80Q8B41`3gmoL00`3O
gml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP03
0<[:bP32`/80`/;200D0lo?c0P24Q8@0102a/K40g]kN0=kNgP3YjNT20??cl`80moOg0`3kno/40?oo
o`040?gmo@3kno/0no_k0?gmo@@0oooo00<0oOgm0?_kn`3kno/00P3oool00`3De=@0ZJVY0:VYZ@03
06][J`80hn?S00<0kno_0?_kn`3kno/00P3oool00`3moOd0no_k0?_kn`080?_kn`@0oooo00<0oOgm
0?_kn`3kno/00P0000001020P800oooo0?ooo`3moOd40?_kn`030?gmo@3oool0oooo0080no_k00<0
oOgm0?ooo`3oool00`3kno/20?ooo`030?gmo@3kno/0no_k00L0no_k1P3oool20?_kn`D0oooo0P3k
no/0103inOT0moOg0?Ogm`3inOT20?_kn`80lo?c00<0kNg]0>OWi`3WinL00P24Q8@00`2l_;`0lo?c
0??cl`030820P080g]kN00<0jNWY0??cl`3clo<00P3kno/30?Ogm`80oooo0`3kno/20?ooo`030820
P000000000000080no_k00<0oOgm0?ooo`3oool00P3oool0103moOd0no_k0?_kn`3moOd20?ooo`80
no_k00<0oOgm0?ooo`3oool00P3kno/00`1nOWh00000000000030?_kn`L0oooo0P3kno/00`3moOd0
oooo0?ooo`080?_kn`80oooo00<0oOgm0?_kn`3kno/00P3oool0103moOd0no_k0?_kn`3moOd20?oo
o`D0no_k0P3gmoL30??cl`<0g]kN0P24Q8@70??cl`030=_Kf`32`/80`/;200<0c/k>0P3WinL00`3_
knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl208B4Q004
0;6a/@3Ng]h0g]kN0>OWi`80kno_0P3gmoLG0?ooo`<0>CTi0P36a/H00`3Shn<0oooo0?ooo`050?oo
o`80moOg3@3oool2000000030820P03oool0oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?Og
m`030?_kn`3oool0oooo00P0oooo0P3gmoLD0?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P3_knl0
0`3WinL0g]kN0=kNgP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`02
0?ooo`<0moOg1`3oool00`20P8000000000000070?ooo`040?_kn`3gmoL0moOg0?_kn`T0oooo00<0
P820000000000000503oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00X0oooo00<0
no_k0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0
102a/K40g]kN0=kNgP3WinL20>o_k`80moOg5`3oool303Ti>@80a/K600<0hn?S0?ooo`3oool01@3o
ool20?Ogm`d0oooo0P0000000`20P800oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool00P3g
moL00`3kno/0oooo0?ooo`080?ooo`80moOg503oool0103kno/0moOg0?Ogm`3kno/20?ooo`80kno_
00<0inOW0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0
0P3oool30?Ogm`L0oooo00<0P8200000000000001`3oool0103kno/0moOg0?Ogm`3kno/90?ooo`03
0820P0000000000001@0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`0:0?ooo`03
0?_kn`3gmoL0moOg00D0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3<c<`0`/;20<;2`P050??cl`80R8R8
00@0/k>c0=kNgP3Ng]h0jNWY0P3clo<50?_kn`80oooo0P3kno/0103moOd0oooo0?ooo`3moOd40?_k
n`030?gmo@3oool0oooo0080no_k00<0oOgm0?ooo`3oool00`2DU9@207QhN0030:j^[P3Shn<0hn?S
0080oooo00<0oOgm0?_kn`3kno/00P3kno/30?ooo`030?gmo@3kno/0no_k0080oooo0P3kno/00`3m
oOd0oooo0?ooo`0207alO0040;bl_03kno/0no_k0?gmo@80oooo0P3gmoL00`3kno/0oooo0?ooo`05
0?_kn`D0oooo00<0oOgm0?_kn`3kno/00P3kno/30?ooo`80no_k0`3oool30?_kn`80oooo1@3kno/2
0?ooo`040?_kn`3gmoL0moOg0?Win@80no_k0P3clo<00`3WinL0f][J0=[JfP0208B4Q0030;jn_P3g
moL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`070?_kn`<0oooo0P3kno/00`1nOWh000000000
00020?ooo`030?gmo@3kno/0no_k0080oooo00<0oOgm0?_kn`3kno/00`3kno/50?ooo`80no_k00<0
OWin0000000000000`3oool20?_kn`<0oooo0P3kno/20?ooo`030?gmo@3kno/0no_k00<0no_k0P3o
ool00`3kno/0moOg0?Ogm`020?ooo`030?gmo@3kno/0no_k0080no_k00<0oOgm0?ooo`3oool00`3o
ool70?_kn`<0lo?c0`3Ng]h208B4Q0L0lo?c00<0f=SH0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3g
moL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe
0=kNgP3Ng]h0jn_[0P3gmoL20?ooo`<0moOg0P3oool20?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg
00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`030>o_k`80:BTY00<0N7Qh0<K6aP36a/H0
0P3oool00`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg0080oooo0P3gmoL00`3kno/0oooo
0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg
0?Ogm`050?ooo`030?_kn`3gmoL0moOg00D0oooo0P3gmoL30?ooo`<0moOg0P3oool50?Ogm`80oooo
00<0no_k0?Ogm`3gmoL01@3gmoL00`3WinL0e]KF0=KFeP0208B4Q0030<;2`P3oool0oooo00<0Q8B4
0P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`<0oooo0P3gmoL30?ooo`80moOg00<0O7al000000000000
0P3oool00`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg00D0oooo0P3gmoL00`1lO7`00000
000000030?ooo`80moOg0`3oool20?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_k
n`3gmoL0moOg00D0oooo0P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool0
0P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;Fe]@3N
g]h0g]kN0>_[j`80moOg0P3oool30?Ogm`80oooo0P3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`03
0?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00`3_knl202TY:@0307QhN036a/H0a/K60080
oooo00<0no_k0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`020?ooo`80moOg00<0no_k0?ooo`3o
ool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3g
moL01@3oool00`3kno/0moOg0?Ogm`050?ooo`80moOg0`3oool30?Ogm`80oooo1@3gmoL20?ooo`03
0?_kn`3gmoL0moOg00D0moOg00<0inOW0=KFeP3Fe]H00P24Q8@00`32`/80oooo0?ooo`0308B4Q080
g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL30?ooo`80moOg0`3oool20?Ogm`0307alO000000000000080
oooo00<0no_k0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`050?ooo`80moOg00<0O7al00000000
00000`3oool20?Ogm`<0oooo0P3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0
moOg0?Ogm`050?ooo`80moOg00<0no_k0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo0080
oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN
0=kNgP3WinL20>o_k`80moOg1@3oool20?Ogm`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3kno/0
oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00<0oooo0P3Ng]h00`1gMgL0410@010@40020<K6aP03
0>?Sh`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3oool20?Ogm`030?_kn`3oool0oooo0080
oooo00@0no_k0?Ogm`3gmoL0no_k103oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg
00P0oooo1@3gmoL50?ooo`<0moOg103oool00`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg
0080oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0inOW0>o_
k`3_knl01@3oool20?Ogm`D0oooo00<0P8200000000000001@3oool20?Ogm`040?_kn`3oool0oooo
0?_kn`80moOg1`3oool00`20P8000000000000030?Ogm`D0oooo103gmoL00`3kno/0oooo0?ooo`05
0?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`05
0?ooo`030?_kn`3gmoL0moOg0080moOg0`3oool30=kNgP80Ng]k1`3oool00`3Shn<0a/K60<K6aP03
0<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm
00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg1@3oool20?Ogm`030?_kn`3oool0
oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00<0oooo0P3Ng]h0
0`1gMgL0410@010@40020<K6aP030>?Sh`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3oool2
0?Ogm`030?_kn`3oool0oooo0080oooo00@0no_k0?Ogm`3gmoL0no_k103oool00`3kno/0moOg0?Og
m`020?ooo`030?_kn`3gmoL0moOg00P0oooo1@3gmoL50?ooo`<0moOg103oool00`3kno/0moOg0?Og
m`050?ooo`030?_kn`3gmoL0moOg0080oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?oo
o`0308B4Q080g]kN00<0inOW0>o_k`3_knl01@3oool20?Ogm`D0oooo00<0P8200000000000001@3o
ool20?Ogm`040?_kn`3oool0oooo0?_kn`80moOg1`3oool00`20P8000000000000030?Ogm`D0oooo
103gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool0
0P3gmoL00`3kno/0oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg0080moOg0`3oool30=kNgP80Ng]k
1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102_[jl0f][J0=[JfP3UiND20>o_k`D0no_k
0P3oool20?Ogm`040?_kn`3oool0oooo0?gmo@`0no_k0`3oool20>_[j`030:VYZ@1WIfL0IfMW0080
N7Qh00<0];Bd0>o_k`3_knl00P3gmoL80?_kn`80moOg00<0no_k0?ooo`3oool03`3kno/00`3inOT0
moOg0?Ogm`030?_kn`D0P8201@1lO7`50820P0<0moOg0P3oool=0?_kn`80moOg00<0jNWY0=[JfP3J
f]X00P24Q8@00`30`<00no_k0?_kn`030820P080g]kN00<0jNWY0??cl`3clo<01@3kno/20?Ogm`<0
oooo0P3kno/00`1nOWh00000000000070?_kn`040?gmo@3oool0oooo0?_kn`80moOg1`3kno/00`1n
OWh00000000000050?_kn`<0oooo0P3gmoL80?_kn`80moOg00<0nOWi0?_kn`3kno/00P1lO7`00`1n
OWh0P8200820P00207alO00307inOP20P800P82000D0P82000<0_;bl0?Ogm`3gmoL00P3kno/30?Og
m`<0g]kN0P20P8070?_kn`030=oOg`32`/80`/;200<0d];B0P3WinL00`3_knl0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?S
h`80kno_0P3oool30?Ogm`80oooo0P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80oooo00<0no_k
0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0f][J0;fm_@2m_Kd00P0Y:BT0
0`24Q8@0g]kN0=kNgP020?Ogm`<0oooo00<0no_k0?Ogm`3gmoL0103gmoL00`3kno/0oooo0?ooo`02
0?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool0203gmoL?000000<0moOg0P3o
ool20?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3_knl00`3Shn<0e]KF0=KF
eP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Ogm`070?Ogm`<0oooo0P3g
moL00`1lO7`00000000000050?Ogm`D0oooo00<0no_k0?Ogm`3gmoL01`3gmoL00`1lO7`000000000
00030?ooo`80moOg0`3oool20?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3oool50?Ogm`l0000000<0
O7al0?Ogm`3gmoL00P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL2
08B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_0P3oool30?Ogm`80oooo0P3gmoL0103kno/0oooo0?oo
o`3kno/20?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg
00<0f][J0;fm_@2m_Kd00P0Y:BT00`24Q8@0g]kN0=kNgP020?Ogm`<0oooo00<0no_k0?Ogm`3gmoL0
103gmoL00`3kno/0oooo0?ooo`020?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3o
ool0203gmoL?000000<0moOg0P3oool20?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3o
ool00P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3[jn/0
moOg0?Ogm`070?Ogm`<0oooo0P3gmoL00`1lO7`00000000000050?Ogm`D0oooo00<0no_k0?Ogm`3g
moL01`3gmoL00`1lO7`00000000000030?ooo`80moOg0`3oool20?Ogm`80oooo00<0no_k0?Ogm`3g
moL00`3oool50?Ogm`l0000000<0O7al0?Ogm`3gmoL00P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`03
0=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>
00<0b/[:0<K6aP36a/H01@3_knl208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_1@3gmoL20?ooo`D0
moOg00<0no_k0?ooo`3oool01@3oool80?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P36a/H00`1_Kfl0
61PH01PH60020=kNgPd0moOg203oool20?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3o
ool00`3oool?000000<0moOg2@3oool00`3kno/0moOg0?Ogm`030?Ogm`80kno_00<0inOW0=kNgP3N
g]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL02P3gmoL20?ooo`03
0820P000000000000080oooo00<0no_k0?Ogm`3gmoL00P3oool0103kno/0moOg0?Ogm`3kno/20?oo
o`80moOg00<0no_k0?ooo`3oool00P3gmoL00`1lO7`00000000000050?Ogm`<0oooo0P3gmoL:0?oo
o`030?_kn`3gmoL0moOg00l0000000<0O7al0?Ogm`3gmoL00P3gmoL30>o_k`<0g]kN0P24Q8@50>o_
k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl50?Og
m`80oooo1@3gmoL00`3kno/0oooo0?ooo`050?ooo`P0moOg0P3oool00`3kno/0moOg0?Ogm`020<K6
aP0306m_K`0H61P061PH0080g]kN3@3gmoL80?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL00`3k
no/0oooo0?ooo`030?ooo`l000000`3gmoL90?ooo`030?_kn`3gmoL0moOg00<0moOg0P3_knl00`3W
inL0g]kN0=kNgP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`0:0?Og
m`80oooo00<0P8200000000000000P3oool00`3kno/0moOg0?Ogm`020?ooo`040?_kn`3gmoL0moOg
0?_kn`80oooo0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`0307alO0000000000000D0moOg0`3oool2
0?Ogm`X0oooo00<0no_k0?Ogm`3gmoL03`0000000`1lO7`0moOg0?Ogm`020?Ogm`<0kno_0`3Ng]h2
08B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/9
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0
oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`030<;2`P2<S8`0S8b<0080410@0`3Ng]h0
0`3[jn/0moOg0?Ogm`020?Ogm`80oooo00<0no_k0?Ogm`3gmoL02P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`030?_kn`3gmoL0moOg00<0oooo3`0000030?oooa40moOg00<0jn_[0=kNgP3Ng]h00P24Q8@0
0`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl01@3gmoL20?ooo`D0moOg00<0O7al
0000000000000P3oool00`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k
0?Ogm`3gmoL00P3gmoL00`1lO7`00000000000030?Ogm`80oooo0`3gmoL20?ooo`P0moOg0P3oool0
0`3kno/0moOg0?Ogm`0?000000030820P03oool0oooo00D0moOg0`3Fe]H208b<S0L0moOg00<0gmoO
0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>
c/h0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[2@3gmoL20?ooo`030?_kn`3gmoL0
moOg00D0moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k
0?ooo`3oool00P3gmoL00`32`/80S8b<08b<S002010@40<0g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL2
0?ooo`030?_kn`3gmoL0moOg00X0moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`03
0?ooo`l000000`3ooolA0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@2
0=kNgP030>OWi`3_knl0kno_00D0moOg0P3oool50?Ogm`0307alO000000000000080oooo00<0no_k
0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg0080moOg00<0O7al
0000000000000`3gmoL20?ooo`<0moOg0P3oool80?Ogm`80oooo00<0no_k0?Ogm`3gmoL03`000000
0`20P800oooo0?ooo`050?Ogm`<0e]KF0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4
Q0040;6a/@3Ng]h0g]kN0>_[j`T0moOg0P3oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0
oooo0080moOg00<0no_k0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo0080moOg00<0`/;2
08b<S02<S8`00P0@41030=kNgP030>_[j`3gmoL0moOg0080moOg0P3oool00`3kno/0moOg0?Ogm`0:
0?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL00`3oool?000000<0oooo4@3gmoL0
0`3[jn/0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`05
0?Ogm`80oooo1@3gmoL00`1lO7`00000000000020?ooo`030?_kn`3gmoL0moOg00D0oooo00<0no_k
0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`020?Ogm`0307alO0000000000000<0moOg0P3oool3
0?Ogm`80oooo203gmoL20?ooo`030?_kn`3gmoL0moOg00l0000000<0P8200?ooo`3oool01@3gmoL3
0=KFeP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL2
0>o_k`80moOg0`3oool70?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL0
0`3kno/0oooo0?ooo`0:0?Ogm`030?_kn`3oool0oooo0080BTY:0`1[Jf/00`2e]KD0oooo0?ooo`07
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`080?Ogm`l000001@3gmoL2
0?ooo`030?_kn`3gmoL0moOg0080moOo00@0moOk0?Ogm`3gmoL0no_k0P3oool20>o_k`030>OWi`3N
g]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool00`2<S8`20=KFeP030>OWi`3gmoL0moOg0080oooo203g
moL20?ooo`030820P0000000000000D0moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80oooo00<0
P8200000000000000`3gmoL20?ooo`L0moOg00<0no_k0?ooo`3oool00`3gmoL20?ooo`030?_kn`3g
moL0moOg00l0000000<0O7al0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm
_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0
_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg0`3oool70?Ogm`030?_kn`3o
ool0oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030?_kn`3o
ool0oooo0080BTY:0`1[Jf/00`2e]KD0oooo0?ooo`070?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3g
moL00`3kno/0oooo0?ooo`080?Ogm`l000001@3gmoL20?ooo`030?_kn`3gmoL0moOg0080moOo00@0
moOk0?Ogm`3gmoL0no_k0P3oool20>o_k`030>OWi`3Ng]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool0
0`2<S8`20=KFeP030>OWi`3gmoL0moOg0080oooo203gmoL20?ooo`030820P0000000000000D0moOg
0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80oooo00<0P8200000000000000`3gmoL20?ooo`L0moOg
00<0no_k0?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0moOg00l0000000<0O7al0?Ogm`3gmoL0
1@3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kN
gP3WinL20>o_k`80moOg0`3oool70?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool0
0P3gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030?_kn`3oool0oooo0080BTY:0`1[Jf/00`2e]KD0oooo
0?ooo`070?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`080?Ogm`l00000
1@3gmoL20?ooo`030?_kn`3gmoL0moOg0080moOo00@0moOk0?Ogm`3gmoL0no_k0P3oool20>o_k`03
0>OWi`3Ng]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool00`2<S8`20=KFeP030>OWi`3gmoL0moOg0080
oooo203gmoL20?ooo`030820P0000000000000D0moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80
oooo00<0P8200000000000000`3gmoL20?ooo`L0moOg00<0no_k0?ooo`3oool00`3gmoL20?ooo`03
0?_kn`3gmoL0moOg00l0000000<0O7al0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6
aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinLK0?Ogm`<0oooo1@3gmoL20?ooo`03
0<K6aP2<S8`0S8b<008061PH0`3Ng]h00`3[jn/0moOg0?Ogm`0L0?Ogm`l00000503gmoL00`3[jn/0
g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`0<0?Ogm`03
07alO0000000000000L0moOg00@0no_k0?ooo`3oool0no_k2@3gmoL00`1lO7`000000000000G0?Og
m`l0000000<0O7al0?Ogm`3gmoL00P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m
_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWia/0moOg0`3oool50?Ogm`80oooo00<0a/K608b<
S02<S8`00P0H61P30=kNgP030>_[j`3gmoL0moOg01`0moOg3`00000D0?Ogm`030>_[j`3Ng]h0g]kN
0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_00`0moOg00<0O7al0000
000000001`3gmoL0103kno/0oooo0?ooo`3kno/90?Ogm`0307alO0000000000001L0moOg3`000000
0`1lO7`0moOg0?Ogm`020?Ogm`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H2
0=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Og
m`030??cl`3_knl0kno_0080Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl<0?Ogm`030?_kn`3oool0
oooo00D0moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80[Jf]00<0Fe]K00P8200820P00P3Ng]h=
0?Ogm`D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`080?Ogm`l000001@3gmoL5
0?ooo`80moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0
^[Zj0>o_k`3_knl00`24Q8@20=KFeP030>OWi`3gmoL0moOg0080moOg0`3oool50?Ogm`80oooo00<0
P8200000000000000P3gmoL00`3kno/0oooo0?ooo`0?0?Ogm`0307alO0000000000000D0moOg0`3o
ool40?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool03`0000000`1lO7`0moOg0?Og
m`020?Ogm`<0kno_0`3Ng]h208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm
_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0
_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k``0moOg00<0
no_k0?ooo`3oool01@3gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg0P2][Jd00`1KFe/020P800P8
20020=kNgPd0moOg1@3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00P0moOg3`00
00050?Ogm`D0oooo0P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80kno_00<0inOW0=kNgP3Ng]h0
0P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080e]KF00<0inOW0?Ogm`3gmoL00P3gmoL30?ooo`D0moOg
0P3oool00`20P8000000000000020?Ogm`030?_kn`3oool0oooo00l0moOg00<0O7al000000000000
1@3gmoL30?ooo`@0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`0?0000000307al
O03gmoL0moOg0080moOg0`3_knl30=kNgP80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KF
eP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0
b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_
303gmoL00`3kno/0oooo0?ooo`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20:f][@0305]K
F`0820P020P80080g]kN3@3gmoL50?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL0
203gmoL?000000D0moOg1@3oool20?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P3_knl00`3WinL0
g]kN0=kNgP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Fe]H00`3WinL0moOg0?Ogm`020?Ogm`<0
oooo1@3gmoL20?ooo`030820P000000000000080moOg00<0no_k0?ooo`3oool03`3gmoL00`1lO7`0
0000000000050?Ogm`<0oooo103gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo00l0
000000<0O7al0?Ogm`3gmoL00P3gmoL30>o_k`<0g]kN0P24Q8@20>o_k`030??cl`3gmoL0moOg0080
kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL30>o_kaT0
moOg00<0f][J0;fm_@2m_Kd00P0820P00`1WIfL0a/K60<K6aP020?ooo`d0moOg0P3oool00`3kno/0
moOg0?Ogm`0B0?Ogm`030?_kn`3oool0oooo0080oooo3@3gmoL20?ooo`030?_kn`3gmoL0moOg00P0
moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0
kno_0>o_k`020>o_k`X0moOg00<0O7al000000000000503gmoL00`1lO7`000000000000T0?Ogm`D0
oooo0P3gmoL30>o_k`<0e]KF0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a
/@3Ng]h0g]kN0>_[j`@0moOg0`3_knlI0?Ogm`030=[JfP2m_Kd0_Kfm008020P800<0IfMW0<K6aP36
a/H00P3oool=0?Ogm`80oooo00<0no_k0?Ogm`3gmoL04P3gmoL00`3kno/0oooo0?ooo`020?ooo`d0
moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80kno_00<0hn?S0=KFeP3Fe]H00P24Q8@00`2n_[h0
moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl00P3_knl:0?Ogm`0307alO0000000000001@0
moOg00<0O7al000000000000903gmoL50?ooo`80moOg0`3_knl30=KFeP80Ng]k1`3gmoL00`3Ogml0
a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6
aP2m_Kd0_Kfm00D0oooo0P1kNg/0102YZJT0e]KF0=KFeP3Shn<20>o_k``0moOg00<0lo?c0>o_k`3_
knl03@3gmoL20<K6aP0306MWI`0820P020P80080_Kfm00<0f][J0?Ogm`3gmoL0?`3gmoL0103clo<0
kno_0>o_k`3clo<40?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=KF
eP030>?Sh`3_knl0kno_00X0moOg0P3_knl00`1hN7P000000000000:0?Ogm`030?_kn`3oool0oooo
00L0moOg00<0O7al0000000000001@3gmoL30?ooobH0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0
_Kfm0;fm_@050?ooo`80Ng]k00@0ZJVY0=KFeP3Fe]H0hn?S0P3_knl<0?Ogm`030??cl`3_knl0kno_
00d0moOg0P36a/H00`1WIfL020P800P820020;fm_@030=[JfP3gmoL0moOg03l0moOg00@0lo?c0>o_
k`3_knl0lo?c103gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Fe]H0
0`3Shn<0kno_0>o_k`0:0?Ogm`80kno_00<0N7Qh0000000000002P3gmoL00`3kno/0oooo0?ooo`07
0?Ogm`0307alO0000000000000D0moOg0`3ooolV0?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>00<0b<S80<;2
`P32`/801@3kno/20820P0040:^[Z`3Fe]H0e]KF0>?Sh`80kno_0P3clo<:0?Ogm`030??cl`3_knl0
kno_00D0moOg0P3kno/00`3inOT0moOg0?Ogm`030>_[j`80Kfm_00<0GEeM04Y:BP1:BTX00P3Jf]X0
0`3YjNT0moOg0?Ogm`0<0?Ogm`030;Zj^P1lO7`0O7al00P0moOg0P3kno/00`3inOT0moOg0?Ogm`0V
0?Ogm`030?Gem@3clo<0lo?c0080lo?c00<0inOW0=[JfP3Jf]X00P24Q8@00`30`<00no_k0?_kn`03
08B4Q080f][J00<0iNGU0>o_k`3_knl00P3gmoL30??cl`D0moOg0P3_knl00`1hN7P0000000000002
0?Ogm`030?Win@3kno/0no_k00D0moOg00<0nOWi0?_kn`3kno/01`3gmoL00`1lO7`0000000000005
0?Ogm`<0no_k303gmoL00`3inOT0no_k0?_kn`0B0?Ogm`D0lo?c0`3Jf]X208B4Q0L0no_k00<0g=cL
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:
b/X0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S103_knl:0?Ogm`030??cl`3_knl0
kno_00D0moOg0P3oool00`3kno/0moOg0?Ogm`030=kNgP8061PH00<0DU9B08b<S02<S8`04@3gmoL0
0`1lO7`00000000000080?Ogm`80oooo00<0no_k0?Ogm`3gmoL08`3gmoL0103kno/0oooo0?ooo`3g
moL40>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_
knl0kno_0080moOg0`3_knl50?Ogm`80kno_00<0N7Qh0000000000000P3gmoL00`3kno/0oooo0?oo
o`0?0?Ogm`0307alO0000000000001@0moOg00<0no_k0?ooo`3oool04P3gmoL50>o_k`<0e]KF0P24
Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`@0kno_2P3g
moL00`3clo<0kno_0>o_k`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3Ng]h201PH6003059BDP2<
S8`0S8b<0140moOg00<0O7al000000000000203gmoL20?ooo`030?_kn`3gmoL0moOg02<0moOg00@0
no_k0?ooo`3oool0moOg103_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B4
0P3Ng]h00`3WinL0kno_0>o_k`020?Ogm`<0kno_1@3gmoL20>o_k`0307QhN000000000000080moOg
00<0no_k0?ooo`3oool03`3gmoL00`1lO7`000000000000D0?Ogm`030?_kn`3oool0oooo0180moOg
1@3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P1kNg/0102YZJT0e]KF0=KF
eP3Shn<20>o_kaH0moOg00<0jn_[0=kNgP3Ng]h00`0H61P208b<S0030<;2`P3gmoL0moOg0140moOg
00<0O7al0000000000001@3gmoL00`3kno/0oooo0?ooo`0^0?Ogm`80kno_00<0hn?S0=KFeP3Fe]H0
0P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0inOW0>o_k`3_knl0303gmoL00`1lO7`00000
0000000D0?Ogm`0307alO0000000000002@0moOg0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`<0kno_
0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P1kNg/0102YZJT0e]KF0=KF
eP3Shn<20>o_kaH0moOg00<0jn_[0=kNgP3Ng]h00`0H61P208b<S0030<;2`P3gmoL0moOg0140moOg
00<0O7al0000000000001@3gmoL00`3kno/0oooo0?ooo`0^0?Ogm`80kno_00<0hn?S0=KFeP3Fe]H0
0P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0inOW0>o_k`3_knl0303gmoL00`1lO7`00000
0000000D0?Ogm`0307alO0000000000002@0moOg0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`<0kno_
0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P1kNg/0102YZJT0e]KF0=KF
eP3Shn<20>o_kaH0moOg00<0jn_[0=kNgP3Ng]h00`0H61P208b<S0030<;2`P3gmoL0moOg0140moOg
00<0O7al0000000000001@3gmoL00`3kno/0oooo0?ooo`0^0?Ogm`80kno_00<0hn?S0=KFeP3Fe]H0
0P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0inOW0>o_k`3_knl0303gmoL00`1lO7`00000
0000000D0?Ogm`0307alO0000000000002@0moOg0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`<0kno_
0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24
Q8@0102a/K40g]kN0=kNgP3WinL40>o_ka80moOg0P3_knl00`24Q8@061PH01PH600306][J``0moOg
0`3_knl00`3clo<0moOg0?Ogm`040?Ogm`0307alO000000000000080moOg00@0lo?c0>o_k`3_knl0
lo?c5P3gmoL30>o_k`P0moOg0P3oool20?Ogm`030??cl`3_knl0kno_0080moOg00@0lo?c0>o_k`3_
knl0lo?c0P3gmoL20>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=KF
eP030=[JfP3Ng]h0g]kN00`0moOg00<0O7al0000000000000P3gmoL00`3clo<0kno_0>o_k`0?0?Og
m`0307alO0000000000000<0kno_0P3gmoL30>o_k`80moOg0P3oool00`3kno/0moOg0?Ogm`030>o_
ka@0moOg00<0lo?c0>o_k`3_knl01@3_knl30=KFeP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080
oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kNgP3WinL40>o_ka80moOg0P3_knl00`24
Q8@061PH01PH600306][J``0moOg0`3_knl00`3clo<0moOg0?Ogm`040?Ogm`0307alO00000000000
0080moOg00@0lo?c0>o_k`3_knl0lo?c5P3gmoL30>o_k`P0moOg0P3oool20?Ogm`030??cl`3_knl0
kno_0080moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0
_[jn0?Ogm`3gmoL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN00`0moOg00<0O7al0000000000000P3g
moL00`3clo<0kno_0>o_k`0?0?Ogm`0307alO0000000000000<0kno_0P3gmoL30>o_k`80moOg0P3o
ool00`3kno/0moOg0?Ogm`030>o_ka@0moOg00<0lo?c0>o_k`3_knl01@3_knl30=KFeP80Q8B41`3g
moL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL2
0=;BdP030<S8b02m_Kd0_Kfm0080oooo00<0oOgm0?_kn`3kno/00P24Q8@0102_[jl0f][J0=[JfP3U
iND20>o_k`L0moOg0P3clo<00`3emOD0moOg0?Ogm`050?Ogm`030?Gem@3clo<0lo?c0080c/k>00<0
KFe]00`<300<30`00`0f=SH<07alO0<0N7Qh00<0NWYj07alO01lO7`0101lO7`00`0n?Sh000000000
00020?Ogm`030?Gem@3clo<0lo?c00<0lo?c703gmoL30??cl`80oooo0P3gmoL00`3emOD0lo?c0??c
l`080??cl`80kno_00<0iNGU0=[JfP3Jf]X00P24Q8@00`30`<00no_k0?_kn`0308B4Q080f][J00<0
hn?S0>_[j`3[jn/01@3gmoL20??cl`<0moOg0P1lO7`00`0n?Sh000000000000207alO00307YjNP1h
N7P0N7Qh00l0O7al00<0?Shn0000000000000`1hN7P20?Ogm`D0lo?c0P3oool00`3kno/0moOg0?Og
m`030??cla@0moOg00<0mOGe0??cl`3clo<00P3gmoL30>o_k`<0f][J0P20P8070?_kn`030=oOg`32
`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:
0;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_0P3oool50?Ogm`80kno_00<0
lo?c0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`020:f][@0305MGE`000000000001`000001@3g
moL00`3clo<0kno_0>o_k`0D0?Ogm`<0oooo1@3gmoL30>o_k`80oooo1@3gmoL20>o_k`040??cl`3g
moL0moOg0??cl`@0kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN
00<0jn_[0?Ogm`3gmoL01@3gmoL20>o_k`<0moOg7`0000050?Ogm`80kno_0P3oool00`3kno/0moOg
0?Ogm`0J0?Ogm`80oooo0`3_knl30=kNgP80Ng]k1`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24
Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80oooo1@3gmoL20>o_k`030??cl`3gmoL0moOg00D0moOg
00<0lo?c0>o_k`3_knl00P2][Jd00`1GEeL000000000000L000000D0moOg00<0lo?c0>o_k`3_knl0
503gmoL30?ooo`D0moOg0`3_knl20?ooo`D0moOg0P3_knl0103clo<0moOg0?Ogm`3clo<40>o_k`03
0>OWi`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[j`3gmoL0moOg00D0
moOg0P3_knl30?Ogmal000001@3gmoL20>o_k`80oooo00<0no_k0?Ogm`3gmoL06P3gmoL20?ooo`<0
kno_0`3Ng]h207]kN`L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0
hn?S2@3_knl20?Ogm`040??cl`3_knl0kno_0??cl`80moOg2P3_knl50?Ogm`030??cl`3_knl0kno_
0080moOg00<0lo?c0>o_k`3_knl00P3gmoL60>o_k`@0moOg00<0lo?c0>o_k`3_knl01@3gmoL00`3c
lo<0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00D0moOg0`3_knl20?Ogm`030??cl`3_knl0kno_
0080moOg203_knl30?Ogm`80kno_0P3gmoL00`3clo<0kno_0>o_k`0:0>o_k`030>OWi`3Ng]h0g]kN
0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=KFeP030=[JfP3Ng]h0g]kN00D0kno_0P3gmoL30>o_
k`80moOg00<0lo?c0>o_k`3_knl01`3_knl00`3clo<0moOg0?Ogm`030?Ogm`80kno_00<0lo?c0?Og
m`3gmoL00P3_knl00`3clo<0moOg0?Ogm`050>o_k`D0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_
k`030??cl`3gmoL0moOg00L0moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030??cl`3gmoL0
moOg00D0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KF
eP3Fe]H0hn?S2@3_knl20?Ogm`040??cl`3_knl0kno_0??cl`80moOg2P3_knl50?Ogm`030??cl`3_
knl0kno_0080moOg00<0lo?c0>o_k`3_knl00P3gmoL60>o_k`@0moOg00<0lo?c0>o_k`3_knl01@3g
moL00`3clo<0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00D0moOg0`3_knl20?Ogm`030??cl`3_
knl0kno_0080moOg203_knl30?Ogm`80kno_0P3gmoL00`3clo<0kno_0>o_k`0:0>o_k`030>OWi`3N
g]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=KFeP030=[JfP3Ng]h0g]kN00D0kno_0P3g
moL30>o_k`80moOg00<0lo?c0>o_k`3_knl01`3_knl00`3clo<0moOg0?Ogm`030?Ogm`80kno_00<0
lo?c0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`050>o_k`D0moOg0P3_knl00`3clo<0moOg0?Og
m`050>o_k`030??cl`3gmoL0moOg00L0moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030??c
l`3gmoL0moOg00D0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P050??cl`80Q8B400@0
[Jf]0=KFeP3Fe]H0gmoO0P3WinL20>o_k`<0lo?c0P3_knl20?Ogm`030?Gem@3clo<0lo?c00D0lo?c
00<0mOGe0?Ogm`3gmoL00P3_knl00`3alO40lo?c0??cl`0:0??cl`030?7al@3_knl0kno_00X0lo?c
0P3gmoL00`3emOD0lo?c0??cl`020??cl`030?Gem@3gmoL0moOg00<0moOg3@3clo<20?Ogm`030?Ge
m@3clo<0lo?c0080moOg1@3clo<30>o_k`<0moOg1`3clo<20?Ogm`040??cl`3_knl0kno_0?7al@80
lo?c0P3WinL00`3QhN40f][J0=[JfP0208B4Q0030;bl_03clo<0lo?c00<0P8200P3Fe]H00`3Ogml0
inOW0>OWi`020??cl`<0kno_0P3gmoL80??cl`80moOg00<0lo?c0>o_k`3_knl02P3clo<00`3emOD0
moOg0?Ogm`0=0??cl`80moOg203clo<20?Ogm`030?Gem@3clo<0lo?c0080moOg00<0mOGe0??cl`3c
lo<01@3clo<00`3emOD0moOg0?Ogm`050??cl`D0kno_0`3Fe]H208B4Q0L0lo?c00<0fm_K0<;2`P32
`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K6
0<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h20>o_k`<0moOg0P3_knl50?Ogm`03
0??cl`3_knl0kno_0080moOg00<0no_k0?ooo`3oool00P3_knl00`3clo<0moOg0?Ogm`050>o_k`03
0??cl`3gmoL0moOg00L0kno_1P3gmoL20>o_k`D0moOg0P3_knl0103clo<0moOg0?Ogm`3kno/20?oo
o`80kno_00<0lo?c0?Ogm`3gmoL01@3_knl?0?Ogm`<0kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg
0080oooo00@0moOg0>o_k`3_knl0lo?c0P3gmoL20=kNgP030=[JfP3Fe]H0e]KF0080Q8B400<0^[Zj
0>o_k`3_knl00`24Q8@20=KFeP030>?Sh`3_knl0kno_0080moOg0`3_knl50?Ogm`80kno_00<0lo?c
0?Ogm`3gmoL00P3oool00`3gmoL0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00<0kno_1`3gmoL0
0`3clo<0kno_0>o_k`050?Ogm`<0kno_103gmoL00`3clo<0kno_0>o_k`030?Ogm`80oooo00<0moOg
0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`020>o_k`030??cl`3gmoL0moOg00D0moOg00<0lo?c
0>o_k`3_knl01@3_knl30=KFeP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c
0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102]
[Jd0e]KF0=KFeP3Jf]X20=kNgP80kno_0`3gmoL20>o_k`D0moOg00<0lo?c0>o_k`3_knl00P3gmoL0
0`3kno/0oooo0?ooo`020>o_k`030??cl`3gmoL0moOg00D0kno_00<0lo?c0?Ogm`3gmoL01`3_knl6
0?Ogm`80kno_1@3gmoL20>o_k`040??cl`3gmoL0moOg0?_kn`80oooo0P3_knl00`3clo<0moOg0?Og
m`050>o_k`l0moOg0`3_knl50?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3oool0103gmoL0kno_0>o_
k`3clo<20?Ogm`80g]kN00<0f][J0=KFeP3Fe]H00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080e]KF
00<0hn?S0>o_k`3_knl00P3gmoL30>o_k`D0moOg0P3_knl00`3clo<0moOg0?Ogm`020?ooo`030?Og
m`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl00`3_knl70?Ogm`030??cl`3_knl0kno_00D0moOg
0`3_knl40?Ogm`030??cl`3_knl0kno_00<0moOg0P3oool00`3gmoL0kno_0>o_k`020?Ogm`030??c
l`3_knl0kno_0080kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`050>o_k`<0e]KF
0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040:f][@3>c/h0c/k>0=oOg`80kno_
0P3gmoL70>o_k`040??cl`3gmoL0moOg0??cl`@0kno_00<0lo?c0?Ogm`3gmoL01@3_knl30?Ogm`D0
kno_2P0000000`1hN7P0kno_0>o_k`040>o_k`030??cl`3gmoL0moOg00D0kno_00<0lo?c0?Ogm`3g
moL03@3_knl20?Ogm`030??cl`3_knl0kno_0080kno_0`3gmoL80>o_k`80moOg3`3_knl00`3Shn<0
e]KF0=KFeP0208B4Q0030<;2`P3oool0oooo00<0Ng]k0P3Fe]H00`3Shn<0kno_0>o_k`070>o_k`<0
moOg1@3_knl20?Ogm`030??cl`3_knl0kno_00X0000000<0O7al0?Ogm`3gmoL01@3_knl30?Ogm`L0
kno_0P3gmoL00`3clo<0kno_0>o_k`030>o_k`80moOg00<0lo?c0>o_k`3_knl00P3_knl00`3clo<0
moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg00L0kno_0`3Ng]h30=KFeP80Ng]k1`3gmoL00`3Jf]X0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:
bP2m_Kd0_Kfm00D0moOg0P2<S8`0102][Jd0c/k>0<k>cP3Ogml20>o_k`80moOg1`3_knl0103clo<0
moOg0?Ogm`3clo<40>o_k`030??cl`3gmoL0moOg00D0kno_0`3gmoL50>o_k`X0000000<0N7Qh0>o_
k`3_knl0103_knl00`3clo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg00d0kno_0P3gmoL00`3c
lo<0kno_0>o_k`020>o_k`<0moOg203_knl20?Ogm`l0kno_00<0hn?S0=KFeP3Fe]H00P24Q8@00`32
`/80oooo0?ooo`0307]kN`80e]KF00<0hn?S0>o_k`3_knl01`3_knl30?Ogm`D0kno_0P3gmoL00`3c
lo<0kno_0>o_k`0:0000000307alO03gmoL0moOg00D0kno_0`3gmoL70>o_k`80moOg00<0lo?c0>o_
k`3_knl00`3_knl20?Ogm`030??cl`3_knl0kno_0080kno_00<0lo?c0?Ogm`3gmoL01@3_knl00`3c
lo<0moOg0?Ogm`070>o_k`<0g]kN0`3Fe]H207]kN`L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80
R8R800@0[Jf]0=;BdP3Bd]80gMgM0P3WinL70??cl`80kno_00<0lO7a0??cl`3clo<00`3clo<20>o_
k`030?7al@3clo<0lo?c0080lo?c00<0lO7a0>o_k`3_knl00`3kno/50>o_k`80000000<0?3`l07Qh
N01hN7P00P1hN7P30000000307YjNP3clo<0lo?c0080lo?c0P3_knl00`3alO40lo?c0??cl`020??c
l`040?7al@3_knl0kno_0?7al@@0lo?c00<0lO7a0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`03
0>o_k`80moOg00<0lo?c0>o_k`3_knl00P3_knl80??cl`<0kno_0P3clo<=0>o_k`80lo?c00<0iNGU
0=KFeP3Fe]H00P24Q8@00`32`/80oooo0?ooo`030820P080e]KF00<0gmoO0>OWi`3WinL01@3clo<2
0>o_k`D0lo?c00<0lO7a0>o_k`3_knl01@3clo<2000000040410@020P800P82007alO080N7Qh0P00
00000`1lO7`0moOg0?Ogm`050>o_k`P0lo?c0P3_knl50??cl`<0kno_0P3clo<00`3alO40kno_0>o_
k`020>o_k`030??cl`3gmoL0moOg00D0kno_00<0lo?c0?Ogm`3gmoL01@3_knl20>OWi`<0jn_[0`3J
f]X207]kN`L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3N
g]h20>o_k`D0moOg1@3_knl00`3clo<0moOg0?Ogm`050>o_k`80moOg00<0lo?c0>o_k`3_knl00`3o
ool50>o_k`80000000<0N7Qh0>o_k`3_knl00P3_knl30000000307alO03gmoL0moOg0080moOg1@3_
knl20?Ogm`030??cl`3_knl0kno_00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?ooo`030?Ogm`3_
knl0kno_00<0kno_0P3gmoL00`3clo<0kno_0>o_k`050>o_k`D0moOg4P3_knl20?Ogm`030>OWi`3F
e]H0e]KF0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN00D0moOg1@3_
knl20?Ogm`030??cl`3_knl0kno_0080kno_00<0lo?c0?Ogm`3gmoL00P0000001020P800oooo0?oo
o`3gmoL20>o_k`80000000<0O7al0?Ogm`3gmoL0203_knl50?Ogm`@0kno_00<0lo?c0?Ogm`3gmoL0
2P3_knl00`3clo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg00D0kno_0P3Ng]h30?Ogm`<0g]kN
0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF0=[JfP80g]kN
0P3_knl50?Ogm`D0kno_00<0lo?c0?Ogm`3gmoL01@3_knl20?Ogm`030??cl`3_knl0kno_00<0oooo
1@3_knl20000000307QhN03_knl0kno_0080kno_0`0000000`1lO7`0moOg0?Ogm`020?Ogm`D0kno_
0P3gmoL00`3clo<0kno_0>o_k`030>o_k`80moOg00<0lo?c0>o_k`3_knl00P3oool00`3gmoL0kno_
0>o_k`030>o_k`80moOg00<0lo?c0>o_k`3_knl01@3_knl50?Ogma80kno_0P3gmoL00`3WinL0e]KF
0=KFeP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Fe]H00`3Jf]X0g]kN0=kNgP050?Ogm`D0kno_
0P3gmoL00`3clo<0kno_0>o_k`020>o_k`030??cl`3gmoL0moOg0080000000@0P8200?ooo`3oool0
moOg0P3_knl20000000307alO03gmoL0moOg00P0kno_1@3gmoL40>o_k`030??cl`3gmoL0moOg00X0
kno_00<0lo?c0?Ogm`3gmoL01@3_knl00`3clo<0moOg0?Ogm`050>o_k`80g]kN0`3gmoL30=kNgP80
Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102[Zj/0d];B0=;BdP3Hf=P20=kNgP80
kno_1@3clo<50>o_k`030?7al@3clo<0lo?c00D0kno_1@3clo<30?Ogm`D0kno_0P0000000`1jNWX0
lo?c0??cl`020>o_k`<0000000<0NWYj0??cl`3clo<00P3clo<50>o_k`80lo?c00<0lO7a0>o_k`3_
knl00`3_knl50??cl`80moOg00<0lo?c0>o_k`3_knl00`3_knl50??cl`80kno_203clo<30>o_k`80
lo?c3@3_knl20??cl`030>GUi@3Fe]H0e]KF0080Q8B400<0`<300?_kn`3kno/00`20P8020=KFeP03
0=oOg`3WinL0inOW00D0lo?c1@3_knl20??cl`030?7al@3_knl0kno_0080kno_00<0lO7a0??cl`3c
lo<00P000000101lO7`0moOg0?Ogm`3clo<20>o_k`80000000<0NWYj0??cl`3clo<00P3clo<00`3a
lO40kno_0>o_k`080??cl`80kno_1@3clo<80>o_k`D0lo?c1@3_knl00`3alO40lo?c0??cl`020??c
l`030?7al@3_knl0kno_0080inOW0`3[jn/30=[JfP80P8201`3kno/00`3Ogml0`/;20<;2`P030=;B
dP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgQH0kno_00<0lo?c0?Ogm`3gmoL0203_knl20000
000307alO03gmoL0moOg0080kno_0`0000000`1hN7P0kno_0>o_k`0A0>o_k`030??cl`3gmoL0moOg
00X0kno_00<0lo?c0?Ogm`3gmoL00P3_knl30?Ogm`P0kno_0P3gmoL?0>o_k`030>?Sh`3Fe]H0e]KF
0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=KFeP030>?Sh`3_knl0kno_01@0kno_0P0000000`1h
N7P0kno_0>o_k`030>o_k`80000000<0N7Qh0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`030?Og
m`L0kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80moOg00<0lo?c0>o_k`3_knl0203_knl20?Og
m`030??cl`3_knl0kno_0080kno_0`3Ng]h30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgQH0kno_00<0lo?c0?Ogm`3gmoL0203_knl20000
000307alO03gmoL0moOg0080kno_0`0000000`1hN7P0kno_0>o_k`0A0>o_k`030??cl`3gmoL0moOg
00X0kno_00<0lo?c0?Ogm`3gmoL00P3_knl30?Ogm`P0kno_0P3gmoL?0>o_k`030>?Sh`3Fe]H0e]KF
0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=KFeP030>?Sh`3_knl0kno_01@0kno_0P0000000`1h
N7P0kno_0>o_k`030>o_k`80000000<0N7Qh0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`030?Og
m`L0kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80moOg00<0lo?c0>o_k`3_knl0203_knl20?Og
m`030??cl`3_knl0kno_0080kno_0`3Ng]h30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0
kno_0P24Q8@00`2][Jd0e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3N
g]h00P3gmoL00`3[jn/0g]kN0=kNgP0=0>o_k`X0000000<0N7Qh0>o_k`3_knl00P3Ng]h20>o_k`03
0>OWi`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW103_knl00`3WinL0g]kN0=kNgP020>o_
k`030>OWi`3Ng]h0g]kN01T0kno_00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL2
0>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P1kNg/00`2e]KD0kno_0>o_k`0308B4Q0D0e]KF0P3Ng]h3
0>o_k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00X0000000<0N7Qh
0>o_k`3_knl03@3_knl20=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3gmoL20=kNgP030>OWi`3_knl0
kno_0080kno_00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL90>o_k`<0g]kN0`3F
e]H207]kN`D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@00`2][Jd0e]KF0=KFeP03
0=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3gmoL00`3[jn/0g]kN0=kNgP0=
0>o_k`X0000000<0N7Qh0>o_k`3_knl00P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN0080kno_00@0inOW
0=kNgP3Ng]h0inOW103_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN01T0kno_00<0
inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80g]kN00<0f][J0=KFeP3Fe]H0
0P1kNg/00`2e]KD0kno_0>o_k`0308B4Q0D0e]KF0P3Ng]h30>o_k`80g]kN1@3_knl00`3WinL0g]kN
0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00X0000000<0N7Qh0>o_k`3_knl03@3_knl20=kNgP80kno_
00<0inOW0=kNgP3Ng]h00`3gmoL20=kNgP030>OWi`3_knl0kno_0080kno_00<0inOW0=kNgP3Ng]h0
0P3_knl0103WinL0g]kN0=kNgP3WinL90>o_k`<0g]kN0`3Fe]H207]kN`D0kno_0P3gmoL00`3Jf]X0
_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<c<
c036a/H0a/K600D0lo?c0P24Q8@0102[Zj/0d];B0=;BdP3Fe]H20=[JfP80g]kN0`3WinL20=kNgP80
lo?c00@0kNg]0>OWi`3WinL0hn?S0P3Ng]h20??cl`030>WYj@3Ng]h0g]kN00D0inOW0`3_knl20>OW
i`030>_[j`3_knl0kno_00L0Kfm_0`1hN7P00`2`/;00inOW0>OWi`020=kNgP80inOc00<0hn?Y0=kN
gP3Ng]h00P3WinL0103Shn<0g]kN0=kNgP3WinL20>o_k`80inOW00<0hn?S0=kNgP3Ng]h00P3_knl0
0`3WinL0g]kN0=kNgP050>OWi`030>_[j`3_knl0kno_0080inOW0`3_knl80>OWi`80kno_0P3WinL0
0`3Shn<0g]kN0=kNgP020>OWk`040>?Si`3Ng]h0g]kN0>?Sh`80inOW0P3Jf]X00`3Fe]H0d];B0=;B
dP020820P0030;Zj^P3clo<0lo?c00<0Q8B40P3Bd]800`3Fe]H0f][J0=[JfP020=kNgP<0inOW0P3N
g]h30>o_k`80inOW00<0hn?S0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP0206m_K`0406e]K@1[
Jf/0Jf][079bLP80N7Qh0P1_Kfl00`2_[jl0kno_0>o_k`080>OWi`80kno_0`3WinL20=kNgP80inO_
00<0hn?W0=kNgP3Ng]h00`3[jn/20=kNgP030>OWi`3_knl0kno_0080inOW00<0hN7Q0=[JfP3Jf]X0
0P3_knl0103WinL0g]kN0=kNgP3Shn<40>OWi`030>_[j`3_knl0kno_0080inOW0`3Ng]h30=;BdP80
Q8B41@3clo<20?Ogm`030=gMg@32`/80`/;200<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0
g]kN0P3gmoL00`3[jn/0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80
g]kN00<0inOW0>o_k`3_knl01`3Ng]h30>o_k`030>OWi`3Ng]h0g]kN0080g]kN0P3Ng_L00`3Ng^/0
g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP03
0>OWi`3_knl0kno_0080g]kN0`3_knl80=kNgP80kno_1@3Ng]h20=kNk`030=kNi`3Ng]h0g]kN00<0
g]kN0P3Fe]H00`3Bd]80c/k>0<k>cP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3>c/h00`3Fe]H0
g]kN0=kNgP070=kNgP<0kno_1@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN0080g]kN00@0f][J0=KFeP3F
e]H0hn?S0P3_knl20=kNgP030>OWi`3_knl0kno_00P0g]kN0P3_knl50=kNgP80g]k_00<0g]kW0=kN
gP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP030=[JfP3Fe]H0e]KF0080kno_00<0inOW0=kN
gP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0c/k>0P2<S8`70?Ogm`030=oOg`36a/H0a/K6
00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36
a/H01@3gmoL208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3gmoL00`3[jn/0g]kN0=kNgP030=kN
gP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0inOW0>o_k`3_knl01`3Ng]h30>o_
k`030>OWi`3Ng]h0g]kN0080g]kN0P3Ng_L00`3Ng^/0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_
00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3_knl80=kN
gP80kno_1@3Ng]h20=kNk`030=kNi`3Ng]h0g]kN00<0g]kN0P3Fe]H00`3Bd]80c/k>0<k>cP0208B4
Q0030;jn_P3gmoL0moOg00<0Q8B40P3>c/h00`3Fe]H0g]kN0=kNgP070=kNgP<0kno_1@3Ng]h20>o_
k`030>OWi`3Ng]h0g]kN0080g]kN00@0f][J0=KFeP3Fe]H0hn?S0P3_knl20=kNgP030>OWi`3_knl0
kno_00P0g]kN0P3_knl50=kNgP80g]k_00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`02
0=kNgP030=[JfP3Fe]H0e]KF0080kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`05
0=kNgP<0c/k>0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF
0=[JfP80g]kN0P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H0
0`3Jf]X0g]kN0=kNgP080=kNgP80e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h20=kNeP030=[JeP3Fe]H0
e]KF00d0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP030=KFePX0g]kN0P3Fe]H=0=kNgP80g]kF00@0f][F
0=KFeP3Fe]H0f][J0P3Ng]h20=KFeP030=;BdP3>c/h0c/k>0080Q8B400<0`/;20?ooo`3oool00`2<
S8`20<k>cP030=KFeP3Ng]h0g]kN0080e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3N
g]h0g]kN00d0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3N
g]h00`3Jf]X0e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>
0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF0=[JfP80g]kN
0P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN
0=kNgP080=kNgP80e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h20=kNeP030=[JeP3Fe]H0e]KF00d0g]kN
0P3Fe]H00`3Jf]X0g]kN0=kNgP030=KFePX0g]kN0P3Fe]H=0=kNgP80g]kF00@0f][F0=KFeP3Fe]H0
f][J0P3Ng]h20=KFeP030=;BdP3>c/h0c/k>0080Q8B400<0`/;20?ooo`3oool00`2<S8`20<k>cP03
0=KFeP3Ng]h0g]kN0080e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00d0
g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0
e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@70?oo
o`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0a/K60;fm_@2m_Kd01@3gmoL207=cL`040:VYZ@3Ng]h0g]kN0>_[jah0moOg0P3oool00`3k
no/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg02T0moOg0P3oool30?Ogm`80oooo5@3gmoL20>o_
k`030>OWi`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=kNgP030>_[j`3gmoL0moOg
01`0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg02T0moOg0P3oool30>o_
k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL207=cL`040:VYZ@3Ng]h0g]kN0>_[
jah0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg02T0moOg0P3oool30?Og
m`80oooo5@3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=kN
gP030>_[j`3gmoL0moOg01`0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg
02T0moOg0P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL207=cL`04
0:VYZ@3Ng]h0g]kN0>_[jah0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg
02T0moOg0P3oool30?Ogm`80oooo5@3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0_[jn0?Og
m`3gmoL00`1kNg/20=kNgP030>_[j`3gmoL0moOg01`0moOg0P3oool00`3kno/0moOg0?Ogm`020?oo
o`030?_kn`3gmoL0moOg02T0moOg0P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m
_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040;Zj^P3_knl0kno_0?Ogmg80oooo0P24Q8@00`2j
^[X0kno_0>o_k`0308B4Q080kno_00<0moOg0?ooo`3oool0E`3oool208B4Q080kno_00<0lo?c0?Og
m`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102j^[X0
kno_0>o_k`3gmoMb0?ooo`80Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20>o_k`030?Ogm`3oool0oooo
05L0oooo0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_
k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`03
0??cl`3_knl0kno_0080Q8B400@0^[Zj0>o_k`3_knl0moOgLP3oool208B4Q0030;Zj^P3_knl0kno_
00<0Q8B40P3_knl00`3gmoL0oooo0?ooo`1G0?ooo`80Q8B40P3_knl00`3clo<0moOg0?Ogm`020>o_
k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0b/[:0<K6aP36a/H01@3gmoL508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0<0
Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B40080S8b<1P24Q8@207]kN`L0Q8B400@0P82007]kN`1k
Ng/0P8204@24Q8@00`20P800Ng]k07]kN`0208b<S0<0Q8B40P1kNg/:08B4Q0030820P01kNg/0Ng]k
00l0Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@208b<S00308B4Q01kNg/0Ng]k00D0Q8B40P1kNg/B08B4
Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/00`24Q8@0S8b<08b<S00808B4Q080Ng]k2024Q8@207]k
N`030820P024Q8@0Q8B400l0Q8B400<0P82007]kN`1kNg/02P24Q8@70?Ogm`030=oOg`36a/H0a/K6
00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36
a/H01@3gmoL508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0<0Ng]k1@24Q8@207]kN`03
0820P024Q8@0Q8B40080S8b<1P24Q8@207]kN`L0Q8B400@0P82007]kN`1kNg/0P8204@24Q8@00`20
P800Ng]k07]kN`0208b<S0<0Q8B40P1kNg/:08B4Q0030820P01kNg/0Ng]k00l0Q8B400<0_[jn0?Og
m`3gmoL00`24Q8@208b<S00308B4Q01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0030820P01kNg/0Ng]k
00D0Q8B40P1kNg/00`24Q8@0S8b<08b<S00808B4Q080Ng]k2024Q8@207]kN`030820P024Q8@0Q8B4
00l0Q8B400<0P82007]kN`1kNg/02P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd0jP3oool00`3Ng]h0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6
aP2m_Kd0_Kfm0>X0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@3Z0?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL2
07=cL`0307alO024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@2
07]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00708B4Q0<0Ng]k00<0P820
08B4Q024Q8@00P24Q8@507]kN`D0Q8B400<0P82007]kN`1kNg/00P2<S8`00`28R8P0Q8B408B4Q005
08B4Q0<0Ng]k1@24Q8@207]kN`/0Q8B40P1kNg/508B4Q0D0Ng]k00<0P82008B4Q024Q8@00P1kNg/0
0`20P800Q8B408B4Q00208B4Q0030;jn_P3gmoL0moOg00<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/7
08B4Q00308R8R02<S8`0S8b<0080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0
Q8B400P0Q8B40P1kNg/508B4Q0D0Ng]k1@24Q8@00`20P800Ng]k07]kN`0:08B4Q00307alO01cLg<0
Lg=c00D0Q8B41@1kNg/508B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Lg=c00<0O7al08B4
Q024Q8@00`24Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k00<0P82008B4
Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400L0Q8B40`1kNg/00`20P800Q8B408B4Q00208B4
Q0D0Ng]k1@24Q8@00`20P800Ng]k07]kN`0208b<S00308R8R024Q8@0Q8B400D0Q8B40`1kNg/508B4
Q080Ng]k2`24Q8@207]kN`D0Q8B41@1kNg/00`20P800Q8B408B4Q00207]kN`030820P024Q8@0Q8B4
0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/508B4Q080Ng]k1@24Q8@307]kN`L0Q8B400<0R8R808b<
S02<S8`00P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@207]k
N`D0Q8B41@1kNg/508B4Q0030820P01kNg/0Ng]k00X0Q8B400<0O7al07=cL`1cLg<01@24Q8@507]k
N`D0Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Og
m`@0oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo1@3gmoL20?oo
o`030?_kn`3gmoL0moOg0080oooo1P3gmoL20?ooo`L0moOg00<0no_k0?ooo`3oool00`3oool70?Og
m`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool01@3gmoL20?ooo`<0moOg0`3oool40?Og
m`030?_kn`3oool0oooo00X0moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4
Q080g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL50?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3k
no/0oooo0?ooo`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3oool50?Ogm`80oooo203gmoL50?oo
o`L0moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@5
0>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL4
0?ooo`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool0
0`3kno/0moOg0?Ogm`020?ooo`H0moOg0P3oool70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL0
0`3kno/0oooo0?ooo`050?Ogm`030?_kn`3oool0oooo00D0moOg0P3oool30?Ogm`<0oooo103gmoL0
0`3kno/0oooo0?ooo`0:0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@2
0=kNgP030>_[j`3gmoL0moOg00D0moOg1@3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k
0?ooo`3oool01@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0oooo1@3gmoL20?ooo`P0moOg1@3oool7
0?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41@3_
knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80d];B00<0b<S80;fm_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040;6a/@3Ng]h0
g]kN0>g]k@L0no_k103oool00`3moOd0no_k0?_kn`050?_kn`030?gmo@3oool0oooo00D0no_k0`3o
ool50?_kn`80oooo00<0oOgm0?_kn`3kno/00P3oool60?_kn`80oooo1`3kno/00`3moOd0oooo0?oo
o`030?ooo`L0no_k00<0oOgm0?ooo`3oool01@3kno/00`3moOd0oooo0?ooo`050?_kn`80oooo0`3k
no/30?ooo`@0no_k00<0oOgm0?ooo`3oool0203kno/20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0
_;bl0??cl`3clo<00`24Q8@20=kNgP030>g]k@3kno/0no_k00D0no_k1@3oool70?_kn`030?gmo@3o
ool0oooo00D0no_k00<0oOgm0?ooo`3oool01@3kno/20?ooo`030?gmo@3kno/0no_k00<0oooo1@3k
no/20?ooo`P0no_k1@3oool70?_kn`040?gmo@3oool0oooo0?gmo@@0no_k00<0oOgm0?ooo`3oool0
0P3kno/30?Ogm`<0g]kN0P24Q8@50??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h20>OWi`030>o_
k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3g
moL0moOg0080Q8B400@0/K6a0=kNgP3Ng]h0kno_K@3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B4
00<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>o_k`3oool0oooo0540oooo0`3gmoL30=kNgP80Q8B4
1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3N
g]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24Q8@0102a/K40g]kN0=kN
gP3_knm]0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN
00<0kno_0?ooo`3oool0D@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3o
ool208B4Q0040;6a/@3Ng]h0g]kN0>o_kfl0oooo00<0moOg0>o_k`3_knl00P24Q8@00`32`/80oooo
0?ooo`0308B4Q080g]kN00<0kno_0?ooo`3oool0E03oool30>o_k`80Q8B41`3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m
_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3_knm_0?ooo`030?Ogm`3_knl0kno_0080Q8B4
00<0`/;20?ooo`3oool00`24Q8@20=kNgP030>o_k`3oool0oooo05@0oooo0`3_knl208B4Q0L0oooo
00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3F
e]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_K`3oool00`3gmoL0kno_
0>o_k`0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`1D0?ooo`<0kno_
0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_kaH0oooo
2P0000000`20P800oooo0?ooo`1<0?ooo`030?Ogm`3_knl0kno_0080Q8B400<0_[jn0?Ogm`3gmoL0
0`1kNg/20=kNgP030>_[j`3gmoL0moOg0540oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3Ogml0a/K6
0<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m
_Kd0_Kfm00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knlF0?ooo`X0000000<0P8200?ooo`3oool0
C03oool00`3gmoL0kno_0>o_k`0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3[jn/0moOg
0?Ogm`1A0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P050??cl`80Q8B400@0
/K6a0=kNgP3Ng]h0kNg]0P3kno/20>?Sh`<0Q8B40P20P80209RHV0040;jn_P3Shn<0hn?S0?7al@L0
oooo0P0000000`10@400P8200820P0030820P080000000<0P8200?ooo`3oool0BP3oool20?_kn`03
0?7al@3WinL0inOW0080Q8B400<0_;bl0??cl`3clo<00`20P8020=kNgP030>_[j`3gmoL0moOg0540
oooo0`3kno/30=kNgP80Q8B41`3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN
0=kNgP3[jn/20?Ogm`80a/K60`0820P200000080<C4a00@0O7al0<K6aP36a/H0hn?S1`3oool20000
00030820P03oool0oooo00<0oooo0P0000000`20P800oooo0?ooo`1:0?ooo`80moOg00<0jn_[0=kN
gP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0E03oool30=kN
gP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Og
m`80a/K60`0820P200000080<C4a00@0O7al0<K6aP36a/H0hn?S1`3oool2000000030820P03oool0
oooo00<0oooo0P0000000`20P800oooo0?ooo`1:0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@0
0`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0E03oool30=kNgP80Q8B41`3_knl0
0`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KF
eP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102e]KD0g]kN0=kNgP3[jn/20?Ogm`80@T920`3Fe]H2
0>o_k`80Ng]k00@0?Shn000000000000Jf][0P3Fe]H50?ooo`80000000<0P8200?ooo`3oool00`3o
ool2000000030820P03oool0oooo04`0oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?oo
o`0308B4Q080g]kN00<0kno_0?ooo`3oool0D@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:
0;fm_@2m_Kd01@3gmoL208b<S0040;Fe]@3Ng]h0g]kN0>_[j`80moOg0P12@T830=KFeP80kno_0P1k
Ng/0100n?Sh000000000001[Jf/20=KFePD0oooo0P0000000`20P800oooo0?ooo`030?ooo`800000
00<0P8200?ooo`3oool0C03oool00`3_knl0g]kN0=kNgP0208B4Q0030<;2`P3oool0oooo00<0Q8B4
0P3Ng]h00`3_knl0oooo0?ooo`1A0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd0
0`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm
_@050?_kn`80R8R800@0/k>c0=kNgP3Ng]h0jn_[0P3gmoL20:6QX@<0jn_[0P3gmoL20;fm_@0407in
OP0n?Sh0?Shn06UYJ@80U9BD1@3oool2000000030410@020P800P82000<0P8200P0000000`20P800
oooo0?ooo`1<0?ooo`030>o_k`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP03
0>g]k@3kno/0no_k04l0oooo1@3kno/30>OWi`80P8201`3kno/00`3Ogml0`/;20<;2`P030=;BdP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo
0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`T0oooo00@0_Kfm07]kN`1kNg/0IfMW0P1BDU850?oo
o`X0000000<0P8200?ooo`3oool0C03oool00`3_knl0g]kN0=kNgP0208B4Q0030<;2`P3oool0oooo
00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`1?0?ooo`80moOg0`3oool30>o_k`80Ng]k1`3oool00`3S
hn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP03
0<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`T0oooo00@0_Kfm07]k
N`1kNg/0IfMW0P1BDU850?ooo`X0000000<0P8200?ooo`3oool0C03oool00`3_knl0g]kN0=kNgP02
08B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`1?0?ooo`80moOg0`3oool3
0>o_k`80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL2
0?Ogm`T0oooo00@0moOg0>o_k`3_knl0O7al0P0820QL0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24
Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0jn_[0?Ogm`3gmoL00P3gmoM?0?ooo`<0moOg0`3N
g]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW0P3g
moL90?ooo`040?Ogm`3_knl0kno_07alO08020P8G03oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B4
00<0_[jn0?Ogm`3gmoL00`1kNg/20=kNgP030>_[j`3gmoL0moOg0080moOgC`3oool30?Ogm`<0g]kN
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<208B4Q0040:n_[`3Jf]X0f][J0>WYj@80moOg
2@3oool0103kno/0moOg0?Ogm`1nOWh200@415`0oooo0P3gmoL00`3_knl0inOW0>OWi`0208B4Q003
0;bl_03clo<0lo?c00<0P8200P3Ng]h00`3[jn/0moOg0?Ogm`020?_kndl0oooo0`3gmoL30=kNgP80
Q8B41@3clo<20?Ogm`030=[JfP2m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80
moOg303oool00`20P80000000000001L0?ooo`80moOg00<0lo?c0>o_k`3_knl00P24Q8@00`2j^[X0
kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0D@3oool30?Ogm`<0g]kN0P24Q8@50>o_k`80
moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoL<0?ooo`03
0820P0000000000005`0oooo0P3gmoL00`3clo<0kno_0>o_k`0208B4Q0030;Zj^P3_knl0kno_00<0
Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`1A0?ooo`<0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0
_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<c<
c036a/H0a/K600D0lo?c0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`80no_k0`3oool20?_kn`D0
oooo00<0P8200000000000007`3oool20?_kn`D0oooo0P3kno/00`3moOd0oooo0?ooo`0G0?ooo`<0
no_k2P3oool20?_kn`030?gmo@3oool0oooo0080oooo00@0oOgm0?_kn`3kno/0oOgm0P3oool20?Og
m`030>o_k`3WinL0inOW0080Q8B400<0_;bl0??cl`3clo<00`24Q8@20=kNgP030>_[j`3gmoL0moOg
0080oooo0`3kno/50?ooo`80no_k00<0oOgm0?ooo`3oool00P3oool00`3moOd0no_k0?_kn`0G0?oo
o`<0no_k103oool00`3moOd0no_k0?_kn`0B0?ooo`030?gmo@3kno/0no_k00D0oooo0P3kno/30?Og
m`<0g]kN0P28R8P50??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3N
g]h0jn_[103gmoL30?ooo`80moOg1@3oool00`20P80000000000000O0?ooo`80moOg1@3oool20?Og
m`030?_kn`3oool0oooo01L0oooo0`3gmoL:0?ooo`80moOg00<0no_k0?ooo`3oool00P3oool0103k
no/0moOg0?Ogm`3kno/20?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`03
08B4Q080g]kN00<0jn_[0?Ogm`3gmoL00P3oool30?Ogm`D0oooo0P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`030?_kn`3gmoL0moOg01L0oooo0`3gmoL40?ooo`030?_kn`3gmoL0moOg0180oooo00<0no_k
0?Ogm`3gmoL01@3oool50?Ogm`<0g]kN0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4
Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOg0`3oool20?Ogm`D0oooo00<0P8200000000000007`3oool2
0?Ogm`D0oooo0P3gmoL00`3kno/0oooo0?ooo`0G0?ooo`<0moOg2P3oool20?Ogm`030?_kn`3oool0
oooo0080oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0
_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>_[j`3gmoL0moOg0080oooo0`3gmoL50?ooo`80moOg00<0
no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`0G0?ooo`<0moOg103oool00`3kno/0moOg0?Og
m`0B0?ooo`030?_kn`3gmoL0moOg00D0oooo1@3gmoL30=kNgP80S8b<1`3gmoL00`3Ogml0a/K60<K6
aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0
_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm``0oooo00<0P8200000000000003`3o
ool00`3kno/0moOg0?Ogm`050?ooo`80moOg7`3oool30?Ogm`D0oooo0P3gmoLJ0?ooo`80kno_00<0
inOW0=kNgP3Ng]h00P1kNg/00`2m_Kd0oooo0?ooo`0308b<S080g]kN00<0jn_[0?Ogm`3gmoL0703o
ool20?Ogm`030?_kn`3oool0oooo0080000000<0O7al0?Ogm`3gmoL07P3oool0103kno/0moOg0?Og
m`3kno/40?ooo`030?_kn`3gmoL0moOg0080oooo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m
_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm``0oooo00<0P820000000000000
3`3oool00`3kno/0moOg0?Ogm`050?ooo`80moOg7`3oool30?Ogm`D0oooo0P3gmoLJ0?ooo`80kno_
00<0inOW0=kNgP3Ng]h00P1kNg/00`2m_Kd0oooo0?ooo`0308b<S080g]kN00<0jn_[0?Ogm`3gmoL0
703oool20?Ogm`030?_kn`3oool0oooo0080000000<0O7al0?Ogm`3gmoL07P3oool0103kno/0moOg
0?Ogm`3kno/40?ooo`030?_kn`3gmoL0moOg0080oooo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0
_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8
b02m_Kd0_Kfm00D0no_k0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`D0no_k0P3oool20?_kn`04
0?gmo@3oool0oooo0820P08000000P3kno/00`3moOd0oooo0?ooo`0:0?ooo`030?gmo@3kno/0no_k
00D0oooo203kno/20?ooo`80no_k00<0oOgm0?ooo`3oool00P3oool0103moOd0no_k0?_kn`3moOd2
0?ooo`80no_k00<0oOgm0?ooo`3oool01@3oool30?_kn`D0oooo1`3kno/30?ooo`<0no_k0P3oool5
0?_kn`80oooo00@0oOgm0?_kn`3kno/0oOgm0P3oool20??cl`030>WYj@3Ng]h0g]kN0080P82000<0
_[jn0?_kn`3kno/00`28R8P20=kNgP030>_[j`3gmoL0moOg0080no_k0`3oool20?_kn`<0oooo1@3k
no/=0?ooo`80no_k00<0oOgm0?ooo`3oool00P20P8000`1nOWh0O7al07alO0030?_kn`D0oooo0P3k
no/20?ooo`030?gmo@3kno/0no_k00<0no_k0P3oool00`3moOd0no_k0?_kn`070?ooo`040?gmo@3k
no/0no_k0?gmo@@0oooo00<0oOgm0?_kn`3kno/00P3kno/30??cl`<0g]kN0P24Q8@70?_kn`030=cL
g02m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0
a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg0P3oool20?Ogm`040?_k
n`3oool0oooo0820P08000000P3gmoL00`3kno/0oooo0?ooo`0D0?ooo`H0moOg0P3oool20?Ogm`03
0?_kn`3oool0oooo0080oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030?_kn`3oool0oooo
00l0oooo1@3gmoL30?ooo`<0moOg0P3oool50?Ogm`80oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool2
0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>_[j`3gmoL0
moOg0080moOg0`3oool20?Ogm`<0oooo1@3gmoLD0?ooo`030820P0000000000000<0moOg1@3oool2
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg0180oooo0P3gmoL3
0>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN
0>_[j`L0moOg0P3oool20?Ogm`040?_kn`3oool0oooo0820P08000000P3gmoL00`3kno/0oooo0?oo
o`0D0?ooo`H0moOg0P3oool20?Ogm`030?_kn`3oool0oooo0080oooo00@0no_k0?Ogm`3gmoL0no_k
0P3oool20?Ogm`030?_kn`3oool0oooo00l0oooo1@3gmoL30?ooo`<0moOg0P3oool50?Ogm`80oooo
00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3g
moL00`24Q8@20=kNgP030>_[j`3gmoL0moOg0080moOg0`3oool20?Ogm`<0oooo1@3gmoLD0?ooo`03
0820P0000000000000<0moOg1@3oool20?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`03
0?_kn`3gmoL0moOg0180oooo0P3gmoL30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd0
0P3gmoL00`3clo<0kno_0>o_k`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_1@3gmoL40?ooo`04
0?_kn`3gmoL0moOg07alO08000000P3oool00`3kno/0moOg0?Ogm`050?ooo`D0moOg00<0no_k0?oo
o`3oool00P3oool00`3kno/0moOg0?Ogm`020?Ogm`X0oooo00<0no_k0?Ogm`3gmoL01@3oool00`3k
no/0moOg0?Ogm`050?ooo`D0moOg0`3oool70?Ogm`/0oooo0P3gmoL50?ooo`80moOg00<0no_k0?oo
o`3oool00`3oool20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=kN
gP030>_[j`3gmoL0moOg0080moOg1@3oool30?Ogm`X0oooo2P0000000`20P800oooo0?ooo`020?Og
m`0307alO0000000000000P0oooo2P0000020?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Og
m`3gmoL00P3gmoL00`3kno/0oooo0?ooo`030?ooo`D0moOg0P3oool30?Ogm`<0kno_0P24Q8@20>o_
k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080
Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl50?Ogm`@0oooo00@0no_k0?Ogm`3gmoL0O7al0P000002
0?ooo`030?_kn`3gmoL0moOg00D0oooo1@3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0
moOg0080moOg2P3oool00`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg00D0oooo1@3gmoL3
0?ooo`L0moOg2`3oool20?Ogm`D0oooo0P3gmoL00`3kno/0oooo0?ooo`030?ooo`80kno_00<0inOW
0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL5
0?ooo`<0moOg2P3oool:000000030820P03oool0oooo0080moOg00<0O7al000000000000203oool:
00000080moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`020?Ogm`030?_kn`3oool0
oooo00<0oooo1@3gmoL20?ooo`<0moOg0`3_knl208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl0
0`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>
cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knl20?ooo`D0moOg0P3oool2
0?Ogm`040?_kn`3oool0oooo0820P08000000P3oool00`3kno/0moOg0?Ogm`050?ooo`<0moOg0P3o
ool00`3kno/0moOg0?Ogm`070?ooo`H0moOg0P3oool20?Ogm`030?_kn`3oool0oooo00D0oooo00<0
no_k0?Ogm`3gmoL01@3oool20?Ogm`030?_kn`3oool0oooo00<0moOg1`3oool50?Ogm`<0oooo0`3g
moL70?ooo`80moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B4
00<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_00L0moOg203oool20?Ogm`030?_k
n`3oool0oooo0080000000@0O7al0?Ogm`3gmoL0no_k0P3oool2000000030820P03oool0oooo00D0
oooo1@3gmoL30?ooo`8000001@3oool300000080moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0
moOg0?Ogm`020?ooo`040?_kn`3gmoL0moOg0?_kn`L0oooo0P3gmoL30>o_k`<0g]kN0P1kNg/70?Og
m`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3gmoL20?oo
o`80moOg00@0no_k0?ooo`3oool0P8200P0000020?ooo`030?_kn`3gmoL0moOg00D0oooo0`3gmoL2
0?ooo`030?_kn`3gmoL0moOg00L0oooo1P3gmoL20?ooo`80moOg00<0no_k0?ooo`3oool01@3oool0
0`3kno/0moOg0?Ogm`050?ooo`80moOg00<0no_k0?ooo`3oool00`3gmoL70?ooo`D0moOg0`3oool3
0?Ogm`L0oooo0P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24
Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl01`3gmoL80?ooo`80moOg00<0
no_k0?ooo`3oool00P000000101lO7`0moOg0?Ogm`3kno/20?ooo`80000000<0P8200?ooo`3oool0
1@3oool50?Ogm`<0oooo0P0000050?ooo`<000000P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_k
n`3gmoL0moOg0080oooo00@0no_k0?Ogm`3gmoL0no_k1`3oool20?Ogm`<0kno_0`3Ng]h207]kN`L0
moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_0P3oool50?Ogm`80
oooo0P3gmoL0103kno/0oooo0?ooo`20P80200000080oooo00<0no_k0?Ogm`3gmoL01@3oool30?Og
m`80oooo00<0no_k0?Ogm`3gmoL01`3oool60?Ogm`80oooo0P3gmoL00`3kno/0oooo0?ooo`050?oo
o`030?_kn`3gmoL0moOg00D0oooo0P3gmoL00`3kno/0oooo0?ooo`030?Ogm`L0oooo1@3gmoL30?oo
o`<0moOg1`3oool20?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P3_knl00`3WinL0g]kN0=kNgP02
08B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`070?Ogm`P0oooo0P3gmoL0
0`3kno/0oooo0?ooo`020000000407alO03gmoL0moOg0?_kn`80oooo0P0000000`20P800oooo0?oo
o`050?ooo`D0moOg0`3oool2000000D0oooo0`0000020?Ogm`030?_kn`3oool0oooo0080oooo00<0
no_k0?Ogm`3gmoL00P3oool0103kno/0moOg0?Ogm`3kno/70?ooo`80moOg0`3_knl30=kNgP80Ng]k
1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_
knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3WinL20>o_k`80oooo
0`3gmoL70?ooo`030820P0000000000000D0oooo0P3gmoL00`3kno/0oooo0?ooo`080?ooo`80moOg
00<0no_k0?ooo`3oool00P3gmoL60?ooo`l000001@3gmoL20<K6aP0306MWI`0820P020P800<00000
0P1JFUX00`0];Bd0000000000007000000<0oooo0`3gmoL?00000080moOg00<0jn_[0=kNgP3Ng]h0
0P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL30<K6aP8020P8
0`00000201PH600306m_K`36a/H0a/K60080oooo00<0no_k0?Ogm`3gmoL00P0000000`20P800oooo
0?ooo`030?ooo`80000000<0O7al0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`080?ooo`800000
1@3gmoL300000080oooo00<0no_k0?Ogm`3gmoL01@3oool?000000<0moOg0`3Ng]h208B4Q0L0oooo
00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>
c/h00`36a/H0_Kfm0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3Ng]h0inOW0P3_knl20?ooo`<0moOg
1`3oool00`20P8000000000000050?ooo`80moOg00<0no_k0?ooo`3oool0203oool20?Ogm`030?_k
n`3oool0oooo0080moOg1P3oool?000000D0moOg0P36a/H00`1WIfL020P800P8200300000080FUYJ
00<0;Bd]0000000000001`0000030?ooo`<0moOg3`0000020?Ogm`030>_[j`3Ng]h0g]kN0080Q8B4
00<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[j`3gmoL0moOg0080moOg0`36a/H200P820<00000
0P0H61P00`1_Kfl0a/K60<K6aP020?ooo`030?_kn`3gmoL0moOg0080000000<0P8200?ooo`3oool0
0`3oool20000000307alO03gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL0203oool2000000D0moOg
0`0000020?ooo`030?_kn`3gmoL0moOg00D0oooo3`0000030?Ogm`<0g]kN0P24Q8@70?ooo`030=kN
gP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0
a/K60;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN0>OWi`80kno_0P3oool30?Ogm`L0oooo
00<0P8200000000000001@3oool20?Ogm`030?_kn`3oool0oooo00P0oooo0P3gmoL00`3kno/0oooo
0?ooo`020?Ogm`H0oooo3`0000050?Ogm`80a/K600<0IfMW00P8200820P00`00000205YJFP0302d]
;@000000000000L000000`3oool30?Ogm`l000000P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030<;2
`P3oool0oooo00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`<0a/K60P0820P30000008061PH
00<0Kfm_0<K6aP36a/H00P3oool00`3kno/0moOg0?Ogm`02000000030820P03oool0oooo00<0oooo
0P0000000`1lO7`0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00P0oooo0P0000050?Ogm`<00000
0P3oool00`3kno/0moOg0?Ogm`050?ooo`l000000`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36
a/H0a/K600D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL;0?Ogm`040?_kn`3oool0oooo0820P080
00001@3gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`H0
moOg3`0000020?ooo`030?_kn`3gmoL0moOg0080410@00<0CTi>08b<S02<S8`00`3gmoL207=cL`03
03Xj>P00000000000080oooo0`0000080?Ogm`8000001`3gmoL0103kno/0oooo0?ooo`20P8020000
0080kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_
k`3_knl00P3gmoL301PH6080Jf][0`3oool20:f][@0305MGE`00000000000080c/k>00<0inOW0?oo
o`3oool02P0000000`1lO7`0moOg0?Ogm`020?Ogm`030?_kn`3oool0oooo00P0moOg2P0000020?Og
m`030?_kn`3oool0oooo00D0moOg3`0000030>o_k`<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm
00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36
a/H01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWi`/0moOg00@0no_k0?ooo`3oool0P8200P000005
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo1P3gmoL?
00000080oooo00<0no_k0?Ogm`3gmoL00P0@41000`1>CTh0S8b<08b<S0030?Ogm`80Lg=c00<0>SXj
0000000000000P3oool3000000P0moOg0P0000070?Ogm`040?_kn`3oool0oooo0820P08000000P3_
knl00`3WinL0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_
k`020?Ogm`<061PH0P1[Jf/30?ooo`80[Jf]00<0EeMG0000000000000P3>c/h00`3WinL0oooo0?oo
o`0:0000000307alO03gmoL0moOg0080moOg00<0no_k0?ooo`3oool0203gmoL:00000080moOg00<0
no_k0?ooo`3oool01@3gmoL?000000<0kno_0`3Fe]H208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3F
e]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@05
0>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL20?ooo`D0moOg00<0O7al0000000000000P3g
moL00`3kno/0oooo0?ooo`0:0?Ogm`030?_kn`3oool0oooo00d0moOg3`0000020?Ogm`030?_kn`3o
ool0oooo0080000000<0O7al0?Ogm`3gmoL00`3oool20?Ogm`0307alO000000000000080moOg0`00
00080?ooo`8000000P3oool00`3kno/0moOg0?Ogm`020?ooo`040?_kn`3gmoL0moOg07alO0800000
0P3gmoL00`3WinL0e]KF0=KFeP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3WinL0kno_
0>o_k`020?Ogm`<000001@3gmoL20?ooo`030;Fe]@1[Jf/0Jf][0080DU9B00<0YJFU0?Ogm`3gmoL0
0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL50?ooo`@0moOg
00<0no_k0?ooo`3oool00`3gmoL20?ooo`030?_kn`3gmoL0moOg00D0moOg3`0000030?Ogm`<0g]kN
0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[
1`3gmoL20?ooo`D0moOg00<0O7al0000000000000P3gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030?_k
n`3oool0oooo00d0moOg3`0000020?Ogm`030?_kn`3oool0oooo0080000000<0O7al0?Ogm`3gmoL0
0`3oool20?Ogm`0307alO000000000000080moOg0`0000080?ooo`8000000P3oool00`3kno/0moOg
0?Ogm`020?ooo`040?_kn`3gmoL0moOg07alO08000000P3gmoL00`3WinL0e]KF0=KFeP0208B4Q003
0;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`020?Ogm`<000001@3gmoL20?ooo`03
0;Fe]@1[Jf/0Jf][0080DU9B00<0YJFU0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`030?Ogm`80
oooo00<0no_k0?Ogm`3gmoL0203gmoL50?ooo`@0moOg00<0no_k0?ooo`3oool00`3gmoL20?ooo`03
0?_kn`3gmoL0moOg00D0moOg3`0000030?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m
_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm
0;fm_@020?Ogm`030?Gem@3clo<0lo?c0080Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<50?Ogm`80
no_k0P3gmoL0103inOT0no_k0?_kn`1nOWh200000080moOg00<0nOWi0?_kn`3kno/00P3gmoL00`3i
nOT0no_k0?_kn`030?Ogm`80no_k00<0oOgm0?ooo`3oool00P3gmoL00`3inOT0no_k0?_kn`080?Og
m`l000000P3gmoL00`3kno/0oooo0?ooo`0200@4100306=SH`32`/80`/;200<0oooo0P32`/800`1Q
HF400000000000020?Ogm`<00000203kno/200000080no_k00<0nOWi0?Ogm`3gmoL00P3kno/0103i
nOT0moOg0?Ogm`1lO7`200000080lo?c00<0iNGU0=KFeP3Fe]H00P24Q8@00`2l_;`0lo?c0??cl`03
08B4Q080f][J00<0iNGU0>o_k`3_knl00P3gmoL300@41080hn?S1@3kno/00`34a<@0S8b<08b<S002
02d];@0309:BTP3gmoL0moOg0080oooo00@0no_k0?Ogm`3gmoL0nOWi103kno/00`3inOT0moOg0?Og
m`080?Ogm`D0no_k0P3gmoL50?_kn`<0moOg0P3kno/00`3inOT0moOg0?Ogm`020?_kn`030?Win@3g
moL0moOg00l000000`3clo<30=[JfP80Q8B41@3clo<20?Ogm`030=gMg@32`/80`/;200<0c/k>0P3W
inL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool0
0`3kno/0moOg0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_2@3gmoL0103kno/0oooo0?oo
o`20P802000000L0moOg00<0no_k0?ooo`3oool00`3gmoL50?ooo`80moOg00<0no_k0?ooo`3oool0
203gmoL?00000080moOg00<0no_k0?ooo`3oool00P0820P00`1:BTX0S8b<08b<S0030?ooo`80S8b<
00<0ATI60000000000000P3gmoL3000000P0moOg0P00000:0?Ogm`0307alO000000000000080kno_
00<0hn?S0=KFeP3Fe]H00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080e]KF00<0hn?S0>o_k`3_knl0
0P3gmoL300P82080c/k>0`3oool20?Ogm`030=;BdP2][Jd0[Jf]008020P800<0P8200?Ogm`3gmoL0
0P3oool0103kno/0moOg0?Ogm`3kno/20?oooa@0moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80
oooo00<0no_k0?Ogm`3gmoL03`0000030>o_k`<0e]KF0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0
c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd0
0P3oool00`3kno/0moOg0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_2@3gmoL0103kno/0
oooo0?ooo`20P802000000L0moOg00<0no_k0?ooo`3oool00`3gmoL50?ooo`80moOg00<0no_k0?oo
o`3oool0203gmoL?00000080moOg00<0no_k0?ooo`3oool00P0820P00`1:BTX0S8b<08b<S0030?oo
o`80S8b<00<0ATI60000000000000P3gmoL3000000P0moOg0P00000:0?Ogm`0307alO00000000000
0080kno_00<0hn?S0=KFeP3Fe]H00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080e]KF00<0hn?S0>o_
k`3_knl00P3gmoL300P82080c/k>0`3oool20?Ogm`030=;BdP2][Jd0[Jf]008020P800<0P8200?Og
m`3gmoL00P3oool0103kno/0moOg0?Ogm`3kno/20?oooa@0moOg0P3oool00`3kno/0moOg0?Ogm`08
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL03`0000030>o_k`<0e]KF0P24Q8@70?Ogm`030=oOg`36a/H0
a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm
_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF0>OWi`80moOg1@3oool40?Ogm`040?_kn`3oool0
oooo0820P08000000P3oool00`3kno/0moOg0?Ogm`050?Ogm`<0oooo2P3gmoL50?ooo`030?_kn`3g
moL0moOg00l000001@3gmoL20<K6aP0306MWI`0820P020P800<000000P1JFUX00`0];Bd000000000
00020?ooo`<000000P3oool60?Ogm`8000000P3gmoL00`3kno/0oooo0?ooo`050?Ogm`0307alO000
000000000080moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0
kno_0?ooo`3oool00P3oool308b<S08061PH0`3Fe]H20=kNgP030:6QX@1SHf<0Hf=S0080000000<0
O7al0?Ogm`3gmoL00P3gmoL0103kno/0oooo0?ooo`3kno/90?Ogm`030?_kn`3oool0oooo00D0oooo
1@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_k
n`3oool0oooo00l000000`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24
Q8@0102][Jd0e]KF0=KFeP3WinL20?Ogm`D0oooo103gmoL0103kno/0oooo0?ooo`20P80200000080
oooo00<0no_k0?Ogm`3gmoL01@3gmoL30?ooo`X0moOg1@3oool00`3kno/0moOg0?Ogm`0?000000D0
moOg0P36a/H00`1WIfL020P800P8200300000080FUYJ00<0;Bd]0000000000000P3oool300000080
oooo1P3gmoL200000080moOg00<0no_k0?ooo`3oool01@3gmoL00`1lO7`00000000000020?Ogm`03
0>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>o_k`3oool0oooo0080
oooo0`2<S8`201PH60<0e]KF0P3Ng]h00`2QXJ40Hf=S06=SH`020000000307alO03gmoL0moOg0080
moOg00@0no_k0?ooo`3oool0no_k2@3gmoL00`3kno/0oooo0?ooo`050?ooo`D0moOg0P3oool00`3k
no/0moOg0?Ogm`030?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`0?0000
00<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg
00Sooooo0006ooooo`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80Q8B400@0[Jf]0=KFeP3F
e]H0inOW0P3gmoL50?_kn`80moOg1@3kno/00`1nOWh00000000000020?_kn`030?Win@3gmoL0moOg
00D0moOg0`3kno/:0?Ogm`D0no_k00<0nOWi0?Ogm`3gmoL03`0000050?Ogm`80gmoO00<0/;2`0820
P020P8000`1lO7`20:VYZ@0305EEE@00000000000080no_k0`0000020?_kn`<0moOg0`3kno/20000
0080O7al00<0OWin0820P020P8001@1lO7`00`0n?Sh00000000000020?Ogm`030>_[j`3Ng]h0g]kN
0080Q8B400<0`<300?_kn`3kno/00`20P8020=kNgP030>_[j`3gmoL0moOg0080no_k0`32`/82059B
DP<0Jf][0P1_Kfl00`20P800T92@092@T0020000000307alO03gmoL0moOg0080moOg00@0nOWi0?_k
n`3kno/0nOWi2@3gmoL00`3inOT0no_k0?_kn`050?_kn`<0moOg103kno/00`3inOT0moOg0?Ogm`03
0?_kn`80moOg00<0nOWi0?_kn`3kno/00P3gmoL00`3inOT0no_k0?_kn`0?000000<0lo?c0`3Ng]h2
08B4Q0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW2@3gmoL2
0?ooo`040?_kn`3gmoL0moOg07alO08000007`3gmoL?000000l0moOg00<0O7al0000000000000P3g
moL3000000D0moOg0`3oool?00000080moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Og
m`0307]kN`80g]kN00<0inOW0>o_k`3_knl01@3gmoL208b<S0D0000000<0GemO0;fm_@2m_Kd00P00
00000`1lO7`0moOg0?Ogm`0J0?Ogm`80oooo4P3gmoL?000000<0kno_0`3Ng]h208B4Q0L0moOg00<0
gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h0
0`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW2@3gmoL20?ooo`040?_kn`3g
moL0moOg07alO08000007`3gmoL?000000l0moOg00<0O7al0000000000000P3gmoL3000000D0moOg
0`3oool?00000080moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN
00<0inOW0>o_k`3_knl01@3gmoL208b<S0D0000000<0GemO0;fm_@2m_Kd00P0000000`1lO7`0moOg
0?Ogm`0J0?Ogm`80oooo4P3gmoL?000000<0kno_0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H0
0`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6
aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl<0?Ogm`0307alO000000000000080moOg
00<0no_k0?ooo`3oool08`3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool0
2P3gmoL00`1lO7`00000000000020?Ogm`<00000303gmoL00`3kno/0oooo0?ooo`020?ooo`030?_k
n`3gmoL0moOg00<0moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B4
0P3Fe]H00`3Shn<0kno_0>o_k`0<0?Ogm`030;Vi^@1kNg/0Ng]k008061PH00<0R8R80?Ogm`3gmoL0
903gmoL20?ooo`030?_kn`3gmoL0moOg01L0moOg0`3Fe]H208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6
aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl<0?Ogm`0307alO000000000000080moOg
00<0no_k0?ooo`3oool08`3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool0
2P3gmoL00`1lO7`00000000000020?Ogm`<00000303gmoL00`3kno/0oooo0?ooo`020?ooo`030?_k
n`3gmoL0moOg00<0moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B4
0P3Fe]H00`3Shn<0kno_0>o_k`0<0?Ogm`030;Vi^@1kNg/0Ng]k008061PH00<0R8R80?Ogm`3gmoL0
903gmoL20?ooo`030?_kn`3gmoL0moOg01L0moOg0`3Fe]H208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6
aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl<0?Ogm`0307alO000000000000080moOg
00<0no_k0?ooo`3oool08`3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool0
2P3gmoL00`1lO7`00000000000020?Ogm`<00000303gmoL00`3kno/0oooo0?ooo`020?ooo`030?_k
n`3gmoL0moOg00<0moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B4
0P3Fe]H00`3Shn<0kno_0>o_k`0<0?Ogm`030;Vi^@1kNg/0Ng]k008061PH00<0R8R80?Ogm`3gmoL0
903gmoL20?ooo`030?_kn`3gmoL0moOg01L0moOg0`3Fe]H208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm
_@050?Ogm`80S8b<00@0/K6a0=KFeP3Fe]H0hn?S0P3_knl20?Ogm`<0kno_1`3gmoL00`1lO7`00000
0000000B0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3gmoL30?ooo`030?_kn`3gmoL0moOg01`0moOg
2P00000A0?Ogm`040??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q003
0<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`020>o_k`D0moOg0`1[Jf/200000003
00@4100820P020P80080_Kfm00<0f][J0?Ogm`3gmoL02P3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0
oooo7P3gmoL00`3kno/0oooo0?ooo`070?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg00<0f][J0;fm_@2m
_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm
0;fm_@050?Ogm`80S8b<00@0/K6a0=KFeP3Fe]H0hn?S0P3_knl20?Ogm`<0kno_1`3gmoL00`1lO7`0
00000000000B0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3gmoL30?ooo`030?_kn`3gmoL0moOg01`0
moOg2P00000A0?Ogm`040??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4
Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`020>o_k`D0moOg0`1[Jf/20000
000300@4100820P020P80080_Kfm00<0f][J0?Ogm`3gmoL02P3gmoL00`3kno/0oooo0?ooo`050?Og
m`<0oooo7P3gmoL00`3kno/0oooo0?ooo`070?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0
_Kfm0;fm_@050?_kn`80R8R800@0/K6a0=[JfP3Jf]X0iNGU0P3_knl70?Ogm`80lo?c00@0mOGe0?Og
m`3gmoL0O7al0P0000070?Ogm`030?Gem@3clo<0lo?c00<0no_k1@3gmoL20?_kn`030?Win@3gmoL0
moOg0080moOg1P3kno/20?Ogm`80lo?c00<0mOGe0?Ogm`3gmoL03@3gmoL20?_kn`030?Win@3gmoL0
moOg00<0moOg1`1lO7`307QhN080no_k0`3gmoL30??cl`T0moOg00<0mOGe0??cl`3clo<01@3clo<0
0`3UiND0e]KF0=KFeP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Jf]X00`3QhN40inOW0>OWi`05
0?Ogm`80lo?c0`2a/K4207alO00307inOP20P800P8200080f][J00<0jNWY0?Ogm`3gmoL00P3gmoL0
103inOT0no_k0?_kn`3inOT40?Ogm`030?Win@3kno/0no_k00D0moOg1@3kno/30?Ogm`80lo?c3`3g
moL00`3inOT0no_k0?_kn`050?Ogm`030?Win@3kno/0no_k0080moOg00<0mOGe0??cl`3clo<01@3c
lo<30=[JfP80P8201`3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3W
inL20>o_k`80moOg0`3oool20?Ogm`80kno_00@0lo?c0?Ogm`3gmoL0O7al0P0000070?Ogm`030??c
l`3_knl0kno_00<0oooo3`3gmoL00`3kno/0oooo0?ooo`020?Ogm`80kno_00<0lo?c0?Ogm`3gmoL0
3@3gmoL20?ooo`030?_kn`3gmoL0moOg00X0moOg0`3_knl20?ooo`<0moOg0`3_knl<0?Ogm`030??c
l`3_knl0kno_0080moOg00<0inOW0=KFeP3Fe]H00P24Q8@00`32`/80oooo0?ooo`0308B4Q080e]KF
00<0f][J0=kNgP3Ng]h00P3oool30?Ogm`80kno_3`3gmoL0103kno/0oooo0?ooo`3kno/?0?Ogm`80
oooo0`3gmoL20>o_k`l0moOg00<0no_k0?ooo`3oool02P3gmoL00`3clo<0kno_0>o_k`020>o_k`<0
moOg0`3Ng]h207]kN`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0
inOW0P3_knl20?Ogm`<0oooo0P3gmoL20>o_k`040??cl`3gmoL0moOg07alO08000001`3gmoL00`3c
lo<0kno_0>o_k`030?ooo`l0moOg00<0no_k0?ooo`3oool00P3gmoL20>o_k`030??cl`3gmoL0moOg
00d0moOg0P3oool00`3kno/0moOg0?Ogm`0:0?Ogm`<0kno_0P3oool30?Ogm`<0kno_303gmoL00`3c
lo<0kno_0>o_k`020?Ogm`030>OWi`3Fe]H0e]KF0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=KF
eP030=[JfP3Ng]h0g]kN0080oooo0`3gmoL20>o_k`l0moOg00@0no_k0?ooo`3oool0no_k3`3gmoL2
0?ooo`<0moOg0P3_knl?0?Ogm`030?_kn`3oool0oooo00X0moOg00<0lo?c0>o_k`3_knl00P3_knl3
0?Ogm`<0g]kN0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF
0>?Sh`80kno_303gmoL00`1lO7`00000000000020?Ogm`030??cl`3_knl0kno_00P0moOg1@3_knlI
0?Ogm`030??cl`3_knl0kno_00L0moOg00<0lo?c0>o_k`3_knl00`3_knlI0?Ogm`D0kno_00<0lo?c
0?Ogm`3gmoL00P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Fe]H0
0`3Shn<0kno_0>o_k`0:0?Ogm`80kno_00<0lo?c0?Ogm`3gmoL01@3_knl50?Ogm`030??cl`3_knl0
kno_01`0moOg0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`80kno_00<0lo?c0?Ogm`3gmoL02P3gmoL3
0>o_k`<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF
0>?Sh`80kno_303gmoL00`1lO7`00000000000020?Ogm`030??cl`3_knl0kno_00P0moOg1@3_knlI
0?Ogm`030??cl`3_knl0kno_00L0moOg00<0lo?c0>o_k`3_knl00`3_knlI0?Ogm`D0kno_00<0lo?c
0?Ogm`3gmoL00P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Fe]H0
0`3Shn<0kno_0>o_k`0:0?Ogm`80kno_00<0lo?c0?Ogm`3gmoL01@3_knl50?Ogm`030??cl`3_knl0
kno_01`0moOg0P3_knl00`3clo<0moOg0?Ogm`050?Ogm`80kno_00<0lo?c0?Ogm`3gmoL02P3gmoL3
0>o_k`<0e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<208B4Q0040:f][@3Fe]H0e]KF
0=oOg`80inOW0P3gmoL30??cl`80moOg0P3clo<0103emOD0moOg0?Ogm`1lO7`200000080moOg00<0
mOGe0??cl`3clo<00P3clo<00`3emOD0moOg0?Ogm`080??cl`80moOg00<0mOGe0??cl`3clo<00P3c
lo<30?Ogm`030?Gem@3clo<0lo?c0080moOg0P3clo<00`3emOD0moOg0?Ogm`020?Ogm`040?Win@3k
no/0no_k0?Ogm`@0lo?c00<0mOGe0?Ogm`3gmoL0203clo<20?Ogm`030?Gem@3clo<0lo?c00D0moOg
0P3clo<30?Ogm`<0lo?c1`3gmoL20??cl`040?7al@3_knl0kno_0?7al@80lo?c0P3_knl00`3UiND0
f][J0=[JfP0208B4Q0030;bl_03clo<0lo?c00<0P8200P3Fe]H00`3Shn<0kno_0>o_k`020??cl`<0
moOg0P3clo<30?Ogm`80lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3alO40kno_0>o_k`020?Ogm`03
0?Gem@3clo<0lo?c00<0lo?c1@3gmoL50??cl`P0moOg0P3clo<80?Ogm`D0lo?c0P3gmoL00`3emOD0
lo?c0??cl`020??cl`030?Gem@3gmoL0moOg00<0moOg1@3clo<20?Ogm`<0kno_0`3Jf]X208B4Q0D0
lo?c0P3gmoL00`3Jf]X0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102][Jd0e]KF0=KFeP3Jf]X20=kNgP80
moOg0`3_knl20?Ogm`80kno_00@0lo?c0?Ogm`3gmoL0O7al0P0000050?Ogm`80kno_00<0lo?c0?Og
m`3gmoL00`3_knl70?Ogm`030??cl`3_knl0kno_0080kno_0`3gmoL00`3clo<0kno_0>o_k`020?Og
m`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80kno_00<0lo?c
0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`050?Ogm`030??cl`3_knl0kno_00D0moOg0P3_knl3
0?Ogm`<0kno_2@3gmoL00`3clo<0kno_0>o_k`050>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj
0>o_k`3_knl00`24Q8@20=KFeP030>?Sh`3_knl0kno_0080kno_0`3gmoL20>o_k`X0moOg00<0lo?c
0>o_k`3_knl00P3gmoL0103clo<0kno_0>o_k`3clo<70?Ogm`D0kno_203gmoL20>o_k`X0moOg00<0
lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`080?Ogm`D0kno_0P3gmoL30>o_k`<0g]kN0P24
Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3N
g]h20?Ogm`<0kno_0P3gmoL20>o_k`040??cl`3gmoL0moOg07alO08000001@3gmoL20>o_k`030??c
l`3gmoL0moOg00<0kno_1`3gmoL00`3clo<0kno_0>o_k`020>o_k`<0moOg00<0lo?c0>o_k`3_knl0
0P3gmoL20>o_k`030??cl`3gmoL0moOg0080moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`03
0??cl`3gmoL0moOg0080kno_00<0lo?c0?Ogm`3gmoL01@3gmoL00`3clo<0kno_0>o_k`050?Ogm`80
kno_0`3gmoL30>o_k`T0moOg00<0lo?c0>o_k`3_knl01@3_knl00`3WinL0g]kN0=kNgP0208B4Q003
0;Zj^P3_knl0kno_00<0Q8B40P3Fe]H00`3Shn<0kno_0>o_k`020>o_k`<0moOg0P3_knl:0?Ogm`03
0??cl`3_knl0kno_0080moOg00@0lo?c0>o_k`3_knl0lo?c1`3gmoL50>o_k`P0moOg0P3_knl:0?Og
m`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl0203gmoL50>o_k`80moOg0`3_knl30=kN
gP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?S
h`@0kno_0`3gmoL20>o_k`80oooo00@0moOg0>o_k`3_knl0N7Qh0P0000020>o_k`030??cl`3gmoL0
moOg0080kno_00<0lo?c0?Ogm`3gmoL00`3gmoL20>o_k`0307QhN0000000000000L000000`3_knl0
0`3clo<0moOg0?Ogm`020>o_k`80oooo00<0moOg0>o_k`3_knl01@3_knl00`3clo<0moOg0?Ogm`02
0>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl00`3gmoL20>o_k`030??cl`3gmoL0
moOg0080moOg0`3_knl20?Ogm`<0kno_0`3oool70>o_k`80moOg00@0lo?c0>o_k`3_knl0lo?c0P3g
moL20>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@50=kNgP80moOg0`3_
knl20?ooo`P0kno_0P3gmoL00`3clo<0kno_0>o_k`050?Ogm`030??cl`3_knl0kno_0080moOg00<0
lo?c0>o_k`3_knl01@3gmoL30>o_k`80moOg0`3_knl20?ooo`P0kno_0P3gmoL00`3clo<0kno_0>o_
k`050?Ogm`80kno_00@0lo?c0?Ogm`3gmoL0lo?c0P3_knl50?Ogm`D0kno_0`3Fe]H208b<S0L0moOg
00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3>c/h0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S103_knl30?Ogm`80kno_
0P3oool0103gmoL0kno_0>o_k`1hN7P200000080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3clo<0
moOg0?Ogm`030?Ogm`80kno_00<0N7Qh0000000000001`0000030>o_k`030??cl`3gmoL0moOg0080
kno_0P3oool00`3gmoL0kno_0>o_k`050>o_k`030??cl`3gmoL0moOg0080kno_00<0lo?c0?Ogm`3g
moL00P3gmoL00`3clo<0kno_0>o_k`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL30>o_k`80
moOg0`3_knl30?ooo`L0kno_0P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_00<0hn?S0=KF
eP3Fe]H00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q0D0g]kN0P3gmoL30>o_k`80oooo203_knl20?Og
m`030??cl`3_knl0kno_00D0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`050?Og
m`<0kno_0P3gmoL30>o_k`80oooo203_knl20?Ogm`030??cl`3_knl0kno_00D0moOg0P3_knl0103c
lo<0moOg0?Ogm`3clo<20>o_k`D0moOg1@3_knl30=KFeP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP03
0<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=KFeP030<c<c032`/80`/;2
00D0no_k0P24Q8@0102][Jd0e]KF0=KFeP3Ogml20>OWi`80kno_0`3gmoL20>o_k`80moOg00@0lo?c
0>o_k`3_knl0N7Qh0P0000020>?Sh`030>g]k@3gmoL0moOg0080kno_00<0lo?c0?Ogm`3gmoL00`3c
lo<20>o_k`0307QhN000000000000080N7Qh00<0NWYj07alO01lO7`00P0000030>o_k`030??cl`3g
moL0moOg0080kno_0P3gmoL00`3clo<0kno_0>o_k`020??cl`040?7al@3_knl0kno_0??cl`80moOg
0P3_knl00`3clo<0moOg0?Ogm`020??cl`030?7al@3_knl0kno_00<0lo?c0P3_knl00`3clo<0moOg
0?Ogm`020??cl`<0kno_0P3gmoL30>o_k`<0moOg0P3_knl20??cl`030?7al@3_knl0kno_0080lo?c
00@0lO7a0>o_k`3_knl0lo?c0P3gmoL20>o_k`030>?Sh`3Fe]H0e]KF0080P82000<0_[jn0?_kn`3k
no/00`28R8P20=KFeP030=oOg`3WinL0inOW0080moOg0`3_knl20?Ogm`<0kno_0P3clo<00`3alO40
kno_0>o_k`020?Ogm`030??cl`3_knl0kno_0080moOg00@0mOGe0??cl`3clo<0lO7a0P3_knl20??c
l`030?7al@3_knl0kno_0080moOg00<0mOGe0??cl`3clo<00`3_knl20?Ogm`<0kno_0P3gmoL20>o_
k`030?7al@3clo<0lo?c00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030?Gem@3clo<0lo?c
0080kno_00@0lO7a0??cl`3clo<0lO7a0P3_knl20?Ogm`030?Gem@3clo<0lo?c00D0kno_0`3Fe]H2
08R8R0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h2
0>o_k`<0moOg1`3_knl00`1hN7P00000000000020=KFeP030>OWi`3gmoL0moOg0080kno_00<0lo?c
0?Ogm`3gmoL01@3_knl00`1hN7P00000000000020>o_k`030??cl`3gmoL0moOg008000000`3_knl0
0`3clo<0moOg0?Ogm`070>o_k`80moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030??cl`3g
moL0moOg00X0kno_00<0lo?c0?Ogm`3gmoL01@3_knl20?Ogm`P0kno_0P3gmoL00`3clo<0kno_0>o_
k`050>o_k`030??cl`3gmoL0moOg0080kno_00<0hn?S0=KFeP3Fe]H00P1kNg/00`2m_Kd0oooo0?oo
o`0308b<S080c/k>00<0gmoO0>o_k`3_knl00P3gmoL80>o_k`80moOg00<0lo?c0>o_k`3_knl00P3g
moL00`3clo<0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00P0kno_0P3gmoL00`3clo<0kno_0>o_
k`030>o_k`80moOg1`3_knl00`3clo<0moOg0?Ogm`030>o_k`80moOg00<0lo?c0>o_k`3_knl00P3g
moL00`3clo<0kno_0>o_k`080>o_k`80moOg00<0lo?c0>o_k`3_knl01@3_knl30=KFeP80Q8B41`3o
ool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl2
0=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102][Jd0e]KF0=KFeP3Jf]X20=kNgP80kno_0`3g
moL70>o_k`0307QhN000000000000080e]KF00<0inOW0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Og
m`050>o_k`0307QhN000000000000080kno_00<0lo?c0?Ogm`3gmoL00P0000030>o_k`030??cl`3g
moL0moOg00L0kno_0P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_00<0lo?c0?Ogm`3gmoL0
2P3_knl00`3clo<0moOg0?Ogm`050>o_k`80moOg203_knl20?Ogm`030??cl`3_knl0kno_00D0kno_
00<0lo?c0?Ogm`3gmoL00P3_knl00`3Shn<0e]KF0=KFeP0207]kN`030;fm_@3oool0oooo00<0S8b<
0P3>c/h00`3Ogml0kno_0>o_k`020?Ogm`P0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030??c
l`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl0203_knl20?Ogm`030??cl`3_knl0kno_00<0kno_
0P3gmoL70>o_k`030??cl`3gmoL0moOg00<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030??c
l`3_knl0kno_00P0kno_0P3gmoL00`3clo<0kno_0>o_k`050>o_k`<0e]KF0P24Q8@70?ooo`030=kN
gP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80d];B00<0
b<S80;fm_@2m_Kd01@3kno/208B4Q0040:f][@3Fe]H0e]KF0=oOg`80inOW0P3_knl30??cl`L0kno_
00<0QXJ601dM7@0M7Ad00P2][Jd00`3@d=00lo?c0??cl`020>o_k`030?7al@3clo<0lo?c00<0lo?c
0P3_knl00`1hN7P00000000000020>o_k`030?7al@3clo<0lo?c008000000`3_knl00`3alO40lo?c
0??cl`070>o_k`80lo?c00@0lO7a0>o_k`3_knl0lO7a0P3clo<20>o_k`030?7al@3clo<0lo?c0080
lo?c00<0lO7a0>o_k`3_knl00`3_knl50??cl`D0kno_0P3clo<80>o_k`80lo?c00<0lO7a0>o_k`3_
knl01@3_knl00`3alO40lo?c0??cl`020>o_k`030>?Sh`3Fe]H0e]KF0080P82000<0_[jn0?_kn`3k
no/00`28R8P20=;BdP030=gMg@3WinL0inOW0080lo?c203_knl20??cl`030?7al@3_knl0kno_0080
lo?c00<0lO7a0>o_k`3_knl01@3clo<00`3alO40kno_0>o_k`020>o_k`030?7al@3clo<0lo?c0080
lo?c00<0lO7a0>o_k`3_knl00`3_knl20??cl`L0kno_00<0lO7a0??cl`3clo<00`3_knl20??cl`03
0?7al@3_knl0kno_0080lo?c00<0lO7a0>o_k`3_knl0203_knl20??cl`030?7al@3_knl0kno_0080
kno_0`3WinL30=KFeP80O7al1`3kno/00`3Lg=`0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF
0=KFeP3Shn<>0>o_k`0309BDU00i>CT0>CTi0080Q8B400<0^[Zj0>o_k`3_knl01@3_knl30?Ogm`80
kno_00<0N7Qh0000000000001@3_knl2000001X0kno_0P3gmoL00`3clo<0kno_0>o_k`030>o_k`80
moOg00<0lo?c0>o_k`3_knl07P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0
Q8B40P3Fe]H00`3Jf]X0g]kN0=kNgP0F0>o_k`040??cl`3gmoL0moOg0??cl`@0kno_00<0lo?c0?Og
m`3gmoL0<03_knl30=kNgP<0e]KF0P1cLg<70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q004
0:f][@3Fe]H0e]KF0>?Sh`h0kno_00<0U9BD03Ti>@0i>CT00P24Q8@00`2j^[X0kno_0>o_k`050>o_
k`<0moOg0P3_knl00`1hN7P00000000000050>o_k`8000006P3_knl20?Ogm`030??cl`3_knl0kno_
00<0kno_0P3gmoL00`3clo<0kno_0>o_k`0N0>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Og
m`3gmoL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN01H0kno_00@0lo?c0?Ogm`3gmoL0lo?c103_knl0
0`3clo<0moOg0?Ogm`0`0>o_k`<0g]kN0`3Fe]H207=cL`L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H2
0=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Og
m`030??cl`3_knl0kno_0080Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0kno_0P3Ng]h50>o_
k`030<K6aP2LW9`0W9bL0080000000<0CTi>09bLW02LW9`00P3_knl00`3Kfm/0a/K60<K6aP0304Y:
BP80moOg00<0O7al0000000000001`0000060>o_k`80g]kN0P3_knl00`3WinL0g]kN0=kNgP020?Og
m`040>_[j`3Ng]h0g]kN0>OWi`@0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP0G
0>o_k`80moOg00<0jn_[0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80g]kN00<0
f][J0=KFeP3Fe]H00P1kNg/00`2e]KD0kno_0>o_k`0308B4Q0D0e]KF0P3Ng]h30>o_k`80g]kN0`3_
knl20?Ogm`030>_[j`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3clo<0moOg0?Og
m`0B0>o_k`80g]kN0P3_knl00`3WinL0g]kN0=kNgP030>o_k`80g]kN00<0inOW0>o_k`3_knl00P3_
knl00`3WinL0g]kN0=kNgP020?Ogm`040>_[j`3Ng]h0g]kN0>OWi`T0kno_0`3Ng]h30=KFeP80Ng]k
0P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_
k`0208B4Q0030:f][@3Fe]H0e]KF00<0e]KF0P3Ng]h30>o_k`80g]kN1@3_knl00`36a/H0W9bL09bL
W0020000000304i>CP2LW9`0W9bL0080kno_00<0fm_K0<K6aP36a/H00`1:BTX20?Ogm`0307alO000
0000000000L000001P3_knl20=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3gmoL0103[jn/0g]kN0=kN
gP3WinL40>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h05`3_knl20?Ogm`030>_[
j`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW0P3_knl20=kNgP030=[JfP3Fe]H0e]KF0080
Ng]k00<0]KFe0>o_k`3_knl00`24Q8@50=KFeP80g]kN0`3_knl20=kNgP<0kno_0P3gmoL00`3[jn/0
g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0kno_00<0lo?c0?Ogm`3gmoL04P3_knl20=kNgP80
kno_00<0inOW0=kNgP3Ng]h00`3_knl20=kNgP030>OWi`3_knl0kno_0080kno_00<0inOW0=kNgP3N
g]h00P3gmoL0103[jn/0g]kN0=kNgP3WinL90>o_k`<0g]kN0`3Fe]H207]kN`80kno_00<0lo?c0?Og
m`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=;BdP030<[:bP32`/80`/;20080moOg00<0mOGe0??cl`3clo<00P24Q8@0102[Zj/0
d];B0=;BdP3Fe]H20=[JfP80g]kN0`3WinL20=kNgP80kno_00@0jn_[0>OWi`3WinL0d];B0P2m_Kd2
0492@P0304Y:BP1BDU80DU9B00D0N7Qh0`28R8P20>_[j`030;:b/P1hN7P0N7Qh00L0Kfm_0`3_knl0
0`3[jn/0inOW0>OWi`020=kNgP80inO_00<0hn?W0=kNgP3Ng]h00P3[jn/0103UiND0g]kN0=kNgP3W
inL20>o_k`80inOW00<0hn?S0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP050>OWi`030>_[j`3_
knl0kno_0080inOW0`3_knl80>OWi`80kno_0P3[jn/00`3UiND0g]kN0=kNgP020>OWk`040>?Si`3N
g]h0g]kN0>?Sh`80inOW0P3Ng]h00`3Hf=P0d];B0=;BdP020820P0030;Zj^P3clo<0lo?c00<0Q8B4
0P3Fe]H00`3Hf=P0f][J0=[JfP020=kNgP<0inOW0P3Ng]h30>o_k`80jn_[00<0iNGU0=kNgP3Ng]h0
0P3_knl00`3WinL0g]kN0=kNgP050>OWi`030>g]k@3clo<0lo?c0080inOW00<0jn_[0>o_k`3_knl0
203WinL20>o_k`<0inOW0P3Ng]h20>OWk`030>?Si`3Ng]h0g]kN00<0inOW0P3Ng]h00`3WinL0kno_
0>o_k`020>OWi`030>?Sh`3Ng]h0g]kN0080lo?c00@0jNWY0=kNgP3Ng]h0hn?S103WinL00`3]kNd0
lo?c0??cl`020>OWi`<0g]kN0`3Bd]820820P080lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3Kfm/0
`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:
bP36a/H0a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3N
g]h00`3Ng]h208B4Q00304I6AP0820P020P80080000000<05ADE02TY:@0Y:BT00`36a/H20=kNgP03
0>OWi`3_knl0kno_00L0g]kN0`3_knl00`3WinL0g]kN0=kNgP020=kNgP80g]k_00<0g]kW0=kNgP3N
g]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0
kno_0>o_k`020=kNgP<0kno_203Ng]h20>o_k`D0g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP03
0=KFeP3>c/h0c/k>0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN00L0
g]kN0`3_knl50=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP03
0>OWi`3_knl0kno_00P0g]kN0P3_knl50=kNgP80g]k_00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0
kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3[jn/0moOg0?Ogm`050=kNgP<0
c/k>0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0
g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80Q8B400<0ATI600P8200820P00P0000000`0E5AD0
:BTY02TY:@030<K6aP80g]kN00<0inOW0>o_k`3_knl01`3Ng]h30>o_k`030>OWi`3Ng]h0g]kN0080
g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0
g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3_knl80=kNgP80kno_1@3Ng]h20=kNk`03
0=kNi`3Ng]h0g]kN00D0g]kN00<0e]KF0<k>cP3>c/h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080
e]KF00<0f][J0=kNgP3Ng]h01`3Ng]h30>o_k`D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP03
0>OWi`3_knl0kno_0080g]kN00<0inOW0>o_k`3_knl0203Ng]h20>o_k`D0g]kN0P3Ng^l00`3Ng^L0
g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP03
0>_[j`3gmoL0moOg00D0g]kN0`3>c/h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B4
00@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0
g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80
g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00<0
e]KF2P3Ng]h20=KFePd0g]kN0P3Ng]H0103Jf]H0e]KF0=KFeP3Jf]X20=kNgP80e]KF00<0d];B0<k>
cP3>c/h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080c/k>00<0e]KF0=kNgP3Ng]h00P3Fe]H:0=kN
gP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kN
gP80e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h20=kNeP030=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KF
eP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3oool0
0`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>
cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h0
0`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h2
0=KFeP030=[JfP3Ng]h0g]kN00X0g]kN0P3Ng]H00`3Jf]H0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0
e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H:0=kNgP80e]KF3@3Ng]h20=kNeP040=[JeP3Fe]H0
e]KF0=[JfP80g]kN0P3Fe]H00`3Bd]80c/k>0<k>cP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3>
c/h00`3Fe]H0g]kN0=kNgP020=KFePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kN
gP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0
f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF
1`3Ng]h30=KFeP<0c/k>0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL207=cL`040:VYZ@3N
g]h0g]kN0>_[jaH0moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P3oool00`3kno/0moOg0?Ogm`0G0?Ogm`80oooo00<0no_k0?Ogm`3gmoL03@3gmoL20?ooo`<0moOg
0P3oool?0?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P3_knl00`3WinL0g]kN0=kNgP0208B4Q003
0;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Ogm`0A0?Ogm`030?_kn`3oool0oooo00P0
moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg01@0moOg00<0no_k0?ooo`3o
ool04P3gmoL20?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Lg=c
00@0ZJVY0=kNgP3Ng]h0jn_[5P3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0
moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg01L0moOg0P3oool00`3kno/0moOg0?Ogm`0=0?Ogm`80
oooo0`3gmoL20?ooo`l0moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN
0080Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=kNgP030>_[j`3gmoL0moOg0140moOg00<0no_k0?oo
o`3oool0203gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL0503gmoL00`3k
no/0oooo0?ooo`0B0?Ogm`80oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80`/;200D0
lo?c0P1lO7`0102b/[80inOW0>OWi`3alO4F0?_kn`80oooo00<0oOgm0?_kn`3kno/00`3kno/20?oo
o`030?gmo@3kno/0no_k0080oooo00<0oOgm0?_kn`3kno/05`3kno/20?ooo`030?gmo@3kno/0no_k
00d0no_k0P3oool30?_kn`80oooo3`3kno/0103moOd0oooo0?ooo`3moOd20?_kn`80moOg00<0lo?c
0>o_k`3_knl00P24Q8@00`2l_;`0lo?c0??cl`030820P080inOW00<0lO7a0?_kn`3kno/04@3kno/0
0`3moOd0oooo0?ooo`080?_kn`80oooo00<0oOgm0?_kn`3kno/00P3oool00`3moOd0no_k0?_kn`0D
0?_kn`030?gmo@3oool0oooo0180no_k0P3oool30?Ogm`<0kno_0P24Q8@50??cl`80moOg00<0f][J
0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:
b/X0_Kfm0;fm_@050>o_k`80Q8B400@0^[Zj0>o_k`3_knl0moOgLP3oool208B4Q0030;Zj^P3_knl0
kno_00<0Q8B40P3_knl00`3gmoL0oooo0?ooo`1G0?ooo`80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0
_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm
_@2m_Kd01@3_knl208B4Q0040;Zj^P3_knl0kno_0?Ogmg80oooo0P24Q8@00`2j^[X0kno_0>o_k`03
08B4Q080kno_00<0moOg0?ooo`3oool0E`3oool208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@03
0<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm
00D0kno_0P24Q8@0102j^[X0kno_0>o_k`3gmoMb0?ooo`80Q8B400<0^[Zj0>o_k`3_knl00`24Q8@2
0>o_k`030?Ogm`3oool0oooo05L0oooo0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h2
0>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?oo
o`030?_kn`3gmoL0moOg00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/208b<
S00308R8R024Q8@0Q8B40080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`L0Q8B400@0P82007]k
N`1kNg/0P8202@24Q8@00`28R8P0S8b<08b<S00508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1cLg<:
08B4Q0030820P01kNg/0Ng]k00X0Q8B400<0R8R808b<S02<S8`00P24Q8@00`2n_[h0moOg0?Ogm`05
08B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/0
0`20P800Q8B408B4Q00808B4Q080Ng]k2024Q8@207]kN`030820P024Q8@0Q8B400D0Q8B40P2<S8`0
0`28R8P0Q8B408B4Q00508B4Q0030820P01kNg/0Ng]k00X0Q8B41`3gmoL00`3Ogml0a/K60<K6aP03
0<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm
0080oooo00<0no_k0?Ogm`3gmoL01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k4P24Q8@307]k
N`80S8b<00<0R8R808B4Q024Q8@00P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k1`24Q8@01020
P800Ng]k07]kN`20P80908B4Q00308R8R02<S8`0S8b<00D0Q8B400<0P82007]kN`1kNg/01@24Q8@2
07=cL`X0Q8B400<0P82007]kN`1kNg/02P24Q8@00`28R8P0S8b<08b<S00208B4Q0030;jn_P3gmoL0
moOg00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B400<0P82007]kN`1kNg/01@24Q8@2
07]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/808B4Q080Ng]k00<0P82008B4Q024Q8@01@24Q8@2
08b<S00308R8R024Q8@0Q8B400D0Q8B400<0P82007]kN`1kNg/02P24Q8@70?Ogm`030=oOg`36a/H0
a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm
_@2m_Kd01@3oool207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00@0Q8B408b<
S02<S8`0R8R81`24Q8@207=cL`0307alO024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q007
08B4Q0<0Ng]k00<0P82008B4Q024Q8@00P24Q8@507]kN`D0Q8B400<0P82007]kN`1kNg/02P24Q8@3
07]kN`D0Q8B40P1kNg/308b<S0P0Q8B40P1kNg/508B4Q080Ng]k00@0MgMg07=cL`1cLg<0O7al0P24
Q8@207]kN`030820P024Q8@0Q8B40080Q8B400<0`/;20?ooo`3oool00`1kNg/208B4Q00308R8R02<
S8`0S8b<0080Ng]k1@24Q8@307]kN`X0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0
P82008B4Q024Q8@01@24Q8@308b<S080Ng]k1@24Q8@507]kN`D0Q8B400<0O7al07=cL`1cLg<02P24
Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool2
07]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00@0Q8B408b<S02<S8`0R8R81`24
Q8@207=cL`0307alO024Q8@0Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00708B4Q0<0Ng]k00<0
P82008B4Q024Q8@00P24Q8@507]kN`D0Q8B400<0P82007]kN`1kNg/02P24Q8@307]kN`D0Q8B40P1k
Ng/308b<S0P0Q8B40P1kNg/508B4Q080Ng]k00@0MgMg07=cL`1cLg<0O7al0P24Q8@207]kN`030820
P024Q8@0Q8B40080Q8B400<0`/;20?ooo`3oool00`1kNg/208B4Q00308R8R02<S8`0S8b<0080Ng]k
1@24Q8@307]kN`X0Q8B40P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@0
1@24Q8@308b<S080Ng]k1@24Q8@507]kN`D0Q8B400<0O7al07=cL`1cLg<02P24Q8@00`20P800Ng]k
07]kN`0508B4Q0D0Ng]k1@24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30>OWi`80d];B00<0b<S80;fm_@2m_Kd01@3kno/20820P00409VIV@2a
/K40/K6a0;Rh^080_[jn0P2i^KT30;jn_P80`/;20P2m_Kd01030`<00`/;20<;2`P30`<040;jn_P03
0<30`032`/80`/;20080]KFe00<0^[Zj0;jn_P2n_[h00`32`/820;Vi^@030;bl_02n_[h0_[jn0080
`/;200<0`<300;jn_P2n_[h00P32`/830;Vi^@030;bl_02n_[h0_[jn0080`/;21@2i^KT20;jn_P04
0<30`032`/80`/;20<30`080_Kfm1`2n_[h00`30`<00`/;20<;2`P030;Vi^@80_[jn00<0`<300<;2
`P32`/800P2i^KT50<;2`P<0_[jn0`32`/820;Vi^@80_[jn00<0`<300<;2`P32`/800P2i^KT0102g
]kL0]KFe0;Fe]@2j^[X20;jn_P80^KVi00<0]KFe0;6a/@2a/K400P24Q8@00`30`<00no_k0?_kn`03
0820P080/K6a00<0^[Zj0<;2`P32`/800P2i^KT30;jn_P80`/;20`2m_Kd70;jn_P030<30`032`/80
`/;20080^KVi00@0_;bl0;jn_P2n_[h0`<300P32`/820;Vi^@030;bl_02n_[h0_[jn0080`/;200<0
`<300;jn_P2n_[h00`36a/H20;Vi^@<0_[jn0P32`/850;Vi^@<0_[jn0P32`/800`2n_[h0^KVi0;Vi
^@070;jn_P040<30`032`/80`/;20;jn_P80^KVi0P2n_[h00`30`<00`/;20<;2`P050;Vi^@<0/K6a
0P24Q8@70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg
103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool50?Ogm`80oooo
00<0no_k0?Ogm`3gmoL00P3oool60?Ogm`80oooo1`3gmoL00`3kno/0oooo0?ooo`030?ooo`L0moOg
00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`80oooo0`3gmoL30?ooo`@0moOg
00<0no_k0?ooo`3oool02P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B4
0P3Ng]h00`3[jn/0moOg0?Ogm`050?Ogm`D0oooo1`3gmoL00`3kno/0oooo0?ooo`050?Ogm`030?_k
n`3oool0oooo00D0moOg0P3oool00`3kno/0moOg0?Ogm`030?ooo`D0moOg0P3oool80?Ogm`D0oooo
1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0L0
moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN
0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`03
0?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0
moOg0?Ogm`020?ooo`H0moOg0P3oool70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0
oooo0?ooo`050?Ogm`030?_kn`3oool0oooo00D0moOg0P3oool30?Ogm`<0oooo103gmoL00`3kno/0
oooo0?ooo`0:0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP03
0>_[j`3gmoL0moOg00D0moOg1@3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3o
ool01@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0oooo1@3gmoL20?ooo`P0moOg1@3oool70?Ogm`04
0?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41`3gmoL00`3O
gml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<k>cP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3_knm]0?ooo`80moOg00<0jn_[0=kN
gP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0kno_0?ooo`3oool0D@3oool30?Og
m`<0g]kN0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>o_
kfd0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3_
knl0oooo0?ooo`1A0?ooo`<0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_
k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3<c<`0`/;20<;2`P050??cl`80
R8R800@0/k>c0=kNgP3Ng]h0kno_K@3oool20?_kn`030?7al@3WinL0inOW0080Q8B400<0_[jn0?Og
m`3gmoL00`24Q8@20=kNgP030>o_k`3oool0oooo0540oooo0`3kno/30>OWi`80Q8B41`3clo<00`3H
f=P0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102e]KD0g]kN0=kNgP3_knm_0?ooo`030?Ogm`3_knl0kno_
0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>o_k`3oool0oooo05@0oooo0`3_knl208B4
Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0kno_K`3oool00`3g
moL0kno_0>o_k`0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`1D0?oo
o`<0kno_0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[
j`80moOg1`3oool20<K6aP0406][J`0@4100410@00P8208000000P0a<C400`1lO7`0a/K60<K6aP1I
0?ooo`030>o_k`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[j`3gmoL0
moOg05@0oooo0`3_knl207]kN`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kN
gP3Ng]h0jn_[0P3gmoL70?ooo`80a/K600@0Jf][010@400@410020P80P000002034a<@0307alO036
a/H0a/K605T0oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0
jn_[0?Ogm`3gmoL0E03oool30>o_k`80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0
jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0
102a/K40g]kN0=kNgP3[jn/20?Ogm`L0oooo0P36a/H0101[Jf/0410@010@400820P200000080<C4a
00<0O7al0<K6aP36a/H0F@3oool00`3_knl0g]kN0=kNgP0208B4Q0030<;2`P3oool0oooo00<0Q8B4
0P3Ng]h00`3[jn/0moOg0?Ogm`1D0?ooo`<0kno_0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3g
moL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg1`3oool20492@P0408b<S03Fe]H0e]KF0>?Sh`80
kno_0P24Q8@00`12@T800000000000020=KFeP030>_[j`3oool0oooo0580oooo0P3gmoL00`3[jn/0
g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3_knl0oooo0?ooo`1A0?ooo`<0
moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0
jn_[0P3gmoL70?ooo`80@T9200@0S8b<0=KFeP3Fe]H0hn?S0P3_knl208B4Q0030492@P0000000000
0080e]KF00<0jn_[0?ooo`3oool0DP3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Og
m`3gmoL00`1kNg/20=kNgP030>o_k`3oool0oooo0540oooo0`3gmoL30=kNgP80Q8B41`3gmoL00`3J
f]X0_Kfm0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP03
0<[:bP32`/80`/;200D0lo?c0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogm`L0oooo0P2QXJ401036
a/H0jn_[0>_[j`3alO420?Ogm`80`/;200<0PX:20492@P12@T800P2DU9@00`3:b/X0oooo0?ooo`1B
0?ooo`80moOg00<0kno_0>OWi`3WinL00P24Q8@00`2l_;`0lo?c0??cl`030820P080g]kN00<0kNg]
0?_kn`3kno/0D@3oool30?Ogm`<0g]kN0P24Q8@50??cl`80moOg00<0f][J0;fm_@2m_Kd00`3Bd]82
0>OWi`030>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_
k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLA0?ooo`030<;2`P24Q8@0Q8B40080DU9B00<0ZJVY
0?ooo`3oool0DP3oool20?Ogm`030??cl`3_knl0kno_0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@2
0=kNgP030>_[j`3gmoL0moOg0540oooo0`3gmoL30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0
_Kfm00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6
aP36a/H01@3_knl208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg4@3oool00`32`/80Q8B408B4Q002
059BDP030:VYZ@3oool0oooo0580oooo0P3gmoL00`3clo<0kno_0>o_k`0208B4Q0030;Zj^P3_knl0
kno_00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`1A0?ooo`<0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL0
0`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KF
eP030<k>cP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogma40oooo00<0moOg
0>o_k`3_knl00P0820P00`24Q8@0oooo0?ooo`1B0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@0
0`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0C`3oool50?Ogm`<0g]kN0P2<S8`7
0?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kN
gP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg4@3oool0
0`3gmoL0kno_0>o_k`0200P8200308B4Q03oool0oooo0580oooo0P3gmoL00`3[jn/0g]kN0=kNgP02
08B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`1?0?ooo`D0moOg0`3Ng]h2
08b<S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0inOW0P3Fe]H00`3<c<`0`/;20<;2`P050?_kn`80Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<A
0?ooo`030?_kn`3gmoL0moOg008010@400<0PX:20?ooo`3oool0DP3oool20?Ogm`030>_[j`3Ng]h0
g]kN0080P82000<0_[jn0?_kn`3kno/00`28R8P20=[JfP030>WYj@3gmoL0moOg04l0oooo1@3kno/3
0=kNgP80R8R81`3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL2
0>o_ka@0oooo0P0000000`20P800oooo0?ooo`1B0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P1kNg/0
0`2m_Kd0oooo0?ooo`0308b<S080e]KF00<0inOW0?Ogm`3gmoL0E03oool30=kNgP80Q8B41`3oool0
0`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KF
eP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_ka@0oooo0P000000
0`20P800oooo0?ooo`1B0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P1kNg/00`2m_Kd0oooo0?ooo`03
08b<S080e]KF00<0inOW0?Ogm`3gmoL0E03oool30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@03
0=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm
00D0moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Ogm`l0oooo0P0000000`20P800oooo0?ooo`1B
0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0jn_[
0?Ogm`3gmoL00P3gmoLc0?ooo`<0moOg6@3oool30?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm
_@2m_Kd01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg3`3oool2000000030820P03oool0
oooo0580oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h0
0`3[jn/0moOg0?Ogm`020?Ogmc<0oooo0`3gmoLI0?ooo`<0moOg0`3Ng]h208B4Q0L0moOg00<0f][J
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38
b<P0_Kfm0;fm_@020?Ogm`030?Gem@3clo<0lo?c0080Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<5
0?_kn`@0oooo00@0oOgm0?_kn`3kno/0oOgm1`3oool2000000030820P03oool0oooo00d0oooo0P3k
no/W0?ooo`80no_k2`3oool20?_kn`d0oooo0P3clo<00`3YjNT0g]kN0=kNgP0208B4Q0030;bl_03c
lo<0lo?c00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`020?_kn`D0oooo0`3kno/G0?ooo`D0no_k3`3o
ool30?_kn`L0oooo00<0oOgm0?_kn`3kno/02P3oool00`3moOd0no_k0?_kn`020?ooo`<0moOg0`3N
g]h208B4Q080lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3Hf=P0_Kfm0;fm_@030=;BdP80inOW00<0
kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c
0>o_k`3_knl00P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`T0oooo00@0no_k0?Ogm`3gmoL0no_k
1`3oool2000000030820P03oool0oooo00d0oooo0P3gmoLW0?ooo`80moOg2`3oool20?Ogm`d0oooo
0P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[jn/0moOg
0?Ogm`070?ooo`<0moOg5`3oool50?OgmaT0oooo00<0no_k0?Ogm`3gmoL02P3oool00`3kno/0moOg
0?Ogm`020?ooo`<0moOg0`3Ng]h208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm
0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m
_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`T0oooo
00@0no_k0?Ogm`3gmoL0no_k1`3oool2000000030820P03oool0oooo00d0oooo0P3gmoLW0?ooo`80
moOg2`3oool20?Ogm`d0oooo0P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;Zj^P3_knl0kno_00<0
Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`070?ooo`<0moOg5`3oool50?OgmaT0oooo00<0no_k0?Ogm`3g
moL02P3oool00`3kno/0moOg0?Ogm`020?ooo`<0moOg0`3Ng]h208B4Q080kno_00<0lo?c0?Ogm`3g
moL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20=;BdP030<[:bP32`/80`/;20080moOg00<0mOGe0??cl`3clo<00P24Q8@0102a/K40g]kN
0=kNgP3[jn/20?Ogm`D0no_k0P3oool50?_kn`030?gmo@3oool0oooo00D0oooo0P0000000`20P800
oooo0?ooo`0=0?ooo`80no_k0`3oool00`3moOd0no_k0?_kn`020?ooo`80no_k00<0oOgm0?ooo`3o
ool06P3oool20?_kn`P0oooo1@3kno/50?ooo`80no_k00<0oOgm0?ooo`3oool00`3oool20>o_k`03
0>OWi`3Ng]h0g]kN0080Q8B400<0_;bl0??cl`3clo<00`24Q8@20=kNgP030>_[j`3gmoL0moOg0080
no_k0`3oool50?_knaL0oooo1@3kno/30?ooo`80no_k0`3oool20?_kn`l0oooo00<0oOgm0?_kn`3k
no/02P3oool00`3moOd0no_k0?_kn`020?ooo`<0lo?c0`3Ng]h20820P080lo?c00<0mOGe0?Ogm`3g
moL00P3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo
0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN0=kNgP3_knl20?ooo`D0
moOg0P3oool20?Ogm`030?_kn`3oool0oooo00P0oooo0P0000000`20P800oooo0?ooo`0B0?ooo`03
0?_kn`3gmoL0moOg0080oooo0P3gmoL00`3kno/0oooo0?ooo`0T0?ooo`<0moOg1`3oool20?Ogm`03
0?_kn`3oool0oooo00<0oooo0P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0
Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`<0oooo0P3gmoLR0?ooo`80moOg0`3oool20?Ogmb40
oooo0`3_knl30=kNgP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102a/K40g]kN
0=kNgP3_knl20?ooo`D0moOg0P3oool20?Ogm`030?_kn`3oool0oooo00P0oooo0P0000000`20P800
oooo0?ooo`0B0?ooo`030?_kn`3gmoL0moOg0080oooo0P3gmoL00`3kno/0oooo0?ooo`0T0?ooo`<0
moOg1`3oool20?Ogm`030?_kn`3oool0oooo00<0oooo0P3_knl00`3WinL0g]kN0=kNgP0208B4Q003
0;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`<0oooo0P3gmoLR0?ooo`80
moOg0`3oool20?Ogmb40oooo0`3_knl30=kNgP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo
0P1kNg/0102][Jd0g]kN0=kNgP3WinL20>o_k`D0moOg1`3oool00`3kno/0moOg0?Ogm`050?ooo`80
000000<0P8200?ooo`3oool0203oool20?Ogm`030?_kn`3oool0oooo00l0oooo0P3gmoL00`3kno/0
oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool0203oool20?Ogm`030?_kn`3oool0oooo00l0
oooo0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg00D0moOg00<0lo?c0>o_k`3_
knl00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL00P3gmoL80?ooo`80
moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`0:0?ooo`030820P0000000000000P0
00002@3oool00`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg00X0oooo00<0no_k0?Ogm`3g
moL00P3oool00`3kno/0moOg0?Ogm`020?ooo`<0moOg0`3_knl208B4Q0L0oooo00<0g]kN0;fm_@2m
_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0_Kfm
0;fm_@050?ooo`80Ng]k00@0[Jf]0=kNgP3Ng]h0inOW0P3_knl50?Ogm`L0oooo00<0no_k0?Ogm`3g
moL01@3oool2000000030820P03oool0oooo00P0oooo0P3gmoL00`3kno/0oooo0?ooo`0?0?ooo`80
moOg00<0no_k0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo00P0oooo0P3gmoL00`3kno/0
oooo0?ooo`0?0?ooo`80moOg00<0no_k0?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`050?Ogm`03
0??cl`3_knl0kno_0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[j`3gmoL0moOg0080
moOg203oool20?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL02P3oool00`20P800
000000000008000000T0oooo00<0no_k0?Ogm`3gmoL01@3oool00`3kno/0moOg0?Ogm`0:0?ooo`03
0?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL00P3oool30?Ogm`<0kno_0P24Q8@70?ooo`03
0=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>
00<0b<S80<;2`P32`/801@3kno/20820P0040:n_[`3Ng]h0g]kN0>WYj@80lo?c1@3gmoL40?_kn`04
0?gmo@3oool0oooo0?_kn`80moOg0P3oool00`3moOd0no_k0?_kn`02000000030820P03oool0oooo
00<0no_k1@3oool50?_kn`80oooo0`3kno/00`3moOd0oooo0?ooo`040?_kn`030?gmo@3oool0oooo
0080moOg00@0no_k0?ooo`3oool0oOgm2@3kno/00`3moOd0oooo0?ooo`080?_kn`80oooo0`3kno/2
0?ooo`H0no_k0P3oool20?Ogm`030?_kn`3oool0oooo00D0no_k00<0nOWi0?Ogm`3gmoL00P3clo<0
0`3]kNd0inOW0>OWi`0208B4Q0030<30`03kno/0no_k00<0Q8B40P3Ng]h00`3YjNT0lo?c0??cl`02
0?Ogm`D0no_k0`3oool20?Ogm`030?_kn`3oool0oooo0080oooo00<0oOgm0?_kn`3kno/01@3kno/0
0`3moOd0oooo0?ooo`020?ooo`030820P000000000000080O7al00<0OWin0820P020P8000`000002
0?ooo`D0no_k0P3oool00`3kno/0moOg0?Ogm`030?ooo`X0no_k1@3oool00`3moOd0no_k0?_kn`07
0?_kn`<0moOg0`3WinL208B4Q0L0no_k00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kN
gP3Ng]h0jn_[2`3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P00
00000`20P800oooo0?ooo`030?Ogm`L0oooo00<0no_k0?Ogm`3gmoL00P3oool30?Ogm`030?_kn`3o
ool0oooo00@0moOg00<0no_k0?ooo`3oool00P3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80oooo
00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`030?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
0P3oool30?Ogm`80oooo1P3gmoL20?ooo`80moOg00<0no_k0?ooo`3oool00P3gmoL0103kno/0oooo
0?ooo`3kno/20?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080
g]kN00<0inOW0>o_k`3_knl01`3gmoL30?ooo`80moOg00<0no_k0?ooo`3oool01@3oool50?Ogm`03
0?_kn`3oool0oooo0080oooo00<0P8200000000000000P3gmoL00`3kno/0oooo0?ooo`0300000080
oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`P0
oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H0
1@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`/0moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20?oo
o`030?_kn`3gmoL0moOg0080000000<0P8200?ooo`3oool00`3gmoL70?ooo`030?_kn`3gmoL0moOg
0080oooo0`3gmoL00`3kno/0oooo0?ooo`040?Ogm`030?_kn`3oool0oooo0080moOg00@0no_k0?oo
o`3oool0no_k0P3gmoL20?ooo`030?_kn`3gmoL0moOg0080moOg00<0no_k0?ooo`3oool00`3gmoL2
0?ooo`030?_kn`3gmoL0moOg0080oooo0`3gmoL20?ooo`H0moOg0P3oool20?Ogm`030?_kn`3oool0
oooo0080moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0
_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_00L0moOg0`3oool20?Ogm`030?_kn`3o
ool0oooo00D0oooo1@3gmoL00`3kno/0oooo0?ooo`020?ooo`030820P000000000000080moOg00<0
no_k0?ooo`3oool00`0000020?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`030?ooo`80moOg00<0
no_k0?ooo`3oool01@3gmoL80?ooo`80moOg00<0no_k0?ooo`3oool01@3gmoL30=kNgP80Q8B41`3g
moL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/40?Ogm`L0oooo00@0
no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030?_kn`3oool0oooo0080000000<0P8200?ooo`3oool0
0`3oool20?Ogm`030?_kn`3oool0oooo00D0moOg3`0000020?ooo`040?_kn`3gmoL0moOg0=oOg`80
a/K60P0820P00`0410@000000000000205YJFP0302d];@000000000000P000001@3oool?00000080
oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_
k`3_knl00`24Q8@20=kNgP030>OWi`3_knl0kno_00L0oooo0`3gmoL20?ooo`030=kNgP2m_Kd0_Kfm
008020P800<010@40000000000000P0H61P0101_Kfl0a/K60<K6aP3Ogml20?Ogm`80oooo00<0P820
0000000000000P3gmoL00`3kno/0oooo0?ooo`03000000L0oooo0P3gmoL00`3kno/0oooo0?ooo`03
0?Ogm`l0000000<0O7al0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@5
0>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoL7
0?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P3gmoL00`3kno/0oooo0?ooo`02000000030820P03o
ool0oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`050?Ogm`l000000P3oool0103kno/0moOg0?Og
m`3Ogml20<K6aP8020P800<010@40000000000000P1JFUX00`0];Bd0000000000008000000D0oooo
3`0000020?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q003
0;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`070?ooo`<0moOg0P3oool00`3Ng]h0
_Kfm0;fm_@0200P8200300@4100000000000008061PH00@0Kfm_0<K6aP36a/H0gmoO0P3gmoL20?oo
o`030820P000000000000080moOg00<0no_k0?ooo`3oool00`0000070?ooo`80moOg00<0no_k0?oo
o`3oool00`3gmoL?0000000307alO03gmoL0moOg0080moOg00<0no_k0?ooo`3oool01@3gmoL30=kN
gP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Ogm`0208B4Q004
0;6a/@3Ng]h0g]kN0>OWi`80kno_1`3gmoL80?ooo`80moOg00<0no_k0?ooo`3oool00P0000000`20
P800oooo0?ooo`030?Ogm`X0oooo3`0000020?ooo`040?_kn`3gmoL0moOg08R8R08061PH0P2<S8`0
0`36a/H0oooo0?ooo`0207]kN`0303hn?P000000000000<0oooo0P0000000`20P800oooo0?ooo`05
0?Ogm`8000001P3gmoL40?ooo`030820P000000000000080oooo00@0no_k0?Ogm`3gmoL0no_k0P3o
ool20>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_
knl0kno_00D0moOg1`3oool00`2<S8`061PH01PH600207=cL`030;Fe]@3gmoL0moOg0080[Jf]00@0
Fe]K00P8200820P0Kfm_0P3Fe]H20?ooo`030820P0000000000000P000001@3gmoL40?ooo`030?_k
n`3gmoL0moOg00<0moOg3`0000000`20P800oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080moOg
0`3_knl30=KFeP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm0080oooo00<0no_k0?Ogm`3gmoL00P24
Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`L0moOg203oool20?Ogm`030?_kn`3oool0oooo00800000
00<0P8200?ooo`3oool00`3gmoL:0?ooo`l000000P3oool0103kno/0moOg0?Ogm`28R8P201PH6080
S8b<00<0a/K60?ooo`3oool00P1kNg/00`0n?Sh00000000000030?ooo`80000000<0P8200?ooo`3o
ool01@3gmoL2000000H0moOg103oool00`20P8000000000000020?ooo`040?_kn`3gmoL0moOg0?_k
n`80oooo0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3W
inL0kno_0>o_k`050?Ogm`L0oooo00<0S8b<01PH600H61P00P1cLg<00`2e]KD0moOg0?Ogm`020:f]
[@0405]KF`0820P020P806m_K`80e]KF0P3oool00`20P800000000000008000000D0moOg103oool0
0`3kno/0moOg0?Ogm`030?Ogm`l0000000<0P8200?ooo`3oool00P3oool00`3kno/0moOg0?Ogm`02
0?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0inOW0P3Bd]800`38b<P0_Kfm0;fm_@020?ooo`030?gmo@3kno/0no_k
0080Q8B400@0/K6a0=kNgP3Ng]h0jNWY0P3clo<50?_kn`80moOg0P3kno/00`3moOd0oooo0?ooo`03
0?ooo`D0no_k0P0000000`1nOWh0no_k0?_kn`030?_kn`80oooo00<0oOgm0?_kn`3kno/01@3kno/?
00000080oooo00@0oOgm0?_kn`3kno/0Q8B40P0<30`20<;2`P030=oOg`3kno/0no_k0080_Kfm00<0
GemO0000000000000`3kno/20000000307inOP3kno/0no_k00D0no_k0P0000030?_kn`<0moOg103o
ool00`20P8000000000000020?_kn`040?Win@3gmoL0moOg0?Win@80no_k0P3clo<00`3WinL0f][J
0=[JfP0208B4Q0030<30`03kno/0no_k00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`020?_kn`<0moOg
0P3kno/50?ooo`0308J6QP0<30`030`<0080]KFe00<0f=SH0?_kn`3kno/00P3Bd]801028R8P0?Shn
03hn?P1WIfL2092@T080no_k00<0_;bl07alO01lO7`00P1lO7`00`1nOWh0P8200820P0030820P0L0
no_k0P3oool00`3moOd0no_k0?_kn`030?_kn`l0000000<0OWin0?_kn`3kno/01`3kno/30??cl`<0
f][J0P24Q8@70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`00
1_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80
moOg1@3oool40?Ogm`030?_kn`3oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P0000000`1lO7`0
moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg00D0moOg3`0000050?ooo`030820P0000000000000D0
moOg0P3oool00`20P8000000000000030?Ogm`80000000<0O7al0?Ogm`3gmoL01@3oool2000000<0
oooo0`3gmoL40?ooo`030820P0000000000000X0moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`32`/80
oooo0?ooo`0308B4Q080g]kN00<0kno_0?ooo`3oool00P3oool50?Ogm`D0oooo00<0P82000000000
00000P3gmoL00`3kno/0oooo0?ooo`020?Ogm`040;Fe]@1cLg<0Lg=c05mOG`80BTY:1`3gmoL00`3k
no/0oooo0?ooo`080?ooo`80moOg203oool?0000000307alO03gmoL0moOg0080moOg00<0no_k0?oo
o`3oool00P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q004
0;6a/@3Ng]h0g]kN0>_[j`80moOg1@3oool40?Ogm`030?_kn`3oool0oooo00D0oooo00<0no_k0?Og
m`3gmoL00P0000000`1lO7`0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg00D0moOg3`0000050?oo
o`030820P0000000000000D0moOg0P3oool00`20P8000000000000030?Ogm`80000000<0O7al0?Og
m`3gmoL01@3oool2000000<0oooo0`3gmoL40?ooo`030820P0000000000000X0moOg00<0jn_[0=kN
gP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0kno_0?ooo`3oool00P3oool50?Og
m`D0oooo00<0P8200000000000000P3gmoL00`3kno/0oooo0?ooo`020?Ogm`040;Fe]@1cLg<0Lg=c
05mOG`80BTY:1`3gmoL00`3kno/0oooo0?ooo`080?ooo`80moOg203oool?0000000307alO03gmoL0
moOg0080moOg00<0no_k0?ooo`3oool00P3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm
_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>_[j`80moOg1@3oool40?Ogm`030?_kn`3oool0
oooo00D0oooo00<0no_k0?Ogm`3gmoL00P0000000`1lO7`0moOg0?Ogm`050?ooo`030?_kn`3gmoL0
moOg00D0moOg3`0000050?ooo`030820P0000000000000D0moOg0P3oool00`20P800000000000003
0?Ogm`80000000<0O7al0?Ogm`3gmoL01@3oool2000000<0oooo0`3gmoL40?ooo`030820P0000000
000000X0moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0kno_
0?ooo`3oool00P3oool50?Ogm`D0oooo00<0P8200000000000000P3gmoL00`3kno/0oooo0?ooo`02
0?Ogm`040;Fe]@1cLg<0Lg=c05mOG`80BTY:1`3gmoL00`3kno/0oooo0?ooo`080?ooo`80moOg203o
ool?0000000307alO03gmoL0moOg0080moOg00<0no_k0?ooo`3oool00P3oool30?Ogm`<0g]kN0P24
Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OWi`T0moOg0P3o
ool00`3kno/0moOg0?Ogm`080?Ogm`80000000<0O7al0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3g
moL0moOg0080oooo00<0no_k0?Ogm`3gmoL03`0000020?ooo`040?_kn`3gmoL0moOg0820P08020P8
0P2<S8`00`32`/80moOg0?Ogm`0208b<S00304I6AP000000000000<0moOg0P0000000`1lO7`0moOg
0?Ogm`020?ooo`<0moOg0P0000030?Ogm`<0oooo0P3gmoL20?ooo`030820P0000000000000X0moOg
00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0inOW0>o_k`3_knl0
1@3gmoL20?ooo`D0moOg00<0P82000P8200820P00P3>c/h00`3Shn<0moOg0?Ogm`020?Ogm`040=;B
dP2][Jd0[Jf]05]KF`8020P84P3gmoL20?ooo`P0moOg3`0000000`20P800oooo0?ooo`020?Ogm`03
0?_kn`3oool0oooo0080moOg0`3_knl30=kNgP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg
0P24Q8@0102][Jd0e]KF0=KFeP3WinL90?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL200000003
07alO03gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00l0
00000P3oool0103kno/0moOg0?Ogm`20P80200P82080S8b<00<0`/;20?Ogm`3gmoL00P2<S8`00`16
ATH00000000000030?Ogm`80000000<0O7al0?Ogm`3gmoL00P3oool30?Ogm`8000000`3gmoL30?oo
o`80moOg0P3oool00`20P80000000000000:0?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Og
m`3gmoL00`1kNg/20=kNgP030>OWi`3_knl0kno_00D0moOg0P3oool50?Ogm`030820P00820P020P8
0080c/k>00<0hn?S0?Ogm`3gmoL00P3gmoL0103Bd]80[Jf]0:f][@1KFe/200P82180moOg0P3oool8
0?Ogm`l0000000<0P8200?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`020?Ogm`<0kno_0`3Ng]h2
08B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl2
0?Ogm`<0oooo0P3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg1@3oool2000000030820P03oool0
oooo00D0moOg00<0no_k0?ooo`3oool01@3gmoL?00000080moOg00@0no_k0?ooo`3oool0g]kN0P2m
_Kd200P8200300@41000000000000080FUYJ00<0;Bd]0000000000000`3oool20000000307alO03g
moL0moOg00D0moOg0P00000:0?Ogm`0307alO000000000000080oooo00<0no_k0?Ogm`3gmoL00`3g
moL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=KFeP030>?Sh`3_
knl0kno_00D0moOg0P3oool50?Ogm`030<;2`P2<S8`0S8b<008061PH00<0Lg=c0<k>cP3>c/h00P3_
knl0102UYJD0FUYJ05YJFP0];Bd200000080oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`X0moOg
0`3oool?0000000307alO03gmoL0moOg00X0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6
aP050>o_k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl20?Ogm`<0oooo0P3gmoL20?ooo`030?_k
n`3gmoL0moOg00<0moOg1@3oool2000000030820P03oool0oooo00D0moOg00<0no_k0?ooo`3oool0
1@3gmoL?00000080moOg00@0no_k0?ooo`3oool0g]kN0P2m_Kd200P8200300@41000000000000080
FUYJ00<0;Bd]0000000000000`3oool20000000307alO03gmoL0moOg00D0moOg0P00000:0?Ogm`03
07alO000000000000080oooo00<0no_k0?Ogm`3gmoL00`3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080
Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=KFeP030>?Sh`3_knl0kno_00D0moOg0P3oool50?Ogm`03
0<;2`P2<S8`0S8b<008061PH00<0Lg=c0<k>cP3>c/h00P3_knl0102UYJD0FUYJ05YJFP0];Bd20000
0080oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`X0moOg0`3oool?0000000307alO03gmoL0moOg
00X0moOg0`3Ng]h208B4Q0L0kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3<c<`0`/;20<;2`P050??cl`80R8R800@0/K6a0=[JfP3J
f]X0inOW0P3clo<50?_kn`80moOg0P3kno/00`3inOT0moOg0?Ogm`030?Ogm`D0no_k0P0000000`1n
OWh0no_k0?_kn`050?Ogm`030?Win@3kno/0no_k0080no_k00<0nOWi0?Ogm`3gmoL03`0000020?Og
m`040?Win@3kno/0no_k0>_[j`80f][J0P20P8000`1nOWh0O7al07alO0020:VYZ@0305EEE@000000
000000<0no_k0P0000000`1lO7`0moOg0?Ogm`020?Ogm`<0no_k0P00000:07alO00303hn?P000000
00000080no_k00<0nOWi0?Ogm`3gmoL00`3gmoL20??cl`030>OWi`3Jf]X0f][J0080Q8B400<0_[jn
0?Ogm`3gmoL00`24Q8@20=[JfP030>OWi`3clo<0lo?c00D0moOg0P3kno/50?Ogm`030=gMg@32`/80
`/;20080DU9B00<0GEeM06MWI`1WIfL00P1hN7P01022PX80S8b<08b<S016ATH2000000D0no_k1@3g
moL50?_kn`X0moOg0`3kno/?0000000307inOP3kno/0no_k00D0moOg0P3kno/30??cl`<0g]kN0P24
Q8@70??cl`030=SHf02m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S0040;6a/@3Fe]H0e]KF0>OWi`80moOg0P3o
oolB0?Ogm`80000000<0O7al0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3gmoL0moOg00l000003`3g
moL00`1lO7`00000000000030?Ogm`80000000<0O7al0?Ogm`3gmoL00P3gmoL30?ooo`l000002P3g
moL00`3WinL0e]KF0=KFeP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3[jn/0moOg0?Og
m`0?0?Ogm`80S8b<00<0ATI60000000000000P000000101OGel0_Kfm0;fm_@1OGel200000080moOg
00<0no_k0?ooo`3oool01@3gmoL30?ooo`l0moOg3`0000000`20P800oooo0?ooo`050?Ogm`80oooo
0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102a/K40e]KF0=KF
eP3WinL20?Ogm`80oooo4P3gmoL20000000307alO03gmoL0moOg00P0moOg0P3oool00`3kno/0moOg
0?Ogm`0?000000l0moOg00<0O7al0000000000000`3gmoL20000000307alO03gmoL0moOg0080moOg
0`3oool?000000X0moOg00<0inOW0=KFeP3Fe]H00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN
00<0jn_[0?Ogm`3gmoL03`3gmoL208b<S00304I6AP00000000000080000000@0GemO0;fm_@2m_Kd0
GemO0P0000020?Ogm`030?_kn`3oool0oooo00D0moOg0`3oool?0?Ogm`l0000000<0P8200?ooo`3o
ool01@3gmoL20?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP03
0>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B4
00@0/K6a0=kNgP3Ng]h0inOW103_knl30?ooo`l0moOg0P0000000`1lO7`0moOg0?Ogm`030?ooo`D0
moOg0P3oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3oool0oooo00L0moOg0P3oool00`3kno/0
moOg0?Ogm`080?Ogm`80oooo00<0P8200000000000000`3gmoL20000000307alO03gmoL0moOg00D0
moOg0P3oool80?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030>_[j`3Fe]H0e]KF0080
Q8B400<0`/;20?ooo`3oool00`24Q8@20=KFeP030>?Sh`3_knl0kno_0080oooo503gmoL0102i^KT0
Ng]k07]kN`1:BTX201PH60d0moOg1@3ooolA0?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?oo
o`3oool02P3gmoL30=kNgP80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40
g]kN0=kNgP3WinL40>o_k`<0oooo3`3gmoL20000000307alO03gmoL0moOg00<0oooo1@3gmoL20?oo
o`030?_kn`3gmoL0moOg00D0moOg00<0no_k0?ooo`3oool01`3gmoL20?ooo`030?_kn`3gmoL0moOg
00P0moOg0P3oool00`20P8000000000000030?Ogm`80000000<0O7al0?Ogm`3gmoL01@3gmoL20?oo
o`P0moOg0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80oooo00<0jn_[0=KFeP3Fe]H00P24Q8@00`32
`/80oooo0?ooo`0308B4Q080e]KF00<0hn?S0>o_k`3_knl00P3ooolD0?Ogm`040;Vi^@1kNg/0Ng]k
04Y:BP8061PH3@3gmoL50?oooa40moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`0:
0?Ogm`<0g]kN0P1kNg/70?ooo`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30=kNgP80d];B00<0b<S80;fm_@2m_Kd01@3kno/208B4Q0040:n_[`3Jf]X0f][J
0>GUi@80kno_0P3clo<?0?Ogm`030?Gem@3clo<0lo?c0080000000<0OWin0?_kn`3kno/00`3kno/5
0?Ogm`80no_k00<0nOWi0?Ogm`3gmoL01@3gmoL00`3inOT0no_k0?_kn`070?Ogm`80no_k00<0nOWi
0?Ogm`3gmoL01@3gmoL00`3inOT0no_k0?_kn`020820P0030410@0000000000000<0O7al0P000000
0`1lO7`0moOg0?Ogm`050?Ogm`80no_k203gmoL20?_kn`030?Win@3gmoL0moOg00X0moOg00<0inOW
0=KFeP3Fe]H00P24Q8@00`30`<00no_k0?_kn`030820P080e]KF00<0hn?S0>o_k`3_knl04@3gmoL0
0`3De=@0/K6a0;6a/@0207alO00405mOG`12@T80@T9205MGE`80Jf][3@3gmoL50?_kn`l0moOg1@3k
no/50?Ogm`030?Win@3kno/0no_k00L0moOg0`3clo<30=[JfP80P8201`3kno/00`3Ogml0`/;20<;2
`P030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0
_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_k`80moOg0`3_knl<0?Ogm`030??cl`3_
knl0kno_0080000000<0P8200?ooo`3oool09P3gmoL00`3kno/0oooo0?ooo`0:0000000307alO03g
moL0moOg01`0moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3F
e]H00`3Shn<0kno_0>o_k`020>o_k`l0moOg00<0/K6a06][J`1[Jf/00P000000100410@020P800P8
201SHf<20;fm_B40moOg0P3oool00`3kno/0moOg0?Ogm`0?0?Ogm`<0kno_0`3Fe]H208B4Q0L0moOg
00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3F
e]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?Ogm`<0kno_
303gmoL00`3clo<0kno_0>o_k`02000000030820P03oool0oooo02H0moOg00<0no_k0?ooo`3oool0
2P0000000`1lO7`0moOg0?Ogm`0L0?Ogm`80kno_00<0hn?S0=KFeP3Fe]H00P24Q8@00`2n_[h0moOg
0?Ogm`0307]kN`80e]KF00<0hn?S0>o_k`3_knl00P3_knl?0?Ogm`030;6a/@1[Jf/0Jf][00800000
00@010@400P8200820P0Hf=S0P2m_KdQ0?Ogm`80oooo00<0no_k0?Ogm`3gmoL03`3gmoL30>o_k`<0
e]KF0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`00
1_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3_knl208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80
kno_3`3gmoL20?ooo`030?_kn`3gmoL0moOg0080000000<0O7al0?Ogm`3gmoL00`3_knlK0?Ogm`04
0?_kn`3oool0oooo0?_knbX0moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030>OWi`3Ng]h0
g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=KFeP030>?Sh`3_knl0kno_00`0moOg00<0no_k
0?ooo`3oool01`3gmoL0103clo<0kno_0>o_k`3clo<K0?Ogm`<0oooo1`3gmoL00`3clo<0kno_0>o_
k`080?Ogm`D0kno_0P3gmoL30>o_k`<0e]KF0P1kNg/50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP05
0>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl?0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P00
00000`1lO7`0moOg0?Ogm`030>o_ka/0moOg00@0no_k0?ooo`3oool0no_k:P3gmoL0103clo<0kno_
0>o_k`3clo<20?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080
e]KF00<0hn?S0>o_k`3_knl0303gmoL00`3kno/0oooo0?ooo`070?Ogm`040??cl`3_knl0kno_0??c
la/0moOg0`3oool70?Ogm`030??cl`3_knl0kno_00P0moOg1@3_knl20?Ogm`<0kno_0`3Fe]H207]k
N`D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102][Jd0e]KF0=KFeP3Shn<20>o_
k`l0moOg0P3oool00`3kno/0moOg0?Ogm`020000000307alO03gmoL0moOg00<0kno_6`3gmoL0103k
no/0oooo0?ooo`3kno/Z0?Ogm`040??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3WinL0g]kN0=kN
gP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Fe]H00`3Shn<0kno_0>o_k`0<0?Ogm`030?_kn`3o
ool0oooo00L0moOg00@0lo?c0>o_k`3_knl0lo?c6`3gmoL30?ooo`L0moOg00<0lo?c0>o_k`3_knl0
203gmoL50>o_k`80moOg0`3_knl30=KFeP80Ng]k1@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3g
moL207]kN`040:VYZ@3Fe]H0e]KF0>?Sh`80kno_1@3gmoL20>o_k`80oooo00@0no_k0?Ogm`3gmoL0
lo?c0P3_knl50?Ogm`80000000<0O7al0?Ogm`3gmoL05@3gmoL20>o_k`80oooo00<0no_k0?Ogm`3g
moL00P3_knl00`3clo<0moOg0?Ogm`0G0?Ogm`<0kno_0P3gmoL30>o_k`<0oooo103gmoL00`3clo<0
kno_0>o_k`020?Ogm`040??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4
Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`020?Ogm`<0kno_0P3oool30?Og
m`80kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0kno_0>o_k`0G0?Ogm`<0kno_0P3ooolD0?Og
m`040?_kn`3oool0oooo0?_kn`L0moOg1@3_knl30=KFeP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP03
0<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K6
00D0moOg0P1kNg/0102YZJT0e]KF0=KFeP3Shn<20>o_k`D0moOg0P3_knl20?ooo`040?_kn`3gmoL0
moOg0??cl`80kno_1@3gmoL20000000307alO03gmoL0moOg01D0moOg0P3_knl20?ooo`030?_kn`3g
moL0moOg0080kno_00<0lo?c0?Ogm`3gmoL05`3gmoL30>o_k`80moOg0`3_knl30?ooo`@0moOg00<0
lo?c0>o_k`3_knl00P3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_00<0hn?S0=KFeP3Fe]H0
0P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl00P3gmoL30>o_k`80oooo
0`3gmoL20>o_k`030??cl`3gmoL0moOg0080moOg00<0lo?c0>o_k`3_knl05`3gmoL30>o_k`80oooo
503gmoL0103kno/0oooo0?ooo`3kno/70?Ogm`D0kno_0`3Fe]H208b<S0L0moOg00<0gmoO0<K6aP36
a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3Fe]H00`3<c<`0`/;2
0<;2`P050?_kn`80P82000@0[Jf]0=[JfP3Jf]X0hN7Q0P3WinL50?Ogm`80kno_1@3gmoL00`3emOD0
lo?c0??cl`050?Ogm`80000000<0O7al0?Ogm`3gmoL02P3clo<00`3gmoL0no_k0?_kn`020??cl`H0
moOg0P3clo<50?Ogm`80lo?c00<0mOGe0?Ogm`3gmoL0203gmoL:0??cl`030?Ogm`3kno/0no_k00D0
lo?c0P3gmoL30>o_k`L0moOg00<0mOGe0??cl`3clo<00P3gmoL0103clo<0kno_0>o_k`3clo<20?Og
m`80kno_00<0hn?S0=KFeP3Fe]H00P20P8000`2n_[h0no_k0?_kn`0308R8R080f][J00<0iNGU0>o_
k`3_knl00P3gmoL30>o_k`D0moOg0P3clo<00`3emOD0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_
0080moOg00<0mOGe0??cl`3clo<0203clo<20?_kn`030?Ogm`3clo<0lo?c00D0moOg0`3clo<70?Og
m`<0lo?c1`3gmoL00`3emOD0lo?c0??cl`020??cl`040?Gem@3gmoL0moOg0?Gem@80lo?c0P3kno/0
0`3gmoL0lo?c0??cl`050>o_k`<0e]KF0P28R8P70?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4
Q0030;6a/@3Ng]h0g]kN00<0g]kN1@3gmoL40>o_k`030??cl`3gmoL0moOg00P0moOg0P0000000`1l
O7`0moOg0?Ogm`0:0>o_k`030?Ogm`3oool0oooo0080kno_203gmoL20>o_k`030??cl`3gmoL0moOg
00d0moOg2P3_knl00`3gmoL0oooo0?ooo`020>o_k`D0moOg1P3_knl90?Ogm`040??cl`3_knl0kno_
0??cl`80moOg0P3_knl00`3Shn<0e]KF0=KFeP0207]kN`030;fm_@3oool0oooo00<0S8b<0P3Fe]H0
0`3Shn<0kno_0>o_k`020?Ogm`D0kno_2P3gmoL00`3clo<0kno_0>o_k`020?Ogm`030??cl`3_knl0
kno_00P0kno_0P3oool00`3gmoL0kno_0>o_k`080?Ogm`80kno_1@3gmoL30>o_k`L0moOg00<0lo?c
0>o_k`3_knl0203_knl20?ooo`030?Ogm`3_knl0kno_00D0kno_0`3Fe]H208B4Q0L0oooo00<0g]kN
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:
b/X0_Kfm0;fm_@050?ooo`80Q8B400<0/K6a0=kNgP3Ng]h00`3Ng]h50?Ogm`@0kno_00<0lo?c0?Og
m`3gmoL0203gmoL20000000307alO03gmoL0moOg00X0kno_00<0moOg0?ooo`3oool00P3_knl80?Og
m`80kno_00<0lo?c0?Ogm`3gmoL03@3gmoL:0>o_k`030?Ogm`3oool0oooo0080kno_1@3gmoL60>o_
k`T0moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030>?Sh`3Fe]H0e]KF0080Ng]k00<0_Kfm
0?ooo`3oool00`2<S8`20=KFeP030>?Sh`3_knl0kno_0080moOg1@3_knl:0?Ogm`030??cl`3_knl0
kno_0080moOg00<0lo?c0>o_k`3_knl0203_knl20?ooo`030?Ogm`3_knl0kno_00P0moOg0P3_knl5
0?Ogm`<0kno_1`3gmoL00`3clo<0kno_0>o_k`080>o_k`80oooo00<0moOg0>o_k`3_knl01@3_knl3
0=KFeP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0e]KF0=KFeP3Shn<;
0>o_k`040??cl`3gmoL0moOg0??cl`@0kno_00<0lo?c0?Ogm`3gmoL00P0000000`1lO7`0moOg0?Og
m`030?Ogm`D0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`H0kno_0P3gmoL20>o_k`030??cl`3g
moL0moOg00D0kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3_
knl0kno_00d0moOg203_knl20?Ogm`D0kno_0P3gmoL00`3clo<0kno_0>o_k`050>o_k`030>?Sh`3F
e]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN00L0kno_0`3g
moL50>o_k`80moOg00<0lo?c0>o_k`3_knl01@3gmoL00`3clo<0kno_0>o_k`0:0?Ogm`D0kno_0`3g
moL20>o_k`80moOg00<0lo?c0>o_k`3_knl00`3_knl20?Ogm`030??cl`3_knl0kno_00D0moOg0P3_
knl00`3clo<0moOg0?Ogm`030?Ogm`X0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3F
e]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@05
0?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S2`3_knl0103clo<0moOg0?Ogm`3clo<40>o_k`030??c
l`3gmoL0moOg0080000000<0O7al0?Ogm`3gmoL00`3gmoL50>o_k`80moOg00<0lo?c0>o_k`3_knl0
0P3gmoL60>o_k`80moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg0080kno_
00<0lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0kno_0>o_k`0=0?Ogm`P0kno_0P3gmoL50>o_k`80moOg
00<0lo?c0>o_k`3_knl01@3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B4
0P3Fe]H00`3Jf]X0g]kN0=kNgP070>o_k`<0moOg1@3_knl20?Ogm`030??cl`3_knl0kno_00D0moOg
00<0lo?c0>o_k`3_knl02P3gmoL50>o_k`<0moOg0P3_knl20?Ogm`030??cl`3_knl0kno_00<0kno_
0P3gmoL00`3clo<0kno_0>o_k`050?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00`3gmoL:0>o_k`<0g]kN
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80d];B00<0b<S80;fm_@2m_Kd00P3gmoL00`3emOD0lo?c0??cl`0208B4Q0040:^[Z`3B
d]80d];B0=gMg@80inOW1@3_knl?0??cl`80000000<0MWIf0>_[j`3[jn/02P3clo<00`3alO40kno_
0>o_k`020??cl`H0kno_0P3gmoLG0??cl`<0moOg2P3clo<20>o_ka80lo?c00<0lO7a0>o_k`3_knl0
0P3WinL00`3Ogml0e]KF0=KFeP0208B4Q0030;bl_03clo<0lo?c00<0Q8B40P3Bd]800`3MgMd0inOW
0>OWi`020>o_ka80lo?c0P3gmoL00`3emOD0lo?c0??cl`030??cl`80moOg00<0mOGe0??cl`3clo<0
1@3clo<50>o_k`<0moOg5P3clo<0103emOD0moOg0?Ogm`3emOD20??cl`X0kno_0`3Ng]h208B4Q080
lo?c00<0mOGe0?Ogm`3gmoL00P3clo<00`3Hf=P0_Kfm0;fm_@030=;BdP80inOW00<0kno_0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl0
0P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgPD0kno_103gmoL0103clo<0kno_0>o_k`3clo<40?Og
m`030??cl`3_knl0kno_0080000000<0Kfm_0=kNgP3Ng]h00`3_knl50?Ogm`d0kno_103gmoL00`3c
lo<0kno_0>o_k`050?Ogm`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl00P3_knl00`3c
lo<0moOg0?Ogm`030?Ogm``0kno_1P3gmoL20>o_k`D0moOg0P3_knl0103clo<0moOg0?Ogm`3clo<2
0>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080c/k>00<0gmoO
0>o_k`3_knl00P3_knl50?Ogm`<0kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg0080moOg00@0lo?c
0>o_k`3_knl0lo?c103gmoL00`3clo<0kno_0>o_k`0:0>o_k`D0moOg0P3_knl00`3clo<0moOg0?Og
m`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL01@3_knl50?Ogm`030??cl`3_knl0kno_00X0kno_0`3N
g]h208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c
0>o_k`3_knl00P24Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgPD0kno_103gmoL0103clo<0kno_0>o_
k`3clo<40?Ogm`030??cl`3_knl0kno_0080000000<0Kfm_0=kNgP3Ng]h00`3_knl50?Ogm`d0kno_
103gmoL00`3clo<0kno_0>o_k`050?Ogm`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl0
0P3_knl00`3clo<0moOg0?Ogm`030?Ogm``0kno_1P3gmoL20>o_k`D0moOg0P3_knl0103clo<0moOg
0?Ogm`3clo<20>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080
c/k>00<0gmoO0>o_k`3_knl00P3_knl50?Ogm`<0kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg0080
moOg00@0lo?c0>o_k`3_knl0lo?c103gmoL00`3clo<0kno_0>o_k`0:0>o_k`D0moOg0P3_knl00`3c
lo<0moOg0?Ogm`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL01@3_knl50?Ogm`030??cl`3_knl0kno_
00X0kno_0`3Ng]h208B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>
cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0
moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL20?Ogm``0kno_00<0lo?c0?Ogm`3gmoL01@3_knl203Ti
>@0305mOG`24Q8@0Q8B400X0kno_00<0lo?c0?Ogm`3gmoL00P3oool=0>o_k`80moOg00<0lo?c0>o_
k`3_knl00`3_knl20?Ogm`030??cl`3_knl0kno_00X0kno_00<0lo?c0?Ogm`3gmoL00P3oool=0>o_
k`80moOg00<0lo?c0>o_k`3_knl02P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg
00<0Q8B41@3Ng]h:0>o_k`80moOg00<0lo?c0>o_k`3_knl00P3_knl00`3clo<0moOg0?Ogm`0=0>o_
k`80moOg00<0no_k0?ooo`3oool0303_knl00`3clo<0moOg0?Ogm`0E0>o_k`D0moOg0P3_knl30=kN
gP<0e]KF0P1kNg/70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>OW
i`80moOg303_knl00`3clo<0moOg0?Ogm`050>o_k`80>CTi00<0GemO08B4Q024Q8@02P3_knl00`3c
lo<0moOg0?Ogm`020?ooo`d0kno_0P3gmoL00`3clo<0kno_0>o_k`030>o_k`80moOg00<0lo?c0>o_
k`3_knl02P3_knl00`3clo<0moOg0?Ogm`020?ooo`d0kno_0P3gmoL00`3clo<0kno_0>o_k`0:0>o_
k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@50=kNgPX0kno_0P3gmoL00`3c
lo<0kno_0>o_k`020>o_k`030??cl`3gmoL0moOg00d0kno_0P3gmoL00`3kno/0oooo0?ooo`0<0>o_
k`030??cl`3gmoL0moOg01D0kno_1@3gmoL20>o_k`<0g]kN0`3Fe]H207]kN`L0moOg00<0gmoO0<K6
aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0inOW0P3>c/h00`38b<P0
`/;20<;2`P050?_kn`80Q8B400@0[Jf]0=KFeP3Fe]H0gmoO103WinL30??cl`80inOW1@3_knl00`3]
kNd0jn_[0>_[j`020>o_k`030>_[j`3WinL0inOW0080Kfm_00<0FEUI0492@P12@T800`3:b/X20>o_
k`030>GUi@3Kfm/0fm_K0080WIfM00<0b<S80??cl`3clo<00P3gmoL30>o_k`030?7al@3clo<0lo?c
0080inOW0P3_knl00`3[jn/0inOW0>OWi`020??cl`040>g]k@3WinL0inOW0>_[j`80kno_0P3clo<0
0`3]kNd0inOW0>OWi`020>o_k`030>_[j`3WinL0inOW00<0lo?c0P3_knl00`3alO40lo?c0??cl`02
0?Ogm`<0kno_0P3clo<80>o_k`80lo?c00<0kNg]0>OWi`3WinL00P3_knl0103[jn/0inOW0>OWi`3[
jn/20>o_k`80inOW00<0gmoO0=KFeP3Fe]H00P20P8000`2n_[h0no_k0?_kn`0308B4Q0D0f][J0P3W
inL30>o_k`80inOW0`3_knl20??cl`030>g]k@3WinL0inOW0080kno_00<0kNg]0>_[j`3[jn/0203_
knl20??cl`030?7al@3_knl0kno_0080lo?c00<0mOGe0?Ogm`3gmoL00`3_knl20??cl`<0kno_0P3W
inL20>o_k`030>g]k@3[jn/0jn_[00<0kno_0P3WinL00`3[jn/0kno_0>o_k`020>o_k`030>_[j`3W
inL0inOW0080kno_00@0jn_[0>OWi`3WinL0jn_[0P3_knl50??cl`80kno_0`3Ng]h30=KFeP80Ng]k
1`3kno/00`3Ogml0`/;20<;2`P030=;BdP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_
knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@00`2][Jd0e]KF0=KFeP030=KFeP80g]kN0`3g
moL20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP020:FUY@0305=CD`00
0000000000<0YJFU0P3_knl00`3Kfm/0a/K60<K6aP0204Y:BP0309fMW@3_knl0kno_00D0kno_00<0
lo?c0?Ogm`3gmoL00P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW
103_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00<0moOg2P3_knl20?Ogm`X0kno_
00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80g]kN00<0f][J0=KFeP3F
e]H00P1kNg/00`2m_Kd0oooo0?ooo`0308B4Q0D0e]KF0P3Ng]h30>o_k`80g]kN1@3_knl00`3WinL0
g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00P0kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80
moOg0`3_knl20=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3_knl20=kNgP030>OWi`3_knl0kno_0080
kno_00<0inOW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL90>o_k`<0g]kN0`3Fe]H207]k
N`L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
kno_0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400<0[Jf]0=KFeP3Fe]H00`3Fe]H20=kNgP<0
moOg0P3Ng]h50>o_k`030>OWi`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00P2UYJD00`1CDe<0
0000000000030:FUY@80kno_00<0fm_K0<K6aP36a/H00P1:BTX00`2MWId0kno_0>o_k`050>o_k`03
0??cl`3gmoL0moOg0080g]kN0P3_knl00`3WinL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OW
i`@0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP030?Ogm`X0kno_0P3gmoL:0>o_
k`030>OWi`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW0P3_knl20=kNgP030=[JfP3Fe]H0
e]KF0080Ng]k00<0_Kfm0?ooo`3oool00`24Q8@50=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW
0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP080>o_k`80moOg00<0lo?c0>o_k`3_knl0203_knl2
0?Ogm`<0kno_0P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0kno_0P3Ng]h00`3WinL0kno_0>o_k`02
0>o_k`030>OWi`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW2@3_knl30=kNgP<0e]KF0P1k
Ng/70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>OWi`80c/k>00<0b<S80<;2`P32`/801@3kno/208B4Q0040:^[Z`3Bd]80d];B0=KFeP80f][J0P3N
g]h30>_[j`80g]kN0P3_knl0103[jn/0inOW0>OWi`3Shn<20=kNgP80kno_00<0inOW0=kNgP3Ng]h0
0P32`/800`22PX80@T920492@P0305MGE`D0N7Qh0P20P8000`2d];@0inOW0>OWi`020>OWi`<0kno_
00<0kNg]0>_[j`3[jn/00P3Ng]h20>OWk`030>?Si`3Ng]h0g]kN0080inOW00@0hn?S0=kNgP3Ng]h0
inOW0P3_knl20>OWi`030>?Sh`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h00`3[jn/20>?Sh`03
0>WYj@3_knl0kno_0080inOW0`3_knl20>_[j`H0inOW0P3_knl20>OWi`030>?Sh`3Ng]h0g]kN0080
inO_00@0hn?W0=kNgP3Ng]h0hn?S0P3WinL20=kNgP030=SHf03Bd]80d];B0080P82000<0_[jn0?_k
n`3kno/00`24Q8@20=;BdP030=KFeP3Jf]X0f][J0080g]kN0`3WinL20=kNgP<0kno_0P3WinL00`3S
hn<0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0inOW00<0jn_[0>o_k`3_knl00P3[jn/00`3]
kNd0kno_0>o_k`080>OWi`80lo?c0`3WinL20=kNgP80inO_00<0hn?W0=kNgP3Ng]h00`3WinL20=kN
gP030>WYj@3clo<0lo?c0080inOW00<0hn?S0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3QhN42
0>?Sh`80inOW00<0jn_[0>o_k`3_knl00P3WinL30=kNgP<0d];B0P20P8070?_kn`030=cLg02m_Kd0
_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6
aP36a/H01@3gmoL208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kNgP03
0=kNgP80kno_00<0inOW0=kNgP3Ng]h00P3Ng]h00`2a/K40Q8B408B4Q00300P82080000000<05ADE
02TY:@0Y:BT00P2e]KD00`3:b/X0g]kN0=kNgP020=kNgP<0kno_00<0inOW0=kNgP3Ng]h00P3Ng]h2
0=kNk`030=kNi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20>o_k`030>OWi`3Ng]h0
g]kN00<0g]kN0P3Fe]H00`3Shn<0kno_0>o_k`020=kNgP<0kno_203Ng]h20>o_k`D0g]kN0P3Ng^l0
0`3Ng^L0g]kN0=kNgP050=kNgP030=KFeP3>c/h0c/k>0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@2
0<k>cP030=KFeP3Ng]h0g]kN00L0g]kN0`3_knl50=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h0
0`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00P0g]kN0P3_knl50=kNgP80g]k_00<0g]kW
0=kNgP3Ng]h01@3Ng]h00`3[jn/0moOg0?Ogm`050=kNgP80kno_00@0inOW0=kNgP3Ng]h0f][J0P3F
e]H20=kNgP030>OWi`3_knl0kno_00D0g]kN0`3>c/h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3F
e]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP05
0?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF2@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_
knl00`3WinL0g]kN0=kNgP020=kNgP030;6a/@24Q8@0Q8B400<020P80P0000000`0E5AD0:BTY02TY
:@020;Fe]@030<[:bP3Ng]h0g]kN0080g]kN0`3_knl00`3WinL0g]kN0=kNgP020=kNgP80g]k_00<0
g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3N
g]h20=KFeP030>?Sh`3_knl0kno_0080g]kN0`3_knl80=kNgP80kno_1@3Ng]h20=kNk`030=kNi`3N
g]h0g]kN00D0g]kN00<0e]KF0<k>cP3>c/h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080c/k>00<0
e]KF0=kNgP3Ng]h01`3Ng]h30>o_k`D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_
knl0kno_0080g]kN00<0inOW0>o_k`3_knl0203Ng]h20>o_k`D0g]kN0P3Ng^l00`3Ng^L0g]kN0=kN
gP050=kNgP030>_[j`3gmoL0moOg00D0g]kN0P3_knl0103WinL0g]kN0=kNgP3Jf]X20=KFeP80g]kN
00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24
Q8@0102YZJT0c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[J
fP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h20=KFeP030=[JfP3Ng]h0g]kN00X0g]kN
0P3Ng]H00`3Jf]H0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h0
0`3Fe]H:0=kNgP80e]KF3@3Ng]h20=kNeP040=[JeP3Fe]H0e]KF0=[JfP80g]kN0P3Fe]H00`3Bd]80
c/k>0<k>cP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3>c/h00`3Fe]H0g]kN0=kNgP020=KFePX0
g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0
g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0
e]KF0=KFeP020=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@50>o_
k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050>o_k`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KF
ePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN
00P0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3J
f]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00<0e]KF2P3Ng]h20=KFePd0g]kN0P3Ng]H0103J
f]H0e]KF0=KFeP3Jf]X20=kNgP80e]KF00<0d];B0<k>cP3>c/h00P24Q8@00`2j^[X0kno_0>o_k`03
08B4Q080c/k>00<0e]KF0=kNgP3Ng]h00P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J
0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgP80e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h2
0=kNeP030=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3J
f]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool0
0`3kno/0moOg0?Ogm`0207]kN`040:f][@3Ng]h0g]kN0>_[jah0moOg0P3oool00`3kno/0moOg0?Og
m`020?ooo`030?_kn`3gmoL0moOg01h0moOg00<0no_k0?ooo`3oool0203gmoL20?ooo`<0moOg0P3o
oolE0?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0
jn_[0?Ogm`3gmoL06@3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080oooo00<0
no_k0?Ogm`3gmoL0703gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg0P3oool30>o_k`<0g]kN0P24
Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0moOg0?Ogm`0207]kN`040:f][@3Ng]h0
g]kN0>_[jah0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg01h0moOg00<0
no_k0?ooo`3oool0203gmoL20?ooo`<0moOg0P3ooolE0?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24
Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0jn_[0?Ogm`3gmoL06@3gmoL00`3kno/0oooo0?oo
o`020?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL0703gmoL20?ooo`030?_kn`3g
moL0moOg00P0moOg0P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool0
0`3kno/0moOg0?Ogm`0207]kN`040:f][@3Ng]h0g]kN0>_[jah0moOg0P3oool00`3kno/0moOg0?Og
m`020?ooo`030?_kn`3gmoL0moOg01h0moOg00<0no_k0?ooo`3oool0203gmoL20?ooo`<0moOg0P3o
oolE0?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0
jn_[0?Ogm`3gmoL06@3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_kn`3gmoL0moOg0080oooo00<0
no_k0?Ogm`3gmoL0703gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg0P3oool30>o_k`<0g]kN0P24
Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040;Zj^P3_knl0kno_0?Ogmg80oooo0P24
Q8@00`32`/80oooo0?ooo`0308B4Q080kno_00<0moOg0?ooo`3oool0E`3oool208B4Q0L0oooo00<0
g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H0
0`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0^[Zj0>o_k`3_knl0moOgLP3oool208B4Q0030<;2`P3o
ool0oooo00<0Q8B40P3_knl00`3gmoL0oooo0?ooo`1G0?ooo`80Q8B41`3oool00`3Ng]h0_Kfm0;fm
_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0
_Kfm00D0moOg1@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k4P24Q8@307]kN`D0Q8B40P1kNg/0
0`20P800Q8B408B4Q00808B4Q080Ng]k1`24Q8@01020P800Ng]k07]kN`20P80A08B4Q0030820P01k
Ng/0Ng]k00D0Q8B40P1kNg/:08B4Q0030820P01kNg/0Ng]k00l0Q8B400<0_[jn0?Ogm`3gmoL01@24
Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k4P24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k00<0
P82008B4Q024Q8@02024Q8@207]kN`P0Q8B40P1kNg/00`20P800Q8B408B4Q00?08B4Q0030820P01k
Ng/0Ng]k00X0Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg1@24Q8@00`20P800Ng]k07]kN`05
08B4Q080Ng]k4P24Q8@307]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k1`24Q8@0
1020P800Ng]k07]kN`20P80A08B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/:08B4Q0030820P01k
Ng/0Ng]k00l0Q8B400<0_[jn0?Ogm`3gmoL01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k4P24
Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`P0Q8B40P1k
Ng/00`20P800Q8B408B4Q00?08B4Q0030820P01kNg/0Ng]k00X0Q8B41`3gmoL00`3Ogml0a/K60<K6
aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<[:bP32`/80
`/;200D0lo?c0P20P8001022PX80Q8B408B4Q022PX840820P0<0Q8B41020P8000`22PX80Q8B408B4
Q00508B4Q00308J6QP28R8P0R8R80080P82000<0PX:208B4Q024Q8@01@20P8000`22PX80Q8B408B4
Q0020820P00308:2PP24Q8@0Q8B40080Q8B40`20P8000`22PX80Q8B408B4Q0070820P080Q8B400<0
PX:20820P020P8000`20P80:08B4Q0<0P8200P24Q8@00`22PX80P8200820P0020820P0<0Q8B40P20
P80608B4Q080P8200P24Q8@00`22PX80P8200820P0050820P00308:2PP24Q8@0Q8B40080P82000<0
PX:208B4Q024Q8@00P24Q8@00`2l_;`0lo?c0??cl`0307alO080Q8B400<0PX:20820P020P8000P20
P80308B4Q0D0P8201@24Q8@208R8R00308J6QP24Q8@0Q8B40080P82000@0PX:208B4Q024Q8@0PX:2
1020P8000`22PX80Q8B408B4Q0020820P00308:2PP24Q8@0Q8B400<0Q8B40P20P80308B4Q0L0P820
1@24Q8@00`22PX80P8200820P00:08B4Q00308:2PP20P800P8200080Q8B400<0PX:20820P020P800
1@20P80508B4Q0L0lo?c00<0fm_K0<;2`P32`/800`3>c/h20>OWi`030>o_k`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_k`80Ng]k00<0P82008B4Q024Q8@00`24
Q8@207]kN`D0Q8B40P1kNg/00`20P800Q8B408B4Q00508B4Q00308R8R02<S8`0S8b<0080Ng]k00<0
P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400L0Q8B40`1kNg/00`20P800Q8B408B4
Q00208B4Q0D0Ng]k1@24Q8@00`20P800Ng]k07]kN`0:08B4Q0<0Ng]k1@24Q8@207]kN`/0Q8B40P1k
Ng/508B4Q0D0Ng]k00<0P82008B4Q024Q8@00P1kNg/00`20P800Q8B408B4Q00208B4Q0030;Zj^P3_
knl0kno_00<0Lg=c1@24Q8@207]kN`D0Q8B40`1kNg/508B4Q080S8b<00<0R8R808B4Q024Q8@00P1k
Ng/00`20P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`D0Q8B41@1k
Ng/308B4Q080S8b<00<0Q8B407]kN`1kNg/02P24Q8@00`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24
Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/5
08B4Q080Ng]k00<0P82008B4Q024Q8@01@24Q8@00`28R8P0S8b<08b<S00207]kN`030820P024Q8@0
Q8B400<0Q8B40P1kNg/00`20P800Q8B408B4Q00708B4Q0<0Ng]k00<0P82008B4Q024Q8@00P24Q8@5
07]kN`D0Q8B400<0P82007]kN`1kNg/02P24Q8@307]kN`D0Q8B40P1kNg/;08B4Q080Ng]k1@24Q8@5
07]kN`030820P024Q8@0Q8B40080Ng]k00<0P82008B4Q024Q8@00P24Q8@00`2j^[X0kno_0>o_k`03
07=cL`D0Q8B40P1kNg/508B4Q0<0Ng]k1@24Q8@208b<S00308R8R024Q8@0Q8B40080Ng]k00<0P820
08B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/508B4Q0D0Ng]k0`24Q8@2
08b<S00308B4Q01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/01@24Q8@507]kN`D0Q8B41`3_knl0
0`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KF
eP030<k>cP36a/H0a/K600D0kno_0P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]k
N`030820P024Q8@0Q8B400D0Q8B400<0R8R808b<S02<S8`00P1kNg/00`20P800Q8B408B4Q00308B4
Q080Ng]k00<0P82008B4Q024Q8@01`24Q8@307]kN`030820P024Q8@0Q8B40080Q8B41@1kNg/508B4
Q0030820P01kNg/0Ng]k00X0Q8B40`1kNg/508B4Q080Ng]k2`24Q8@207]kN`D0Q8B41@1kNg/00`20
P800Q8B408B4Q00207]kN`030820P024Q8@0Q8B40080Q8B400<0^[Zj0>o_k`3_knl00`1cLg<508B4
Q080Ng]k1@24Q8@307]kN`D0Q8B40P2<S8`00`28R8P0Q8B408B4Q00207]kN`030820P024Q8@0Q8B4
00<0Q8B40P1kNg/00`20P800Q8B408B4Q00808B4Q080Ng]k1@24Q8@507]kN`<0Q8B40P2<S8`00`24
Q8@0Ng]k07]kN`0:08B4Q0030820P01kNg/0Ng]k00D0Q8B41@1kNg/508B4Q0L0kno_00<0e]KF0;fm
_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0
_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_kn`3gmoL0moOg
00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`020?oo
o`H0moOg0P3oool70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo0?ooo`030?Og
m`D0oooo1@3gmoL20?ooo`<0moOg0`3oool40?Ogm`030?_kn`3oool0oooo00X0moOg00<0jn_[0=kN
gP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL50?oo
o`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo
0080oooo00<0no_k0?Ogm`3gmoL00`3oool50?Ogm`80oooo203gmoL50?ooo`L0moOg00<0no_k0?oo
o`3oool00`3oool20?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0
_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kNgP3Ng]h0jn_[1`3gmoL40?ooo`030?_kn`3gmoL0moOg
00D0moOg00<0no_k0?ooo`3oool01@3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`020?oo
o`H0moOg0P3oool70?Ogm`030?_kn`3oool0oooo00<0oooo1`3gmoL00`3kno/0oooo0?ooo`030?Og
m`D0oooo1@3gmoL20?ooo`<0moOg0`3oool40?Ogm`030?_kn`3oool0oooo00X0moOg00<0jn_[0=kN
gP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL01@3gmoL50?oo
o`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo
0080oooo00<0no_k0?Ogm`3gmoL00`3oool50?Ogm`80oooo203gmoL50?ooo`L0moOg00<0no_k0?oo
o`3oool00`3oool20?Ogm`030?_kn`3oool0oooo00D0moOg0`3Ng]h208B4Q0L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0
_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_K`3oool00`3_knl0g]kN0=kNgP0208B4
Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`1D0?ooo`<0g]kN0P24Q8@70?oo
o`030>?Sh`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>o_kfl0oooo00<0kno_0=kN
gP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0kno_0?ooo`3oool0E03oool30=kN
gP80Q8B41`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102a/K40g]kN0=kNgP3_knm_0?oo
o`030??cl`3WinL0inOW0080Q8B400<0`<300?_kn`3kno/00`24Q8@20=kNgP030>o_k`3oool0oooo
05@0oooo0`3WinL208B4Q0L0no_k00<0gmoO0<;2`P32`/800`3Bd]820>OWi`030>o_k`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3N
g]h0kno_K`3oool00`3gmoL0kno_0>o_k`0208B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3_
knl0oooo0?ooo`1D0?ooo`<0kno_0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3_knl00`3c
lo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208B4Q004
0;6a/@3Ng]h0g]kN0>o_kfl0oooo00<0moOg0>o_k`3_knl00P24Q8@00`2n_[h0moOg0?Ogm`0308B4
Q080g]kN00<0kno_0?ooo`3oool0E03oool30>o_k`80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0
kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmf/0oooo0P3gmoL00`3clo<0kno_0>o_k`0208B4
Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`1A0?ooo`<0moOg0`3Ng]h208B4
Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Og
mf/0oooo0P3gmoL00`3clo<0kno_0>o_k`0208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[
jn/0moOg0?Ogm`1A0?ooo`<0moOg0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<c<c036a/H0a/K600D0
lo?c0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?OgmbH0oooo0P3:b/Y30?ooo`80no_k00<0lO7a0>OW
i`3WinL00P24Q8@00`2l_;`0lo?c0??cl`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL06@3oool00`3S
hn<0a/K60<K6aP0c0?ooo`D0no_k0`3Ng]h208R8R0D0lo?c0P3gmoL00`3MgMd0`/;20<;2`P030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0
moOg0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?OgmbH0oooo0P2DU9A50?ooo`030>o_k`3Ng]h0g]kN
0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>_[j`3gmoL0moOg01T0oooo00<0a/K608b<
S02<S8`0<`3oool20?Ogm`<0oooo0`3Ng]h208b<S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Ogm`80
Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoLV0?ooo`80U9BDA@3oool00`3_knl0g]kN0=kNgP0208B4
Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`0I0?ooo`030<K6aP2<S8`0S8b<
03<0oooo0P3gmoL30?ooo`<0g]kN0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q004
0;6a/@3Ng]h0g]kN0>OWi`80kno_8`3oool00`3kno/0moOg0?Ogm`02000000<0a/K600<0hn?S0?oo
o`3oool03`3oool?000000030820P03oool0oooo01`0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0207]k
N`030;fm_@3oool0oooo00<0S8b<0P3Fe]H00`3WinL0moOg0?Ogm`0F0?ooo`040?Ogm`3_knl0kno_
07QhN08000000P36a/H00`3Shn<0oooo0?ooo`0?0?ooo`l0000000<0P8200?ooo`3oool04P3oool3
0=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3WinL2
0>o_kb<0oooo00<0no_k0?Ogm`3gmoL00P0000030<K6aP030>?Sh`3oool0oooo00l0oooo3`000000
0`20P800oooo0?ooo`0L0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P1kNg/00`2m_Kd0oooo0?ooo`03
08b<S080e]KF00<0inOW0?Ogm`3gmoL05P3oool0103gmoL0kno_0>o_k`1hN7P200000080a/K600<0
hn?S0?ooo`3oool03`3oool?000000030820P03oool0oooo0180oooo0`3Ng]h208B4Q0L0oooo00<0
g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H0
0`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knlS0?ooo`030?_kn`3g
moL0moOg008000000`36a/H00`3Shn<0oooo0?ooo`0?0?ooo`l0000000<0P8200?ooo`3oool0703o
ool20?Ogm`030>_[j`3Ng]h0g]kN0080Ng]k00<0_Kfm0?ooo`3oool00`2<S8`20=KFeP030>OWi`3g
moL0moOg01H0oooo00@0moOg0>o_k`3_knl0N7Qh0P0000020<K6aP030>?Sh`3oool0oooo00l0oooo
3`0000000`20P800oooo0?ooo`0B0?ooo`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3g
moL208B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg0P3oool20?Ogm`030?_kn`3oool0oooo01L0oooo
00<0^KVi07=cL`1cLg<00P0H61P307]kN`030;fm_@3oool0oooo00T0oooo00@0no_k0?Ogm`3gmoL0
no_k0P3oool?000000030820P03oool0oooo0140oooo00<0no_k0?Ogm`3gmoL0203oool20?Ogm`03
0>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>_[j`3gmoL0moOg0080
moOg0`3oool20?Ogm`l0oooo00@0^KVi07=cL`1cLg<0ATI60P0H61P207]kN`030;fm_@3oool0oooo
00l0oooo3`0000000`20P800oooo0?ooo`0?0?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0
_Kfm0;fm_@050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0jn_[1`3gmoL20?ooo`80moOg00<0no_k0?oo
o`3oool05`3oool00`2i^KT0Lg=c07=cL`0201PH60<0Ng]k00<0_Kfm0?ooo`3oool02@3oool0103k
no/0moOg0?Ogm`3kno/20?ooo`l0000000<0P8200?ooo`3oool04@3oool00`3kno/0moOg0?Ogm`08
0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0jn_[
0?Ogm`3gmoL00P3gmoL30?ooo`80moOg3`3oool0102i^KT0Lg=c07=cL`16ATH201PH6080Ng]k00<0
_Kfm0?ooo`3oool03`3oool?000000030820P03oool0oooo00l0oooo0`3_knl30=kNgP80Q8B41`3g
moL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h2
0=;BdP030<S8b02m_Kd0_Kfm0080moOg00<0mOGe0??cl`3clo<00P24Q8@0102a/K40g]kN0=kNgP3Y
jNT20??cl`80no_k0`3gmoL20?ooo`D0no_k00<0oOgm0?ooo`3oool00P3oool00`3moOd0no_k0?_k
n`050?ooo`D0no_k00<0oOgm0?ooo`3oool00P3gmoL00`2OWil0ATI604I6AP0206][J`<0DU9B00<0
ZJVY0?ooo`3oool0103oool00`3moOd0no_k0?_kn`020?ooo`030?gmo@3kno/0no_k00<0no_k3`00
00000`1nOWh0no_k0?_kn`020?_kn`/0oooo0P3kno/20?ooo`030?gmo@3kno/0no_k0080no_k00<0
oOgm0?ooo`3oool00`3oool20??cl`030>WYj@3Ng]h0g]kN0080Q8B400<0_;bl0??cl`3clo<00`24
Q8@20=kNgP030>_[j`3gmoL0moOg0080moOg0`3oool50?_kn`X0oooo0P3gmoL0102OWil0ATI604I6
AP1IFET206][J`80DU9B00<0ZJVY0?ooo`3oool01@3kno/:0?ooo`l0000000<0OWin0?_kn`3kno/0
0P3kno/00`3moOd0oooo0?ooo`030?ooo`D0no_k0P3oool30??cl`<0inOW0P24Q8@20??cl`030?Ge
m@3gmoL0moOg0080lo?c00<0f=SH0;fm_@2m_Kd00`3Bd]820>OWi`030>o_k`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080Q8B400@0
/K6a0=kNgP3Ng]h0inOW0P3_knl20?ooo`<0moOg103oool0103kno/0moOg0?Ogm`3kno/40?ooo`03
0?_kn`3gmoL0moOg00D0oooo1@3gmoL00`3kno/0oooo0?ooo`020>o_k`0308B4Q00H61P061PH0080
_Kfm0`0Y:BT00`2DU9@0oooo0?ooo`040?ooo`030?_kn`3gmoL0moOg00D0oooo00<0no_k0?Ogm`3g
moL03`0000000`1lO7`0moOg0?Ogm`020?Ogm`/0oooo0P3gmoL50?ooo`80moOg00<0no_k0?ooo`3o
ool00`3oool20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=kNgP03
0>_[j`3gmoL0moOg0080moOg1@3oool30?Ogm`X0oooo0P3_knl01024Q8@061PH01PH601[Jf/20;fm
_@80:BTY00<0U9BD0?ooo`3oool01@3gmoL:0?ooo`l0000000<0O7al0?Ogm`3gmoL00P3gmoL00`3k
no/0oooo0?ooo`030?ooo`D0moOg0P3oool30?Ogm`<0kno_0P24Q8@20>o_k`030??cl`3gmoL0moOg
0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080Q8B400@0/K6a0=kNgP3N
g]h0inOW0P3_knl20?ooo`<0moOg103oool0103kno/0moOg0?Ogm`3kno/40?ooo`030?_kn`3gmoL0
moOg00D0oooo1@3gmoL00`3kno/0oooo0?ooo`020>o_k`0308B4Q00H61P061PH0080_Kfm0`0Y:BT0
0`2DU9@0oooo0?ooo`040?ooo`030?_kn`3gmoL0moOg00D0oooo00<0no_k0?Ogm`3gmoL03`000000
0`1lO7`0moOg0?Ogm`020?Ogm`/0oooo0P3gmoL50?ooo`80moOg00<0no_k0?ooo`3oool00`3oool2
0>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24Q8@20=kNgP030>_[j`3gmoL0
moOg0080moOg1@3oool30?Ogm`X0oooo0P3_knl01024Q8@061PH01PH601[Jf/20;fm_@80:BTY00<0
U9BD0?ooo`3oool01@3gmoL:0?ooo`l0000000<0O7al0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?oo
o`030?ooo`D0moOg0P3oool30?Ogm`<0kno_0P24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0
e]KF0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h0
0`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_0P3oool50?Ogm`80oooo0P3g
moL00`3kno/0oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg00D0oooo0`3gmoL20?ooo`030?_kn`3g
moL0moOg0080Hf=S00<0N7Qh08b<S02<S8`00P3oool300P8200307=cL`3Ng]h0g]kN0080oooo0P3g
moL00`3kno/0oooo0?ooo`050?ooo`030?_kn`3gmoL0moOg00l0000000<0P8200?ooo`3oool00P3o
ool50?Ogm`<0oooo0`3gmoL70?ooo`80moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OW
i`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_00L0moOg
203oool20?Ogm`030?_kn`3oool0oooo0080Hf=S00@0N7Qh08b<S02<S8`0a/K60P3oool200P82003
07alO03_knl0kno_00D0oooo1@3gmoL30?ooo`80moOg3`0000000`1lO7`0moOg0?Ogm`020?ooo`04
0?_kn`3gmoL0moOg0?_kn`L0oooo0P3gmoL30>o_k`<0g]kN0P1kNg/70?Ogm`030=oOg`36a/H0a/K6
00<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36
a/H01@3gmoL208B4Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3gmoL20?ooo`80moOg00<0no_k0?oo
o`3oool01@3oool00`3kno/0moOg0?Ogm`050?ooo`<0moOg0P3oool00`3kno/0moOg0?Ogm`0206=S
H`0307QhN02<S8`0S8b<0080oooo0`0820P00`1cLg<0g]kN0=kNgP020?ooo`80moOg00<0no_k0?oo
o`3oool01@3oool00`3kno/0moOg0?Ogm`0?000000030820P03oool0oooo0080oooo1@3gmoL30?oo
o`<0moOg1`3oool20?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P3_knl00`3WinL0g]kN0=kNgP02
08B4Q0030;jn_P3gmoL0moOg00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`070?Ogm`P0oooo0P3gmoL0
0`3kno/0oooo0?ooo`0206=SH`0407QhN02<S8`0S8b<0<K6aP80oooo0P0820P00`1lO7`0kno_0>o_
k`050?ooo`D0moOg0`3oool20?Ogm`l0000000<0O7al0?Ogm`3gmoL00P3oool0103kno/0moOg0?Og
m`3kno/70?ooo`80moOg0`3_knl30=kNgP80Ng]k1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20<k>cP030<S8b032`/80`/;200D0no_k0P20
P800102_[jl0g]kN0=kNgP3[jn/70?Ogm`80oooo0P3gmoL0103kno/0oooo0?ooo`3moOd20?_kn`80
oooo00<0oOgm0?_kn`3kno/0203kno/20;fm_@030;Vi^@2e]KD0]KFe0080=SHf00<0OWin0<K6aP36
a/H00P3kno/302d];@0307EeM@2m_Kd0_Kfm0080oooo0P3gmoL00`3kno/0oooo0?ooo`020?_kn`04
0?gmo@3oool0oooo0?gmo@80no_k3`0000000`20P800oooo0?ooo`070?_kn`<0oooo0`3gmoL20?oo
o`80no_k00<0oOgm0?ooo`3oool01@3kno/00`3inOT0moOg0?Ogm`020??cl`030>WYj@3Ng]h0g]kN
0080Q8B400<0`<300?_kn`3kno/00`24Q8@20=kNgP030>WYj@3clo<0lo?c0080moOg0`3kno/20?Og
m`<0oooo0P3kno/00`3moOd0oooo0?ooo`020;Vi^@030;Ng]`2e]KD0]KFe0080=SHf00@0OWin0<K6
aP36a/H0hn?S0P3oool202d];@0307YjNP36a/H0a/K600X0no_k0`3oool20?Ogm`l0000000<0OWin
0?_kn`3kno/00P3oool00`3moOd0no_k0?_kn`030?_kn`80oooo00<0oOgm0?_kn`3kno/00P3gmo/3
0??cl`<0g]kN0P20P8070?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08
ooooo`001_ooool30>o_k`80c/k>00<0a/K60;fm_@2m_Kd01@3oool207]kN`040:f][@3Ng]h0g]kN
0>OWi`80kno_1@3gmoL20?ooo`80moOg00@0no_k0?ooo`3oool0no_k0P3gmoL50?ooo`D0moOg0`3o
ool207]kN`0307MgM`1cLg<0Lg=c008020P800<0Q8B40?ooo`3oool00P3gmoL3059BDP0307MgM`2L
W9`0W9bL0080oooo0P3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo00<0oooo3`00
00000`20P800oooo0?ooo`020?Ogm`P0oooo0`3gmoL20?ooo`80moOg00<0no_k0?ooo`3oool00P3o
ool00`3kno/0moOg0?Ogm`050?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?ooo`3oool00`24
Q8@20=kNgP030>_[j`3gmoL0moOg0080moOg0`3oool20?Ogm`<0oooo0P3gmoL00`3kno/0oooo0?oo
o`0207]kN`0307=cL`1[Jf/0Jf][008020P800<0Q8B40?ooo`3oool00`3oool2059BDP0307MgM`2L
W9`0W9bL00D0moOg203oool20?Ogm`l0000000<0P8200?ooo`3oool01@3oool00`3kno/0moOg0?Og
m`020?ooo`030?_kn`3gmoL0moOg0080moOo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm
_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0
_Kfm00D0oooo0P1kNg/0102][Jd0g]kN0=kNgP3WinL20>o_k`D0moOg0P3oool20?Ogm`040?_kn`3o
ool0oooo0?_kn`80moOg1@3oool50?Ogm`<0oooo0P1kNg/00`1gMgL0Lg=c07=cL`0200P8200308B4
Q03oool0oooo0080moOg0`1BDU800`1gMgL0W9bL09bLW0020?ooo`80moOg00<0no_k0?ooo`3oool0
0P3gmoL00`3kno/0oooo0?ooo`030?ooo`l0000000<0P8200?ooo`3oool00P3gmoL80?ooo`<0moOg
0P3oool20?Ogm`030?_kn`3oool0oooo0080oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3[jn/0g]kN
0=kNgP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`<0oooo
0P3gmoL30?ooo`80moOg00<0no_k0?ooo`3oool00P1kNg/00`1cLg<0Jf][06][J`0200P8200308B4
Q03oool0oooo00<0oooo0P1BDU800`1gMgL0W9bL09bLW0050?Ogm`P0oooo0P3gmoL?000000030820
P03oool0oooo00D0oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`020?Ogo`<0moOg
0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0inOW
2`3gmoL0103kno/0oooo0?ooo`3kno/70?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20<k>cP03
08b<S01:BTX0BTY:0080S8b<00<0`/;20?Ogm`3gmoL00P3oool308b<S00307=cL`1JFUX0FUYJ00@0
moOg00<0no_k0?ooo`3oool0203gmoL?0000000307alO03gmoL0moOg0080oooo2`3gmoL20?ooo`L0
moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0_[jn0?Og
m`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_00L0moOg0`3oool50?Ogm`80c/k>00<0T92@059B
DP1BDU800P2<S8`00`32`/80moOg0?Ogm`030?Ogm`80S8b<00<0Kfm_059BDP1BDU800P3gmoL00`3k
no/0oooo0?ooo`0:0?Ogm`l0000000<0O7al0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`020?Og
m`030?_kn`3oool0oooo0080moOg0`3_knl30=KFeP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0
moOg0P24Q8@0102][Jd0e]KF0=KFeP3WinL;0?Ogm`040?_kn`3oool0oooo0?_kn`L0moOg0P3oool0
0`3kno/0moOg0?Ogm`030?Ogm`80c/k>00<0S8b<04Y:BP1:BTX00P2<S8`00`32`/80moOg0?Ogm`02
0?ooo`<0S8b<00<0Lg=c05YJFP1JFUX0103gmoL00`3kno/0oooo0?ooo`080?Ogm`l0000000<0O7al
0?Ogm`3gmoL00P3oool;0?Ogm`80oooo1`3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80kno_00<0
inOW0=kNgP3Ng]h00P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl01`3g
moL30?ooo`D0moOg0P3>c/h00`2@T900DU9B059BDP0208b<S0030<;2`P3gmoL0moOg00<0moOg0P2<
S8`00`1_Kfl0DU9B059BDP020?Ogm`030?_kn`3oool0oooo00X0moOg3`0000000`1lO7`0moOg0?Og
m`050?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL30>o_k`<0e]KF0P24
Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<208B4Q0040:f][@3Fe]H0e]KF0>GUi@80lo?c2@3g
moL0103inOT0no_k0?_kn`3inOT40?Ogm`030?Win@3kno/0no_k0080no_k00<0nOWi0?Ogm`3gmoL0
0`3gmoL20>?Sh`030<;2`P2QXJ40XJ6Q0080`/;200<0gMgM0?Ogm`3gmoL00P3kno/30;Fe]@0307=c
L`0a<C40<C4a00@0moOg00<0nOWi0?_kn`3kno/01@3gmoL00`3inOT0no_k0?_kn`0?07alO0030;Zj
^P3gmoL0moOg0080no_k2`3gmoL20?_kn`D0moOg1@3kno/00`3inOT0moOg0?Ogm`020??cl`030>OW
i`3Jf]X0f][J0080Q8B400<0_;bl0??cl`3clo<00`24Q8@20=kNgP030>OWi`3_knl0kno_0080moOg
0`3kno/20?Ogm`<0no_k1@3gmoL20>OWi`030<K6aP2UYJD0YJFU0080`/;200<0gMgM0?Ogm`3gmoL0
0`3gmoL20;Fe]@03075aL@0];Bd0;Bd]0080moOg00<0nOWi0?_kn`3kno/01@3gmoL30?_kn`80moOg
201lO7`20820P00307inOP1lO7`0O7al0080O7al00<0^[Zj0?Ogm`3gmoL01@3gmoL00`3inOT0no_k
0?_kn`020?Ogm`030?Win@3kno/0no_k0080moOg0`3clo<30=[JfP80Q8B41@3clo<20?Ogm`030=[J
fP2m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0
b/[:0;fm_@2m_Kd01@3_knl208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_4@3gmoL00`3kno/0oooo
0?ooo`0D0?Ogm`<0g]kN00<0Lg=c00P8200820P0303gmoL00`3kno/0oooo0?ooo`0V0?Ogm`80oooo
00<0no_k0?Ogm`3gmoL01@3gmoL00`3WinL0e]KF0=KFeP0208B4Q0030;Zj^P3_knl0kno_00<0Q8B4
0P3Ng]h00`3WinL0kno_0>o_k`020?Ogm`<0oooo2P3gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg
0P3Ng]h00`1cLg<020P800P8200:0?Ogm`<0oooo2P3gmoL20?ooo`030?_kn`3gmoL0moOg01L0moOg
0`3Ng]h208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0kno_0P24Q8@0102][Jd0e]KF0=KF
eP3Shn<20>o_ka40moOg00<0no_k0?ooo`3oool0503gmoL30=kNgP0307=cL`0820P020P800`0moOg
00<0no_k0?ooo`3oool09P3gmoL20?ooo`030?_kn`3gmoL0moOg00D0moOg00<0inOW0=KFeP3Fe]H0
0P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080g]kN00<0inOW0>o_k`3_knl00P3gmoL30?ooo`X0moOg
0P3oool00`3kno/0moOg0?Ogm`080?Ogm`80g]kN00<0Lg=c00P8200820P02P3gmoL30?ooo`X0moOg
0P3oool00`3kno/0moOg0?Ogm`0G0?Ogm`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd0
0`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`38b<P0_Kfm0;fm
_@020?Ogm`030?Gem@3clo<0lo?c0080Q8B400@0[jn_0=[JfP3Jf]X0iNGU0P3_knl20??cl`l0moOg
00<0nOWi0?_kn`3kno/0203gmoL20?_kn`030?Win@3gmoL0moOg00L0moOg0`3[jn/00`1lO7`030`<
00`<30020>?Sh`80moOg00<0nOWi0?_kn`3kno/01@3gmoL00`3inOT0no_k0?_kn`0O0?Ogm`80no_k
1@3gmoL20?_kn`040?Ogm`3clo<0lo?c0?Gem@80moOg0P3clo<00`3UiND0e]KF0=KFeP0208B4Q003
0;bl_03clo<0lo?c00<0Q8B40P3Jf]X00`3QhN40inOW0>OWi`0?0?Ogm`80no_k00<0nOWi0?Ogm`3g
moL01@3gmoL00`3inOT0no_k0?_kn`020>_[j`0307inOP0@4100410@0080hn?S00<0kNg]0?Ogm`3g
moL01@3gmoL30?_kn`80moOg0P3kno/00`3inOT0moOg0?Ogm`030?Ogm`80no_k00<0nOWi0?Ogm`3g
moL04P3gmoL50??cl`<0f][J0P24Q8@50??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h20>OWi`03
0>o_k`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_k
n`3gmoL0moOg0080Q8B400@0/K6a0=kNgP3Ng]h0inOW103_knlJ0?Ogm`80oooo00<0no_k0?Ogm`3g
moL02P3gmoL00`24Q8@0410@010@40020<k>cP80moOg00<0no_k0?ooo`3oool09`3gmoL20?ooo`L0
moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Og
m`3gmoL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN0080moOg0`3_knlD0?Ogm`030?_kn`3oool0oooo
0080moOg00<0R8R801PH600H61P00P3>c/h00`3Shn<0moOg0?Ogm`0:0?Ogm`80oooo00<0no_k0?Og
m`3gmoL06P3gmoL50>o_k`<0e]KF0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0
moOg0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>OWi`@0kno_6P3gmoL20?ooo`030?_kn`3gmoL0moOg
00X0moOg00<0Q8B4010@400@41000P3>c/h20?Ogm`030?_kn`3oool0oooo02L0moOg0P3oool70?Og
m`040??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0
moOg00<0Q8B40P3Fe]H00`3Jf]X0g]kN0=kNgP020?Ogm`<0kno_503gmoL00`3kno/0oooo0?ooo`02
0?Ogm`0308R8R00H61P061PH0080c/k>00<0hn?S0?Ogm`3gmoL02P3gmoL20?ooo`030?_kn`3gmoL0
moOg01X0moOg1@3_knl30=KFeP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[
0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0oooo0P24Q8@0102]
[Jd0e]KF0=KFeP3Shn<20>o_k`80oooo503gmoL00`3clo<0kno_0>o_k`0?0?Ogm`<0oooo00<0]KFe
06][J`1[Jf/00P1kNg/20?Ogm`030?_kn`3oool0oooo00d0moOg0P3oool00`3kno/0moOg0?Ogm`0:
0?Ogm`<0oooo203gmoL20?ooo`D0moOg0P3_knl0103clo<0moOg0?Ogm`3clo<20>o_k`80moOg00<0
inOW0=KFeP3Fe]H00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0jn_[0?Ogm`3gmoL0503g
moL:0000000303Hf=P1[Jf/0Jf][0080Ng]k00<0^KVi0?Ogm`3gmoL00`3oool70?Ogm`80oooo00<0
no_k0?Ogm`3gmoL06P3gmoL20?ooo`<0kno_0`3Fe]H207]kN`L0oooo00<0g]kN0;fm_@2m_Kd00`3F
e]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@05
0?ooo`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?oooa@0moOg00<0lo?c0>o_k`3_knl03`3g
moL30?ooo`030;Fe]@1[Jf/0Jf][0080Ng]k0P3gmoL00`3kno/0oooo0?ooo`0=0?Ogm`80oooo00<0
no_k0?Ogm`3gmoL02P3gmoL30?ooo`P0moOg0P3oool50?Ogm`80kno_00@0lo?c0?Ogm`3gmoL0lo?c
0P3_knl20?Ogm`030>OWi`3Fe]H0e]KF0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>_[
j`3gmoL0moOg01@0moOg2P0000000`0f=SH0Jf][06][J`0207]kN`030;Vi^@3gmoL0moOg00<0oooo
1`3gmoL20?ooo`030?_kn`3gmoL0moOg01X0moOg0P3oool30>o_k`<0e]KF0P1kNg/70?ooo`030=kN
gP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0
a/K60;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sh`T0kno_0P3gmoL0103clo<0kno_
0>o_k`3clo<20?Ogm`X0kno_1@3gmoL00`3clo<0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_0080
moOg0`3_knl00`3Bd]80]KFe0;Fe]@0203Ti>@80moOg00<0lo?c0>o_k`3_knl01@3gmoL00`3clo<0
kno_0>o_k`020?Ogm`030??cl`3_knl0kno_00D0moOg0`3_knl20?Ogm`030??cl`3_knl0kno_0080
moOg203_knl30?Ogm`80kno_0P3gmoL00`3clo<0kno_0>o_k`0:0>o_k`030>OWi`3Ng]h0g]kN0080
Q8B400<0_[jn0?Ogm`3gmoL00`1kNg/20=KFeP030=[JfP3Ng]h0g]kN00D0kno_0P3gmoL30>o_k`80
moOg00<0lo?c0>o_k`3_knl01@3_knl20000000307alO03gmoL0moOg00<0moOg0P0000000`1OGel0
_Kfm0;fm_@0203Ti>@0309RHV03gmoL0moOg00D0kno_1@3gmoL20>o_k`030??cl`3gmoL0moOg00D0
kno_00<0lo?c0?Ogm`3gmoL01`3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_00<0lo?c0?Og
m`3gmoL01@3_knl30=KFeP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg0P24Q8@0102][Jd0
e]KF0=KFeP3Shn<90>o_k`80moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL:0>o_k`D0moOg00<0lo?c
0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`020?Ogm`<0kno_00<0d];B0;Fe]@2e]KD00P0i>CT2
0?Ogm`030??cl`3_knl0kno_00D0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`05
0?Ogm`<0kno_0P3gmoL00`3clo<0kno_0>o_k`020?Ogm`P0kno_0`3gmoL20>o_k`80moOg00<0lo?c
0>o_k`3_knl02P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Fe]H0
0`3Jf]X0g]kN0=kNgP050>o_k`80moOg0`3_knl20?Ogm`030??cl`3_knl0kno_00D0kno_0P000000
0`1lO7`0moOg0?Ogm`030?Ogm`80000000<0GemO0;fm_@2m_Kd00P0i>CT00`2HV9P0moOg0?Ogm`05
0>o_k`D0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg00L0moOg00@0lo?c
0>o_k`3_knl0lo?c0P3gmoL20>o_k`030??cl`3gmoL0moOg00D0kno_0`3Fe]H208B4Q0L0moOg00<0
gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h0
0`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S2@3_knl20?Ogm`040??cl`3_
knl0kno_0??cl`80moOg2P3_knl50?Ogm`030??cl`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl0
0P3gmoL30>o_k`030=;BdP2e]KD0]KFe0080>CTi0P3gmoL00`3clo<0kno_0>o_k`050?Ogm`030??c
l`3_knl0kno_0080moOg00<0lo?c0>o_k`3_knl01@3gmoL30>o_k`80moOg00<0lo?c0>o_k`3_knl0
0P3gmoL80>o_k`<0moOg0P3_knl20?Ogm`030??cl`3_knl0kno_00X0kno_00<0inOW0=kNgP3Ng]h0
0P24Q8@00`2n_[h0moOg0?Ogm`0307]kN`80e]KF00<0f][J0=kNgP3Ng]h01@3_knl20?Ogm`<0kno_
0P3gmoL00`3clo<0kno_0>o_k`050>o_k`80000000<0O7al0?Ogm`3gmoL00`3gmoL20000000305mO
G`2m_Kd0_Kfm0080>CTi00<0V9RH0?Ogm`3gmoL01@3_knl50?Ogm`80kno_00<0lo?c0?Ogm`3gmoL0
1@3_knl00`3clo<0moOg0?Ogm`070?Ogm`040??cl`3_knl0kno_0??cl`80moOg0P3_knl00`3clo<0
moOg0?Ogm`050>o_k`<0e]KF0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3_knl208B4Q0040:f]
[@3Fe]H0e]KF0=[JfP80g]kN3`3_knl50?Ogm`80kno_00<0lo?c0?Ogm`3gmoL01@3_knl00`3clo<0
moOg0?Ogm`0:0>o_k`030??cl`3gmoL0moOg008000001`3_knl00`3clo<0moOg0?Ogm`030?Ogm`80
kno_00<0lo?c0?Ogm`3gmoL01@3_knl30?OgmaH0kno_00<0lo?c0?Ogm`3gmoL00P3gmoL00`3clo<0
kno_0>o_k`030>o_k`80g]kN00<0f][J0=KFeP3Fe]H00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080
e]KF00<0f][J0=kNgP3Ng]h0303_knl00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_0080
000000<0N7Qh0>o_k`3_knl00`3_knl20000000307QhN03_knl0kno_0080000000<0N7Qh0>o_k`3_
knl00`3_knl20?Ogm`<0kno_0P3gmoL50>o_k`D0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0
kno_0>o_k`020>o_k`040??cl`3gmoL0moOg0??cl``0kno_0`3Fe]H208B4Q0L0kno_00<0e]KF0;fm
_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0
a/K60<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0f][J0P3Ng]h?0>o_k`D0moOg0P3_knl00`3c
lo<0moOg0?Ogm`050>o_k`030??cl`3gmoL0moOg00X0kno_00<0lo?c0?Ogm`3gmoL00P0000070>o_
k`030??cl`3gmoL0moOg00<0moOg0P3_knl00`3clo<0moOg0?Ogm`050>o_k`<0moOg5P3_knl00`3c
lo<0moOg0?Ogm`020?Ogm`030??cl`3_knl0kno_00<0kno_0P3Ng]h00`3Jf]X0e]KF0=KFeP0208B4
Q0030;Zj^P3_knl0kno_00<0Q8B40P3Fe]H00`3Jf]X0g]kN0=kNgP0<0>o_k`030??cl`3gmoL0moOg
0080moOg00<0lo?c0>o_k`3_knl00P0000000`1hN7P0kno_0>o_k`030>o_k`80000000<0N7Qh0>o_
k`3_knl00P0000000`1hN7P0kno_0>o_k`030>o_k`80moOg0`3_knl20?Ogm`D0kno_1@3gmoL00`3c
lo<0kno_0>o_k`020?Ogm`030??cl`3_knl0kno_0080kno_00@0lo?c0?Ogm`3gmoL0lo?c303_knl3
0=KFeP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool0
00Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`00`2a/K40e]KF0=KFeP030=KF
eP80g]kN0`3_knl20=kNgP80kno_00@0lo?c0?Ogm`3gmoL0jn_[0P3Ng]h20>o_k`030>OWi`3Ng]h0
g]kN00d0kno_0P3gmoL00`3clo<0kno_0>o_k`080>o_k`80<C4a700000000`1hN7P0kno_0>o_k`0=
0>o_k`80moOg0P3_knl00`3WinL0g]kN0=kNgP020>o_k`040>OWi`3Ng]h0g]kN0>OWi`80kno_0P3N
g]h00`3Jf]X0e]KF0=KFeP0207]kN`030;fm_@3oool0oooo00<0Q8B41@3Fe]H20=kNgP<0kno_0P3N
g]h30?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0g]kN0=kNgP0:0000000307alO03g
moL0moOg0080>CTi00<07AdM0000000000006@0000000`1_Kfl0g]kN0=kNgP020>o_k`040>OWi`3N
g]h0g]kN0>_[j`80moOg1`3_knl30=kNgP<0e]KF0P1kNg/70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3g
moL208b<S0030;6a/@3Fe]H0e]KF00<0e]KF0P3Ng]h30>o_k`80g]kN0P3_knl0103clo<0moOg0?Og
m`3[jn/20=kNgP80kno_00<0inOW0=kNgP3Ng]h03@3_knl20?Ogm`030??cl`3_knl0kno_00P0kno_
0P0a<C4L0000000307QhN03_knl0kno_00d0kno_0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080kno_
00@0inOW0=kNgP3Ng]h0inOW0P3_knl20=kNgP030=[JfP3Fe]H0e]KF0080Ng]k00<0_Kfm0?ooo`3o
ool00`24Q8@50=KFeP80g]kN0`3_knl20=kNgP<0moOg0P3_knl00`3WinL0g]kN0=kNgP020>o_k`03
0>OWi`3Ng]h0g]kN00X0000000<0O7al0?Ogm`3gmoL00P0i>CT00`0M7Ad000000000000I00000003
06m_K`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0jn_[0P3gmoL70>o_k`<0g]kN0`3Fe]H207]k
N`L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Bd]800`38b<P0_Kfm0;fm_@050?_kn`80R8R800@0[Jf]0=;BdP3Bd]80e]KF0P3Jf]X20=kN
gP<0inOW0P3Ng]h20>o_k`040>g]k@3[jn/0jn_[0>GUi@80g]kN0P3_knl00`3WinL0g]kN0=kNgP05
0>OWi`<0lo?c0P3WinL00`3[jn/0kno_0>o_k`020>_[j`030>WYj@3WinL0inOW0080inOW0`3_knl0
0`3[jn/0inOW0>OWi`0208R8R080Kfmh00<0Kfmd06m_K`1_Kfl01@1_Kfl00`1dM7@0N7Qh07QhN005
06m_K`80O7al00<0MWIf06m_K`1_Kfl01@1_Kfl00`2_[jl0kno_0>o_k`020>OWi`<0kno_203WinL2
0??cl`80inOW00<0hn?S0=kNgP3Ng]h00P3Winl0103ShnL0g]kN0=kNgP3Shn<20>OWi`80g]kN00<0
f=SH0=;BdP3Bd]800P20P8000`30`<00oooo0?ooo`0308B4Q080d];B00<0e]KF0=[JfP3Jf]X00P3N
g]h30>OWi`80g]kN0`3clo<20>OWi`030>?Sh`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@1_
Kfl00`1dM7@0N7Qh07QhN00206m_K`030;6a/@3clo<0lo?c0080S8b<00<0OWin06m_K`1_Kfl00`1_
Kfl207alO0D0Kfm_0P1_KgP00`1_Kg@0Kfm_06m_K`0506m_K`0307AdM01hN7P0N7Qh0080Kfm_00<0
YjNW0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3UiND20>_[j`80inOW00<0jn_[0>o_k`3_knl0
0P3WinL30=kNgP<0d];B0P20P8070?_kn`030=oOg`32`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>
c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h30?Ogm`80g]kN00<0inOW0>o_k`3_knl01`3Ng]h30>o_k`030>OWi`3Ng]h0g]kN0080g]kN
0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0P3gmoL00`3[jn/0g]kN
0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3_knl80=kNgP80kno_1@3Ng]h20=kNk`030=kN
i`3Ng]h0g]kN00D0g]kN00<0e]KF0<k>cP3>c/h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080c/k>
00<0e]KF0=kNgP3Ng]h01`3Ng]h30>o_k`D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OW
i`3_knl0kno_0080g]kN00<0inOW0>o_k`3_knl0203Ng]h20?Ogm`D0g]kN0P3Ng^l00`3Ng^L0g]kN
0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OW
i`3_knl0kno_00D0g]kN0`3>c/h208B4Q0L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0
ZJVY0<k>cP3>c/h0e]KF2@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0g]kN0P3_knl00`3WinL0g]kN
0=kNgP050=kNgP<0moOg0P3Ng]h00`3WinL0kno_0>o_k`070=kNgP<0kno_00<0inOW0=kNgP3Ng]h0
0P3Ng]h20=kNk`030=kNi`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20?Ogm`030>_[
j`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl00P3Ng]h30>o_k`P0g]kN0P3_knl50=kNgP80g]k_
00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3Fe]H0c/k>0<k>cP0208B4Q0030<;2`P3oool0oooo00<0Q8B4
0P3>c/h00`3Fe]H0g]kN0=kNgP070=kNgP<0kno_1@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN
00<0inOW0>o_k`3_knl00P3Ng]h00`3WinL0kno_0>o_k`080=kNgP80moOg1@3Ng]h20=kNk`030=kN
i`3Ng]h0g]kN00D0g]kN00<0inOW0>o_k`3_knl01@3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN
00<0inOW0>o_k`3_knl01@3Ng]h30<k>cP80Q8B41`3oool00`3Shn<0a/K60<K6aP030<k>cP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24
Q8@0102YZJT0c/k>0<k>cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20>o_k`030>OW
i`3Ng]h0g]kN00D0g]kN0`3gmoL20=kNgP030>OWi`3_knl0kno_00L0g]kN0`3_knl00`3WinL0g]kN
0=kNgP020=kNgP80g]k_00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP80moOg
00<0jn_[0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`020=kNgP<0kno_203Ng]h20>o_k`D0g]kN
0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP030=KFeP3>c/h0c/k>0080Q8B400<0`/;20?ooo`3oool0
0`24Q8@20<k>cP030=KFeP3Ng]h0g]kN00L0g]kN0`3_knl50=kNgP80kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h00`3WinL0kno_0>o_k`020=kNgP030>OWi`3_knl0kno_00P0g]kN0P3gmoL50=kNgP80g]k_
00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h00`3WinL0kno_0>o_k`050=kNgP<0c/k>0P24Q8@70?ooo`030>?Sh`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3g
moL208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF
00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgP80e]KF00<0f][J0=kNgP3Ng]h0
2P3Ng]h20=kNeP030=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN
0=kNgP030=KFePX0g]kN0P3Fe]H=0=kNgP80g]kF00@0f][F0=KFeP3Fe]H0f][J0P3Ng]h20=KFeP03
0=;BdP3>c/h0c/k>0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20<k>cP030=KFeP3Ng]h0g]kN0080
e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF00<0f][J0=kNgP3N
g]h0203Ng]h20=KFeP030=[JfP3Ng]h0g]kN00X0g]kN0P3Ng]H00`3Jf]H0e]KF0=KFeP0:0=kNgP03
0=[JfP3Fe]H0e]KF0080e]KF00@0f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0e]KF0`3>c/h208B4
Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KF
ePX0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN
00P0g]kN0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3J
f]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00<0e]KF2P3Ng]h20=KFePd0g]kN0P3Ng]H0103J
f]H0e]KF0=KFeP3Jf]X20=kNgP80e]KF00<0d];B0<k>cP3>c/h00P24Q8@00`2n_[h0moOg0?Ogm`03
08B4Q080c/k>00<0e]KF0=kNgP3Ng]h00P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J
0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgP80e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h2
0=kNeP030=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3J
f]X20=KFePL0g]kN0`3Fe]H30<k>cP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0kno_0P1kNg/0
102][Jd0g]kN0=kNgP3[jn/A0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3g
moL0moOg0080oooo00<0no_k0?Ogm`3gmoL04@3gmoL0103kno/0oooo0?ooo`3kno/D0?Ogm`80oooo
0`3gmoL20?ooo`X0moOg00<0no_k0?ooo`3oool0203gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B4
00<0^[Zj0>o_k`3_knl00`1kNg/20=kNgP030>_[j`3gmoL0moOg00`0moOg00<0no_k0?ooo`3oool0
3@3gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL03`3gmoL30?oooaL0moOg
0P3oool30>o_k`<0g]kN0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[
j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Ng]k00@0
[Jf]0=kNgP3Ng]h0jn_[4@3gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg0P3oool00`3kno/0moOg
0?Ogm`020?ooo`030?_kn`3gmoL0moOg0140moOg00@0no_k0?ooo`3oool0no_k503gmoL20?ooo`<0
moOg0P3oool:0?Ogm`030?_kn`3oool0oooo00P0moOg0P3_knl00`3WinL0g]kN0=kNgP0208B4Q003
0;Zj^P3_knl0kno_00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Ogm`0<0?Ogm`030?_kn`3oool0oooo00d0
moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00l0moOg0`3ooolG0?Ogm`80
oooo0`3_knl30=kNgP80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3Ng]h00`3[jn/0
moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0c<c<0<K6aP36a/H01@3clo<20820P0040;Bd
]03WinL0inOW0?7alA40no_k0P3oool00`3moOd0no_k0?_kn`080?_kn`80oooo00<0oOgm0?_kn`3k
no/00P3oool00`3moOd0no_k0?_kn`0A0?_kn`040?gmo@3oool0oooo0?gmoA@0no_k0P3oool30?_k
n`80oooo2P3kno/00`3moOd0oooo0?ooo`080?_kn`80moOg00<0lo?c0>o_k`3_knl00P24Q8@00`2l
_;`0lo?c0??cl`030820P080inOW00<0lO7a0?_kn`3kno/0303kno/00`3moOd0oooo0?ooo`0=0?_k
n`80oooo00<0oOgm0?_kn`3kno/00P3oool00`3moOd0no_k0?_kn`0?0?_kn`<0oooo5`3kno/20?oo
o`<0moOg0`3_knl208R8R0D0lo?c0P3gmoL00`3MgMd0`/;20<;2`P030<k>cP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P24Q8@0102j^[X0
kno_0>o_k`3gmoMb0?ooo`80Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20>o_k`030?Ogm`3oool0oooo
05L0oooo0P2<S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H01@3gmoL208B4Q0040;Zj^P3_knl0kno_0?Og
mg80oooo0P24Q8@00`2n_[h0moOg0?Ogm`0308B4Q080kno_00<0moOg0?ooo`3oool0E`3oool208b<
S0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80Q8B400@0R8R808b<S02<S8`0Q8B40P1kNg/508B4
Q080Ng]k3`24Q8@00`28R8P0S8b<08b<S00307]kN`D0Q8B40P1kNg/00`24Q8@0S8b<08b<S00808B4
Q080Ng]k1`24Q8@01020P800Ng]k07]kN`20P80408B4Q00308R8R02<S8`0S8b<00X0Q8B400<0P820
07]kN`1kNg/01@24Q8@207]kN`X0Q8B400<0P82007]kN`1kNg/01@24Q8@00`28R8P0S8b<08b<S007
08B4Q0030<;2`P3oool0oooo00<0S8b<0P24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k3@24Q8@2
08b<S00408R8R024Q8@0Q8B40820P080Ng]k1@24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1k
Ng/808B4Q080Ng]k00<0P82008B4Q024Q8@00P2<S8`00`28R8P0Q8B408B4Q00808B4Q080S8b<00<0
Q8B407]kN`1kNg/02P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Og
m`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q00408R8R02<S8`0
S8b<08B4Q080Ng]k1@24Q8@207]kN`l0Q8B400<0R8R808b<S02<S8`00`1kNg/508B4Q080Ng]k00<0
Q8B408b<S02<S8`02024Q8@207]kN`L0Q8B400@0P82007]kN`1kNg/0P8201024Q8@00`28R8P0S8b<
08b<S00:08B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/:08B4Q0030820P01kNg/0Ng]k00D0Q8B4
00<0R8R808b<S02<S8`01`24Q8@00`32`/80oooo0?ooo`0308b<S080Q8B400<0P82007]kN`1kNg/0
1@24Q8@207]kN`d0Q8B40P2<S8`01028R8P0Q8B408B4Q020P80207]kN`D0Q8B40P1kNg/00`20P800
Q8B408B4Q00808B4Q080Ng]k2024Q8@207]kN`030820P024Q8@0Q8B40080S8b<00<0R8R808B4Q024
Q8@02024Q8@208b<S00308B4Q01kNg/0Ng]k00X0Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0_Kfm00D0no_k
0P2n_[h01030`<00`/;20<;2`P2n_[h20;Vi^@D0_[jn0P2i^KT?0;jn_P030<30`032`/80`/;200<0
^KVi1@2n_[h20;Vi^@030;jn_P32`/80`/;200P0_[jn0P2i^KT70;jn_P040;bl_02i^KT0^KVi0;bl
_0@0_[jn00<0`<300<;2`P32`/802P2n_[h00`2l_;`0^KVi0;Vi^@050;jn_P80^KVi2P2n_[h00`2l
_;`0^KVi0;Vi^@050;jn_P030<30`032`/80`/;200L0_[jn00<0gMgM0?_kn`3kno/00`32`/820;jn
_P030;bl_02i^KT0^KVi00D0_[jn0P2i^KT=0;jn_P80`/;200@0`<300;jn_P2n_[h0_;bl0P2i^KT5
0;jn_P80^KVi00<0_;bl0;jn_P2n_[h0202n_[h20;Vi^@P0_[jn0P2i^KT00`2l_;`0_[jn0;jn_P02
0<;2`P030<30`02n_[h0_[jn00P0_[jn0P32`/800`2n_[h0^KVi0;Vi^@0:0;jn_PL0no_k00<0g=cL
0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36
a/H0_Kfm0;fm_@3Z0?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd0jP3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg
00<0lo?c0>o_k`3_knl00P1kNg/00`20P800Q8B408B4Q00308B4Q080Ng]k1@24Q8@207]kN`040820
P024Q8@0Q8B408R8R080S8b<1@24Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/00`20P800
Q8B408B4Q00708B4Q0<0Ng]k00<0P82008B4Q024Q8@00P24Q8@507]kN`80S8b<00@0R8R808B4Q024
Q8@0P8200P1kNg/:08B4Q0<0Ng]k1@24Q8@207]kN`/0Q8B40P1kNg/208b<S00308R8R024Q8@0Q8B4
00D0Ng]k00<0P82008B4Q024Q8@00P1kNg/00`20P800Q8B408B4Q00208B4Q0030;Zj^P3_knl0kno_
00<0Ng]k1@24Q8@207]kN`D0Q8B40`1kNg/208b<S00308R8R024Q8@0Q8B400D0Q8B40P1kNg/00`20
P800Q8B408B4Q00308B4Q080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`D0Q8B41@1kNg/508B4
Q0030820P01kNg/0Ng]k00X0Q8B400<0P82007]kN`1kNg/01@24Q8@507]kN`D0Q8B40P3_knl00`3c
lo<0moOg0?Ogm`020>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08oooo
o`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0207]kN`03
0820P024Q8@0Q8B400<0Q8B40P1kNg/508B4Q080Ng]k00@0P82008B4Q024Q8@0R8R80P2<S8`508B4
Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400L0Q8B40`1kNg/00`20
P800Q8B408B4Q00208B4Q0D0Ng]k0P2<S8`01028R8P0Q8B408B4Q020P80207]kN`X0Q8B40`1kNg/5
08B4Q080Ng]k2`24Q8@207]kN`80S8b<00<0R8R808B4Q024Q8@01@1kNg/00`20P800Q8B408B4Q002
07]kN`030820P024Q8@0Q8B40080Q8B400<0^[Zj0>o_k`3_knl00`1kNg/508B4Q080Ng]k1@24Q8@3
07]kN`80S8b<00<0R8R808B4Q024Q8@01@24Q8@207]kN`030820P024Q8@0Q8B400<0Q8B40P1kNg/0
0`20P800Q8B408B4Q00808B4Q080Ng]k1@24Q8@507]kN`D0Q8B400<0P82007]kN`1kNg/02P24Q8@0
0`20P800Ng]k07]kN`0508B4Q0D0Ng]k1@24Q8@20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF
0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:
b/X0_Kfm0;fm_@020?Ogm`030??cl`3_knl0kno_0080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]k
N`D0Q8B40P1kNg/01020P800Q8B408B4Q028R8P208b<S0D0Q8B40P1kNg/00`20P800Q8B408B4Q003
08B4Q080Ng]k00<0P82008B4Q024Q8@01`24Q8@307]kN`030820P024Q8@0Q8B40080Q8B41@1kNg/2
08b<S00408R8R024Q8@0Q8B40820P080Ng]k2P24Q8@307]kN`D0Q8B40P1kNg/;08B4Q080Ng]k0P2<
S8`00`28R8P0Q8B408B4Q00507]kN`030820P024Q8@0Q8B40080Ng]k00<0P82008B4Q024Q8@00P24
Q8@00`2j^[X0kno_0>o_k`0307]kN`D0Q8B40P1kNg/508B4Q0<0Ng]k0P2<S8`00`28R8P0Q8B408B4
Q00508B4Q080Ng]k00<0P82008B4Q024Q8@00`24Q8@207]kN`030820P024Q8@0Q8B400P0Q8B40P1k
Ng/508B4Q0D0Ng]k1@24Q8@00`20P800Ng]k07]kN`0:08B4Q0030820P01kNg/0Ng]k00D0Q8B41@1k
Ng/508B4Q080kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_00<0
lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0
102a/K40g]kN0=kNgP3_knl20?ooo`D0moOg103oool00`3kno/0moOg0?Ogm`050?Ogm`030?_kn`3o
ool0oooo00D0moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool60?Ogm`80oooo1`3g
moL00`3kno/0oooo0?ooo`030?ooo`L0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?oo
o`020?ooo`<0moOg0P3oool30?Ogm`<0oooo103gmoL00`3kno/0oooo0?ooo`0:0?Ogm`030>_[j`3N
g]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>_[j`3gmoL0moOg00D0moOg1@3o
ool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool01@3gmoL80?ooo`D0moOg0P3o
ool80?Ogm`D0oooo1`3gmoL0103kno/0oooo0?ooo`3kno/40?Ogm`030?_kn`3oool0oooo00D0moOg
0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Q8B400@0/K6a0=kNgP3Ng]h0kno_
0P3oool50?Ogm`@0oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3kno/0oooo0?ooo`050?Ogm`<0oooo
1@3gmoL20?ooo`030?_kn`3gmoL0moOg0080oooo1P3gmoL20?ooo`L0moOg00<0no_k0?ooo`3oool0
0`3oool70?Ogm`030?_kn`3oool0oooo00D0moOg00<0no_k0?ooo`3oool00P3oool30?Ogm`80oooo
0`3gmoL30?ooo`@0moOg00<0no_k0?ooo`3oool02P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;jn
_P3gmoL0moOg00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`050?Ogm`D0oooo1`3gmoL00`3kno/0oooo
0?ooo`050?Ogm`030?_kn`3oool0oooo00D0moOg203oool50?Ogm`80oooo203gmoL50?ooo`L0moOg
00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo0?ooo`050?Ogm`<0g]kN0P24Q8@70?Ogm`03
0=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80c/k>
00<0b<S80<;2`P32`/801@3kno/208B4Q0040;6a/@3Ng]h0g]kN0>o_k`80oooo1@3kno/40?ooo`03
0?gmo@3kno/0no_k00D0no_k00<0oOgm0?ooo`3oool01@3kno/30?ooo`D0no_k0P3oool00`3moOd0
no_k0?_kn`020?ooo`H0no_k0P3oool70?_kn`030?gmo@3oool0oooo00<0oooo1`3kno/00`3moOd0
oooo0?ooo`050?_kn`030?gmo@3oool0oooo0080oooo0`3kno/20?ooo`<0no_k0`3oool40?_kn`03
0?gmo@3oool0oooo00P0no_k0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030<30`03kno/0no_k00<0
Q8B40P3Ng]h00`3]kNd0no_k0?_kn`050?_kn`D0oooo1`3kno/00`3moOd0oooo0?ooo`050?_kn`03
0?gmo@3oool0oooo00D0no_k203oool50?_kn`80oooo203kno/50?ooo`L0no_k00@0oOgm0?ooo`3o
ool0oOgm103kno/00`3moOd0oooo0?ooo`020?_kn`<0moOg0`3Ng]h208B4Q0L0no_k00<0gmoO0<;2
`P32`/800`3Bd]820=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>c/h00`36a/H0
_Kfm0;fm_@050?ooo`80Q8B400@0/K6a0=kNgP3Ng]h0kno_K@3oool20?Ogm`030>_[j`3Ng]h0g]kN
0080Q8B400<0`/;20?ooo`3oool00`24Q8@20=kNgP030>o_k`3oool0oooo0540oooo0`3gmoL30=kN
gP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102a/K40g]kN0=kNgP3_knm]0?oo
o`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN00<0kno_0?oo
o`3oool0D@3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3gmoL208B4Q004
0;6a/@3Ng]h0g]kN0>o_kfl0oooo00<0moOg0>o_k`3_knl00P24Q8@00`2n_[h0moOg0?Ogm`0308B4
Q080g]kN00<0kno_0?ooo`3oool0E03oool30>o_k`80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KF
eP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0
moOg0P24Q8@0102a/K40g]kN0=kNgP3_knm_0?ooo`030?Ogm`3_knl0kno_0080Q8B400<0_[jn0?Og
m`3gmoL00`24Q8@20=kNgP030>o_k`3oool0oooo05@0oooo0`3_knl208B4Q0L0moOg00<0f][J0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0
`/;20<;2`P050??cl`80Q8B400@0/K6a0=kNgP3Ng]h0kNg]0P3kno][0?ooo`80no_k00<0lO7a0>OW
i`3WinL00P24Q8@00`2l_;`0lo?c0??cl`0308B4Q080g]kN00<0kNg]0?_kn`3kno/08`3oool00`30
`<00P8200820P0080820P2H0oooo0`3_knl208B4Q0D0lo?c0P3gmoL00`3Jf]X0_Kfm0;fm_@030=;B
dP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0
kno_0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmf/0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4
Q0030;Zj^P3_knl0kno_00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`0S0?ooo`030820P00000000000
00P000009P3oool30>o_k`80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_knl00`3c
lo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3_knl208B4Q004
0;6a/@3Ng]h0g]kN0>_[j`80moOgJ`3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_
k`3_knl00`24Q8@20=kNgP030>_[j`3gmoL0moOg02<0oooo00<0P8200000000000002000000V0?oo
o`<0kno_0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg
00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@020?ooo`030?_kn`3gmoL0moOg0080
Q8B400@0/K6a0=kNgP3Ng]h0jn_[103gmoMY0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`2n
_[h0moOg0?Ogm`0308B4Q080g]kN00<0inOW0>o_k`3_knl08`3oool00`20P8000000000000050?oo
o`<000008@3oool50?Ogm`<0g]kN0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool00`3kno/0
moOg0?Ogm`0208B4Q0040;6a/@3Ng]h0g]kN0>_[j`@0moOgJ@3oool20?Ogm`030>_[j`3Ng]h0g]kN
0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0kno_02<0oooo00<0P8200000
000000001@3oool300000240oooo1@3gmoL30=kNgP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>
cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm00D0
oooo0P24Q8@0102a/K40g]kN0=kNgP3[jn/20?Ogmf/0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4
Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3_knl0oooo0?ooo`0S0?ooo`030820P00000000000
00D0oooo0`00000S0?ooo`<0moOg0`3Ng]h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3Fe]H00`3:b/X0_Kfm0;fm_@050?ooo`80
Q8B400@0/K6a0=kNgP3Ng]h0jn_[0P3gmoM[0?ooo`80moOg00<0jn_[0=kNgP3Ng]h00P24Q8@00`32
`/80oooo0?ooo`0308B4Q080g]kN00<0kno_0?ooo`3oool08`3oool00`20P8000000000000050?oo
o`<000008`3oool30?Ogm`<0g]kN0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[
jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q004
0;6a/@3Ng]h0g]kN0>_[j`80moOgJ`3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`/;20?oo
o`3oool00`24Q8@20=kNgP030>o_k`3oool0oooo02<0oooo00<0P8200000000000001@3oool30000
02<0oooo0`3gmoL30=kNgP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0_Kfm00D0no_k0P24Q8@0102a/K40
g]kN0=kNgP3[jn/20?Ogm`D0no_k103oool0103moOd0no_k0?_kn`3moOd40?ooo`030?gmo@3kno/0
no_k00l0oooo00<0oOgm0?_kn`3kno/0303oool00`3moOd0no_k0?_kn`050?ooo`030?gmo@3kno/0
no_k00l0oooo00<0oOgm0?_kn`3kno/00P3oool30?_kn`P0oooo0P3kno/50?ooo`80no_k00<0oOgm
0?ooo`3oool00`3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0`<300?_kn`3kno/00`20P802
0=kNgP030>g]k@3kno/0no_k0080no_k1@3oool30?_kn`D0oooo0P3kno/00`3moOd0oooo0?ooo`0=
0?ooo`80no_k00<0OWin0000000000001@20P80300000080oooo0P3kno/00`3moOd0oooo0?ooo`03
0?ooo`80no_k00<0oOgm0?ooo`3oool01`3oool0103moOd0no_k0?_kn`3moOd20?ooo`80no_k00<0
oOgm0?ooo`3oool00P3kno/30??cl`<0g]kN0P24Q8@70?_kn`030=oOg`32`/80`/;200<0d];B0P3N
g]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL2
08B4Q0040;6a/@3Ng]h0g]kN0>_[j`L0moOg103oool0103kno/0moOg0?Ogm`3kno/40?ooo`030?_k
n`3gmoL0moOg00l0oooo00<0no_k0?Ogm`3gmoL0303oool00`3kno/0moOg0?Ogm`050?ooo`030?_k
n`3gmoL0moOg00l0oooo00<0no_k0?Ogm`3gmoL00P3oool30?Ogm`P0oooo0P3gmoL50?ooo`80moOg
00<0no_k0?ooo`3oool00`3oool20?Ogm`030>_[j`3Ng]h0g]kN0080Q8B400<0_[jn0?Ogm`3gmoL0
0`1kNg/20=kNgP030>_[j`3gmoL0moOg0080moOg1@3oool30?Ogm`D0oooo0P3gmoL00`3kno/0oooo
0?ooo`0=0?ooo`80moOg00<0O7al000000000000200000020?ooo`80moOg00<0no_k0?ooo`3oool0
0`3oool20?Ogm`030?_kn`3oool0oooo00L0oooo00@0no_k0?Ogm`3gmoL0no_k0P3oool20?Ogm`03
0?_kn`3oool0oooo0080moOg0`3_knl30=kNgP80Q8B41`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0moOg
0P24Q8@0102a/K40g]kN0=kNgP3[jn/70?Ogm`@0oooo00@0no_k0?Ogm`3gmoL0no_k103oool00`3k
no/0moOg0?Ogm`0?0?ooo`030?_kn`3gmoL0moOg00`0oooo00<0no_k0?Ogm`3gmoL01@3oool00`3k
no/0moOg0?Ogm`0?0?ooo`030?_kn`3gmoL0moOg0080oooo0`3gmoL80?ooo`80moOg1@3oool20?Og
m`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3[jn/0g]kN0=kNgP0208B4Q0030;jn_P3gmoL0moOg
00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Ogm`020?Ogm`D0oooo0`3gmoL50?ooo`80moOg00<0no_k0?oo
o`3oool03@3oool20?Ogm`0307alO0000000000000P000000P3oool20?Ogm`030?_kn`3oool0oooo
00<0oooo0P3gmoL00`3kno/0oooo0?ooo`070?ooo`040?_kn`3gmoL0moOg0?_kn`80oooo0P3gmoL0
0`3kno/0oooo0?ooo`020?Ogm`<0kno_0`3Ng]h208B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>c/h2
0=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050>o_
k`80Q8B400@0/K6a0=kNgP3Ng]h0inOW0P3_knl20?OgmaL0oooo0`3gmoL:0?ooo`80moOg5@3oool2
0?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool0203oool20?Ogma@0oooo00@0no_k
0?Ogm`3gmoL0no_k0P3oool20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0^[Zj0>o_k`3_knl00`24
Q8@20=kNgP030>_[j`3gmoL0moOg0080oooo0`3gmoLA0?ooo`040?_kn`3gmoL0moOg0?_kn`T0oooo
00<0no_k0?Ogm`3gmoL0503oool00`3kno/0moOg0?Ogm`020?ooo`030?_kn`3gmoL0moOg00X0oooo
00<0no_k0?Ogm`3gmoL01@3gmoL30=kNgP80Q8B41`3_knl00`3Fe]H0_Kfm0;fm_@030<k>cP80kno_
00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0kno_0P24
Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg5`3oool30?Ogm`X0oooo0P3gmoLE0?ooo`80moOg
00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`080?ooo`80moOg503oool0103kno/0moOg
0?Ogm`3kno/20?ooo`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080
g]kN00<0jn_[0?Ogm`3gmoL00P3oool30?Ogma40oooo00@0no_k0?Ogm`3gmoL0no_k2@3oool00`3k
no/0moOg0?Ogm`0D0?ooo`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL02P3oool00`3k
no/0moOg0?Ogm`050?Ogm`<0g]kN0P24Q8@70>o_k`030=KFeP2m_Kd0_Kfm00<0c/k>0P3_knl00`3c
lo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:0;fm_@2m_Kd01@3gmoL208b<S004
0;Fe]@3Ng]h0g]kN0>_[j`80moOg0P3oool30?Ogm`80oooo0P3gmoL0103kno/0oooo0?ooo`3kno/4
0?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0
oooo0080oooo00<0no_k0?Ogm`3gmoL03`0000050?Ogm`030?_kn`3oool0oooo00D0moOg0P3oool0
0`3kno/0moOg0?Ogm`050?ooo`030?_kn`3gmoL0moOg00D0oooo0P3gmoL30?ooo`<0moOg0P3oool5
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3gmoL00`3WinL0e]KF0=KFeP0208B4Q0030<;2`P3oool0
oooo00<0Q8B40P3Ng]h00`3[jn/0moOg0?Ogm`070?Ogm`<0oooo1@3gmoL20?ooo`030?_kn`3gmoL0
moOg00D0oooo00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0
oooo00<0oooo0P3gmoL30?ooo`80moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80oooo00<0no_k
0?Ogm`3gmoL01@3oool20?Ogm`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`02
0?ooo`<0kno_0`3Ng]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0
moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80S8b<00@0]KFe0=kN
gP3Ng]h0jn_[0P3gmoL20?ooo`<0moOg0P3oool20?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0
no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool00P3o
ool00`3kno/0moOg0?Ogm`0?000000D0moOg00<0no_k0?ooo`3oool01@3gmoL20?ooo`030?_kn`3g
moL0moOg00D0oooo00<0no_k0?Ogm`3gmoL01@3oool20?Ogm`<0oooo0`3gmoL20?ooo`D0moOg0P3o
ool00`3kno/0moOg0?Ogm`050?Ogm`030>OWi`3Fe]H0e]KF0080Q8B400<0`/;20?ooo`3oool00`24
Q8@20=kNgP030>_[j`3gmoL0moOg00L0moOg0`3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL01@3o
ool00`3kno/0moOg0?Ogm`020?Ogm`030?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00`3o
ool20?Ogm`<0oooo0P3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Og
m`050?ooo`80moOg00<0no_k0?ooo`3oool00`3oool20?Ogm`030?_kn`3oool0oooo0080oooo0`3_
knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?oo
ool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm00D0moOg0P2<S8`0102e]KD0g]kN0=kNgP3[
jn/20?Ogm`80oooo0`3gmoL20?ooo`80moOg00@0no_k0?ooo`3oool0no_k103gmoL00`3kno/0oooo
0?ooo`020?Ogm`030?_kn`3oool0oooo00<0oooo0P3gmoL00`3kno/0oooo0?ooo`020?ooo`030?_k
n`3gmoL0moOg00l000001@3gmoL00`3kno/0oooo0?ooo`050?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
1@3oool00`3kno/0moOg0?Ogm`050?ooo`80moOg0`3oool30?Ogm`80oooo1@3gmoL20?ooo`030?_k
n`3gmoL0moOg00D0moOg00<0inOW0=KFeP3Fe]H00P24Q8@00`32`/80oooo0?ooo`0308B4Q080g]kN
00<0jn_[0?Ogm`3gmoL01`3gmoL30?ooo`D0moOg0P3oool00`3kno/0moOg0?Ogm`050?ooo`030?_k
n`3gmoL0moOg0080moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg
0`3oool20?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg00D0oooo
0P3gmoL00`3kno/0oooo0?ooo`030?ooo`80moOg00<0no_k0?ooo`3oool00P3oool30>o_k`<0g]kN
0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3oool208B4Q0040;6a/@3Ng]h0g]kN0>OWi`80kno_
0P3gmoL50?ooo`D0moOg00<0no_k0?ooo`3oool01@3gmoL20?ooo`030?_kn`3gmoL0moOg00<0oooo
1@3gmoL50?ooo`l000000P3oool00`3kno/0moOg0?Ogm`080?Ogm`80oooo00<0no_k0?Ogm`3gmoL0
203oool50?Ogm`D0oooo1@3gmoL20?ooo`030?_kn`3gmoL0moOg00P0moOg0P3oool00`3_knl0g]kN
0=kNgP0208B4Q0030<;2`P3oool0oooo00<0Q8B40P3Ng]h00`3WinL0kno_0>o_k`050?ooo`D0moOg
0P3oool00`3kno/0moOg0?Ogm`020?Ogm`030?_kn`3oool0oooo0080moOg00@0no_k0?ooo`3oool0
no_k103gmoL00`3kno/0oooo0?ooo`080?Ogm`D0oooo103gmoL00`3kno/0oooo0?ooo`050?Ogm`03
0?_kn`3oool0oooo0080moOg00<0no_k0?ooo`3oool00P3gmoL00`3kno/0oooo0?ooo`050?ooo`03
0?_kn`3gmoL0moOg0080moOg0`3oool30=kNgP80Ng]k1`3oool00`3Shn<0a/K60<K6aP030<k>cP80
g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo
0P24Q8@0102a/K40g]kN0=kNgP3WinL20>o_k`80moOg1@3oool50?Ogm`030?_kn`3oool0oooo00D0
moOg0P3oool00`3kno/0moOg0?Ogm`030?ooo`D0moOg1@3oool?00000080oooo00<0no_k0?Ogm`3g
moL0203gmoL20?ooo`030?_kn`3gmoL0moOg00P0oooo1@3gmoL50?ooo`D0moOg0P3oool00`3kno/0
moOg0?Ogm`080?Ogm`80oooo00<0kno_0=kNgP3Ng]h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080
g]kN00<0inOW0>o_k`3_knl01@3oool50?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3gmoL00`3kno/0
oooo0?ooo`020?Ogm`040?_kn`3oool0oooo0?_kn`@0moOg00<0no_k0?ooo`3oool0203gmoL50?oo
o`@0moOg00<0no_k0?ooo`3oool01@3gmoL00`3kno/0oooo0?ooo`020?Ogm`030?_kn`3oool0oooo
0080moOg00<0no_k0?ooo`3oool01@3oool00`3kno/0moOg0?Ogm`020?Ogm`<0oooo0`3Ng]h207]k
N`L0oooo00<0hn?S0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0
g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl20?oo
o`L0moOg00@0no_k0?ooo`3oool0no_k2@3gmoL00`3kno/0oooo0?ooo`0=0?Ogm`l000002P3gmoL0
0`3kno/0oooo0?ooo`0?0?Ogm`<0oooo203gmoL20?ooo`X0moOg00<0no_k0?ooo`3oool00P3_knl0
0`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Ogm`07
0?Ogm`<0oooo2P3gmoL20?ooo`030?_kn`3gmoL0moOg00D0moOg00<0O7al0000000000004@000000
0`1lO7`0moOg0?Ogm`080?Ogm`80oooo00<0no_k0?Ogm`3gmoL03@3gmoL20?ooo`<0kno_0`3Ng]h2
08B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_knl2
0?ooo`L0moOg00@0no_k0?ooo`3oool0no_k2@3gmoL00`3kno/0oooo0?ooo`0=0?Ogm`l000002P3g
moL00`3kno/0oooo0?ooo`0?0?Ogm`<0oooo203gmoL20?ooo`X0moOg00<0no_k0?ooo`3oool00P3_
knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Ng]k0P3Ng]h00`3[jn/0moOg0?Og
m`070?Ogm`<0oooo2P3gmoL20?ooo`030?_kn`3gmoL0moOg00D0moOg00<0O7al0000000000004@00
00000`1lO7`0moOg0?Ogm`080?Ogm`80oooo00<0no_k0?Ogm`3gmoL03@3gmoL20?ooo`<0kno_0`3N
g]h208B4Q0L0moOg00<0f][J0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo0006
ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P050??cl`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S0P3_
knl20?_kn`L0moOg00@0nOWi0?_kn`3kno/0nOWi0P3gmoL20?_kn`030?Win@3gmoL0moOg0080moOg
00<0nOWi0?_kn`3kno/03@3gmoL?00000080moOg00<0nOWi0?_kn`3kno/00`3kno/20?Ogm`030?Wi
n@3kno/0no_k00l0moOg0`3kno/80?Ogm`80no_k0P3gmoL00`3inOT0no_k0?_kn`050?Ogm`030?Wi
n@3kno/0no_k0080kno_00<0iNGU0=[JfP3Jf]X00P24Q8@00`2l_;`0lo?c0??cl`030820P080f][J
00<0inOW0??cl`3clo<01`3gmoL30?_kn`80moOg00<0nOWi0?_kn`3kno/01@3gmoL20?_kn`030?Wi
n@3gmoL0moOg00D0moOg00<0^[Zj07alO01lO7`04@1lO7`00`2j^[X0moOg0?Ogm`030?_kn`D0moOg
0P3kno/00`3inOT0moOg0?Ogm`0=0?Ogm`80no_k0`3_knl30=[JfP80Q8B41@3clo<20?Ogm`030=[J
fP2m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0
b/[:0<K6aP36a/H01@3_knl208B4Q0040:f][@3Fe]H0e]KF0>?Sh`80kno_3`3gmoL20?ooo`030?_k
n`3gmoL0moOg0180moOg3`0000020?Ogm`030?_kn`3oool0oooo00<0oooo8`3gmoL00`3kno/0oooo
0?ooo`080?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@00`2j^[X0kno_0>o_k`0308B4Q080e]KF
00<0hn?S0>o_k`3_knl0303gmoL00`3kno/0oooo0?ooo`0V0?Ogm`<0oooo6@3gmoL30>o_k`<0e]KF
0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo
0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050>o_k`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S
0P3_knl?0?Ogm`80oooo00<0no_k0?Ogm`3gmoL04P3gmoL?00000080moOg00<0no_k0?ooo`3oool0
0`3ooolS0?Ogm`030?_kn`3oool0oooo00P0moOg0P3_knl00`3WinL0g]kN0=kNgP0208B4Q0030;Zj
^P3_knl0kno_00<0Q8B40P3Fe]H00`3Shn<0kno_0>o_k`0<0?Ogm`030?_kn`3oool0oooo02H0moOg
0`3ooolI0?Ogm`<0kno_0`3Fe]H208B4Q0D0kno_0P3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80g]kN
00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=;BdP030<c<c036a/H0a/K600D0lo?c0P20
P800102][Jd0f][J0=[JfP3UiND20>o_k`D0moOg0P3clo<20?_kn`040?Win@3gmoL0moOg0?Gem@80
lo?c0P3kno/00`3inOT0moOg0?Ogm`020??cl`030?Gem@3gmoL0moOg00d0moOg3`0000020??cl`03
0?Ogm`3kno/0no_k00<0no_k503gmoL30??cl`80moOg0`3clo<30?_kn`T0moOg00@0mOGe0??cl`3c
lo<0mOGe0P3gmoL20>o_k`030>GUi@3Jf]X0f][J0080Q8B400<0_;bl0??cl`3clo<00`24Q8@20=[J
fP030>GUi@3_knl0kno_0080moOg0`3clo<20?_kn`<0moOg0P3clo<00`3gmoL0no_k0?_kn`020?Og
m`030?Gem@3clo<0lo?c01L0moOg0`3clo<20?_kn`D0moOg0`3kno/<0?Ogm`040?Win@3kno/0no_k
0?Win@L0moOg0P3clo<30>o_k`<0e]KF0P28R8P50??cl`80moOg00<0gMgM0<;2`P32`/800`3>c/h2
0=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>c/h0a/K60<K6aP050?Og
m`80Ng]k00@0[Jf]0=kNgP3Ng]h0inOW0P3_knl50?Ogm`80kno_0P3oool0103kno/0moOg0?Ogm`3c
lo<20>o_k`D0moOg0P3_knl00`3clo<0moOg0?Ogm`0=0?Ogm`l000000P3_knl00`3clo<0moOg0?Og
m`0G0?Ogm`<0kno_0P3gmoL30>o_k`<0oooo103gmoL00`3clo<0kno_0>o_k`020?Ogm`040??cl`3_
knl0kno_0??cl`80moOg0P3_knl00`3Shn<0e]KF0=KFeP0208B4Q0030;jn_P3gmoL0moOg00<0Q8B4
0P3Ng]h00`3WinL0kno_0>o_k`020?Ogm`<0kno_0P3oool30?Ogm`80kno_00<0lo?c0?Ogm`3gmoL0
0P3gmoL00`3clo<0kno_0>o_k`0G0?Ogm`<0kno_0P3ooolD0?Ogm`040?_kn`3oool0oooo0?_kn`L0
moOg1@3_knl30=KFeP80S8b<1`3gmoL00`3Ogml0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3g
moL02?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K600D0moOg0P1kNg/0102][Jd0g]kN
0=kNgP3WinL20>o_k`D0moOg0P3_knl20?ooo`040?_kn`3gmoL0moOg0??cl`80kno_1@3gmoL20>o_
k`030??cl`3gmoL0moOg00d0moOg3`0000020>o_k`030??cl`3gmoL0moOg01L0moOg0`3_knl20?Og
m`<0kno_0`3oool40?Ogm`030??cl`3_knl0kno_0080moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL2
0>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=kNgP030>OWi`3_knl0
kno_0080moOg0`3_knl20?ooo`<0moOg0P3_knl00`3clo<0moOg0?Ogm`020?Ogm`030??cl`3_knl0
kno_01L0moOg0`3_knl20?oooa@0moOg00@0no_k0?ooo`3oool0no_k1`3gmoL50>o_k`<0e]KF0P2<
S8`70?Ogm`030=oOg`36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040:f][@3Fe]H0e]KF0=[JfP80g]kN1@3g
moL40>o_k`030??cl`3gmoL0moOg00P0moOg0P3_knl00`3clo<0moOg0?Ogm`0:0>o_k`030?Ogm`3o
ool0oooo00l000000P3gmoL00`1lO7`0000000000008000000X0kno_00<0moOg0?ooo`3oool00P3_
knl50?Ogm`H0kno_2@3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80kno_00<0inOW0=kNgP3Ng]h0
0P1kNg/00`2m_Kd0oooo0?ooo`0308b<S080e]KF00<0hn?S0>o_k`3_knl00P3gmoL50>o_k`X0moOg
00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80oooo00<0P820000000000000
200000020>o_k`D0moOg0`3_knl70?Ogm`030??cl`3_knl0kno_00P0kno_0P3oool00`3gmoL0kno_
0>o_k`050>o_k`<0e]KF0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg
0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01@3oool208B4Q0040:f][@3F
e]H0e]KF0=[JfP80g]kN1@3gmoL40>o_k`030??cl`3gmoL0moOg00P0moOg0P3_knl00`3clo<0moOg
0?Ogm`0:0>o_k`030?Ogm`3oool0oooo00l000000P3gmoL00`1lO7`0000000000008000000X0kno_
00<0moOg0?ooo`3oool00P3_knl50?Ogm`H0kno_2@3gmoL0103clo<0kno_0>o_k`3clo<20?Ogm`80
kno_00<0inOW0=kNgP3Ng]h00P1kNg/00`2m_Kd0oooo0?ooo`0308b<S080e]KF00<0hn?S0>o_k`3_
knl00P3gmoL50>o_k`X0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3clo<0kno_0>o_k`080>o_k`80
oooo00<0P820000000000000200000020>o_k`D0moOg0`3_knl70?Ogm`030??cl`3_knl0kno_00P0
kno_0P3oool00`3gmoL0kno_0>o_k`050>o_k`<0e]KF0P24Q8@70?ooo`030=kNgP2m_Kd0_Kfm00<0
e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>OWi`80d];B00<0b<S80;fm_@2m_Kd0
1@3kno/208B4Q0040:f][@3Fe]H0e]KF0=oOg`80inOW1@3clo<40>o_k`030?7al@3clo<0lo?c00P0
lo?c0P3_knl00`3alO40lo?c0??cl`030??cl`L0kno_00<0lo?c0?Ogm`3gmoL03`1hN7P20??cl`04
07YjNP000000000003`l?0@0N7Qh00<0?3`l0000000000000P3clo<00`3alO40kno_0>o_k`030>o_
k`80lo?c00<0mOGe0?Ogm`3gmoL00P3_knl50??cl`H0kno_2@3clo<0103alO40kno_0>o_k`3alO42
0??cl`80kno_00<0iNGU0=[JfP3Jf]X00P20P8000`2n_[h0no_k0?_kn`0308R8R080e]KF00<0gmoO
0>OWi`3WinL00P3clo<50>o_k`X0lo?c00<0lO7a0>o_k`3_knl01@3clo<00`3alO40kno_0>o_k`02
0>o_k`030?7al@3clo<0lo?c0080moOg00<0O7al000000000000200000020>o_k`D0lo?c0`3_knl7
0??cl`030?7al@3_knl0kno_00P0kno_0P3gmoL00`3clo<0kno_0>o_k`020>o_k`<0inOW0`3Fe]H2
07alO0L0no_k00<0g=cL0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006oooo
o`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@050?Ogm`80Q8B400@0[Jf]0=KFeP3Fe]H0hn?S6`3_knl3
0?Ogma/0kno_00@0N7Qh000000000000N7Qh103_knl00`1hN7P00000000000020?Ogm`030??cl`3_
knl0kno_00<0kno_0P3gmoL00`3clo<0kno_0>o_k`0N0>o_k`030>?Sh`3Fe]H0e]KF0080Q8B400<0
_[jn0?Ogm`3gmoL00`24Q8@20=KFeP030=[JfP3Ng]h0g]kN01H0kno_00@0lo?c0?Ogm`3gmoL0lo?c
103_knl00`3clo<0moOg0?Ogm`020>o_k`0307QhN0000000000000P000008`3_knl30=kNgP<0e]KF
0P1cLg<70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_oo
ool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd01@3gmoL208B4Q0040:f][@3Fe]H0e]KF0>?Sha/0kno_
0`3gmoLK0>o_k`0407QhN0000000000007QhN0@0kno_00<0N7Qh0000000000000P3gmoL00`3clo<0
kno_0>o_k`030>o_k`80moOg00<0lo?c0>o_k`3_knl07P3_knl00`3Shn<0e]KF0=KFeP0208B4Q003
0;jn_P3gmoL0moOg00<0Q8B40P3Fe]H00`3Jf]X0g]kN0=kNgP0F0>o_k`040??cl`3gmoL0moOg0??c
l`@0kno_00<0lo?c0?Ogm`3gmoL00P3_knl00`1hN7P0000000000008000002<0kno_0`3Ng]h30=KF
eP80Lg=c1`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<[:bP2m_Kd0_Kfm0080moOg00<0lo?c0>o_k`3_knl00P24Q8@00`2][Jd0
e]KF0=KFeP030=KFeP80g]kN0`3_knl20=kNgPD0kno_00<0inOW0=kNgP3Ng]h00P3_knl00`3WinL0
g]kN0=kNgP080>o_k`80moOg00<0lo?c0>o_k`3_knl03@3_knl20=kNgP80kno_00<0inOW0=kNgP3N
g]h00P3gmoL0101lO7`000000000001hN7P40>o_k`0307QhN000000000000080kno_00<0inOW0=kN
gP3Ng]h05`3_knl20?Ogm`030>_[j`3Ng]h0g]kN0080kno_00@0inOW0=kNgP3Ng]h0inOW0P3_knl2
0=kNgP030=[JfP3Fe]H0e]KF0080Ng]k00<0]KFe0>o_k`3_knl00`24Q8@50=KFeP80g]kN0`3_knl2
0=kNgP<0kno_0P3gmoL00`3[jn/0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0kno_00<0lo?c
0?Ogm`3gmoL01`3_knl00`1hN7P000000000000800000080g]kN0P3_knl00`3WinL0g]kN0=kNgP03
0>o_k`80g]kN00<0inOW0>o_k`3_knl00P3_knl00`3WinL0g]kN0=kNgP020?Ogm`040>_[j`3Ng]h0
g]kN0>OWi`T0kno_0`3Ng]h30=KFeP80Ng]k0P3_knl00`3clo<0moOg0?Ogm`020>o_k`030=KFeP2m
_Kd0_Kfm00<0c/k>0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0b/[:
0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`0208B4Q0030:f][@3Fe]H0e]KF00<0e]KF0P3Ng]h3
0>o_k`80g]kN1@3_knl00`3WinL0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00P0kno_0P3gmoL0
0`3clo<0kno_0>o_k`0=0>o_k`80g]kN0P3_knl00`3WinL0g]kN0=kNgP020?Ogm`0407alO0000000
000007QhN0@0kno_00<0N7Qh0000000000000P3_knl00`3WinL0g]kN0=kNgP0G0>o_k`80moOg00<0
jn_[0=kNgP3Ng]h00P3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80g]kN00<0f][J0=KFeP3Fe]H0
0P1kNg/00`2e]KD0kno_0>o_k`0308B4Q0D0e]KF0P3Ng]h30>o_k`80g]kN0`3_knl20?Ogm`030>_[
j`3Ng]h0g]kN0080kno_00<0inOW0=kNgP3Ng]h01@3_knl00`3clo<0moOg0?Ogm`070>o_k`0307Qh
N0000000000000P000000P3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00<0kno_0P3Ng]h00`3WinL0kno_
0>o_k`020>o_k`030>OWi`3Ng]h0g]kN0080moOg00@0jn_[0=kNgP3Ng]h0inOW2@3_knl30=kNgP<0
e]KF0P1kNg/20>o_k`030??cl`3gmoL0moOg0080kno_00<0e]KF0;fm_@2m_Kd00`3>c/h20>o_k`03
0??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Bd]800`3:b/X0`/;20<;2`P020?Ogm`030?Ge
m@3clo<0lo?c0080Q8B400@0Zj^[0=;BdP3Bd]80e]KF0P3Jf]X20=kNgP<0inOW0P3Ng]h20>o_k`04
0>_[j`3WinL0inOW0>?Sh`80g]kN0P3_knl00`3WinL0g]kN0=kNgP050>OWi`<0kno_0P3[jn/00`3]
kNd0kno_0>o_k`070>OWi`<0kno_00<0jn_[0>OWi`3WinL00P3Ng]h20>OWk`030>?Si`3Ng]h0g]kN
0080jn_[00@0MWIf000000000000?3`l101hN7P00`0l?3`00000000000020>o_k`030>OWi`3Ng]h0
g]kN00D0inOW00<0jn_[0>o_k`3_knl00P3WinL30>o_k`P0inOW0P3_knl20>_[j`030>GUi@3Ng]h0
g]kN0080inO_00@0hn?W0=kNgP3Ng]h0hn?S0P3WinL20=kNgP030=SHf03Bd]80d];B0080P82000<0
^[Zj0??cl`3clo<00`24Q8@20=KFeP030=SHf03Jf]X0f][J0080g]kN0`3WinL20=kNgP<0kno_0P3[
jn/00`3UiND0g]kN0=kNgP020>o_k`030>OWi`3Ng]h0g]kN00D0inOW00<0kNg]0??cl`3clo<00P3W
inL00`3[jn/0kno_0>o_k`020>OWi`0307AdM0000000000000P000000P3Ng]h20>OWk`030>?Si`3N
g]h0g]kN00<0inOW0P3Ng]h00`3WinL0kno_0>o_k`020>OWi`030>?Sh`3Ng]h0g]kN0080lo?c00@0
jNWY0=kNgP3Ng]h0hn?S103WinL00`3]kNd0lo?c0??cl`020>OWi`<0g]kN0`3Bd]820820P080lo?c
00<0mOGe0?Ogm`3gmoL00P3clo<00`3Kfm/0`/;20<;2`P030<k>cP80inOW00<0kno_0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P24Q8@0102YZJT0c/k>0<k>
cP3Fe]H90=kNgP80kno_00<0inOW0=kNgP3Ng]h00`3Ng]h20>o_k`030>OWi`3Ng]h0g]kN00D0g]kN
0`3_knl20=kNgP030>OWi`3_knl0kno_00L0g]kN0`3_knl00`3WinL0g]kN0=kNgP020=kNgP80g]k_
00<0g]kW0=kNgP3Ng]h00P3Ng]h00`1_Kfl000000000000800000080kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h00`3WinL0kno_0>o_k`020=kNgP<0kno_203Ng]h20>o_k`D0g]kN0P3Ng^l00`3Ng^L0g]kN
0=kNgP050=kNgP030=KFeP3>c/h0c/k>0080Q8B400<0_[jn0?Ogm`3gmoL00`24Q8@20=KFeP030=[J
fP3Ng]h0g]kN00L0g]kN0`3_knl50=kNgP80kno_00<0inOW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_
0>o_k`020=kNgP030>OWi`3_knl0kno_0080g]kN00<0Kfm_000000000000200000020=kNgP80g]k_
00<0g]kW0=kNgP3Ng]h01@3Ng]h00`3WinL0kno_0>o_k`050=kNgP80kno_00<0inOW0=kNgP3Ng]h0
1@3Ng]h00`3[jn/0moOg0?Ogm`050=kNgP<0c/k>0P24Q8@70?Ogm`030=oOg`36a/H0a/K600<0c/k>
0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0b/[:0<K6aP36a/H01@3g
moL208B4Q0040:VYZ@3>c/h0c/k>0=KFePT0g]kN0P3_knl00`3WinL0g]kN0=kNgP030=kNgP80kno_
00<0inOW0=kNgP3Ng]h01@3Ng]h30>o_k`80g]kN00<0inOW0>o_k`3_knl01`3Ng]h30>o_k`030>OW
i`3Ng]h0g]kN0080g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP020=kNgP0306m_K`000000000000P00000
0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN0`3_knl80=kNgP80kno_
1@3Ng]h20=kNk`030=kNi`3Ng]h0g]kN00D0g]kN00<0e]KF0<k>cP3>c/h00P24Q8@00`2n_[h0moOg
0?Ogm`0308B4Q080e]KF00<0f][J0=kNgP3Ng]h01`3Ng]h30>o_k`D0g]kN0P3_knl00`3WinL0g]kN
0=kNgP050=kNgP030>OWi`3_knl0kno_0080g]kN00<0inOW0>o_k`3_knl00P3Ng]h00`1_Kfl00000
0000000800000080g]kN0P3Ng^l00`3Ng^L0g]kN0=kNgP050=kNgP030>OWi`3_knl0kno_00D0g]kN
0P3_knl00`3WinL0g]kN0=kNgP050=kNgP030>_[j`3gmoL0moOg00D0g]kN0`3>c/h208B4Q0L0moOg
00<0gmoO0<K6aP36a/H00`3>c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0kno_0P3>
c/h00`36a/H0_Kfm0;fm_@050?ooo`80Q8B400@0ZJVY0<k>cP3>c/h0e]KF0P3Ng]h20=KFePX0g]kN
00<0f][J0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN
0P3Fe]H00`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF
0=KFeP020=KFeP030=[JfP3Ng]h0g]kN00<0e]KF2P3Ng]h20=KFePd0g]kN0P3Ng]H0103Jf]H0e]KF
0=KFeP3Jf]X20=kNgP80e]KF00<0d];B0<k>cP3>c/h00P24Q8@00`32`/80oooo0?ooo`0308B4Q080
c/k>00<0e]KF0=kNgP3Ng]h00P3Fe]H:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3N
g]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgP80e]KF00<0f][J0=kNgP3Ng]h02P3Ng]h20=kNeP03
0=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3Fe]H0103Jf]X0g]kN0=kNgP3Jf]X20=KF
ePL0g]kN0`3Fe]H30<k>cP80Q8B41`3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3_knl20<k>cP030<K6aP2m_Kd0_Kfm00D0oooo0P24Q8@0102YZJT0
c/k>0<k>cP3Fe]H20=kNgP80e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN
0080e]KF00<0f][J0=kNgP3Ng]h0203Ng]h20=KFeP030=[JfP3Ng]h0g]kN00X0g]kN0P3Ng]H00`3J
f]H0e]KF0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00`3Fe]H:0=kN
gP80e]KF3@3Ng]h20=kNeP040=[JeP3Fe]H0e]KF0=[JfP80g]kN0P3Fe]H00`3Bd]80c/k>0<k>cP02
08B4Q0030<;2`P3oool0oooo00<0Q8B40P3>c/h00`3Fe]H0g]kN0=kNgP020=KFePX0g]kN00<0f][J
0=KFeP3Fe]H00P3Fe]H00`3Jf]X0g]kN0=kNgP020=KFeP030=[JfP3Ng]h0g]kN00P0g]kN0P3Fe]H0
0`3Jf]X0g]kN0=kNgP0:0=kNgP80g]kF00<0f][F0=KFeP3Fe]H02P3Ng]h00`3Jf]X0e]KF0=KFeP02
0=KFeP040=[JfP3Ng]h0g]kN0=[JfP80e]KF1`3Ng]h30=KFeP<0c/k>0P24Q8@70?ooo`030=kNgP2m
_Kd0_Kfm00<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80c/k>00<0a/K6
0;fm_@2m_Kd01@3oool208B4Q0040:VYZ@3>c/h0c/k>0=KFeP80g]kN0P3Fe]H:0=kNgP030=[JfP3F
e]H0e]KF0080e]KF00<0f][J0=kNgP3Ng]h00P3Fe]H00`3Jf]X0g]kN0=kNgP080=kNgP80e]KF00<0
f][J0=kNgP3Ng]h02P3Ng]h20=kNeP030=[JeP3Fe]H0e]KF00X0g]kN00<0f][J0=KFeP3Fe]H00P3F
e]H00`3Jf]X0g]kN0=kNgP030=KFePX0g]kN0P3Fe]H=0=kNgP80g]kF00@0f][F0=KFeP3Fe]H0f][J
0P3Ng]h20=KFeP030=;BdP3>c/h0c/k>0080Q8B400<0`/;20?ooo`3oool00`24Q8@20<k>cP030=KF
eP3Ng]h0g]kN0080e]KF2P3Ng]h00`3Jf]X0e]KF0=KFeP020=KFeP030=[JfP3Ng]h0g]kN0080e]KF
00<0f][J0=kNgP3Ng]h0203Ng]h20=KFeP030=[JfP3Ng]h0g]kN00X0g]kN0P3Ng]H00`3Jf]H0e]KF
0=KFeP0:0=kNgP030=[JfP3Fe]H0e]KF0080e]KF00@0f][J0=kNgP3Ng]h0f][J0P3Fe]H70=kNgP<0
e]KF0`3>c/h208B4Q0L0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00So
oooo0006ooooo`<0g]kN0P3>c/h00`3:b/X0a/K60<K6aP050?Ogm`80Lg=c00@0ZJVY0=kNgP3Ng]h0
jn_[5P3gmoL20?ooo`030?_kn`3gmoL0moOg00<0moOg0P3oool00`3kno/0moOg0?Ogm`020?ooo`03
0?_kn`3gmoL0moOg01L0moOg0P3oool00`3kno/0moOg0?Ogm`0=0?Ogm`80oooo0`3gmoL20?ooo`l0
moOg00@0no_k0?ooo`3oool0no_k0P3gmoL20>o_k`030>OWi`3Ng]h0g]kN0080Q8B400<0_[jn0?Og
m`3gmoL00`1kNg/20=kNgP030>_[j`3gmoL0moOg0140moOg00<0no_k0?ooo`3oool0203gmoL20?oo
o`030?_kn`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL0503gmoL00`3kno/0oooo0?ooo`0B0?Og
m`80oooo0`3_knl30=kNgP80Q8B41`3gmoL00`3Jf]X0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Og
m`3gmoL02?ooool000Kooooo0`3Ng]h20<k>cP030<[:bP36a/H0a/K600D0moOg0P1cLg<0102YZJT0
g]kN0=kNgP3[jn/F0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00`3gmoL20?ooo`030?_kn`3gmoL0moOg
0080oooo00<0no_k0?Ogm`3gmoL05`3gmoL20?ooo`030?_kn`3gmoL0moOg00d0moOg0P3oool30?Og
m`80oooo3`3gmoL0103kno/0oooo0?ooo`3kno/20?Ogm`80kno_00<0inOW0=kNgP3Ng]h00P24Q8@0
0`2n_[h0moOg0?Ogm`0307]kN`80g]kN00<0jn_[0?Ogm`3gmoL04@3gmoL00`3kno/0oooo0?ooo`08
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL00P3oool00`3kno/0moOg0?Ogm`0D0?Ogm`030?_kn`3oool0
oooo0180moOg0P3oool30>o_k`<0g]kN0P24Q8@70?Ogm`030=[JfP2m_Kd0_Kfm00<0e]KF0P3Ng]h0
0`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80d];B00<0b/[:0<;2`P32`/801@3clo<207al
O0040;:b/P3WinL0inOW0?7alAH0no_k0P3oool00`3moOd0no_k0?_kn`030?_kn`80oooo00<0oOgm
0?_kn`3kno/00P3oool00`3moOd0no_k0?_kn`0G0?_kn`80oooo00<0oOgm0?_kn`3kno/03@3kno/2
0?ooo`<0no_k0P3oool?0?_kn`040?gmo@3oool0oooo0?gmo@80no_k0P3gmoL00`3clo<0kno_0>o_
k`0208B4Q0030;bl_03clo<0lo?c00<0P8200P3WinL00`3alO40no_k0?_kn`0A0?_kn`030?gmo@3o
ool0oooo00P0no_k0P3oool00`3moOd0no_k0?_kn`020?ooo`030?gmo@3kno/0no_k01@0no_k00<0
oOgm0?ooo`3oool04P3kno/20?ooo`<0moOg0`3_knl208B4Q0D0lo?c0P3gmoL00`3Jf]X0_Kfm0;fm
_@030=;BdP80inOW00<0kno_0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP030<[:bP2m_Kd0
_Kfm00D0kno_0P24Q8@0102j^[X0kno_0>o_k`3gmoMb0?ooo`80Q8B400<0^[Zj0>o_k`3_knl00`24
Q8@20>o_k`030?Ogm`3oool0oooo05L0oooo0P24Q8@50>o_k`80moOg00<0f][J0;fm_@2m_Kd00`3>
c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3:b/X0_Kfm0;fm_@05
0>o_k`80Q8B400@0^[Zj0>o_k`3_knl0moOgLP3oool208B4Q0030;Zj^P3_knl0kno_00<0Q8B40P3_
knl00`3gmoL0oooo0?ooo`1G0?ooo`80Q8B41@3_knl20?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>00<0a/K60;fm_@2m_Kd00P3oool0
0`3kno/0moOg0?Ogm`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0<0Ng]k0P2<S8`0
0`28R8P0Q8B408B4Q00207]kN`030820P024Q8@0Q8B400P0Q8B40P1kNg/708B4Q0040820P01kNg/0
Ng]k0820P0T0Q8B400<0R8R808b<S02<S8`01@24Q8@00`20P800Ng]k07]kN`0508B4Q080Lg=c2P24
Q8@00`20P800Ng]k07]kN`0:08B4Q00308R8R02<S8`0S8b<0080Q8B400<0_[jn0?Ogm`3gmoL01@24
Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k4P24Q8@00`20P800Ng]k07]kN`0508B4Q080Ng]k00<0
P82008B4Q024Q8@02024Q8@207]kN`P0Q8B40P1kNg/00`20P800Q8B408B4Q00508B4Q080S8b<00<0
R8R808B4Q024Q8@01@24Q8@00`20P800Ng]k07]kN`0:08B4Q0L0moOg00<0gmoO0<K6aP36a/H00`3>
c/h20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@02
0?ooo`030?_kn`3gmoL0moOg00D0Q8B400<0P82007]kN`1kNg/01@24Q8@207]kNa80Q8B40`1kNg/2
08b<S00308R8R024Q8@0Q8B40080Ng]k00<0P82008B4Q024Q8@02024Q8@207]kN`L0Q8B400@0P820
07]kN`1kNg/0P8202@24Q8@00`28R8P0S8b<08b<S00508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1c
Lg<:08B4Q0030820P01kNg/0Ng]k00X0Q8B400<0R8R808b<S02<S8`00P24Q8@00`2n_[h0moOg0?Og
m`0508B4Q0030820P01kNg/0Ng]k00D0Q8B40P1kNg/B08B4Q0030820P01kNg/0Ng]k00D0Q8B40P1k
Ng/00`20P800Q8B408B4Q00808B4Q080Ng]k2024Q8@207]kN`030820P024Q8@0Q8B400D0Q8B40P2<
S8`00`28R8P0Q8B408B4Q00508B4Q0030820P01kNg/0Ng]k00X0Q8B41`3gmoL00`3Ogml0a/K60<K6
aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3WinL20=;BdP030<S8b02m_Kd0
_Kfm0080oooo00<0oOgm0?_kn`3kno/01@32`/800`30`<00_Kfm0;fm_@050<;2`P80_Kfm4P32`/83
0;fm_@80a/K600<0a<C40<;2`P32`/800P2m_Kd00`30`<00`/;20<;2`P080<;2`P80_Kfm1`32`/80
1030`<00_Kfm0;fm_@30`<090<;2`P030<C4a036a/H0a/K600D0`/;200<0`<300;fm_@2m_Kd01@32
`/820;Vi^@X0`/;200<0`<300;fm_@2m_Kd02P32`/800`34a<@0a/K60<K6aP020<;2`P030=oOg`3k
no/0no_k00D0`/;200<0`<300;fm_@2m_Kd01@32`/820;fm_A80`/;200<0`<300;fm_@2m_Kd01@32
`/820;fm_@030<30`032`/80`/;200P0`/;20P2m_Kd80<;2`P80_Kfm00<0`<300<;2`P32`/801@32
`/820<K6aP030<C4a032`/80`/;200D0`/;200<0`<300;fm_@2m_Kd02P32`/870?_kn`030=oOg`32
`/80`/;200<0d];B0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:
0;fm_@2m_Kd0jP3oool00`3Ng]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool0
00Kooooo0`3_knl20=KFeP030<[:bP2m_Kd0_Kfm0>X0oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20=kN
gP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0_Kfm0;fm_@3Z07=cL`03
09fMW@36a/H0a/K600<0c/k>0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool30=kNgP80c/k>
00<0a/K60;fm_@2m_Kd0jP1cLg<00`2MWId0a/K60<K6aP030<k>cP80g]kN00<0jn_[0?Ogm`3gmoL0
2?ooool000Kooooo0`3Ng]h20=KFeP030<k>cP36a/H0a/K601h0moOg00<0no_k0?ooo`3oool09P3g
moL00`3kno/0oooo0?ooo`0V0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0903gmoL20?ooo`030?_kn`3g
moL0moOg02@0moOg0P3oool00`3kno/0moOg0?Ogm`0S0?Ogm`030=[JfP2m_Kd0_Kfm00<0c/k>0P3_
knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30=kNgP80e]KF00<0c/k>0<K6aP36a/H07P3gmoL0
0`3kno/0oooo0?ooo`0V0?Ogm`030?_kn`3oool0oooo02H0moOg0P3oool00`3kno/0moOg0?Ogm`0T
0?Ogm`80oooo00<0no_k0?Ogm`3gmoL0903gmoL20?ooo`030?_kn`3gmoL0moOg02<0moOg00<0f][J
0;fm_@2m_Kd00`3>c/h20>o_k`030??cl`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3Fe]H00`3>
c/h0a/K60<K6aP0N0?Ogm`030?_kn`3oool0oooo02H0moOg00<0no_k0?ooo`3oool09P3gmoL20?oo
o`030?_kn`3gmoL0moOg02@0moOg0P3oool00`3kno/0moOg0?Ogm`0T0?Ogm`80oooo00<0no_k0?Og
m`3gmoL08`3gmoL00`3Jf]X0_Kfm0;fm_@030<k>cP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Ko
oooo0`3Ng]h20=KFeP030<c<c032`/80`/;20180no_k0P3clo<20>_[j`040?7al@3gmoL0moOg0?Wi
n@@0no_k00<0oOgm0?ooo`3oool09P3kno/00`3moOd0oooo0?ooo`0V0?_kn`80oooo00<0oOgm0?_k
n`3kno/0903kno/20?ooo`030?gmo@3kno/0no_k02@0no_k0P3oool00`3moOd0no_k0?_kn`0S0?_k
n`030=cLg02m_Kd0_Kfm00<0d];B0P3WinL00`3_knl0moOg0?Ogm`08ooooo`001_ooool30=kNgP80
e]KF00<0b/[:0;fm_@2m_Kd04P3oool20>o_k`80g]kN00@0jn_[0?Ogm`3gmoL0no_kd03oool00`3N
g]h0_Kfm0;fm_@030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20=KFeP03
0<[:bP2m_Kd0_Kfm0180oooo0P3_knl20=kNgP040>_[j`3gmoL0moOg0?_knm00oooo00<0g]kN0;fm
_@2m_Kd00`3Fe]H20=kNgP030>_[j`3gmoL0moOg00Sooooo0006ooooo`<0g]kN0P3>c/h00`36a/H0
_Kfm0;fm_@0?0?Ogm`<0_Kfm0P1cLg<205YJFP0406=SH`1[Jf/0Jf][0820P080U9BD0P3Fe]H00`3W
inL0moOg0?Ogm`050?Ogm`<0oooo3`3gmoL00`3kno/0oooo0?ooo`0D0?Ogm`80oooo00<0no_k0?Og
m`3gmoL03@3gmoL20?oooaD0moOg0P3oool00`3kno/0moOg0?Ogm`0=0?Ogm`80oooo503gmoL0103k
no/0oooo0?ooo`3kno/?0?Ogm`80oooo503gmoL00`3kno/0oooo0?ooo`0?0?Ogm`<0oooo303gmoL0
0`3Ogml0a/K60<K6aP030=KFeP80g]kN00<0jn_[0?Ogm`3gmoL02?ooool000Kooooo0`3Ng]h20<k>
cP030<K6aP2m_Kd0_Kfm00l0moOg0`2m_Kd207=cL`80FUYJ00@0Hf=S06][J`1[Jf/0P8200P2DU9@2
0=KFeP030>OWi`3gmoL0moOg00D0moOg0`3oool?0?Ogm`030?_kn`3oool0oooo01@0moOg0P3oool0
0`3kno/0moOg0?Ogm`0=0?Ogm`80oooo5@3gmoL20?ooo`030?_kn`3gmoL0moOg00d0moOg0P3ooolD
0?Ogm`040?_kn`3oool0oooo0?_kn`l0moOg0P3ooolD0?Ogm`030?_kn`3oool0oooo00l0moOg0`3o
ool<0?Ogm`030=oOg`36a/H0a/K600<0e]KF0P3Ng]h00`3[jn/0moOg0?Ogm`08ooooo`001_ooool3
0>o_k`80e]KF00<0b/[:0;fm_@2m_Kd01`3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80_Kfm0`1[
Jf/20:f][@80kno_00@0gmoO0<k>cP3>c/h0YJFU0P1kNg/208b<S0030;Fe]@3Ng]h0g]kN00l0kno_
00<0inOW0=kNgP3Ng]h04@3_knl0103WinL0g]kN0=kNgP3WinLA0>o_k`030>OWi`3Ng]h0g]kN0140
kno_00<0inOW0=kNgP3Ng]h04P3_knl30=kNgQ40kno_00<0inOW0=kNgP3Ng]h04P3_knl20=kNgP03
0>OWi`3_knl0kno_00l0kno_0`3Ng]hB0>o_k`80g]kN00<0inOW0>o_k`3_knl03`3_knl20=kNgP03
0<k>cP2m_Kd0_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF
00<0b/[:0;fm_@2m_Kd01`3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80_Kfm0`1[Jf/20:f][@80
kno_00@0gmoO0<k>cP3>c/h0YJFU0P1kNg/208b<S0030;Fe]@3Ng]h0g]kN00l0kno_00<0inOW0=kN
gP3Ng]h04@3_knl0103WinL0g]kN0=kNgP3WinLA0>o_k`030>OWi`3Ng]h0g]kN0140kno_00<0inOW
0=kNgP3Ng]h04P3_knl30=kNgQ40kno_00<0inOW0=kNgP3Ng]h04P3_knl20=kNgP030>OWi`3_knl0
kno_00l0kno_0`3Ng]hB0>o_k`80g]kN00<0inOW0>o_k`3_knl03`3_knl20=kNgP030<k>cP2m_Kd0
_Kfm00<0e]KF0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0b/[:0;fm
_@2m_Kd01`3_knl0103WinL0g]kN0=kNgP3WinL20>o_k`80_Kfm0`1[Jf/20:f][@80kno_00@0gmoO
0<k>cP3>c/h0YJFU0P1kNg/208b<S0030;Fe]@3Ng]h0g]kN00l0kno_00<0inOW0=kNgP3Ng]h04@3_
knl0103WinL0g]kN0=kNgP3WinLA0>o_k`030>OWi`3Ng]h0g]kN0140kno_00<0inOW0=kNgP3Ng]h0
4P3_knl30=kNgQ40kno_00<0inOW0=kNgP3Ng]h04P3_knl20=kNgP030>OWi`3_knl0kno_00l0kno_
0`3Ng]hB0>o_k`80g]kN00<0inOW0>o_k`3_knl03`3_knl20=kNgP030<k>cP2m_Kd0_Kfm00<0e]KF
0P3_knl00`3clo<0moOg0?Ogm`08ooooo`001_ooool30>o_k`80e]KF00<0c/k>0<K6aP36a/H03@3g
moL209bLW0<0[Jf]1`3oool00`3kno/0moOg0?Ogm`0207]kN`030:VYZ@3Fe]H0e]KF02<0moOg00@0
no_k0?ooo`3oool0no_k9@3gmoL00`3kno/0oooo0?ooo`0V0?Ogm`030?_kn`3oool0oooo02H0moOg
0`3ooolV0?Ogm`80oooo00<0g]kN0;fm_@2m_Kd00`3Fe]H20>o_k`030??cl`3gmoL0moOg00Sooooo
0006ooooo`<0kno_0P3Fe]H00`3>c/h0a/K60<K6aP0=0?Ogm`80W9bL0`2][Jd70?ooo`030?_kn`3g
moL0moOg0080Ng]k00<0ZJVY0=KFeP3Fe]H08`3gmoL0103kno/0oooo0?ooo`3kno/U0?Ogm`030?_k
n`3oool0oooo02H0moOg00<0no_k0?ooo`3oool09P3gmoL30?ooobH0moOg0P3oool00`3Ng]h0_Kfm
0;fm_@030=KFeP80kno_00<0lo?c0?Ogm`3gmoL02?ooool000Kooooo0`3_knl20=kNgP030=;BdP36
a/H0a/K600d0oooo0P2<S8`30<K6aP80kno_0P3oool0103kno/0moOg0?Ogm`3[jn/20=kNgP80U9BD
00<0]KFi0=KFgP3Fe]h0b@3oool00`3Shn<0a/K60<K6aP030=kNgP80kno_00<0moOg0?ooo`3oool0
2?ooool000Kooooo0`3_knl20=kNgP030=;BdP36a/H0a/K600d0oooo0P2<S8`30<K6aP80kno_0P3o
ool0103kno/0moOg0?Ogm`3[jn/20=kNgP80U9BD00<0]KFi0=KFgP3Fe]h0b@3oool00`3Shn<0a/K6
0<K6aP030=kNgP80kno_00<0moOg0?ooo`3oool02?ooool000Kooooo0`3clo<20=kNgP030=3@d032
`/80`/;20080no_k00<0nOWi0?Ogm`3gmoL00P3kno/0103moOd0oooo0?ooo`3moOd20?_kn`80Q8B4
0`2j^[X20=_Kf`80inOW00@0hn?S0=oOg`3Ogml0emOG0P3>c/h208B4Q0030:^[[`3Bd]X0d];J0080
no_k00<0oOgm0?ooo`3oool01@3kno/00`3inOT0moOg0?Ogm`020?_kn`030?gmo@3oool0oooo00`0
no_k00<0nOWi0?Ogm`3gmoL02P3kno/00`3moOd0oooo0?ooo`050?_kn`<0moOg0P3kno/00`3moOd0
oooo0?ooo`0=0?_kn`80moOg2P3kno/00`3moOd0oooo0?ooo`050?_kn`80moOg00<0nOWi0?_kn`3k
no/00`3oool<0?_kn`<0moOg2P3kno/20?ooo`030?gmo@3kno/0no_k00<0no_k0P3gmoL00`3inOT0
no_k0?_kn`020?ooo`030?gmo@3kno/0no_k00X0no_k0P3gmoL00`3inOT0no_k0?_kn`080?_kn`80
oooo00<0oOgm0?_kn`3kno/00P3kno/0103inOT0moOg0?Ogm`3inOT20?_kn`80oooo00<0oOgm0?_k
n`3kno/02P3kno/20?Ogm`030?Win@3kno/0no_k0080no_k00<0gmoO0<;2`P32`/800`3WinL20??c
l`030?Win@3oool0oooo00Sooooo0006ooooo`<0moOg0P3Ng]h00`3>c/h0_Kfm0;fm_@020?Ogm`03
0??cl`3_knl0kno_0080moOg00@0no_k0?ooo`3oool0no_k0P3gmoL207]kN`<0[Jf]0P36a/H20<k>
cP040<[:bP36a/H0a/K60<;2`P80_Kfm0P1cLg<00`2QXJD0c/kF0<k>eP020?Ogm`030?_kn`3oool0
oooo00D0moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3kno/0oooo0?ooo`0<0?Ogm`030??cl`3_knl0
kno_00X0moOg00<0no_k0?ooo`3oool01@3gmoL30>o_k`80moOg00<0no_k0?ooo`3oool03@3gmoL2
0>o_k`X0moOg00<0no_k0?ooo`3oool01@3gmoL20>o_k`030??cl`3gmoL0moOg00<0oooo303gmoL3
0>o_k`X0moOg0P3oool00`3kno/0moOg0?Ogm`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL00P3oool0
0`3kno/0moOg0?Ogm`0:0?Ogm`80kno_00<0lo?c0?Ogm`3gmoL0203gmoL20?ooo`030?_kn`3gmoL0
moOg0080moOg00@0lo?c0>o_k`3_knl0lo?c0P3gmoL20?ooo`030?_kn`3gmoL0moOg00X0moOg0P3_
knl00`3clo<0moOg0?Ogm`020?Ogm`030=[JfP2m_Kd0_Kfm00<0kno_0P3gmoL00`3kno/0oooo0?oo
o`08ooooo`001_ooool30?Ogm`80g]kN00<0c/k>0;fm_@2m_Kd00P3gmoL00`3clo<0kno_0>o_k`02
0?Ogm`040?_kn`3oool0oooo0?_kn`80moOg0P1kNg/30:f][@80a/K60P3>c/h0103:b/X0a/K60<K6
aP32`/820;fm_@80Lg=c00<0XJ6U0<k>eP3>c]H00P3gmoL00`3kno/0oooo0?ooo`050?Ogm`030??c
l`3_knl0kno_0080moOg00<0no_k0?ooo`3oool0303gmoL00`3clo<0kno_0>o_k`0:0?Ogm`030?_k
n`3oool0oooo00D0moOg0`3_knl20?Ogm`030?_kn`3oool0oooo00d0moOg0P3_knl:0?Ogm`030?_k
n`3oool0oooo00D0moOg0P3_knl00`3clo<0moOg0?Ogm`030?ooo``0moOg0`3_knl:0?Ogm`80oooo
00<0no_k0?Ogm`3gmoL00`3gmoL20>o_k`030??cl`3gmoL0moOg0080oooo00<0no_k0?Ogm`3gmoL0
2P3gmoL20>o_k`030??cl`3gmoL0moOg00P0moOg0P3oool00`3kno/0moOg0?Ogm`020?Ogm`040??c
l`3_knl0kno_0??cl`80moOg0P3oool00`3kno/0moOg0?Ogm`0:0?Ogm`80kno_00<0lo?c0?Ogm`3g
moL00P3gmoL00`3Jf]X0_Kfm0;fm_@030>o_k`80moOg00<0no_k0?ooo`3oool02?ooool000Kooooo
0`3kno/20>OWi`030=;BdP2m_Kd0_Kfm0080lo?c00<0lO7a0>o_k`3_knl00P3clo<0103emOD0moOg
0?Ogm`3emOD20??cl`80S8b<0`2@T9020<K6aP80c/k>00@0c<c<0<[:bP3:b/X0`<300P2e]KD206=S
H`030:6QX`3Ogn<0gmoS0080lo?c00<0mOGe0?Ogm`3gmoL01@3clo<00`3alO40kno_0>o_k`020??c
l`030?Gem@3gmoL0moOg00`0lo?c00<0lO7a0>o_k`3_knl02P3clo<00`3emOD0moOg0?Ogm`050??c
l`<0kno_0P3clo<00`3emOD0moOg0?Ogm`0=0??cl`80kno_2P3clo<00`3emOD0moOg0?Ogm`050??c
l`80kno_00<0lO7a0??cl`3clo<00`3gmoL<0??cl`<0kno_2P3clo<20?Ogm`030?Gem@3clo<0lo?c
00<0lo?c0P3_knl00`3alO40lo?c0??cl`020?Ogm`030?Gem@3clo<0lo?c00X0lo?c0P3_knl00`3a
lO40lo?c0??cl`080??cl`80moOg00<0mOGe0??cl`3clo<00P3clo<0103alO40kno_0>o_k`3alO42
0??cl`80moOg00<0mOGe0??cl`3clo<02P3clo<20>o_k`030?7al@3clo<0lo?c0080lo?c00<0f=SH
0;fm_@2m_Kd00`3clo<20?Ogm`030?_kn`3oool0oooo00Sooooo0006ooooo`<0oooo0P3_knl00`3F
e]H0_Kfm0;fm_@0=0>o_k`80W9bL0`1cLg<20<K6aPD0c/k>00<0_[jn0:f][@2][Jd00P1BDU800`2Q
XJ40kno_0>o_k`390>o_k`030=KFeP2m_Kd0_Kfm00D0moOg00<0no_k0?ooo`3oool02?ooool000Ko
oooo0`3oool20>o_k`030=KFeP2m_Kd0_Kfm00d0kno_0P2LW9`307=cL`80a/K61@3>c/h00`2n_[h0
[Jf]0:f][@02059BDP030:6QX@3_knl0kno_0<T0kno_00<0e]KF0;fm_@2m_Kd01@3gmoL00`3kno/0
oooo0?ooo`08ooooo`001_ooool50?ooo`030>?Sh`36a/H0a/K600X0moOg00<0lo?c0>o_k`3_knl0
0P3gmoL307=cL`80W9bL0P3Ng]h0103Fe]H0c/k>0<k>cP2MWId206][J`80_Kfm00<0e]KF0>o_k`3_
knl04P3gmoL20>o_k`d0moOg0P3oool0103kno/0moOg0?Ogm`3clo<20>o_ka80moOg0P3_knl=0?Og
m`80oooo00<0no_k0?Ogm`3gmoL00P3_knl00`3clo<0moOg0?Ogm`0@0?Ogm`80kno_00<0lo?c0?Og
m`3gmoL02P3gmoL20?ooo`030?_kn`3gmoL0moOg0080kno_00<0lo?c0?Ogm`3gmoL03`3gmoL00`3c
lo<0kno_0>o_k`0<0?Ogm`030?_kn`3oool0oooo00<0moOg0P3_knl00`3clo<0moOg0?Ogm`0?0?Og
m`030??cl`3_knl0kno_00`0moOg00<0no_k0?ooo`3oool00P3gmoL00`3Ogml0a/K60<K6aP030?Og
m`D0oooo2?ooool000Kooooo1@3oool00`3Shn<0a/K60<K6aP0:0?Ogm`030??cl`3_knl0kno_0080
moOg0`1cLg<209bLW080g]kN00@0e]KF0<k>cP3>c/h0WIfM0P1[Jf/20;fm_@030=KFeP3_knl0kno_
0180moOg0P3_knl=0?Ogm`80oooo00@0no_k0?Ogm`3gmoL0lo?c0P3_knlB0?Ogm`80kno_3@3gmoL2
0?ooo`030?_kn`3gmoL0moOg0080kno_00<0lo?c0?Ogm`3gmoL0403gmoL20>o_k`030??cl`3gmoL0
moOg00X0moOg0P3oool00`3kno/0moOg0?Ogm`020>o_k`030??cl`3gmoL0moOg00l0moOg00<0lo?c
0>o_k`3_knl0303gmoL00`3kno/0oooo0?ooo`030?Ogm`80kno_00<0lo?c0?Ogm`3gmoL03`3gmoL0
0`3clo<0kno_0>o_k`0<0?Ogm`030?_kn`3oool0oooo0080moOg00<0gmoO0<K6aP36a/H00`3gmoL5
0?ooo`Sooooo0006ooooo`D0oooo00<0hn?S0<K6aP36a/H02P3kno/00`3inOT0moOg0?Ogm`020?_k
n`<0^KVi0P2][Jd50;Fe]@030:f][@2UYJD0YJFU0080g]kN00<0jn_[0?Ogm`3gmoL04P3kno/20?Og
m`d0no_k0P3oool0103moOd0no_k0?_kn`3inOT20?Ogma80no_k0P3gmoL=0?_kn`80oooo00<0oOgm
0?_kn`3kno/00P3gmoL00`3inOT0no_k0?_kn`0@0?_kn`80moOg00<0nOWi0?_kn`3kno/02P3kno/2
0?ooo`030?gmo@3kno/0no_k0080moOg00<0nOWi0?_kn`3kno/03`3kno/00`3inOT0moOg0?Ogm`0<
0?_kn`030?gmo@3oool0oooo00<0no_k0P3gmoL00`3inOT0no_k0?_kn`0?0?_kn`030?Win@3gmoL0
moOg00`0no_k00<0oOgm0?ooo`3oool00P3kno/00`3QhN40a/K60<K6aP030?_kn`D0oooo2?ooool0
00Kooooo1@3oool00`3Shn<0a/K60<K6aP0B0?ooo`80_Kfm0P2<S8`0102DU9@0W9bL09bLW02m_Kd2
0=kNg/h0oooo00<0hn?S0<K6aP36a/H0203oool8ooooo`001_ooool50?ooo`030>?Sh`36a/H0a/K6
0180oooo0P2m_Kd208b<S00409BDU02LW9`0W9bL0;fm_@80g]kNcP3oool00`3Shn<0a/K60<K6aP08
0?ooo`Sooooo0006ooooo`D0oooo00<0g]kN0;fm_@2m_Kd01@3gmoL20>o_k`030??cl`3gmoL0moOg
00l0moOg00<0lo?c0>o_k`3_knl04P3gmoL20>o_k`030??cl`3gmoL0moOg00l0moOg0P3_knl00`3c
lo<0moOg0?Ogm`0@0?Ogm`80kno_00<0lo?c0?Ogm`3gmoL03`3gmoL20>o_k`030??cl`3gmoL0moOg
00l0moOg00<0lo?c0>o_k`3_knl04P3gmoL20>o_k`030??cl`3gmoL0moOg00l0moOg00<0lo?c0>o_
k`3_knl04@3gmoL00`3clo<0kno_0>o_k`0B0?Ogm`030??cl`3_knl0kno_0140moOg00<0lo?c0>o_
k`3_knl00P3gmoL00`3Jf]X0_Kfm0;fm_@080?ooo`Sooooo0006ooooo`D0oooo00<0g]kN0;fm_@2m
_Kd01@3gmoL20>o_k`030??cl`3gmoL0moOg00l0moOg00<0lo?c0>o_k`3_knl04P3gmoL20>o_k`03
0??cl`3gmoL0moOg00l0moOg0P3_knl00`3clo<0moOg0?Ogm`0@0?Ogm`80kno_00<0lo?c0?Ogm`3g
moL03`3gmoL20>o_k`030??cl`3gmoL0moOg00l0moOg00<0lo?c0>o_k`3_knl04P3gmoL20>o_k`03
0??cl`3gmoL0moOg00l0moOg00<0lo?c0>o_k`3_knl04@3gmoL00`3clo<0kno_0>o_k`0B0?Ogm`03
0??cl`3_knl0kno_0140moOg00<0lo?c0>o_k`3_knl00P3gmoL00`3Jf]X0_Kfm0;fm_@080?ooo`So
oooo0006ooooo`D0oooo00<0hN7Q0<;2`P32`/800P3Ogml00`3MgMd0f][J0=[JfP030=_Kf`D0f][J
0P3Ogml30=[JfP80gmoO0P3Jf]X0103MgMd0gmoO0=oOg`3Kfm/20=KFePD0gmoO1@3Jf]X50=oOg`03
0=gMg@3Jf]X0f][J00<0fm_K103Jf]X30=oOg`030=gMg@3Jf]X0f][J0080gmoO0P3Jf]X00`3MgMd0
gmoO0=oOg`020=KFeP030=_Kf`3Ogml0gmoO00<0gmoO1@3Jf]X50=oOg`<0f][J0`3Kfm/40=[JfP<0
gmoO0P3Jf]X30=oOg`<0f][J0P3Ogml20=KFeP030=_Kf`3Ogml0gmoO0080gmoO00<0gMgM0=[JfP3J
f]X00`3Jf]X50=oOg`80f][J0`3Kfm/50=[JfP030=gMg@3Ogml0gmoO0080f][J0`3Ogml20=[JfP<0
gmoO0P3Fe]H00`3Kfm/0gmoO0=oOg`020=oOg`030=gMg@3Jf]X0f][J0080f][J00<0gMgM0=oOg`3O
gml00`3Ogml20=[JfP<0fm_K1@3Jf]X30=oOg`80f][J0`3Ogml20=[JfP80gmoO00<0fm_K0=KFeP3F
e]H01@3Ogml00`3MgMd0f][J0=[JfP020=[JfP030=gMg@3Ogml0gmoO0080gmoO00<0gMgM0=[JfP3J
f]X00`3Kfm/50=[JfP80gmoO0`3Jf]X30=oOg`80f][J0P3Ogml00`3Kfm/0e]KF0=KFeP020=oOg`03
0=7Ad@32`/80`/;200P0oooo2?ooool000Kooooo1@3oool00`3Shn<0a/K60<K6aP020<K6aP030<;2
`P2m_Kd0_Kfm0080a/K600<0`/;20;fm_@2m_Kd00`2m_Kd20<K6aP<0_Kfm0P36a/H20;fm_@040<;2
`P36a/H0a/K60<;2`P80_Kfm1@36a/H50;fm_@D0a/K600<0`/;20;fm_@2m_Kd00P36a/H00`32`/80
_Kfm0;fm_@020;fm_@<0a/K600<0`/;20;fm_@2m_Kd00P36a/H20;fm_@030<;2`P36a/H0a/K60080
_Kfm00<0`/;20<K6aP36a/H00`36a/H50;fm_@D0a/K60`2m_Kd20<K6aP030<;2`P2m_Kd0_Kfm0080
_Kfm0`36a/H20;fm_@<0a/K60`2m_Kd20<K6aP80_Kfm00<0`/;20<K6aP36a/H00P36a/H00`32`/80
_Kfm0;fm_@030;fm_@D0a/K60P2m_Kd00`32`/80a/K60<K6aP050;fm_@030<;2`P36a/H0a/K60080
_Kfm0`36a/H20;fm_@<0a/K60P2m_Kd00`32`/80a/K60<K6aP020<K6aP030<;2`P2m_Kd0_Kfm0080
_Kfm00<0`/;20<K6aP36a/H00`36a/H20;fm_@030<;2`P36a/H0a/K600D0_Kfm0`36a/H20;fm_@<0
a/K60P2m_Kd20<K6aP030<;2`P2m_Kd0_Kfm00D0a/K600<0`/;20;fm_@2m_Kd00P2m_Kd00`32`/80
a/K60<K6aP020<K6aP040<;2`P2m_Kd0_Kfm0<;2`P80a/K61@2m_Kd20<K6aP<0_Kfm0`36a/H20;fm
_@80a/K600<0`/;20;fm_@2m_Kd01@36a/H80?ooo`Sooooo0006ooooo`D0oooo00<0hn?S0<K6aP36
a/H00P36a/H00`32`/80_Kfm0;fm_@020<K6aP030<;2`P2m_Kd0_Kfm00<0_Kfm0P36a/H30;fm_@80
a/K60P2m_Kd01032`/80a/K60<K6aP32`/820;fm_@D0a/K61@2m_Kd50<K6aP030<;2`P2m_Kd0_Kfm
0080a/K600<0`/;20;fm_@2m_Kd00P2m_Kd30<K6aP030<;2`P2m_Kd0_Kfm0080a/K60P2m_Kd00`32
`/80a/K60<K6aP020;fm_@030<;2`P36a/H0a/K600<0a/K61@2m_Kd50<K6aP<0_Kfm0P36a/H00`32
`/80_Kfm0;fm_@020;fm_@<0a/K60P2m_Kd30<K6aP<0_Kfm0P36a/H20;fm_@030<;2`P36a/H0a/K6
0080a/K600<0`/;20;fm_@2m_Kd00`2m_Kd50<K6aP80_Kfm00<0`/;20<K6aP36a/H01@2m_Kd00`32
`/80a/K60<K6aP020;fm_@<0a/K60P2m_Kd30<K6aP80_Kfm00<0`/;20<K6aP36a/H00P36a/H00`32
`/80_Kfm0;fm_@020;fm_@030<;2`P36a/H0a/K600<0a/K60P2m_Kd00`32`/80a/K60<K6aP050;fm
_@<0a/K60P2m_Kd30<K6aP80_Kfm0P36a/H00`32`/80_Kfm0;fm_@050<K6aP030<;2`P2m_Kd0_Kfm
0080_Kfm00<0`/;20<K6aP36a/H00P36a/H01032`/80_Kfm0;fm_@32`/820<K6aPD0_Kfm0P36a/H3
0;fm_@<0a/K60P2m_Kd20<K6aP030<;2`P2m_Kd0_Kfm00D0a/K6203oool8ooooo`001_ooooom0?oo
o`Sooooo0006ooooood0oooo2?ooool000Koooooo@3oool8ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<ooooo`00ooooool<
ooooo`00ooooool<ooooo`00ooooool<ooooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{89, 378.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 9.1 The BasicInput palette", "Caption",
  CellTags->"Fig. 9.1"],

Cell[TextData[{
  "\nFor example, the degree symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\[Degree]\)]],
  " can be used to replace the symbol ",
  StyleBox["Degree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in an expression, as in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"Cos", "[", 
            RowBox[{"45", " ", 
              FormBox["\[Degree]",
                "TraditionalForm"]}], "]"}],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tVariables can also be given overbars, tildes, or hats using the \
palettes.  For instance, the variable ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["x",
              FontSlant->"Plain"], "^"],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " was created by typing ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "  and then applying the button at the bottom ",
  "right-hand",
  " side of the basic input palette.  If you need to clear the value of this \
variable, you must type ",
  StyleBox["Remove[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rather than ",
  StyleBox["Remove[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["x",
            FontSlant->"Plain"], "^"], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["].",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "\tSymbols with subscripts such as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\_a\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can also be defined. Superscripts as in ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\^a\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " (almost) always mean ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " to the power ",
  Cell[BoxData[
      FormBox[
        StyleBox["a",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", so they should not be used to name variables. Two exceptions are ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x\^*\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[Dagger]"], TraditionalForm]]],
  ". In this book we use the symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^*\)\)]],
  " in the text to mean the complex conjugate of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tHowever, these types of symbols should be used with care. For instance, \
if we define ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x = 1\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = 1\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.33"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "and then attempt to use a different variable ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["x",
              FontSlant->"Plain"], "^"],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " in a calculation, we receive a rude shock:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(y\  = \ x\&^\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.34"],

Cell[BoxData[
    \(1\&^\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " in ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["x",
              FontSlant->"Plain"], "^"],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " has been replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " because we previously defined ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x = 1\),
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". Because of naming conflicts like this, complicated symbols with hats or \
subscripts should probably be avoided by beginning users."
}], "Text"],

Cell[TextData[{
  "\tMany of the symbols on the palette can also be created using keystrokes. \
For example, Greek letters can be created using the escape key (Esc): Esc ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " Esc creates ",
  StyleBox["\[Alpha]",
    FontFamily->"Symbol"],
  ", Esc ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " Esc creates ",
  StyleBox["\[Beta]",
    FontFamily->"Symbol"],
  ", etc. Keyboard equivalents can be found by placing your cursor over the \
symbol in question in several of the palettes, including the ",
  "CompleteCharacters",
  " and  ",
  "BasicTypesetting",
  " palettes (but not BasicInput). The keyboard equivalent appears at the \
bottom of the palette."
}], "Text",
  CellTags->"i:11"],

Cell["\<\
\tIntrinsic functions can also be accessed from the palettes.  For \
example, the square root of an expression can be taken by highlighting the \
expression with the mouse, then clicking the square root symbol on the \
BasicInput palette. 
\tTo take a power of an expression, highlight the expression with the mouse,  \
click the power button (top left corner of the BasicInput palette) and  then \
key the power. \
\>", "Text"],

Cell["\<\
\tThe other intrinsic functions available on this and other \
palettes, such as sums, integrals, and derivatives, will be discussed in \
later sections of this chapter.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.5 Lists, Vectors and Matrices", "Subtitle",
  CellTags->{"Sec. 9.5", "c:16"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["9.5.1 Defining Lists, Vectors, and Matrices", "Subsubtitle",
  CellTags->"c:17"],

Cell[TextData[{
  "It is often useful to manipulate more than one number at the same time. To \
group numbers or variables or expressions together, use a ",
  StyleBox["list",
    FontSlant->"Italic"],
  ". For example, the following defines a list of four integers and names the \
list ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:26"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\  = \ {\(-1\), 4, 2, 6}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.35"],

Cell[BoxData[
    \({\(-1\), 4, 2, 6}\)], "Output"]
}, Open  ]],

Cell["\<\
Note that when typing the list, one must use curly brackets {}. \
\
\>", "Text"],

Cell[TextData[{
  "This list is what one would call an \"array\" in a standard computer \
language like Fortran or C. In physics, this list might represent a \
four-dimensional vector. We use boldface to refer to vectors in the text, \
such as the vector ",
  StyleBox["a",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "that ",
  "corresponds to the",
  StyleBox[" Mathematica ",
    FontSlant->"Italic"],
  "list ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe dimension of a list is the number of elements in the list (the ",
  StyleBox["length",
    FontSlant->"Italic"],
  " of the list). In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", there is an intrinsic function called ",
  StyleBox["Length",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that one can use to determine the dimension:"
}], "Text",
  CellTags->"i:27"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[a]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.36"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell["Here's another  list:  ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\  = \ {x, x + 2  y, Sqrt[2], 15.4}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.37"],

Cell[BoxData[
    \({x, x + 2\ y, \@2, 15.4`}\)], "Output"]
}, Open  ]],

Cell["\<\
As you can see, the elements of a list don't have to be the same \
type of object: they can be mixtures of numbers, variables, expressions, or \
anything else you want.  For example, an element of a list can be another \
list:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c\  = \ {2, a}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.38"],

Cell[BoxData[
    \({2, {\(-1\), 4, 2, 6}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If every element of a list is another list of the same dimension, then we \
have made a matrix. For example, since ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are both of dimension 4, the object"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d = {a, b}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.39"],

Cell[BoxData[
    \({{\(-1\), 4, 2, 6}, {x, x + 2\ y, \@2, 15.4`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "is a matrix with two rows and four columns. To display this matrix in the \
standard way, use the intrinsic function ",
  StyleBox["MatrixForm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:28"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[d]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.40"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "4", "2", "6"},
            {"x", \(x + 2\ y\), \(\@2\), "15.4`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tIt is sometimes necessary to refer to particular elements of a list. For \
this ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  "uses ",
  "double square brackets, ",
  StyleBox["[[ ]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, the second element of ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be referred to as  ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["[[2]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Elements of a list can also be changed this way. For example,"
}], "Text",
  CellTags->"i:29"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b[\([1]\)]\  = \ \(-10\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.41"],

Cell[BoxData[
    \(\(-10\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "changed the first element of ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to -10, as we can see by asking for ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[":",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.42"],

Cell[BoxData[
    \({\(-10\), x + 2\ y, \@2, 15.4`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the text, elements of a vector are often also referred to using \
subscript notation. For instance, the ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            StyleBox["i",
              FontSlant->"Italic"], "th"}]], TraditionalForm]]],
  " element of a vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["a",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " may be written as ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ", or as ",
  StyleBox["a",
    FontWeight->"Bold"],
  "[[",
  StyleBox["i",
    FontSlant->"Italic"],
  "]]."
}], "Text"],

Cell[TextData[{
  "\t In order to refer to elements of a matrix, use row/column notation in \
the square brackets. For example ",
  StyleBox["d[[1,3]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the element of ",
  StyleBox["d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the first row, third column :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d[\([1, 3]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.43"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One can also think of this reference in terms of nested lists.  If the ",
  StyleBox["i",
    FontSlant->"Italic"],
  "th element of list ",
  StyleBox["c",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also a list, then the ",
  StyleBox["j",
    FontSlant->"Italic"],
  "th element of ",
  StyleBox["that",
    FontSlant->"Italic"],
  " list can be picked out using the notation ",
  StyleBox["c[[i,j]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or the equivalent notation ",
  StyleBox["c[[i]][[j]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " .  If ",
  StyleBox["this",
    FontSlant->"Italic"],
  " element is also a list, we can pick out the ",
  StyleBox["k",
    FontSlant->"Italic"],
  "th element of ",
  StyleBox["that",
    FontSlant->"Italic"],
  " list using ",
  StyleBox["c[[i,j,k]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["c[[i]][[j]][[k]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on. "
}], "Text"],

Cell[TextData[{
  "\tFor example, the second element of  ",
  StyleBox["c",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Courier"],
  StyleBox["= {2,{-1,4,2,6}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the list ",
  StyleBox["{-1,4,2,6}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and we can choose the fourth element  from that list by asking for ",
  StyleBox["c[[2,4]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or equivalently "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(c[\([2]\)]\)[\([4]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.44"],

Cell[BoxData[
    \(6\)], "Output"]
}, Open  ]],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table\ 9  .7\ Some\ Definitions\ Involving\ Lists, \ 
              Vectors\ and\ Matrices\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {Cell[TextData[StyleBox["{a,b,c}",
                    FontWeight->"Bold"]]], 
                  RowBox[{\(A\ list\), ",", 
                    RowBox[{"or", " ", "the", " ", "vector", " ", 
                      RowBox[{"(", 
                        StyleBox[\(a, b, c\),
                          FontSlant->"Italic"], ")"}]}]}]},
                {Cell[TextData[StyleBox["{{a,b,c},{d,e,f}}",
                    FontWeight->"Bold"]]], \(A\ 2 - by - \ 
                    3\ matrix\ \((2\ rows, 3\ columns)\)\)},
                {
                  RowBox[{
                    StyleBox[\(list[\([i]\)]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "\[IndentingNewLine]"}], 
                  RowBox[{"The", " ", 
                    StyleBox[
                      RowBox[{
                        StyleBox["i",
                          FontSlant->"Italic"], "th"}]], " ", "element", " ", 
                    "of", " ", 
                    StyleBox["list",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}]},
                {
                  RowBox[{
                    StyleBox[\(matrix[\([i, j]\)]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "\[IndentingNewLine]", "or", 
                    "\[IndentingNewLine]", 
                    StyleBox[\(\(matrix[\([i]\)]\)[\([j]\)]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "\[IndentingNewLine]"}], 
                  RowBox[{"\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{
                      "The", " ", "element", " ", "in", " ", "the", " ", 
                        StyleBox[
                          RowBox[{
                            StyleBox["i",
                              FontSlant->"Italic"], "th"}]], " ", "row"}], 
                      ",", 
                      RowBox[{
                        StyleBox[
                          RowBox[{
                            StyleBox["j",
                              FontSlant->"Italic"], "th"}]], " ", "column", 
                        " ", "of", " ", 
                        StyleBox["matrix",
                          FontFamily->"Courier",
                          FontWeight->"Bold"]}]}]}]},
                {
                  StyleBox[\(MatrixForm[matrix]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Display", " ", "the", " ", 
                    StyleBox["matrix",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "in", " ", "standard", 
                    " ", \(row/column\), " ", "format"}]}
                },
              ColumnSpacings->3.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.5.2 Vector and Matrix Operations", "Subsubtitle",
  CellTags->{"i:98", "c:18"}],

Cell[CellGroupData[{

Cell["Vector Addition", "Section",
  CellTags->"c:19"],

Cell[TextData[{
  "One way that vectors are used in the physical sciences is to denote \
displacements. For example, a displacement of 3 meters in the x direction and \
2 meters in the y direction can be written as the vector (3,2) . Say a \
displacement ",
  StyleBox["z",
    FontWeight->"Bold"],
  " consists of the sum of three separate displacements ",
  StyleBox["u ",
    FontWeight->"Bold"],
  "= (3,2), ",
  StyleBox["v ",
    FontWeight->"Bold"],
  "= (-3,3), and ",
  StyleBox["w ",
    FontWeight->"Bold"],
  "= (2,-1), we would write this mathematically as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "=", " ", 
          RowBox[{
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"], " ", "+", 
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], " ", "+", " ", 
            StyleBox["w",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". Pictorially, this sum looks like Fig. ",
  ButtonBox["9.2",
    ButtonData:>"Fig. 9.2",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009U0003Gb000`400?l00000o`00003oo`3ooooo
0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo
003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0
ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool0
0?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3o
oomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00
o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?oo
ofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o
0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0oooo
I`3oool00?l0ooooo`3ooomW0?ooo`00YP3oool01P3no_h0oooo0?ooo`3no_h0oooo0?knoP80oooo
00<0o_kn0?ooo`3oool0f@3oool00`3no_h0oooo0?ooo`3H0?ooo`00603oool01`20P80000000000
00010@4000000820P030`<00Q`3oool20820P0D000000P20P81S0?ooo`030820P0000000000000H0
000000<00@410000000000000`00001S0?ooo`030820P010@40000000080000000@00@4100000010
@400OgmoL@3oool01020P800000000000020P81S0?ooo`005`3oool2000000<0oooo0`00002:0?oo
o`<00000J03oool>00000680oooo00D0000000410@00000000000820P0030?ooo`80000000<0P820
0?ooo`3oool0K@3oool01020P800000000000020P81S0?ooo`005P3oool2000000030820P03oool0
oooo00<0oooo0P0000250?ooo`070?knoP3oool0oooo0?ooo`010@40000000410@030?ooo`030?kn
oP3oool0oooo0680oooo00<0P8200000000000002`00001S0?ooo`8000000P3oool0103no_h0oooo
0?ooo`3oool2000006l0oooo00@0P820000000000000P820H`3oool001D0oooo00<0P82000000001
0@401P3oool00`20P8000000000000280?ooo`<00000J@3oool00`20P80000000<30`0080?ooo`03
0820P0000000P82006/0oooo0P0000000`20P800oooo0?ooo`1[0?ooo`040820P000000000000820
P6<0oooo000D0?ooo`040?knoP00000000000?knoPD0oooo00D0o_kn0?ooo`00000000000820P027
0?ooo`<00000J`3oool01@000000oooo0?ooo`3oool0o_kn00H0oooo00<000000?ooo`3oool0HP3o
ool00`3no_h0oooo0?ooo`020?ooo`030?knoP3oool0P82000800000K@3oool01020P80000000000
0020P81S0?ooo`005@3oool2000000H0oooo00D0o_kn0?ooo`00000000000820P0270?ooo`<00000
J`3oool00`20P80000000?ooo`1b0?ooo`030?knoP3oool0P82000800000G`3oool20?knoPX0oooo
00L0o_kn0?ooo`20P800000000410@20P800o_kn0680oooo000D0?ooo`<00000203oool3000008L0
oooo0`00001/0?ooo`030820P0000000`<3007<0oooo00@0P820000000000000P820HP3oool:0820
P0040410@000000000000410@080P82000<0`<300?ooo`3oool0GP3oool001@0oooo00<000000041
0@3oool00P3oool01@3no_h0oooo0?ooo`3oool0o_kn0080oooo0P0000270?ooo`<00000KP3oool0
0`000000oooo0?ooo`1a0?ooo`040820P000000000000820P5h0oooo00@0o_kn0?ooo`3oool0oooo
400000000`20P800oooo0?ooo`1N0?ooo`004`3oool3000000X0oooo0`0000260?ooo`<00000KP3o
ool00`20P80000000?ooo`1a0?ooo`<0000000<0P8200?ooo`3oool0H03oool30000000300410@00
0000000000X0000000<0P8200?ooo`3oool0GP3oool001<0oooo0`00000:0?ooo`<00000QP3oool3
000006h0oooo00@0`<30000000000000`<30K`3oool01@20P8000000000000000000P82006<0oooo
00<000000?ooo`3oool01P3oool01020P800000000000020P81S0?ooo`004`3oool3000000X0oooo
0`0000260?ooo`<00000L03oool00`000000P8200?ooo`030?ooo`030?knoP3oool0oooo06L0oooo
1@00001T0?ooo`030820P0000000oooo00H0oooo00@0P820000000000000P820H`3oool001<0oooo
00<00@410000000000000`3oool00`3no_h0oooo0?ooo`040?ooo`0300410@000000000008H0oooo
0`00001a0?ooo`030000003oool0oooo06/0oooo1P00001U0?ooo`0300410@000000oooo00D0oooo
00@0P820000000000000P820H`3oool001<0oooo0P0000000`010@40oooo0?ooo`080?ooo`<00000
QP3oool300000740oooo00<0@4100000003oool0J03oool00`30`<00P82000000002000000030041
0@000000P82006H0oooo00<0P82000000020P8001@3oool01020P800000000000020P81S0?ooo`00
4`3oool3000000X0oooo0`0000260?ooo`<00000L@3oool00`20P80000000000001[0?ooo`040820
P000000000000820P6L0oooo00<0o_kn0?ooo`0000001@3oool01020P800000000000020P81S0?oo
o`004`3oool3000000X0oooo0`0000020?ooo`030?knoP3oool0oooo0840oooo0`00001a0?ooo`03
0820P0000000000006T0oooo00@0o_kn0?ooo`3oool00000J`3oool00`20P80000000?ooo`030?oo
o`040820P000000000000820P6<0oooo000C0?ooo`<000002P3oool3000008H0oooo0`00001b0?oo
o`80000000<0P8200?ooo`3oool0JP3oool00`000000`<300?ooo`1X0?ooo`030<30`0000000P820
00<0oooo00@0P820000000000000P820H`3oool00100oooo00@0o_kn0?ooo`3oool0oooo0`000009
0?ooo`800000Q`3oool300000780oooo00<00@41000000000000K@3oool01@000000oooo0?ooo`3o
ool0o_kn06L0oooo00D000000820P03oool0oooo0820P002000000030820P03oool0oooo0640oooo
000D0?ooo`<000002@3oool2000008L0oooo0`00001W0?ooo`030000003oool0oooo00P0oooo0P00
00000`010@40oooo0?ooo`1S0?ooo`80o_kn1P3oool2000006H0oooo00@0o_kn0?ooo`3oool0oooo
0P0000020?ooo`040820P000000000000820P6<0oooo000D0?ooo`0307moO`010@40000000P0oooo
00<0000000410@10@400Q`3oool3000006L0oooo00<000000820P03oool01`3oool01030`<000000
00000000001]0?ooo`<00000JP3oool01010@400P8200?ooo`20P80200410@030820P03oool0oooo
0640oooo000E0?ooo`8000000`3oool00`3no_h0oooo0?ooo`020?ooo`03000000010@40P82008L0
oooo00<0000000410@000000J03oool00`000000oooo0?ooo`060?ooo`040820P000000000000041
0F<0oooo00<000000?ooo`3oool01`3oool3000006/0oooo00<0000000410@20P8000P0000000`20
P800oooo0?ooo`1Q0?ooo`005@3oool00`20P8000000000000060?ooo`030820P0000000000008P0
oooo0`00001X0?ooo`8000001`3oool3000000030820P03oool0oooo0680oooo00<0P8200?ooo`3o
ool01@3oool4000006P0oooo00<0o_kn0?ooo`3oool00P0000001020P800000000000020P81S0?oo
o`005@3oool01030`<0000000000002o_kl50?ooo`030410@0000000P82008@0oooo0P20P8000`3o
ool0P82000000002000006P0oooo00@0P820000000000000@4100`20P805000000030<30`03oool0
oooo0680oooo00<0@4100820P020P8000`3oool00`30`<000000000000020000000307moO`3oool0
oooo06X0oooo00D0P82000000000000000000820P01S0?ooo`005`3oool3000000<0oooo00<00@41
0000003oool0QP3oool6000006T0oooo2P0000020?ooo`030?knoP3oool0oooo0680oooo2@00001_
0?ooo`040820P000000000000820P6<0oooo000H0?ooo`H0000000<0P8200?ooo`3oool0Q`3oool4
000006X0oooo2000001Y0?ooo`L0000000<0P8200?ooo`3oool0K@3oool01020P8000@4100000020
P81S0?ooo`006@3oool4000008d0oooo00<0P8200000003oool0J`3oool5000006/0oooo00<0P820
0000000000000P00001b0?ooo`80000000<0P8200?ooo`3oool0H@3oool00?l0ooooo`3ooomW0?oo
o`00o`3ooon80?ooo`030?knoP3oool0oooo0=/0oooo003o0?ooohP0oooo00@0o_kn0?ooo`3oool0
o_knL@3oool00`3no_h0oooo0?ooo`1V0?ooo`00[03oool00`3no_h0oooo0?ooo`3o0?oookL0oooo
003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0
oooo403oool2000000030820P03oool0oooo0580oooo003o0?ooool0oooo3`3oool00`20P8000000
00000002000000030?knoP3oool0oooo0500oooo003o0?ooool0oooo3`3oool00`20P80000000000
00030000000400410@000000P8200820P2X0oooo00@0`<30000000000000@4101@3oool01030`<00
0@4100000010@40G0?ooo`00o`3ooooo0?ooo`l0oooo3000000X0?ooo`030820P000000000000080
00000`3oool00`3no_h0000000000003000001H0oooo003o0?ooool0oooo3`3oool>000002H0oooo
00@0P820000000000000oooo0P0000030?ooo`<000000P3oool00`000000oooo0?ooo`0C0?ooo`00
o`3ooooo0?ooo`l0oooo00<00@41000000000000300000001010@400P8200820P030`<0V0?ooo`04
00000030`<00oooo0820P0<000000`3oool00`10@400oooo0?ooo`0B0?ooo`00o`3ooooo0?ooo`d0
oooo00<0o_kn0?ooo`000000500000000`20P800oooo0?ooo`040?ooo`030?knoP3oool0oooo01T0
oooo00@0o_kn0?ooo`000000oooo0`0000050?ooo`040?knoP3oool0oooo0?knoQ00oooo003o0?oo
ool0oooo3P3oool00`0000000@410000000F000001X0oooo00<0o_kn0?ooo`3oool01@3oool00`20
P800o_kn00000002000001T0oooo003o0?ooool0oooo3P3oool@0000000300410@000000000000L0
00000P20P8000`30`<00oooo0?ooo`0M0?ooo`@000006@3oool003P0oooo00<0o_kn0?ooo`3oool0
o`3ooooB0?oooal000007@3oool01@0000000@410000003oool0o_kn01P0oooo000j0?ooo`<00000
o`3oooo@0?ooob4000006`3oool3000001X0oooo000j0?ooo`D000000P010@7o00000>`0000000@0
0@41000000000000P8205`3oool01020P800000000410@00000J0?ooo`00>P3ooooo00000?T00000
5@3oool01020P80000000000000000030?ooo`030?knoP3oool0oooo01@0oooo000j0?ooool00000
mP0000000`20P800oooo0?ooo`0E0?ooo`030820P00000000000008000006@3oool003X0oooo0P00
00001P010@400000000000000000@4100820P6P0oooo00@0P820000000000000P820K@3oool00`00
00000@4100410@1^0?ooo`<00000KP3oool3000000`0oooo7`0000020820P1X0oooo0`000000103o
ool0P82000000030`<0G0?ooo`00>P3oool60000000300410@000000000006L0oooo00@0P8200000
00000000P820K@3oool3000006h0oooo0`00001^0?ooo`<00000303ooolC0000000400410@000000
000000410@D0000000<0P8200?ooo`3oool0703oool300000080oooo0P0000020?ooo`8000004`3o
ool003X0oooo1P00000010010@4000000000000000040?ooo`030?knoP3oool0oooo05l0oooo00@0
P820000000000000P820K@3oool3000006h0oooo0`00001^0?ooo`<00000303oool=000000030041
0@000000000000X00000803oool00`0000000@41000000040?ooo`H000004P3oool003X0oooo0`00
000010010@40000000000020P804000000030820P030`<00oooo0680oooo00@0P820000000000000
P820K@3oool3000006h0oooo0`00001^0?ooo`<00000303ooolD000000800@410P20P80O0?ooo`80
P82000@00@410000000000000000103oool00`30`<0000000000000300000180oooo000j0?ooo`H0
000000<0P8200?ooo`3oool00P0000000`010@4000000?ooo`1R0?ooo`040820P000000000000820
P6d0oooo0`00001^0?ooo`<00000KP3oool3000000d0oooo4`00000U0?ooo`80000000<00@410?oo
o`3oool01P3oool2000001<0oooo000j0?ooo`0400410@00000000000820P0<000000P3oool01P20
P8000@410000000000000@4100000640oooo00@0P820000000000000P820K@3oool3000006h0oooo
0`00001^0?ooo`<000003@3ooolA00000080oooo00<0o_kn0?ooo`3oool09@3oool00`3no_h0oooo
0?ooo`0J0?ooo`00>P3oool3000000050<30`0000000000000410@1oOgl00`3oool01P20P8000000
000000000000@4100820P5l0oooo00@0P820000000000000P820K@3oool3000006h0oooo0`00001^
0?ooo`<000003@3oool<000000030410@020P800P82004T0oooo000j0?ooo`<0000000D0oooo0000
00000000000000410@050?ooo`D00000GP3oool01020P800000000000020P81]0?ooo`<00000KP3o
ool3000006h0oooo0`00000=0?ooo`030820P0000000000000L00000CP3oool003X0oooo0`000002
0?ooo`@000001@3oool5000005d0oooo00@0P820000000000000P820K@3oool3000006h0oooo0`00
001^0?ooo`<000003@3oool00`20P8000000000000030000000300410@000000oooo04l0oooo000j
0?ooo`<000000P3oool01@20P800000000410@000000`<3000D0oooo00<0`<300000000000000P00
00000`20P800_kno0?ooo`1I0?ooo`040820P000000000000820P6d0oooo0`00001^0?ooo`<00000
KP3oool3000000h0oooo0P0000000`10@400P8200820P01B0?ooo`00>P3oool300000080oooo00D0
o_kn00000000000000000820P0080?ooo`@00000FP3oool01020P800000000000020P81]0?ooo`<0
0000KP3oool3000006h0oooo0`00001U0?ooo`00>P3oool3000000<0oooo00@0P820000000000000
00001`3oool00`3no_h0P82000000004000005P0oooo00@0P820000000000000P820K@3oool30000
06h0oooo0`00001^0?ooo`<000004P3oool00`3no_h0oooo0?ooo`1@0?ooo`00>P3oool3000000<0
oooo00<0`<300000000000000P0000090?ooo`060820P0000000000000000010@400P820EP3oool0
1020P800000000000020P81]0?ooo`<00000KP3oool3000006h0oooo0`00001U0?ooo`00>P3oool3
000000D0oooo1000000:0?ooo`80000000<00@41000000000000E@3oool01020P800000000000020
P81]0?ooo`<00000KP3oool3000006h0oooo0`00001U0?ooo`00>P3oool3000000D0oooo00@00000
00410@00000000000P3oool00`3no_h0oooo0?ooo`060?ooo`D00000103oool00`3no_h0oooo0?oo
o`1=0?ooo`040820P000000000000820P6d0oooo0`00001^0?ooo`<00000KP3oool3000006D0oooo
000j0?ooo`<000001P3oool010010@40000000000020P80;0?ooo`070<30`0000000000000410@00
0000P8200<30`01A0?ooo`040820P000000000000820P6d0oooo0`00001^0?ooo`<00000KP3oool3
000006D0oooo000j0?ooo`<000001P3oool01020P800000000000000000>0?ooo`0400410@000000
0@4100000540oooo00@0P820000000000000P820K@3oool3000006h0oooo0`00001^0?ooo`<00000
I@3oool003X0oooo0`0000060?ooo`040820P00000000000000000h0oooo00H0P82000410@000000
000000410@00001?0?ooo`040820P000000000000820P6d0oooo0`00001^0?ooo`<00000KP3oool3
000006D0oooo000j0?ooo`<000001`3oool4000000l0oooo00H0P82000000000000000000410@020
P81=0?ooo`040820P000000000000820P6d0oooo0`00001^0?ooo`<00000KP3oool3000006D0oooo
000j0?ooo`<00000203oool400000100oooo1@00001<0?ooo`040820P000000000000820P6d0oooo
0`00001^0?ooo`<00000KP3oool3000006D0oooo000j0?ooo`<00000203oool400000140oooo00<0
000000410@0000000P00001;0?ooo`050820P000000000000820P03no_h0K03oool3000006h0oooo
0`00001^0?ooo`<00000I@3oool003X0oooo0`0000090?ooo`04000000010@4000000820P140oooo
00<0`<300000000000000P0000000`20P800_kno0?ooo`3o0?ooool0oooo103oool003X0oooo0`00
00090?ooo`040820P00000000000000001@0oooo1000003o0?ooool0oooo1@3oool003X0oooo0`00
00090?ooo`040820P0010@400000000001<0oooo00<0o_kn0820P00000001000003o0?ooool0oooo
0`3oool003X0oooo0`00000:0?ooo`0400410@0000000000000001D0oooo00H0P820000000000000
00000410@020P82h0?ooo`030?knoP3oool0oooo0?l0ooooA@3oool003X0oooo0`00000;0?ooo`@0
00005P3oool20000000300410@00000000000?l0ooooo`3oool003X0oooo0`00000;0?ooo`@00000
5`3oool5000000@0oooo00<0o_kn0?ooo`3oool0o`3oooog0?ooo`00>P3oool3000000`0oooo0`00
00000`10@400oooo0?ooo`0E0?ooo`070<30`0000000000000410@000000P8200<30`03o0?oooo/0
oooo000j0?ooo`<00000303oool01020P800000000000000000J0?ooo`0400410@0000000@410000
0?l0oooon`3oool003X0oooo0`00000=0?ooo`@000006@3oool01P20P8000@410000000000000@41
00000?l0oooon@3oool003X0oooo0`00000=0?ooo`050820P0010@40000000000020P8006P3oool0
1P20P8000000000000000000@4100820P?l0oooom`3oool003X0oooo0`00000>0?ooo`@00000703o
ool500000?l0oooomP3oool003X0oooo0`00000?0?ooo`<0000000<0P8200?ooo`3oool06P3oool0
0`0000000@410000000200000?l0oooom@3oool003X0oooo0`00000?0?ooo`040451@@0000000000
0410@1d0oooo00<0`<300000000000000P0000000`20P800_kno0?ooo`3o0?oooo40oooo000j0?oo
o`<000003`3oool01020P800000000000000000P0?ooo`@00000o`3oooob0?ooo`00>P3oool30000
0100oooo100000020?ooo`030?knoP3oool0oooo01T0oooo00<0o_kn0820P00000001000003o0?oo
oo00oooo000j0?ooo`<00000403oool01@20P8000000000000000000P8200200oooo00H0P8200000
0000000000000410@020P83o0?ooonh0oooo000j0?ooo`<000004@3oool400000280oooo0P000000
0`010@4000000000003o0?ooond0oooo000j0?ooo`<000003P3oool0103no_h0oooo0?ooo`3oool3
000000030820P03oool0oooo0200oooo1@0000040?ooo`030?knoP3oool0oooo0?l0ooooi@3oool0
03X0oooo0`00000B0?ooo`040410@000000000000410@2<0oooo00L0`<300000000000000@410000
0020P800`<300?l0ooooj@3oool003X0oooo0`00000B0?ooo`040820P00000000000000002H0oooo
00@00@41000000010@400000o`3ooooY0?ooo`00>P3oool3000001<0oooo00@00@41000000000000
00009@3oool01P20P8000@410000000000000@4100000?l0ooooi`3oool003X0oooo0`00000C0?oo
o`030820P00000000000008000009P3oool01P20P8000000000000000000@4100820P?l0ooooi@3o
ool003X0oooo0`00000E0?ooo`<0000000<0P8200?ooo`3oool09@3oool500000?l0ooooi03oool0
03X0oooo0`00000E0?ooo`<0000000<0P8200?ooo`3oool09P3oool00`0000000@41000000020000
0?l0ooooh`3oool003X0oooo0`00000E0?ooo`040820P0000000000000410BT0oooo00<0`<300000
000000000P0000000`20P800_kno0?ooo`3o0?oooml0oooo000j0?ooo`<000005P3oool4000002/0
oooo1000003o0?ooon00oooo000j0?ooo`<000005P3oool0100000000@4100000000000Z0?ooo`03
0?knoP20P800000000@00000o`3ooooN0?ooo`00>P3oool3000001L0oooo1000000/0?ooo`@00000
00<0P8200?ooo`3oool0o`3ooooK0?ooo`00>P3oool3000001L0oooo00D0P8200000000000000000
0<30`00/0?ooo`060820P0000000000000410@000000P820o`3ooooK0?ooo`00>P3oool3000001P0
oooo0`0000000`20P800oooo0?ooo`0/0?ooo`D0000000D0P8200?ooo`3oool0oooo0?knoP3o0?oo
omD0oooo000j0?ooo`<00000603oool01020P8000000000000010@4_0?ooo`050820P00000000000
00410@000000o`3ooooI0?ooo`00>P3oool3000001P0oooo00D0`<3000000000000000000820P00_
0?ooo`80P82000D00@41000000010@4000000<30`03o0?ooomH0oooo000j0?ooo`<000006@3oool0
10010@40000000000000000b0?ooo`0500410@000000000000410@000000o`3ooooE0?ooo`00>P3o
ool3000001X0oooo1000000_0?ooo`030?knoP3oool0oooo00D00000o`3ooooD0?ooo`00>P3oool3
000001X0oooo00D0P82000410@00000000000<30`00b0?ooo`030820P010@40000000080000000<0
P8200?ooo`3oool0o`3oooo@0?ooo`00>P3oool3000001/0oooo0`0000000`20P800oooo0?ooo`0b
0?ooo`03000000010@4000000080000000<0P8200?ooo`3oool0o`3oooo>0?ooo`00>P3oool30000
01/0oooo00@0P82000410@0000000000<P3oool0103no_h0oooo0?ooo`3oool4000000030?ooo`3n
o_h0oooo0?l0ooooc@3oool003X0oooo0`00000K0?ooo`030<30`0000000000000800000=@3oool0
0`30`<00P82000000003000000030<30`03oool0oooo0?l0oooob`3oool003X0oooo0`00000M0?oo
o`04000000010@400000000003D0oooo00<0o_kn0?ooo`0000001000003o0?oool`0oooo000j0?oo
o`<000006P3oool00`3no_h0oooo0?ooo`04000003P0oooo1@00003o0?oool/0oooo000j0?ooo`<0
00007P3oool3000000030820P03oool0oooo03H0oooo00H0P8200410@00000000@4100000020P83o
0?ooolT0oooo000j0?ooo`<000007P3oool01020P800000000000000000j0?ooo`D0000000D0P820
0?ooo`3oool0oooo0?knoP3o0?oool<0oooo000j0?ooo`<000007P3oool01020P800000000000000
000l0?ooo`80000000<00@410000003oool0o`3oooo60?ooo`00>P3oool3000001l0oooo1000000k
0?ooo`070<30`020P8000@41000000010@4000000<30`03o0?oool@0oooo000j0?ooo`<00000803o
ool20000000300410@000000oooo03`0oooo00D00@410000000000000@410000003o0?oool<0oooo
000j0?ooo`<00000803oool4000003/0oooo00<0o_kn0?ooo`3oool01@00003o0?oool80oooo000j
0?ooo`<000008@3oool3000000030820P03oool0oooo03`0oooo00<0P8200410@00000000P000000
0`20P800oooo0?ooo`3o0?oookh0oooo000j0?ooo`<000008@3oool01020P8000000000000000010
0?ooo`03000000010@4000000080000000<0P8200?ooo`3oool0o`3ooonl0?ooo`00>P3oool30000
0240oooo00@0Ogmo0000000000000000?P3oool0103no_h0oooo0?ooo`3oool4000000030?ooo`3n
o_h0oooo0?l0oooo^`3oool003X0oooo0`00000R0?ooo`80000000<00@410000003oool0@03oool0
0`30`<00P82000000003000000030<30`03oool0oooo0?l0oooo^@3oool003X0oooo0`00000S0?oo
o`04000000010@40000000000440oooo00<0o_kn0?ooo`0000001000003o0?oookX0oooo000j0?oo
o`<000008`3oool01@010@400000000000000000P82004<0oooo1@00003o0?oookT0oooo000j0?oo
o`<00000903oool01010@400000000000010@4140?ooo`060820P010@400000000410@000000P820
o`3ooong0?ooo`00>P3oool3000002@0oooo00@0P8200000000000000000AP3oool5000000050820
P03oool0oooo0?ooo`3no_h0o`3ooona0?ooo`00>P3oool3000001l0oooo00<0o_kn0?ooo`3oool0
0`3oool20000000300410@000000oooo04H0oooo0P0000000`010@4000000?ooo`3o0?oook@0oooo
000j0?ooo`<000009@3oool01@20P800000000410@000000P82004H0oooo00L0`<300820P0010@40
000000410@000000`<300?l0oooo/P3oool003X0oooo0`00000R0?ooo`040?knoP3oool0oooo0?oo
o`@00000B@3oool01@010@400000000000010@4000000?l0oooo/@3oool003X0oooo0`00000W0?oo
o`<0000000<0P8200?ooo`3oool0A03oool00`3no_h0oooo0?ooo`0500000?l0oooo/03oool003X0
oooo0`00000W0?ooo`040410@000000000000410@4X0oooo00<0P8200410@00000000P0000000`20
P800oooo0?ooo`3o0?oooj`0oooo000j0?ooo`<000009`3oool01020P800000000000000001<0?oo
o`03000000010@4000000080000000<0P8200?ooo`3oool0o`3ooonZ0?ooo`00>P3oool3000002P0
oooo100000190?ooo`040?knoP3oool0oooo0?ooo`@0000000<0oooo0?knoP3oool0o`3ooonY0?oo
o`00>P3oool3000002P0oooo00D0P8200000000000000@410820P01<0?ooo`030<30`020P8000000
00<0000000<0`<300?ooo`3oool0o`3ooonW0?ooo`00>P3oool3000002T0oooo1000001=0?ooo`03
0?knoP3oool0000000@00000o`3ooonX0?ooo`00>P3oool3000002X0oooo00@0000000410@000000
P820C`3oool500000?l0ooooY`3oool003X0oooo0`00000Z0?ooo`040410@000000000000410@500
oooo00<0P8200410@00000000P0000000`20P800oooo0?ooo`3o0?oooj<0oooo000j0?ooo`<00000
:P3oool01020P800000000000000001B0?ooo`D0000000D0P8200?ooo`3oool0oooo0?knoP3o0?oo
oil0oooo000j0?ooo`<000009@3oool00`3no_h0oooo0?ooo`030?ooo`@00000D`3oool400000?l0
ooooX`3oool003X0oooo0`00000[0?ooo`030820P0000000000000800000DP3oool01`30`<00P820
0000000000000@4100000030`<00o`3ooonP0?ooo`00>P3oool3000002P0oooo00<0o_kn0?ooo`3o
ool00P3oool3000000030820P03oool0oooo04h0oooo00D0o_kn0?ooo`3oool0oooo00410@020000
000300410@000000oooo0?l0ooooWP3oool003X0oooo0`00000]0?ooo`<0000000<0P8200?ooo`3o
ool0D`3oool500000?l0ooooWP3oool003X0oooo0`00000]0?ooo`040820P00000000000000004l0
oooo00<0000000410@20P800103oool00`20P800@41000000002000000030820P03oool0oooo0?l0
ooooVP3oool003X0oooo0`00000^0?ooo`@00000C@3oool00`20P800000000000002000000030?kn
oP3oool0oooo0080oooo00<0000000410@0000000P0000000`20P800oooo0?ooo`3o0?oooiP0oooo
000j0?ooo`<00000;P3oool4000004d0oooo100000040?ooo`040?knoP3oool0oooo0?ooo`@00000
00<0oooo0?knoP3oool0o`3ooonG0?ooo`00>P3oool3000002l0oooo1000001;0?ooo`@0000000<0
P8200?ooo`3oool01P3oool00`30`<00P82000000003000000030<30`03oool0oooo0?l0ooooU@3o
ool003X0oooo0`00000`0?ooo`<0000000<0P8200?knoP3oool0A`3oool5000000X0oooo00<0o_kn
0?ooo`0000001000003o0?oooiH0oooo000j0?ooo`<00000<03oool3000000030820P03oool0oooo
04H0oooo00<0Ogmo000000010@400P00000>0?ooo`D00000o`3ooonE0?ooo`00>P3oool300000300
oooo00@0P8200000000000000000B03oool01010@400000000000010@40@0?ooo`060820P010@400
000000410@000000P820o`3ooonC0?ooo`006P3oool00`3no_h0oooo0?ooo`0M0?ooo`<00000<@3o
ool4000004D0oooo00<0o_kn0000000000000P00000C0?ooo`D0000000D0P8200?ooo`3oool0oooo
0?knoP0f0?ooo`040?knoP3oool0oooo0?kno_l0ooooD`3oool003X0oooo0`00000a0?ooo`@00000
A@3oool5000001D0oooo0P0000000`010@4000000?ooo`3o0?oooi00oooo000C0?ooo`T0P8207P3o
ool300000380oooo0P0000000`010@4000000?ooo`120?ooo`050<30`0000000000000000020P800
5P3oool01`30`<00P82000410@0000000@4100000030`<00<P3oool00`20P800@410000000020000
00070820P03oool0oooo0?ooo`000000@4100820P03o0?oooe00oooo000E0?ooo`030820P0000000
000000800000803oool3000003<0oooo00@0000000410@000000P820@P3oool3000000030820P03o
ool0o_kn01P0oooo00D00@410000000000000@410000000`0?ooo`P0000000@0P8200?ooo`000000
0@410P0000000`20P800oooo0?ooo`3o0?oood`0oooo000F0?ooo`<000008@3oool3000003<0oooo
100000110?ooo`@000006@3oool00`3no_h0oooo0?ooo`05000002l0oooo00@00@41000000000000
00000`3oool01@0000000@410?ooo`0000000@4100<0000000D0o_kn0?ooo`3oool0oooo0?knoP3o
0?ooodT0oooo000F0?ooo`80000000<00@410?ooo`3oool07`3oool300000380oooo00H0o_kn0<30
`00000000@4100000020P80o0?ooo`050820P0000000000000000020P8007@3oool00`20P800@410
00000002000000030820P03oool0oooo02X0oooo00@0P820000000000000@4101@3oool01@30`<00
00000000000000000@410?l0ooooD03oool001H0oooo0`00000Q0?ooo`<00000=03oool400000080
oooo00<0o_kn0?ooo`3oool0>@3oool01020P800000000000000000Q0?ooo`03000000010@400000
0080000000@0P8200?ooo`3oool0o_kn9`3oool01020P800000000000020P8070?ooo`<00000o`3o
oom@0?ooo`005P3oool300000240oooo0`00000e0?ooo`06000000010@4000000000003oool0o_kn
>`3oool010010@40000000000020P80O0?ooo`040?knoP3oool0oooo0?ooo`@0000000<0oooo0?kn
oP3oool09`3oool01020P800000000000020P8070?ooo`<00000o`3ooom@0?ooo`005P3oool30000
0240oooo0`00000e0?ooo`050820P0000000000000000030`<00>P3oool00`20P8000@4100000002
000000030<30`03oool0oooo0240oooo00<0`<300820P00000000`0000000`20P800oooo0?ooo`0U
0?ooo`040820P000000000000820P0L0oooo0`00003o0?oooe00oooo000F0?ooo`<000008@3oool3
000003H0oooo00@0000000410@000000P820>@3oool00`20P800000000000002000002H0oooo00<0
o_kn0?ooo`0000001000000V0?ooo`040820P000000000000820P0L0oooo0`00003o0?oooe00oooo
000F0?ooo`<000008@3oool3000003H0oooo00@0P8200000000000000000>@3oool4000002X0oooo
1@00000U0?ooo`040820P000000000000820P0L0oooo0`00003o0?oooe00oooo000F0?ooo`<00000
8@3oool3000001D0P8208@3oool01@30`<000000000000000000P82003H0oooo00<0P82000000000
00000P0000000`30`<00oooo0?ooo`0Y0?ooo`80P82000@0000000410@000000@4108`3oool01020
P800000000000020P8070?ooo`<00000o`3ooom@0?ooo`005P3oool300000240oooo6000000R0?oo
o`@00000=@3oool40000000300410@3oool0oooo02d0oooo00<0P8200000000000000`00000Q0?oo
o`040820P000000000000820P0L0oooo0`00003o0?oooe00oooo000F0?ooo`<000008@3ooolH0000
02<0oooo1000000c0?ooo`0300410@000000000000800000<P3oool20000000300410@000000P820
0200oooo00@0P820000000000000P8201`3oool300000?l0ooooD03oool001H0oooo0`00000Q0?oo
o`<000005@20P80S0?ooo`050820P0000000000000000030`<00<03oool00`30`<00000000000002
00410@030820P030`<00oooo0380oooo00H0P82000410@0000000@4100000020P80N0?ooo`040820
P000000000000820P0L0oooo0`00003o0?oooe00oooo000F0?ooo`<000008@3oool3000001@0oooo
00<0o_kn0?ooo`3oool08P3oool3000000030820P03oool0oooo02h0oooo100000000`3no_h0oooo
0?ooo`0e0?ooo`05000000010@400000000000010@407@3oool01020P800000000000020P8070?oo
o`<00000o`3ooom@0?ooo`005P3oool300000240oooo0`00000i0?ooo`040820P000000000000000
02l0oooo00D00@4100000000000000000820P00i0?ooo`030820P0000000000000800000703oool0
1020P800000000000020P8070?ooo`<00000o`3ooom@0?ooo`005P3oool300000240oooo0`00000i
0?ooo`040820P00000000000000002h0oooo1@0000000`3oool0o_kn0?ooo`0h0?ooo`D0000000<0
P8200?ooo`3oool0603oool01020P800000000000020P8070?ooo`<00000o`3ooom@0?ooo`005P3o
ool300000240oooo0`00000j0?ooo`@00000:`3oool01P20P800@4100000000000000@410820P3h0
oooo00@0@41000410@00000000000P20P80F0?ooo`80P8200`0000000`20P800oooo0?ooo`030?oo
o`050820P0000000000000410@000000o`3ooom@0?ooo`005P3oool300000240oooo0`00000k0?oo
o`@00000:03oool00`20P800000000000003000000030820P03oool0oooo03/0oooo00@0o_kn0?oo
o`3oool0oooo100000000`20P800o_kn0?ooo`0M0?ooo`030?knoP3oool0oooo0?l0ooooD`3oool0
01H0oooo0`00000Q0?ooo`<00000>`3oool4000000030820P03oool0oooo02D0oooo1@0000140?oo
o`D00000o`3ooomd0?ooo`005P3oool300000240oooo0`00000l0?ooo`040410@000000000000410
@2@0oooo00<0`<300000000000000`0000000`30`<00oooo0?ooo`140?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0o`3ooom`0?ooo`005P3oool300000240oooo0`00000k0?ooo`05
0?knoP1oOgl00000000000010@408`3oool5000004/0oooo00<0P8200000000000000P00003o0?oo
og40oooo000F0?ooo`<000008@3oool3000003d0oooo1000000Q0?ooo`@0000000<00@410820P03o
ool0A@3oool00`3no_h0oooo0?ooo`030?ooo`D0000000<0P8200?ooo`3oool0o`3ooom]0?ooo`00
4P3oool01@30`<00P8200?ooo`30`<00000000800@418@3oool3000003d0oooo00D0P82000000000
00000@410820P00N0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0CP3oool01010
@4000@410000000000020820P?l0ooooK@3oool001<0oooo1P0000000`3no_h0oooo0?ooo`0N0?oo
o`<00000?P3oool4000001`0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`0:0?oo
o`030?knoP3oool0oooo04@0oooo0P0000000`010@4000000820P03o0?ooof`0oooo000E0?ooo`04
0820P0000000000000410B40oooo0`00000o0?ooo`04000000010@4000000820P1/0oooo1@00001F
0?ooo`D00000o`3ooom[0?ooo`00603oool00`20P800oooo0?ooo`0O0?ooo`<00000?`3oool01010
@400000000000010@40H0?ooo`040820P0000000000000410@80000000<0P8200?ooo`3oool03`3o
ool40820P00307moO`3oool0oooo0400oooo00<0P820000000010@400P0000000`20P800oooo0?oo
o`3o0?ooofL0oooo000C0?ooo`030?knoP3oool0oooo02@0oooo0`00000o0?ooo`040820P0000000
0000000001H0oooo1@0000000`010@4000000?ooo`050?ooo`030?knoP3oool0oooo00P0oooo0P00
00001020P800oooo0?ooo`3oool2000000030820P03oool0oooo0400oooo00<0P820000000000000
0P00003o0?ooofP0oooo000j0?ooo`<00000@03oool4000001@0oooo1P0000000`20P800oooo0?oo
o`040?ooo`030?knoP3oool0oooo00H0oooo00<0o_kn0?ooo`20P8000P0000050?ooo`800000@`3o
ool5000000030820P03oool0oooo0?l0ooooI03oool003X0oooo0`0000100?ooo`050820P0000000
000000000020P8003`3oool00`20P800@410000000020000000300410@00000000000080P8204P3o
ool2000000030820P03oool0oooo00<0oooo00<0P820000000000000A03oool01010@4000@410000
000000020820P?l0ooooI03oool003X0oooo0`0000110?ooo`80000000@00@410000003oool0o_kn
2`3oool00`20P800000000000006000001@0oooo0`0000070?ooo`<00000@@3oool0103no_h0oooo
0?ooo`3oool4000000030820P03no_h0oooo0?l0ooooH@3oool003X0oooo0`0000120?ooo`<00000
00<0P8200?ooo`3no_h02@3oool8000001H0oooo0P0000000`010@40oooo0?ooo`050?ooo`<00000
AP3oool500000?l0ooooHP3oool003X0oooo0`0000120?ooo`040410@000000000000410@0L0oooo
0P20P8000`11@D40000000410@03000000030410@020P800oooo00D0oooo00<0o_kn0?ooo`3oool0
3P3oool3000000P0oooo00@0P820000000000000P820AP3oool00`20P80000000000000200000003
0820P03oool0oooo0?l0ooooGP3oool003X0oooo0`0000120?ooo`030820P0000000000000800000
103oool00`20P800000000000006000001X0oooo00<00@41000000000000203oool01020P8000000
00000020P8180?ooo`030820P0000000000000800000o`3ooomO0?ooo`00>P3oool3000004<0oooo
100000030?ooo`P0000000<0P8200?ooo`3oool06@3oool3000000P0oooo00@0P820000000000000
P820@`3oool00`3no_h0oooo0?ooo`030?ooo`D0000000<0P8200?ooo`3oool0o`3ooomK0?ooo`00
>P3oool3000004@0oooo100000030?ooo`@000000P20P80L0?ooo`040820P00000000000000000P0
oooo00@0P8200000000000000000B`3oool01010@4000@410000000000020820P?l0ooooF`3oool0
03X0oooo0`0000150?ooo`<0000000D0P8200?ooo`3oool0P8200000000P0?ooo`040820P0000000
0000000000P0oooo00@0P8200000000000000000C@3oool20000000300410@000000P8200?l0oooo
FP3oool003X0oooo0`0000150?ooo`04000000010@4000000820P0X0oooo00<0o_kn0?ooo`3oool0
5`3oool01020P80000000000000000080?ooo`040820P00000000000000004h0oooo1@00003o0?oo
oeT0oooo000j0?ooo`<00000A@3oool01020P8000@4100000000000T0?ooo`040820P00000000000
000000P0oooo00@0P8200000000000000000C`3oool00`20P800000000410@02000000030820P03o
ool0oooo0?l0ooooE@3oool003X0oooo0`0000160?ooo`@00000103oool00`3no_h0oooo0?ooo`0L
0?ooo`030820P0000000000000d00000D@3oool00`20P80000000000000200000?l0ooooEP3oool0
03X0oooo0`0000160?ooo`0400410@0000000000000000L0oooo00<0o_kn0?ooo`3oool06@3oool0
0`20P80000000000000=00000580oooo1@0000000`20P800oooo0?ooo`3o0?oooe80oooo000j0?oo
o`<00000A`3oool0100000000@4100000000000R0?ooo`040820P00000000000000000P0oooo00@0
P8200000000000000000E03oool01010@4000@410000000000020820P?l0ooooDP3oool003X0oooo
0`0000180?ooo`<0000000<0P8200?ooo`3oool07`3oool01020P800000000410@0000080?ooo`04
0820P0000000000000000580oooo00@0o_kn0?ooo`3oool0oooo100000000`20P800o_kn0?ooo`3o
0?ooodl0oooo000j0?ooo`<00000B03oool010010@40000000000020P8020?ooo`030?knoP3oool0
oooo01`0oooo00@0P8200000000000000000203oool01020P800000000000000001G0?ooo`D00000
o`3ooom@0?ooo`00>P3oool3000004P0oooo00@0P82000000000000000008P3oool3000000P0oooo
00@0P820000000000000@410F03oool00`20P800000000000002000000030820P03oool0oooo0?l0
ooooC03oool003X0oooo0`0000190?ooo`@000008@3oool3000000P0oooo00D0P820000000000000
P8200?knoP1I0?ooo`030820P0000000000000800000o`3ooom=0?ooo`00>P3oool3000004T0oooo
1000000Q0?ooo`@000001`3oool01020P8000@4100000020P81E0?ooo`030?knoP3oool0oooo00<0
oooo1@0000000`20P800oooo0?ooo`3o0?ooodT0oooo000j0?ooo`<00000BP3oool400000240oooo
0`0000070?ooo`<00000GP3oool01010@4000@410000000000020820P?l0ooooB@3oool003X0oooo
0`00001;0?ooo`@00000803oool0103no_h000000000003no_h60?ooo`800000H@3oool200000003
00410@000000P8200?l0ooooB03oool003X0oooo0`00001;0?ooo`@0000000<0P8200?ooo`3oool0
7P3oool3000000@0oooo00@0o_kn0?ooo`0000000000HP3oool500000?l0ooooA`3oool003X0oooo
0`00001;0?ooo`050<30`0000000000000000010@400803oool01030`<00P82000000020P8030?oo
o`030820P0000000@41006@0oooo00<0P820000000010@400P0000000`20P800oooo0?ooo`3o0?oo
od<0oooo000j0?ooo`<00000C03oool4000002<0oooo00<0P8200000000000000P00001X0?ooo`03
0820P0000000000000800000o`3ooom40?ooo`00>P3oool3000004`0oooo00<0o_kn000000000000
0P00000Q0?ooo`030?knoP3oool0oooo06`0oooo1@0000000`20P800oooo0?ooo`3o0?oood00oooo
000j0?ooo`<00000C@3oool01@20P8000000000000000000P8200940oooo00@0@41000410@000000
00000P20P83o0?oood00oooo000j0?ooo`<00000CP3oool20000000300410@000000oooo08h0oooo
00@0o_kn0?ooo`3oool0oooo100000000`20P800o_kn0?ooo`3o0?ooocd0oooo000j0?ooo`<00000
C`3oool3000000030820P03oool0oooo0940oooo1@00003o0?oooch0oooo000j0?ooo`<00000C`3o
ool01@11@D40000000000010@400o_kn09<0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`3o0?ooocX0oooo000j0?ooo`<00000C`3oool01020P800000000000000002F0?ooo`030820
P0000000000000800000o`3ooolk0?ooo`00>P3oool3000004h0oooo00<0o_kn0?ooo`0000000`00
002@0?ooo`030?knoP3oool0oooo00<0oooo1@0000000`20P800oooo0?ooo`3o0?ooocL0oooo000j
0?ooo`<00000D03oool01@20P8000000000000000000Ogmo09L0oooo00@0@41000410@0000000000
0P20P83o0?ooocL0oooo000j0?ooo`<00000D@3oool0100000000@4100000000002I0?ooo`800000
00<00@4100000020P800o`3ooolf0?ooo`00>P3oool300000580oooo0`0000000`20P800oooo0?oo
o`2G0?ooo`D00000o`3ooole0?ooo`00>P3oool300000580oooo00@0@410000000000000@410VP3o
ool00`20P800000000410@02000000030820P030`<00oooo0?l0oooo<@3oool003X0oooo0`00001B
0?ooo`030820P0000000000000800000V`3oool00`20P80000000000000200000?l0oooo<P3oool0
03X0oooo0`00001C0?ooo`@00000W03oool600000?l0oooo<03oool003X0oooo0`00001D0?ooo`@0
0000W@3oool01P20P8000@41000000000000@4100820P?l0oooo;P3oool003X0oooo0`00001E0?oo
o`80000000<00@410820P03oool0V@3oool0103no_h0oooo0?knoP3oool500000?l0oooo;@3oool0
03X0oooo0`00001E0?ooo`<0000000<0P8200?ooo`3oool0W@3oool5000000030?ooo`3no_h0oooo
0?l0oooo:@3oool003X0oooo0`00001E0?ooo`040820P0000000000000000:00oooo00<0`<300000
000000000P0000000`20P800`<300?ooo`3o0?ooobP0oooo000j0?ooo`<00000EP3oool400000:80
oooo1000003o0?ooobT0oooo000j0?ooo`<00000EP3oool4000009`0oooo00<0o_kn0?ooo`3no_h0
0`3oool00`20P80000000000000300000?l0oooo9`3oool003X0oooo0`00001G0?ooo`@00000X`3o
ool01P20P8000@41000000000000@4100820P?l0oooo9@3oool003X0oooo0`00001H0?ooo`<00000
00<0P8200?ooo`3oool0XP3oool20000000300410@00000000000?l0oooo903oool003X0oooo0`00
001H0?ooo`<0000000<0P8200?ooo`3oool0X`3oool500000?l0oooo8`3oool003X0oooo0`00001H
0?ooo`040820P0010@40000000000:H0oooo00L0`<30000000010@400@4100000020P800`<300?l0
oooo803oool003X0oooo0`00001I0?ooo`@00000Z03oool400000?l0oooo803oool003X0oooo0`00
001I0?ooo`@00000Z03oool00`20P80000000000000300000?l0oooo7P3oool003X0oooo0`00001J
0?ooo`@00000Z@3oool01P20P8000@41000000000000@4100820P?l0oooo703oool003X0oooo0`00
001K0?ooo`<0000000<0P8200?ooo`3oool0YP3oool00`3no_h0oooo0000000400000?l0oooo6`3o
ool003X0oooo0`00001K0?ooo`@00000Z`3oool5000000030?ooo`3no_h0oooo0?l0oooo5`3oool0
03X0oooo0`00001K0?ooo`050<30`0000000000000410@20P800Z`3oool00`30`<00000000000002
000000030820P030`<00oooo0?l0oooo5P3oool003X0oooo0`00001L0?ooo`@00000[P3oool40000
0?l0oooo5`3oool003X0oooo0`00001M0?ooo`@00000Y`3oool00`3no_h0oooo0?knoP030?ooo`03
0820P0000000000000<00000o`3ooolE0?ooo`00>P3oool3000005d0oooo00D0P820000000000000
00000<30`02^0?ooo`060820P0010@40000000000010@400P820o`3ooolC0?ooo`00>P3oool30000
05d0oooo00D0o_kn00000000000000000820P02`0?ooo`80000000<00@41000000000000o`3ooolB
0?ooo`00>P3oool3000005d0oooo00D0o_kn0820P0000000000000410@2a0?ooo`D00000o`3ooolA
0?ooo`00>P3oool3000005h0oooo00@0P8200000000000000000/P3oool01@20P800000000000001
0@4000000?l0oooo403oool003X0oooo0`00001O0?ooo`800@410P00002b0?ooo`80P8200P000000
0`010@40@4100?ooo`3o0?ooo`d0oooo000j0?ooo`<00000H03oool400000;<0oooo00<0P8200000
000000000`00003o0?ooo``0oooo000j0?ooo`<00000H03oool400000;D0oooo100000000`20P800
oooo0?ooo`3o0?ooo`T0oooo000j0?ooo`<00000H@3oool0100000000@4100000020P82e0?ooo`03
0820P000000000000080000000<0P8200?ooo`3oool0o`3oool70?ooo`00>P3oool300000640oooo
00@0P8200000000000000000]`3oool5000000030?ooo`3no_h0oooo0?l0oooo1@3oool003X0oooo
0`00001Q0?ooo`040820P0000000000000000;P0oooo00<0P8200000000000000P0000050?ooo`03
0?knoP3oool0oooo0?h0oooo000j0?ooo`<00000HP3oool4000000030820P03oool0oooo0;D0oooo
0P20P803000000030410@03oool0oooo0?l0oooo0`3oool003X0oooo0`00001S0?ooo`80000000<0
0@410000003oool0/P3oool00`3no_h0oooo0?knoP030?ooo`030820P0000000000000<00000o`3o
ool30?ooo`00>P3oool3000006@0oooo0`0000000`20P800oooo0?ooo`2h0?ooo`05000000010@40
000000000020P8000`3oool00`3no_h0oooo0?ooo`3k0?ooo`00>P3oool3000006@0oooo00@0@410
000000000000@410^`3oool01P20P8000000000000010@4000000820P?l0oooo000j0?ooo`<00000
I03oool01020P800000000000000002m0?ooo`D000005@3oool00`3no_h0oooo0?ooo`3V0?ooo`00
>P3oool300000680oooo00<0o_kn0?ooo`3oool00P0000000`010@4000000?ooo`2l0?ooo`050820
P0000000000000410@0000003`3oool00`3no_h0oooo0?ooo`3[0?ooo`00>P3oool3000006D0oooo
00D0P820000000010@4000000820P02m0?ooo`80P8200P0000000`010@40@4100?ooo`0@0?ooo`03
0410@0000000P8200>L0oooo000j0?ooo`<00000IP3oool400000;l0oooo00<0P820000000000000
0`00000=0?ooo`D000000P3oool00`3no_h0oooo0?knoP3R0?ooo`00>P3oool3000006L0oooo0`00
00000`20P800oooo0?ooo`2n0?ooo`@0000000<0P8200?ooo`3oool02@3oool01020P80000000000
00010@42000000030820P03oool0oooo0>@0oooo000j0?ooo`<00000I`3oool01010@40000000000
0011@D710?ooo`030820P000000000000080000000<0P8200?ooo`3oool01P3oool00`20P8000000
0000000500000>H0oooo000j0?ooo`<00000I`3oool01020P80000000000000000330?ooo`D00000
1@3oool00`1oOgl000000000000800000>D0oooo000j0?ooo`<00000J03oool20000000300410@00
0000oooo0<80oooo00<0P8200000000000000P0000040?ooo`<0000000D00@410000000000000000
00410@0400000>@0oooo000j0?ooo`<00000J03oool01@20P8000000000000000000P8200<<0oooo
0P20P803000000030410@03oool0P8200080000000<00@410000000000001`0000000`30`<00oooo
0?ooo`3Q0?ooo`00>P3oool3000006T0oooo1000002o0?ooo`030?knoP3oool0o_kn00<0oooo00<0
P820000000000000200000000`010@4000000000000500000><0oooo000j0?ooo`<00000JP3oool3
000000030820P03oool0oooo0<@0oooo4P00003R0?ooo`00>P3oool3000006X0oooo00@0@4100000
00000000@410a`3oool00`10@40000000000000?00000>40oooo000j0?ooo`<00000JP3oool00`20
P80000000000000200000<H0oooo4`00003P0?ooo`00>P3oool3000006/0oooo0P0000000`010@40
00000?ooo`350?ooo`@0000000<00@41000000000000300000000`20P800oooo0?ooo`3M0?ooo`00
>P3oool3000006`0oooo100000340?oooaD00000g`3oool003X0oooo0`00001]0?ooo`<0000000<0
P8200?ooo`3oool0`03ooolG00000=h0oooo000j0?ooo`<00000K@3oool3000000030820P03oool0
oooo0<00oooo6000003M0?ooo`003`3oool?0820P1`0oooo0`00001]0?ooo`040820P00000000000
00000<40oooo00<0P82000410@0000004`00000010010@40000000000020P83L0?ooo`003`3oool0
0`20P80000000000000<000001`0oooo0`00001^0?ooo`@0000000<0o_kn0?ooo`3oool0_@3oool0
0`20P80000000000000G00000=`0oooo000@0?ooo`h0000000<0P8200?ooo`3oool06@3oool30000
06h0oooo0P0000000`010@4000000?ooo`2o0?oooa/00000f`3oool00140oooo00<0P82000000020
P8002020P802000000030820P03oool0oooo01T0oooo0`00001_0?ooo`@00000_`3ooolL00000003
0<30`03oool0oooo0=L0oooo000B0?ooo`030820P0000000oooo00T0oooo00<000000?ooo`3oool0
6@3oool300000700oooo00@00@41000000000000P820_P3ooolL000000030820P03oool0oooo0=L0
oooo000C0?ooo`8000002@3oool00`20P800oooo0?ooo`0I0?ooo`<00000L03oool30000000307mo
O`3oool0oooo0080oooo00<0o_kn0?ooo`3oool0^P3oool@000000800@4100<0000000410@000000
1@00003I0?ooo`00503oool00`20P800@D510?ooo`0S0?ooo`<00000L03oool01020P80000000000
000000330?ooo`<0P8202`0000000`010@400000000000060000000300410@000000P8200=L0oooo
000E0?ooo`030820P0000000oooo0280oooo0`00001a0?ooo`@000000P3oool00`3no_h0oooo0?oo
o`2l0?ooo`030?knoP3oool0oooo00<0oooo1P0000001@010@4000000000000000000@4100X00000
e`3oool001H0oooo0P00000R0?ooo`<00000L@3oool400000<X0oooo2`0000000`010@4000000000
0004000000030820P03oool0oooo0=@0oooo000G0?ooo`0300000010@400oooo0200oooo0`00000E
0820P5d0oooo100000000`30`<00oooo0?ooo`390?ooo`0407moO`20P800@41000410@`00000eP3o
ool001P0oooo0P00000P0?oooaP00000GP3oool3000000030820P03oool0oooo0;l0oooo00<0o_kn
0?ooo`3oool03@3oool;00000=D0oooo000H0?ooo`030820P0000000oooo01l0oooo6000001N0?oo
o`040820P0000000000000000=@0oooo2@0000000`3oool0o_kn0?ooo`3A0?ooo`006@3oool00`00
00000@410<30`00N0?ooo`<000005@20P81N0?ooo`050<30`0000000000000000020P800e@3oool7
000000030<30`03oool0oooo0=40oooo000J0?ooo`0300000020P800o_kn01d0oooo0`00001d0?oo
o`@00000e03oool5000000040?ooo`000000000000000=<0oooo000J0?ooo`8000007P3oool30000
07D0oooo1000003A0?ooo`030?knoP20P800000000<000000`3oool00`3no_h0oooo0?ooo`3B0?oo
o`006P3oool00`20P80000000820P00M0?ooo`<00000M@3oool01@20P8000000000000000000`<30
0=00oooo00D0P82000000000000000000410@03I0?ooo`006`3oool2000001d0oooo0`00001f0?oo
o`<0000000<0P8200?ooo`3oool0c@3oool500000=X0oooo000K0?ooo`<00000703oool3000007@0
oooo00<0o_kn0?ooo`20P8000`00003>0?ooo`030820P0000000000000800000f`3oool000l0oooo
0P20P80:0?ooo`<00000703oool3000007H0oooo00D0`<300000000000000@410820P03<0?ooo`05
0820P00000000@4100000010@400g03oool000l0oooo00<0P8200000003oool0203oool4000001`0
oooo0`00001g0?ooo`@00000b`3oool500000=d0oooo000@0?ooo`800000203oool0100000000@41
00000000000L0?ooo`<00000N03oool400000<L0oooo00<0o_kn0?ooo`0000001000003N0?ooo`00
403oool01020P80000000410@020P8040?ooo`030820P0000000000000800@417@3oool3000007P0
oooo00D0P82000410@00000000000<30`0370?ooo`050410@0000000000000000010@400g`3oool0
0140oooo2`0000000`3oool0o_kn0?ooo`0K0?ooo`<00000N@3oool3000000030820P03oool0o_kn
0<@0oooo1@00003P0?ooo`004P3oool9000000030820P03oool0oooo01`0oooo0`00001i0?ooo`04
0820P0010@40000000000<D0oooo1@00003Q0?ooo`004P3oool00`30`<00P8200820P00400000080
P8207`3oool3000007T0oooo00D0`<3000000000000000000820P0330?ooo`050410@00000000@41
00000020P800hP3oool003X0oooo0`00001j0?ooo`D00000`@3oool4000000030820P03oool0oooo
0>40oooo000O0?ooo`030?knoP3oool0oooo01P0oooo0`00001k0?ooo`@00000_P3oool00`3no_h0
oooo0000000400000>@0oooo000j0?ooo`<00000O03oool3000000030820P03oool0oooo0;`0oooo
00D0@41000000000000000000820P03U0?ooo`007@3oool00`3no_h0oooo0?ooo`0J0?ooo`<00000
O03oool01020P800000000000000002m0?ooo`@0000000<0P8200?ooo`3oool0i03oool003X0oooo
0`00001l0?ooo`040820P0000000000000000;`0oooo1@00003W0?ooo`00>P3oool3000007d0oooo
1000002j0?ooo`050410@00000000@4100000020P800j03oool003X0oooo0`00001n0?ooo`@00000
^03oool4000000030820P03oool0oooo0>L0oooo000j0?ooo`<00000OP3oool400000;D0oooo00<0
o_kn0?ooo`0000001000003Z0?ooo`00>P3oool3000007l0oooo0`0000000`20P800oooo0?ooo`2c
0?ooo`050410@0000000000000000020P800j`3oool003X0oooo0`00001I0?ooo`l000005`3oool0
1020P800000000000000002d0?ooo`@0000000<0P8200?ooo`3oool0jP3oool003X0oooo0`00001I
0?ooo`l000005`3oool01020P8000000000000010@6c0?ooo`D00000k@3oool003X0oooo0`00001J
0?ooo`050820P000000000000000002o_kl01`3oool00`20P80000000?ooo`0G0?ooo`@00000/@3o
ool01@10@400000000410@000000P8200>h0oooo000j0?ooo`<00000F`3oool01@20P80000000000
0020P800o_kn00L0oooo00<0P8200?ooo`3oool05`3oool0100000000@4100000000002_0?ooo`@0
000000<0P8200?ooo`3oool0k@3oool003X0oooo0`00001K0?ooo`040820P00000000000000000<0
oooo00<0o_kn0?ooo`3oool00P3oool00`20P800oooo0?ooo`0F0?ooo`030?knoP00000000000080
0000[03oool00`3no_h0oooo0000000400000?00oooo000j0?ooo`<00000G03oool4000000L0oooo
00<0P8200?ooo`3oool0603oool3000000030820P03oool0oooo0:X0oooo00<0P820000000000000
0P00003a0?ooo`00>P3oool3000005d0oooo00D0P820000000010@4000000<30`00P0?ooo`040410
@0000000000000000:/0oooo00D0P82000000000000000000410@03b0?ooo`00>P3oool3000005h0
oooo0`0000000`20P800oooo0?ooo`0O0?ooo`@00000Z@3oool500000?<0oooo000j0?ooo`<00000
GP3oool01020P800000000410@00000Q0?ooo`80000000D00@410000003oool0oooo0?knoP2U0?oo
o`030820P00000000@4100800000m03oool003X0oooo0`00001O0?ooo`050820P00000000@410000
0020P800803oool0100000000@4100000000002V0?ooo`050820P0000000000000000010@400m@3o
ool003X0oooo0`00001P0?ooo`@000008@3oool3000000030820P03oool0oooo0:00oooo00<0o_kn
0?ooo`0000001000003f0?ooo`00>P3oool300000640oooo0`0000000`20P800o_kn0?ooo`0N0?oo
o`<0000000<0P8200?ooo`3oool0X@3oool00`20P80000000000000200000?L0oooo000j0?ooo`<0
0000H@3oool01@30`<000000000000000000P82001l0oooo00@0P8200000000000000000XP3oool0
1@20P8000000000000000000@4100?P0oooo000j0?ooo`<00000F`3oool00`20P800oooo0?ooo`05
0?ooo`<00000803oool400000:00oooo1@00003i0?ooo`00>P3oool3000005/0oooo00<000000?oo
o`3no_h01@3oool4000001l0oooo1000002O0?ooo`030820P00000000@4100800000nP3oool003X0
oooo0`00001K0?ooo`8000001`20P80010010@40000000410@11@D4O0?ooo`04000000010@400000
000009d0oooo00D0P82000000000000000000410@03k0?ooo`00>P3oool3000005/0oooo3@00000P
0?ooo`<0000000<0P8200?ooo`3oool0U`3oool00`3no_h0oooo0000000400000?`0oooo000j0?oo
o`<00000IP3oool00`3no_h0oooo0?ooo`0O0?ooo`0400410@00000000000820P9X0oooo00<0P820
0000000000000P00003m0?ooo`00>P3oool3000008P0oooo00@0P8200000000000000000V@3oool0
1@20P8000000000000000000@4100?h0oooo000j0?ooo`<00000R@3oool4000009L0oooo1@00003o
0?ooo`00>P3oool3000008T0oooo1000002F0?ooo`030820P00000000@4100800000o`3oool10?oo
o`00>P3oool3000008X0oooo100000000`30`<00oooo0?ooo`2A0?ooo`050820P000000000000000
0010@400o`3oool20?ooo`00>P3oool3000008/0oooo0`0000000`20P800oooo0?ooo`2>0?ooo`03
0?knoP3oool0000000@00000o`3oool30?ooo`00>P3oool3000008L0oooo00D0o_kn0?ooo`3oool0
oooo0820P00300000940oooo00<0P8200000000000000P00003o0?ooo`@0oooo000j0?ooo`<00000
R`3oool01@30`<000@41000000000000P82008l0oooo00D0P82000000000000000000410@03o0?oo
o`D0oooo000j0?ooo`<00000S03oool4000000030?knoP3oool0oooo08/0oooo1@00003o0?ooo`H0
oooo000j0?ooo`<00000S@3oool4000008`0oooo00<0P820000000010@400P00003o0?ooo`L0oooo
000j0?ooo`<00000S@3oool01@20P8000@41000000000000`<3008X0oooo00D0P820000000000000
00000410@03o0?ooo`P0oooo000j0?ooo`<00000SP3oool3000000030820P03oool0oooo08D0oooo
00<0o_kn0?ooo`0000001000003o0?ooo`T0oooo000j0?ooo`<00000SP3oool01020P80000000000
000000280?ooo`030820P0000000000000800000o`3oool:0?ooo`00>P3oool3000008h0oooo00D0
`<3000000000000000000820P0260?ooo`050820P0000000000000000010@400o`3oool;0?ooo`00
>P3oool3000008l0oooo100000250?ooo`D00000o`3oool<0?ooo`00>P3oool3000008`0oooo00@0
o_kn0?ooo`3oool0oooo100000230?ooo`030820P00000000@4100800000o`3oool=0?ooo`00>P3o
ool300000900oooo00D0P82000000000000000000<30`0210?ooo`050820P0000000000000000010
@400o`3oool>0?ooo`00>P3oool300000940oooo0`0000000`20P800oooo0?ooo`1l0?ooo`030?kn
oP3oool0000000@00000o`3oool?0?ooo`00>P3oool300000940oooo00@0P8200000000000000000
O`3oool00`20P80000000000000200000?l0oooo403oool003X0oooo0`00002A0?ooo`030<30`000
0000000000800000O@3oool01@20P8000000000000000000@4100?l0oooo4@3oool003X0oooo0`00
002C0?ooo`@00000N`3oool500000?l0oooo4P3oool003X0oooo0`00002C0?ooo`@00000NP3oool0
0`20P800000000410@0200000?l0oooo4`3oool003X0oooo0`00002D0?ooo`<0000000<0P8200?oo
o`3oool0MP3oool01@20P8000000000000000000@4100?l0oooo503oool003X0oooo0`00002D0?oo
o`040820P00000000000000007D0oooo00<0o_kn0?ooo`0000001000003o0?oooaD0oooo000j0?oo
o`<00000U03oool01020P8000@4100000000001f0?ooo`030820P0000000000000800000o`3ooolF
0?ooo`00>P3oool3000009D0oooo1000001d0?ooo`050820P0000000000000000010@400o`3ooolG
0?ooo`00>P3oool3000009H0oooo1000001b0?ooo`D00000o`3ooolH0?ooo`00>P3oool3000009H0
oooo1000001a0?ooo`030820P00000000@4100800000o`3ooolI0?ooo`00>P3oool3000009L0oooo
0P0000000`010@40P8200?ooo`1^0?ooo`050820P0000000000000000010@400o`3ooolJ0?ooo`00
>P3oool3000009L0oooo00@0P8200000000000000000K03oool00`3no_h0oooo0000000400000?l0
oooo6`3oool003X0oooo0`00002G0?ooo`040820P00000000000000006d0oooo00<0P82000000000
00000P00003o0?oooa`0oooo000j0?ooo`<00000V03oool4000006/0oooo00D0P820000000000000
00000410@03o0?oooad0oooo000j0?ooo`<00000V@3oool01P010@400000000000000000oooo0?kn
oVL0oooo1@00003o0?oooah0oooo000j0?ooo`<00000V@3oool4000006P0oooo00<0P82000000001
0@400P00003o0?oooal0oooo000j0?ooo`<00000VP3oool010010@40000000000010@41V0?ooo`05
0820P0000000000000000010@400o`3ooolP0?ooo`00>P3oool3000009P0oooo00<0o_kn0?ooo`20
P8000`00001S0?ooo`030?knoP3oool0000000@00000o`3ooolQ0?ooo`00>P3oool3000009/0oooo
0P0000000`010@4000000?ooo`1R0?ooo`030820P0000000000000800000o`3ooolR0?ooo`00>P3o
ool3000009/0oooo00D0P82000000000000000000820P01Q0?ooo`050820P0000000000000000010
@400o`3ooolS0?ooo`00>P3oool3000009`0oooo1000001P0?ooo`D00000o`3ooolT0?ooo`00>P3o
ool3000009d0oooo0`0000000`20P800oooo0?ooo`1L0?ooo`030820P00000000@4100800000o`3o
oolU0?ooo`00>P3oool3000009d0oooo00@0@410000000000000@410G@3oool01@20P80000000000
00000000@4100?l0oooo9P3oool003X0oooo0`00002M0?ooo`040820P00000000000000005X0oooo
00<0o_kn0?ooo`0000001000003o0?ooobL0oooo000j0?ooo`<00000WP3oool20000000300410@00
0000oooo05T0oooo00<0P8200000000000000P00003o0?ooobP0oooo000j0?ooo`<00000WP3oool0
1@1oOgl00000000000000000P82005P0oooo00D0P82000000000000000000410@03o0?ooobT0oooo
000j0?ooo`<00000W`3oool4000000<0oooo00<0o_kn0?ooo`3oool0D@3oool500000?l0oooo:P3o
ool003X0oooo0`00002P0?ooo`@00000E@3oool00`20P800000000410@0200000?l0oooo:`3oool0
03X0oooo0`00002O0?ooo`060?knoP10@4000000000000010@40`<30D`3oool01@20P80000000000
00000000@4100?l0oooo;03oool003X0oooo0`00002P0?ooo`050820P0000000000000000020P800
D03oool00`3no_h0oooo0000000400000?l0oooo;@3oool003X0oooo0`00002Q0?ooo`0400000001
0@40000000000540oooo00<0P8200000000000000P00003o0?ooobh0oooo000j0?ooo`<00000X@3o
ool00`20P800000000000002000004l0oooo00D0P82000000000000000000410@03o0?ooobl0oooo
000j0?ooo`<00000X`3oool30000000300410@3oool0oooo04/0oooo1@00000B0?ooo`030820P03o
ool0oooo0?l0oooo6`3oool003X0oooo0`00002S0?ooo`@00000C03oool20000000300410@000000
00000180oooo0P00003o0?oooad0oooo000j0?ooo`<00000Y03oool20000000300410@20P800oooo
04T0oooo00D0@41000000000000000000410@00B0?ooo`030820P000000000000?l0oooo7@3oool0
03X0oooo0`00002T0?ooo`040820P00000000@41000004T0oooo1@00000C0?ooo`@00000o`3ooolL
0?ooo`00>P3oool300000:@0oooo00@0P8200000000000000000B03oool5000001@0oooo1000003o
0?oooa`0oooo000j0?ooo`<00000Y@3oool4000004H0oooo00D0@41000000000000000000820P00D
0?ooo`040820P000000000000820P0800000o`3ooolK0?ooo`00>P3oool300000:H0oooo10000014
0?ooo`@0000000<0P8200?ooo`3oool04`3oool3000000040?ooo`3no_h000000820P?l0oooo6P3o
ool003X0oooo0`00002V0?ooo`@00000@`3oool20000000300410@000000000001H0oooo00<00@41
0000000000000P3oool00`000000P8200?knoP3o0?oooaT0oooo000j0?ooo`<00000Y`3oool30000
00030820P03oool0oooo03l0oooo00<0P8200000000000000P00000F0?ooo`@000000P3oool00`00
0000P8200?ooo`3o0?oooaT0oooo000j0?ooo`<00000Y`3oool01010@400000000000011@D500?oo
o`050820P0000000000000000010@4005P3oool01020P80000000000000000040?ooo`030000003o
ool0oooo0?l0oooo603oool003X0oooo0`00002W0?ooo`040820P00000000000000003l0oooo1@00
000G0?ooo`<000001@3oool00`20P80000000?ooo`3o0?oooaP0oooo000j0?ooo`<00000Y@3oool0
0`3no_h0oooo0?ooo`020000000300410@000000oooo03`0oooo00<0P8200000000000000P00000H
0?ooo`80000000<00@410?ooo`3oool00`3oool00`20P80000000?ooo`3o0?oooaP0oooo000A0?oo
o`H0P8208`3oool300000:P0oooo00D0P82000000000000000000820P00k0?ooo`050820P0000000
000000000010@400603oool01020P800000000000020P8060?ooo`0300000020P800oooo0?l0oooo
5`3oool000l0oooo00<0P820000000010@401P0000000`20P800oooo0?ooo`0O0?ooo`<00000Z@3o
ool4000003X0oooo0P0000000`010@4000000000000I0?ooo`80000000<00@410?ooo`3oool01@3o
ool2000000030?ooo`3no_h0o_kn0?l0oooo5@3oool000l0oooo00<0P8200000000000000P000004
0?ooo`800000803oool300000:X0oooo0`0000000`20P800oooo0?ooo`0f0?ooo`030820P0000000
0000008000004`3oool00`3no_h0oooo0?ooo`040?ooo`<00000103oool01P3no_h0oooo0?ooo`3o
ool000000820P?l0oooo5`3oool00100oooo0P20P8000`30`<00oooo0?ooo`030?ooo`040<30`000
000000000<30`1h0oooo0`00002Z0?ooo`040410@00000000000000003L0oooo00D0P82000000000
000000000410@00J0?ooo`03000000010@40000000T0oooo00<0P8200410@03oool0o`3ooolF0?oo
o`006@3oool3000001h0oooo0`00002[0?ooo`@00000=@3oool5000001T0oooo00<0P82000000000
00000`0000080?ooo`<00000o`3ooolF0?ooo`006@3oool0103no_h000000000003no_hM0?ooo`<0
0000Z`3oool4000003@0oooo00<0P8200000000000000P00000J0?ooo`<0000000@00@4100000000
000000001@3oool00`20P80000000000000300000?l0oooo5@3oool001X0oooo0P0000000`20P800
oooo0?ooo`0K0?ooo`<00000[03oool400000380oooo00D0P82000000000000000000410@03o0?oo
od80oooo000J0?ooo`<000007@3oool300000:d0oooo0`0000000`20P800oooo0?ooo`0^0?ooo`80
000000<00@41000000000000o`3ooom30?ooo`006P3oool3000001d0oooo0`00000D0?ooo`030?kn
oP3oool0oooo09H0oooo0`0000000`20P800oooo0?ooo`0]0?ooo`030820P0000000000000800000
o`3ooom40?ooo`006@3oool4000001d0oooo0`00000E0820P9P0oooo00@0P8200000000000000000
;P3oool01@20P8000000000000000000@4100?l0ooooA@3oool001P0oooo00<0P820000000000000
0P00000M0?oooaP00000V@3oool4000002`0oooo1@00003o0?ooodH0oooo000H0?ooo`@000007P3o
oolH000009T0oooo1000000[0?ooo`030820P0000000000000800000o`3ooom70?ooo`00503oool2
0820P0D0000000<0@4100?ooo`3oool0703oool3000001D0P820VP3oool4000002T0oooo00D0P820
00000000000000000410@03o0?ooodP0oooo000E0?ooo`030820P0000000000000<000007`3oool3
00000;00oooo0`0000000`20P800oooo0?ooo`0U0?ooo`80000000<00@41000000000000o`3ooom9
0?ooo`005`3oool00`0000000@410000000P0?ooo`<00000/03oool3000000030820P03oool0oooo
02@0oooo00<0P8200000000000000P00003o0?ooodX0oooo000H0?ooo`030820P03oool0oooo01l0
oooo0`00002`0?ooo`040820P0000000000000410BD0oooo00D0P82000000000000000000410@03o
0?oood/0oooo000F0?ooo`040?knoP3oool0P82000000200oooo0`00002a0?ooo`80000000<00@41
0000003oool08P3oool500000?l0ooooC03oool001T0oooo0P00000O0?ooo`<00000/@3oool50000
0240oooo00<0P8200000000000000P00003o0?ooodd0oooo000I0?ooo`80000000<0@4100?ooo`3o
ool0703oool300000;80oooo00D0P82000410@00000000000<30`00O0?ooo`050820P00000000000
00000010@400o`3ooom>0?ooo`006@3oool3000001h0oooo0`00002c0?ooo`<0000000<0P8200?oo
o`3oool0703oool20000000300410@00000000000?l0ooooC`3oool000l0oooo00<0P8200?ooo`3n
o_h01`3oool3000001h0oooo0`00002c0?ooo`040820P00000000@41000001d0oooo00<0P8200000
000000000P00003o0?oooe00oooo000@0?ooo`0300000020P800oooo00D0oooo00@0@41000000000
000000007P3oool300000;<0oooo00D0`<3000000000000000000820P00K0?ooo`050820P0000000
000000000010@400o`3ooomA0?ooo`004@3oool2000000@0oooo100000000`20P800oooo0?ooo`0L
0?ooo`<00000/P3oool01P3no_h0oooo0000000000000@41000001X0oooo1@00003o0?oooe80oooo
000B0?ooo`T000007`3oool300000;80oooo00<0o_kn0?ooo`3oool01000000H0?ooo`030820P000
0000000000800000o`3ooomC0?ooo`004P3oool00`30`<00P82000000003000000030410@020P800
oooo01l0oooo0`00002e0?ooo`050820P0000000000000000030`<005P3oool01@20P80000000000
00000000@4100?l0ooooE03oool003X0oooo0`00002f0?ooo`<0000000<0P8200?ooo`3oool04`3o
ool20000000300410@00000000000?l0ooooE@3oool003X0oooo0`00002f0?ooo`040820P0000000
0000000001@0oooo00<0P8200000000000000P00003o0?oooeH0oooo000j0?ooo`<00000]P3oool0
1@30`<000000000000000000P8200180oooo00D0P82000000000000000000410@03o0?oooeL0oooo
000j0?ooo`<00000]`3oool400000140oooo1@00003o0?oooeP0oooo000j0?ooo`<00000^03oool4
000000l0oooo00<0P8200000000000000P00003o0?oooeT0oooo000j0?ooo`<00000^03oool01@20
P8000000000000000000`<3000d0oooo00D0P82000000000000000000410@03o0?oooeX0oooo000j
0?ooo`<00000^@3oool3000000030820P03oool0oooo00X0oooo0P0000000`010@4000000000003o
0?oooe/0oooo000j0?ooo`<00000^@3oool01020P800000000000000000;0?ooo`030820P0000000
000000800000o`3ooomL0?ooo`00>P3oool300000;T0oooo00<0`<300000000000000P0000090?oo
o`050820P0000000000000000010@400o`3ooomM0?ooo`00>P3oool300000;/0oooo100000070?oo
o`D00000o`3ooomN0?ooo`00>P3oool300000;X0oooo00D0o_kn0000000000000@41000000060?oo
o`030820P0000000000000800000o`3ooomO0?ooo`00>P3oool300000;`0oooo0`0000000`20P800
oooo0?ooo`020?ooo`050820P0000000000000000010@400o`3ooomP0?ooo`00>P3oool300000;`0
oooo00@0P820000000010@4000000`3oool20000000300410@00000000000?l0ooooH@3oool003X0
oooo0`00002l0?ooo`040820P0000000000000000080oooo00<0P8200000000000000P00003o0?oo
of80oooo000j0?ooo`<00000_@3oool4000000050820P0000000000000000010@400o`3ooomS0?oo
o`00>P3oool300000;h0oooo0P0000000`010@4000000000000200000?l0ooooI03oool003X0oooo
0`00002n0?ooo`H00000o`3ooomU0?ooo`00>P3oool300000;h0oooo00D0P8200000000000000@41
0410@03o0?ooofH0oooo000j0?ooo`<00000_@3oool6000000@0oooo00<0o_kn0?ooo`3oool0o`3o
oomO0?ooo`00>P3oool300000;`0oooo00<0P8200000000000000`0000000`010@40oooo0?ooo`3o
0?ooof@0oooo000j0?ooo`<00000^`3oool01@20P8000000000000000000@41000@00000o`3ooomU
0?ooo`00>P3oool300000;X0oooo1@0000020?ooo`0400410@000000000000000?l0ooooI03oool0
03X0oooo0`00002i0?ooo`030820P00000000000008000000`3oool4000000030820P03oool0oooo
0?l0ooooH@3oool003X0oooo0`00002h0?ooo`050820P0000000000000000010@4001@3oool01010
@400000000000010@43o0?ooof<0oooo000j0?ooo`<00000]`3oool20000000300410@0000000000
00H0oooo00@0P8200000000000000000o`3ooomS0?ooo`00>P3oool300000;H0oooo00<0P8200000
000000000P0000080?ooo`@000000`3oool00`3no_h0oooo0?ooo`3o0?oooe`0oooo000j0?ooo`<0
0000]@3oool01@20P8000000000000000000@41000T0oooo00D0P820000000010@4000000820P03o
0?ooof40oooo000j0?ooo`<00000]03oool5000000/0oooo00@0000000410@00000000001@3oool0
0`3no_h0oooo0?ooo`3o0?oooeT0oooo000j0?ooo`<00000/`3oool00`20P8000000000000020000
00d0oooo0`0000000`20P800oooo0?ooo`3o0?oooeh0oooo000j0?ooo`<00000/P3oool01@20P800
0000000000000000@41000h0oooo00@0@410000000000000@410o`3ooomP0?ooo`00>P3oool30000
0;40oooo0P0000000`010@4000000000000?0?ooo`040820P00000000@4100000?l0ooooH03oool0
03X0oooo0`00002`0?ooo`030820P00000000000008000004@3oool400000?l0ooooG`3oool003X0
oooo0`00002_0?ooo`050820P0000000000000000010@4004P3oool01@20P8000@41000000000000
P8200?l0ooooGP3oool003X0oooo0`00002^0?ooo`D00000503oool400000?l0ooooGP3oool003X0
oooo0`00002]0?ooo`030820P00000000000008000005P3oool3000000030820P03oool0oooo0?l0
ooooF`3oool003X0oooo0`00002/0?ooo`050820P0000000000000000010@4005`3oool01010@400
000000000010@43o0?oooed0oooo000j0?ooo`<00000Z`3oool20000000300410@000000000001P0
oooo00@0P8200000000000000000o`3ooomM0?ooo`00>P3oool300000:X0oooo00<0P82000000000
00000P00000J0?ooo`@00000o`3ooomL0?ooo`00>P3oool300000:X0oooo1000000K0?ooo`D00000
o`3ooomK0?ooo`00>P3oool300000:P0oooo00<0P8200000000000000P0000000`30`<00oooo0?oo
o`0J0?ooo`050820P0000000000000000030`<00o`3ooomJ0?ooo`00>P3oool300000:L0oooo00<0
P8200000000000000P00000O0?ooo`<0000000<0P8200?ooo`3oool0o`3ooomH0?ooo`00>P3oool3
00000:L0oooo1000000P0?ooo`0407moO`000000000000000?l0ooooFP3oool003X0oooo0`00002U
0?ooo`030820P00000000@410080000000<0`<300?ooo`3oool07P3oool01@30`<00000000000000
0000P8200?l0ooooF@3oool003X0oooo0`00002T0?ooo`030820P00000000000008000008`3oool2
0000000300410@000000oooo0?l0ooooF03oool003X0oooo0`00002T0?ooo`@000009@3oool40000
0?l0ooooF03oool003X0oooo0`00002R0?ooo`030820P000000000000080000000<0`<300?ooo`3o
ool08`3oool01@20P8000@41000000000000_kno0?l0ooooE`3oool003X0oooo0`00002Q0?ooo`D0
0000:03oool3000000030820P03oool0oooo0?l0ooooE@3oool003X0oooo0`00002P0?ooo`030820
P00000000000008000009`3oool00`3no_h0oooo0820P00300000?l0ooooE`3oool003X0oooo0`00
002O0?ooo`030820P0010@4000000080000000<0`<300?ooo`3oool09`3oool01@30`<0000000000
00000000Ogmo0?l0ooooEP3oool003X0oooo0`00002N0?ooo`D00000;03oool0100000000@410000
0000003o0?oooeH0oooo000j0?ooo`<00000W@3oool00`20P800000000000002000002h0oooo1000
003o0?oooeD0oooo000j0?ooo`<00000W03oool01@20P8000000000000000000@41002l0oooo00D0
P82000000000000000000<30`03o0?oooe@0oooo000j0?ooo`<00000V`3oool500000340oooo1000
003o0?oooe@0oooo000j0?ooo`<00000VP3oool00`20P80000000000000200000380oooo00@0P820
0000000000000000o`3ooomD0?ooo`00>P3oool3000009T0oooo00D0P82000410@00000000000410
@00d0?ooo`@00000o`3ooomC0?ooo`00>P3oool3000009P0oooo1@00000f0?ooo`80000000<00@41
0000003oool0o`3ooomA0?ooo`00>P3oool3000009L0oooo00<0P8200000000000000P00000g0?oo
o`@00000o`3ooomB0?ooo`00>P3oool3000009H0oooo00D0P82000000000000000000410@00i0?oo
o`0400410@00000000000820P?l0ooooD@3oool003X0oooo0`00002E0?ooo`D00000>P3oool01020
P800000000000000003o0?oooe40oooo000j0?ooo`<00000U03oool00`20P8000000000000020000
03/0oooo00@0P8200000000000000000o`3ooomA0?ooo`00>P3oool3000009<0oooo00D0P8200041
0@00000000000410@00m0?ooo`@00000o`3ooom@0?ooo`00>P3oool300000980oooo1@00000o0?oo
o`<0000000<00@410?ooo`3oool0o`3ooom=0?ooo`00>P3oool300000940oooo00<0P82000000000
00000P0000100?ooo`@00000o`3ooom?0?ooo`00>P3oool300000900oooo00D0P820000000000000
00000410@0120?ooo`0400410@00000000000820P?l0ooooCP3oool003X0oooo0`00002?0?ooo`D0
0000@`3oool01020P800000000000000003o0?ooodh0oooo000j0?ooo`<00000SP3oool00`20P800
000000000002000004@0oooo00@0P8200000000000000000103oool00`3no_h0oooo0?ooo`3o0?oo
odL0oooo000j0?ooo`<00000S@3oool01@20P8000@41000000000000@41004H0oooo1000003o0?oo
odd0oooo000j0?ooo`<00000S03oool5000004P0oooo100000060?ooo`030820P0000000000000<0
0000o`3ooom00?ooo`00>P3oool3000008/0oooo00<0P8200000000000000P0000190?ooo`060000
00010@40000000000020P800o_kn0P3oool800000?l0oooo@03oool003X0oooo0`00002:0?ooo`05
0820P0000000000000000010@400B`3oool01@10@400000000000010@400P82000<0000000<00@41
0000000000001000003o0?oood00oooo000j0?ooo`<00000R@3oool5000004`0oooo00<0P8200000
000000003000003o0?oood00oooo000j0?ooo`<00000R03oool00`20P800000000000002000004d0
oooo00<0P8200000000000001`0000000`010@4000000000000200000?l0oooo@03oool003X0oooo
0`0000270?ooo`050820P0010@40000000000010@400C03oool20820P0l00000o`3ooom00?ooo`00
>P3oool3000008H0oooo1@00001;0?ooo`030?knoP1oOgl000000100000000<0P8200?ooo`3oool0
o`3ooolm0?ooo`00>P3oool3000008D0oooo00<0P8200000000000000P00001=0?oooa40000000<0
0@410820P03oool0o`3oooln0?ooo`00>P3oool3000008@0oooo00D0P82000000000000000000410
@01<0?ooo`030820P000000000000100000000<00@410820P03oool0o`3oooln0?ooo`00>P3oool3
000008<0oooo1@00001<0?ooo`030820P0000000000000l0000000@00@41000000000000P820o`3o
oolo0?ooo`00>P3oool300000880oooo00<0P8200000000000000P00001=0?oooaH00000o`3ooolo
0?ooo`00>P3oool300000840oooo00D0P82000410@00000000000410@01=0?ooo`030820P0000000
000001@00000o`3ooolo0?ooo`00>P3oool300000800oooo1@00001?0?ooo`030820P00000000000
0180000000<00@410?ooo`3no_h0o`3ooolm0?ooo`00>P3oool3000007l0oooo00<0P82000000000
00000P00001A0?ooo`0300410@00000000000140000000<00@410000003oool0o`3ooolm0?ooo`00
>P3oool3000007h0oooo00D0P82000000000000000000410@01C0?ooo`030820P0010@4000000100
000000<00@410000003oool0o`3ooolm0?ooo`00>P3oool3000007d0oooo1@00001E0?ooo`030820
P0000000000001400000o`3oooln0?ooo`00>P3oool3000007`0oooo00<0P8200000000000000P00
001G0?oooa<00000o`3oooln0?ooo`00>P3oool3000007/0oooo00D0P82000410@00000000000410
@01I0?ooo`030820P0000000000000l0000000<0P8200?ooo`3oool0o`3ooolk0?ooo`005`3oool0
0`3no_h0oooo0?ooo`0P0?ooo`<00000NP3oool5000005/0oooo00<0P8200000000000003`00003o
0?ooocd0oooo000j0?ooo`<00000N@3oool00`20P800000000000002000005d0oooo00<00@410000
000000003P00003o0?ooocd0oooo000j0?ooo`<00000N03oool01@20P8000000000000000000@410
05l0oooo00<0P82000410@0000003@00003o0?ooocd0oooo000I0?ooo`<000007P3oool3000007L0
oooo1@00001Q0?ooo`030820P0000000000000`00000o`3ooolm0?ooo`00503oool00`3no_h0oooo
0?knoP020?ooo`<000007P3oool3000007H0oooo00<0P8200000000000000P00001S0?ooo`h00000
o`3ooolm0?ooo`006@3oool3000001h0oooo0`00001e0?ooo`050820P0010@40000000000010@400
I@3oool00`20P800@4100000000:000000030<30`03oool0oooo0?l0oooo>P3oool001T0oooo0`00
000N0?ooo`<00000M03oool5000006P0oooo2`0000000`20P800oooo0?ooo`3o0?ooocX0oooo000>
0?ooo`030?knoP3oool0oooo00P0oooo0`00000N0?ooo`<00000L`3oool00`20P800000000000002
000006X0oooo00<0000000410@0000001`0000000`20P800oooo0?ooo`3o0?ooocX0oooo000I0?oo
o`0300410@000000000001h0oooo0`00001b0?ooo`050820P0000000000000000010@400K03oool0
0`10@400000000000006000000030820P03oool0oooo0?l0oooo>P3oool001T0oooo0`00000N0?oo
o`<00000L@3oool5000006h0oooo200000001@20P800oooo0?ooo`3oool0o_kn0?l0oooo>03oool0
00l0oooo200000000`010@40000000000005000000030?knoP3oool0oooo01P0oooo0`00001`0?oo
o`030820P0000000000000800000L03oool7000000030820P03oool0oooo0?l0oooo>P3oool000l0
oooo100000000`010@400000000000020000000300410@000000000000@000006`3oool3000006l0
oooo00D0P82000410@00000000000410@01b0?ooo`040410@0000000000000410@80000000@0@410
0820P020P800`<30o`3oooli0?ooo`003`3oool00`20P80000000?ooo`070?ooo`<000007P3ooolH
000005T0oooo1@00001F0?ooo`030?knoP3oool0oooo01P0oooo00<0o_kn0?ooo`20P8001@000000
0`010@4000000000003o0?ooocX0oooo000?0?ooo`030820P0000000oooo00L0oooo0`00000N0?oo
oaP00000F03oool00`20P800000000000002000006@0oooo00<0o_kn0?ooo`3oool01`3oool00`20
P80000000000000;00000?l0oooo>`3oool00100oooo00<0P82000000030`<001P3oool3000001h0
oooo6000001G0?ooo`050820P0000000000000000010@400H`3oool00`2o_kl0P8200820P0030820
P0030410@0000000000001000000o`3oooll0?ooo`004@3oool2000000030?knoP3oool0oooo00<0
oooo0`00000N0?ooo`<00000J`3oool5000005/0oooo00<0P8200000000000007`00003o0?oooc`0
oooo000B0?ooo`030000003oool0oooo00@0oooo0`00000N0?ooo`<00000JP3oool00`20P8000000
00000002000005`0oooo00<0P8200000000000004@0000000`010@4000000000000;00000?l0oooo
?03oool00180oooo00<0`<3000000020P800103oool3000001h0oooo0`00001Y0?ooo`050820P001
0@40000000000010@400G@3oool00`20P800000000410@0K000000040410@03oool0oooo0410@?l0
oooo?03oool00100oooo00<0o_kn0?ooo`3oool00P0000040?ooo`<000007P3oool3000006P0oooo
1@00001O0?oooa/0000000<00@410000003oool0o`3ooolo0?ooo`00503oool00`000000P8200?oo
o`020?ooo`<000007P3oool3000006L0oooo00<0P8200000000000000P00001P0?oooa`00000o`3o
oom10?ooo`005@3oool010000000P8200?ooo`3oool3000001h0oooo0`00001V0?ooo`050820P000
0000000000000010@400H@3oool00`010@4000000000000G000000030410@03oool0oooo0?l0oooo
@03oool001D0oooo00@0P8200000003no_h0oooo0`00000N0?ooo`<00000I@3oool500000680oooo
6P00003o0?oood<0oooo000F0?ooo`0300410@000000oooo00<000007P3oool3000006@0oooo00<0
P8200000000000000P00001T0?oooaP00000o`3ooom40?ooo`005`3oool00`000000P82000000002
000001h0oooo0`00001T0?ooo`@00000I@3ooolG000000030?ooo`3no_h0oooo0?l0oooo@P3oool0
01L0oooo00D0P8200410@00000000@410000000N0?ooo`<00000HP3oool00`20P800000000410@02
000000030<30`03oool0oooo06@0oooo5@0000000`10@400oooo0?ooo`3o0?oood<0oooo000F0?oo
o`030?knoP3oool0P82000<000007P3oool300000640oooo00<0P8200000000000000P00001X0?oo
oaD00000o`3ooom60?ooo`006@3oool01@0000000@410000003oool0o_kn01`0oooo0`00001Q0?oo
o`@00000J@3ooolD00000?l0ooooA`3oool001T0oooo00<0P8200000000000007P3oool3000005l0
oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`1T0?ooo`030820P000000000000180
000000<0@D510?ooo`3oool0o`3ooom60?ooo`00>P3oool3000005h0oooo00<0P820000000000000
0P00001V0?oooaL00000o`3ooom90?ooo`00>P3oool3000005h0oooo1000001V0?ooo`L0000000<0
oooo0000000000003@00003o0?ooodX0oooo000j0?ooo`<00000G03oool00`20P800000000410@02
000000030<30`03oool0oooo0640oooo00<0P820000000000000100000020820P080oooo00<0P820
0000000000002P0000000`10@400oooo0?ooo`3o0?ooodT0oooo000j0?ooo`<00000F`3oool00`20
P800000000000002000006<0oooo200000060?ooo``00000o`3ooom<0?ooo`00>P3oool3000005/0
oooo1000001S0?ooo`800@411@0000080?ooo`030820P0000000000000P00000o`3ooom=0?ooo`00
>P3oool3000005T0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`1N0?ooo`030820
P0000000000000@000000P20P80:0?ooo`P0000000<0@4100?ooo`3oool0o`3ooom<0?ooo`00>P3o
ool3000005P0oooo00<0P8200000000000000P00001P0?ooo`8000000P010@44000000h0oooo1`00
00000`3oool0o_kn0?ooo`3o0?oood`0oooo000j0?ooo`<00000F03oool400000600oooo1`00000A
0?ooo`D00000o`3ooom@0?ooo`00>P3oool3000005H0oooo00<0P820000000010@400P0000000`30
`<00oooo0?ooo`1K0?ooo`030820P0000000000000@000000P20P80B0?ooo`040<30`00000000000
0410@?l0ooooD@3oool003X0oooo0`00001E0?ooo`030820P0000000000000800000G@3oool80000
01L0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`00>P3oool3000005D0oooo1000001M0?ooo`80
0@411@00000L0?ooo`030?knoP3oool0oooo0?l0ooooC@3oool003X0oooo0`00001C0?ooo`030820
P000000000000080000000<0`<300?ooo`3oool0F03oool00`20P80000000000000400000080P820
o`3ooom]0?ooo`00>P3oool300000580oooo00<0P8200000000000000P00001J0?ooo`8000000P01
0@44000000X0oooo00<0o_kn0?ooo`3oool0o`3ooomS0?ooo`00>P3oool300000580oooo1000001J
0?ooo`L00000o`3ooomb0?ooo`00>P3oool300000500oooo00<0P820000000010@400P0000000`30
`<00oooo0?ooo`1E0?ooo`030820P0000000000000@000000P20P83o0?ooog<0oooo000j0?ooo`<0
0000C`3oool00`20P800000000000002000005L0oooo2000003o0?ooogH0oooo000j0?ooo`<00000
C03oool00`3no_h0oooo0?ooo`04000005L0oooo0P010@4500000?l0ooooN03oool003X0oooo0`00
001=0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0DP3oool00`20P80000000000
000400000080P820o`3ooomi0?ooo`00>P3oool3000004`0oooo1@00001D0?ooo`8000000P010@44
000000X0oooo00<0o_kn0?ooo`3oool0o`3ooom_0?ooo`00>P3oool3000004/0oooo00<0P8200000
000000000P00001D0?ooo`L00000o`3ooomn0?ooo`00>P3oool3000004X0oooo00<0P82000000001
0@400P0000000`30`<00oooo0?ooo`1>0?ooo`030<30`020P800000000D000000P20P83o0?ooogl0
oooo000j0?ooo`<00000B@3oool500000540oooo2000003o0?oooh80oooo000j0?ooo`<00000AP3o
ool00`3no_h0oooo0820P00400000500oooo00<0P820000000010@401@00003o0?oooh@0oooo000j
0?ooo`<00000A`3oool01@20P8000000000000000000@41004h0oooo00<0`<300820P00000001@00
00020820P?l0ooooQ@3oool003X0oooo0`0000160?ooo`D00000CP3oool0100000000@4100000001
0@43000000030820P03oool0oooo00P0oooo00<0o_kn0?ooo`3oool0o`3ooomk0?ooo`00>P3oool3
000004D0oooo00<0P8200000000000000P00001=0?ooo`030820P0000000000000D00000o`3ooon:
0?ooo`00>P3oool3000004@0oooo00D0P820000000010@4000000410@01;0?ooo`030<30`020P800
000000D0000000<0P8200<30`03oool0o`3ooon:0?ooo`00>P3oool3000004<0oooo1@00001;0?oo
o`L0000000<0P8200?ooo`3oool0103oool00`3no_h0oooo0?ooo`3o0?ooohD0oooo000j0?ooo`<0
0000@03oool00`3no_h0oooo0820P004000004X0oooo00<0P820000000010@401@00003o0?oooi00
oooo000j0?ooo`<00000@@3oool01@20P8000000000000000000@41004P0oooo00<0`<300820P000
00001@0000000`20P800`<300?ooo`3o0?oooi00oooo000j0?ooo`<00000@03oool5000004P0oooo
00@0000000410@0000000@410`0000000`20P800oooo0?ooo`080?ooo`030?knoP3oool0oooo0?l0
ooooQ`3oool003X0oooo0`00000o0?ooo`030820P0000000000000800000A`3oool00`20P8000000
0000000500000?l0ooooUP3oool003X0oooo0`00000n0?ooo`050820P00000000@4100000010@400
A@3oool00`30`<00P82000000005000000030820P030`<00oooo0?l0ooooUP3oool003X0oooo0`00
000m0?ooo`D00000A@3oool7000000030820P03oool0oooo00@0oooo00<0o_kn0?ooo`3oool0o`3o
oonA0?ooo`00>P3oool3000003X0oooo00<0o_kn0?ooo`20P800100000140?ooo`030820P0000000
0@4100D00000o`3ooonL0?ooo`00>P3oool3000003/0oooo00D0P82000000000000000000410@012
0?ooo`030<30`020P800000000D0000000<0P8200<30`03oool0o`3ooonL0?ooo`00>P3oool30000
03X0oooo1@0000120?ooo`04000000010@40000000410@<0000000<0P8200?ooo`3oool0203oool0
0`3no_h0oooo0?ooo`3o0?oooi<0oooo000j0?ooo`<00000>@3oool00`20P8000000000000020000
0440oooo00<0P8200000000000001@00003o0?oooj80oooo000j0?ooo`<00000>03oool01@20P800
000000410@000000@41003l0oooo00<0`<300820P00000001@0000000`20P800`<300?ooo`3o0?oo
oj80oooo000j0?ooo`<00000=`3oool5000003l0oooo1`0000000`20P800oooo0?ooo`040?ooo`03
0?knoP3oool0oooo0?l0ooooW@3oool003X0oooo0`00000d0?ooo`030?knoP3oool0P82000@00000
?P3oool00`20P800000000410@0500000?l0ooooZ03oool003X0oooo0`00000e0?ooo`050820P000
0000000000000010@400?03oool00`30`<00P82000000005000000030820P030`<00oooo0?l0oooo
Z03oool003X0oooo0`00000d0?ooo`D00000?03oool0100000000@41000000010@43000000030820
P03oool0oooo00P0oooo00<0o_kn0?ooo`3oool0o`3ooonO0?ooo`00>P3oool3000003<0oooo00<0
P8200000000000000P00000k0?ooo`030820P0000000000000D00000o`3ooon^0?ooo`00>P3oool3
00000380oooo00D0P820000000010@4000000410@00i0?ooo`030<30`020P800000000D0000000<0
P8200<30`03oool0o`3ooon^0?ooo`00>P3oool300000340oooo1@00000i0?ooo`L0000000<0P820
0?ooo`3oool0103oool00`3no_h0oooo0?ooo`3o0?ooojT0oooo000j0?ooo`<00000;P3oool00`3n
o_h0oooo0820P004000003P0oooo00<0P820000000010@401@00003o0?oook@0oooo000j0?ooo`<0
0000;`3oool01@20P8000000000000000000@41003H0oooo00<0`<300820P00000001@0000000`20
P800`<300?ooo`3o0?oook@0oooo000j0?ooo`<00000;P3oool5000003H0oooo00@0000000410@00
00000@410`0000000`20P800oooo0?ooo`080?ooo`030?knoP3oool0oooo0?l0ooooZ`3oool003X0
oooo0`00000]0?ooo`030820P0000000000000800000=@3oool00`20P80000000000000500000?l0
oooo^P3oool003X0oooo0`00000/0?ooo`050820P00000000@4100000010@400<`3oool00`30`<00
P82000000005000000030820P030`<00oooo0?l0oooo^P3oool003X0oooo0`00000[0?ooo`D00000
<`3oool7000000030820P03oool0oooo00@0oooo00<0o_kn0?ooo`3oool0o`3ooone0?ooo`00>P3o
ool3000002P0oooo00<0o_kn0?ooo`20P8001000000b0?ooo`030820P00000000@4100D00000o`3o
ooo00?ooo`00>P3oool3000002T0oooo00D0P82000000000000000000410@00`0?ooo`030<30`020
P800000000D0000000<0P8200<30`03oool09@3oool00`30`<00oooo0?ooo`070?ooo`030820P03o
ool0oooo0?l0ooooSP3oool003X0oooo0`00000X0?ooo`D00000<03oool0100000000@4100000001
0@43000000030820P03oool0oooo00P0oooo00<0o_kn0?ooo`3oool06`3oool00`000000P8200?oo
o`070?ooo`030820P000000000000?l0ooooS`3oool003X0oooo0`00000W0?ooo`030820P0000000
000000800000;`3oool00`20P800000000000005000002X0oooo00<0000000410@3oool01`3oool0
0`20P80000000000003o0?ooohl0oooo000j0?ooo`<000009P3oool01@20P800000000410@000000
@41002d0oooo00<0`<300820P00000001@0000000`20P800`<300?ooo`0Y0?ooo`<0000000<0P820
0?ooo`3oool01@3oool01010@400000000410@30`<3o0?ooohh0oooo000j0?ooo`<000009@3oool5
000002d0oooo1`0000000`20P800oooo0?ooo`040?ooo`030?knoP3oool0oooo02@0oooo10000007
0?ooo`<0000000<0P8200?ooo`3oool0o`3ooon<0?ooo`00>P3oool300000280oooo00<0o_kn0?oo
o`20P8001000000/0?ooo`030820P00000000@4100D00000;P3oool00`20P8000000000000020000
000300410@3oool0oooo00<0oooo1@00003o0?ooohh0oooo000j0?ooo`<000008`3oool01@20P800
0000000000000000@41002X0oooo00<0`<300820P00000001@0000000`20P800`<300?ooo`0^0?oo
o`070820P000000000000820P03oool000000820P0040?ooo`<0000000<0oooo0000003oool0o`3o
oon=0?ooo`00>P3oool300000280oooo1@00000Z0?ooo`04000000010@40000000410@<0000000<0
P8200?ooo`3oool0203oool00`3no_h0oooo0?ooo`0U0?ooo`<000000P3oool00`3no_h000000?oo
o`020?ooo`<000000P3oool00`20P80000000?ooo`3o0?oooh`0oooo000j0?ooo`<000008@3oool0
0`20P800000000000002000002T0oooo00<0P8200000000000001@00000d0?ooo`<000000`3oool0
10000000oooo0?ooo`3oool20000000500410@3oool0oooo0820P0000000o`3ooon=0?ooo`00>P3o
ool300000240oooo00@0000000410@0000000000:@3oool7000000030820P03oool0oooo03<0oooo
0P00000020010@40oooo0?ooo`3oool0P8200000003oool0P8200P0000001@20P800oooo0?ooo`20
P80000000?l0ooooS@3oool003X0oooo0`00000O0?ooo`030820P000000000000080000000<0`<30
0?ooo`3oool0903oool00`20P800000000000004000000030410@020P800oooo03D0oooo0`000004
0?ooo`040<30`0000000P8200820P080000000@0P8200?ooo`3oool0oooo0P00003o0?oooh`0oooo
000j0?ooo`<00000703oool00`3no_h0oooo0820P004000002H0oooo00<00@41000000010@401@00
000i0?ooo`<000001@3oool20000000300410@000000000000@0oooo0P00003o0?oooh`0oooo000j
0?ooo`<000007P3oool4000000030?ooo`3no_h0oooo02<0oooo1`0000000`20P800oooo0?ooo`02
0?ooo`030?knoP3oool0oooo0380oooo0`0000070?ooo`@000001@3oool00`000000P8200?ooo`3o
0?ooohX0oooo000j0?ooo`<00000703oool00`20P800000000000002000000030<30`03oool0oooo
0240oooo00@0P82000410@0000000@410`0000020820P3X0oooo00@0`<3000000000000000001`3o
ool00`010@400000000000060?ooo`030820P010@400oooo0?l0ooooRP3oool003X0oooo0`00000K
0?ooo`030820P00000000000008000008`3oool8000003d0oooo00D0P820000000000000P8200?kn
oP050?ooo`<00000203oool00`000000oooo0?ooo`3o0?ooohT0oooo000j0?ooo`<000006`3oool0
100000000@4100000000000S0?ooo`L00000?@3oool00`3no_h0oooo0820P002000000030820P03o
ool0oooo00@0oooo0`0000060?ooo`030?knoP3oool0P82000D0oooo00<0o_kn0?ooo`3oool0o`3o
oon30?ooo`00>P3oool3000000X0oooo0P20P8000`30`<00oooo0?ooo`0:0?ooo`030820P0000000
00000080000000<0`<300?ooo`3oool07P3oool00`20P80000000000000400000080P820?`3oool0
1@20P800000000410@000000P82000D0oooo00@0`<300000000000000000203oool00`20P8000000
0820P03o0?ooohT0oooo000j0?ooo`<000002@3oool00`1oOgl0000000000002000000P0oooo00<0
o_kn0?ooo`20P8001000000P0?ooo`0300410@0000000@4100D00000103oool00`3no_h0oooo0?oo
o`0i0?ooo`040820P0000000000000410@<0000000<00@410?ooo`3oool0200000040?ooo`030000
00010@4000000080000000<0P8200?ooo`3oool0o`3ooon60?ooo`00>P3oool3000000T0oooo00<0
P8200000000000000`0000090?ooo`@0000000<0oooo0?knoP3oool07@3oool700000?l0ooooiP3o
ool003X0oooo0`0000090?ooo`L000000P20P8040?ooo`030820P000000000000080000000<0`<30
0?ooo`3oool06`3oool01020P8000@41000000010@4300000080P820o`3ooooW0?ooo`00>P3oool3
000000P0oooo0P0000000`010@40000000410@05000000040820P03oool0oooo0820P0@000007@3o
ool800000?l0oooojP3oool003X0oooo0`0000080?ooo`/000000P3oool0100000000@4100000000
000M0?ooo`L00000o`3oooo/0?ooo`00>P3oool3000000L0oooo1@0000000`010@40000000000005
0000000500410@000000000000000030`<006P3oool00`20P80000000000000400000080P820o`3o
ooo]0?ooo`00>P3oool3000000H0oooo00<0P8200000000000003P00000J0?ooo`0300410@000000
0@4100D00000103oool00`3no_h0oooo0?ooo`3o0?ooonT0oooo000j0?ooo`<000001P3oool01020
P8000000000000010@4;0000000300410@3oool0oooo01P0oooo1`00003o0?oooo80oooo000j0?oo
o`<000001P3ooolA000000030820P03oool0oooo01<0oooo00@0P82000410@0000000@410`000002
0820P?l0ooool`3oool003X0oooo0`0000050?ooo`03000000010@40000000/0000000<00@410000
00010@400P0000000`20P800oooo0?ooo`0@0?ooo`P00000o`3oooof0?ooo`00>P3oool3000000D0
oooo4`0000000`20P800oooo0?ooo`0?0?ooo`L00000o`3ooooh0?ooo`00>P3oool3000000@0oooo
3`0000000`010@40000000000003000000030820P03oool0oooo00/0oooo00<0P820000000000000
100000020820P?l0oooon@3oool003X0oooo0`0000030?ooo`030820P0000000000001@000002`3o
ool00`010@40000000410@05000000@0oooo00<0o_kn0?ooo`3oool0o`3ooooe0?ooo`00>P3oool3
000000<0oooo00<0P820000000000000400000000`010@40000000000002000000T0oooo1`00003o
0?ooooh0oooo000j0?ooo`<000000`3ooolH000000H0oooo00@0P82000410@0000000@410`000002
0820P?l0ooooo`3oool001L0oooo00<0o_kn0?ooo`3oool07`3oool0103no_h00000000000000003
0?oooaP0000000@0P8200?ooo`3oool0oooo2000003o0?ooool0oooo0`3oool003X0oooo0`000002
0?oooaT0000000<0P8200?ooo`3oool01`00003o0?ooool0oooo1@3oool003X0oooo0`0000001@3o
ool0P8200000000000000@4101@0000000<00@410820P020P8001P0000020820P?l0ooooo`3oool6
0?ooo`004P3oool500000240oooo00H0o_kn0?ooo`000000000000410@3ooolG000000030820P000
0000000000H00000103oool00`3no_h0oooo0?ooo`3o0?ooool0oooo0P3oool00140oooo1`000000
0`20P800oooo0?ooo`0O0?ooo`<0000000<0P820000000000000500000000`3oool0000000000005
00000?l0ooooo`3oool;0?ooo`00403oool300000080P8200`3oool00`20P80000000820P00O0?oo
o`0400410@00000000000410@1<0000000<0P8200410@00000001@0000020820P?l0ooooo`3oool<
0?ooo`006P3oool00`010@40P8200?ooo`0M0?oooaD0000000<0P8200000000000001P00003o0?oo
ool0oooo3`3oool001/0oooo00<000000?ooo`3oool0703ooolC000000030?knoP3oool0000000H0
0000o`3ooooo0?oooa40oooo000K0?ooo`030410@0000000oooo01`0oooo3P0000001@010@40@410
0820P03oool0P82000H000000P20P83o0?ooool0oooo4P3oool001/0oooo00<0P8200000003oool0
703oool?000000040?ooo`010@40000000410@D00000103oool00`3no_h0oooo0?ooo`3o0?ooool0
oooo3P3oool001/0oooo00<0P820000000000000703oool<0000000300410@3oool0oooo00L00000
o`3ooooo0?oooaL0oooo000K0?ooo`030820P0000000000001`0oooo2P0000030820P0H000000P20
P83o0?ooool0oooo603oool001/0oooo00<00@41000000000000703ooolH00000?l0ooooo`3ooolE
0?ooo`006`3oool3000001/0oooo6@00003o0?ooool0oooo5@3oool001T0oooo00D0P82000000000
000000000820P00J0?ooo`040820P0000000000000410AH00000o`3ooooo0?oooaD0oooo000D0?oo
o`050?knoP3oool0oooo0?ooo`20P8001000000K0?ooo`D00000o`3ooooo0?ooobX0oooo000H0?oo
o`@000006`3oool40000000300410@000000oooo01<0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?oo
oa<0oooo000D0?ooo`80P82000<0000000410@0000000P0000000`10@400oooo0?ooo`0I0?ooo`03
0820P03oool0oooo00<00000o`3ooooo0?ooobX0oooo000A0?ooo`X000007`3oool300000?l0oooo
o`3ooolZ0?ooo`004@3oool8000000030?knoP3oool0oooo01h0oooo0`00003o0?ooool0oooo:P3o
ool00180oooo00@0000000410@000000@4100P20P80R0?ooo`<00000o`3ooooo0?ooobX0oooo000B
0?ooo`030820P0000000oooo02D0oooo0`00003o0?ooool0oooo:P3oool00100oooo00@0o_kn0?oo
o`20P80000000P3oool00`3no_h0oooo0?ooo`0Q0?ooo`<00000o`3ooooo0?ooobX0oooo000@0?oo
o`030?knoP3oool0oooo008000009@3oool300000?l0ooooo`3ooolZ0?ooo`004`3oool200000003
0820P03oool0oooo0280oooo0`00003o0?ooool0oooo:P3oool001@0oooo2000000N0?ooo`<00000
o`3ooooo0?ooobX0oooo000D0?ooo`030820P0000000000000D0000000<00@410?ooo`3oool06`3o
ool300000?l0ooooo`3ooolZ0?ooo`005@3oool70000000300410@000000oooo01/0oooo0`00003o
0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0
oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3o
ool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0
oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00
003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?oo
ool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo
:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool0
03X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo
0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o
0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0
oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3o
ool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0
oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00
003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?oo
ool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo
:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool0
03X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo
0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o
0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0
oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3o
ool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0
oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00
003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?oo
ool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo
:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool0
03X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo
0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o
0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0
oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3o
ool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0
oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00
003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?oo
ool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo
:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool0
03X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo
0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o
0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0
oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3o
ool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0
oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3oool00100oooo00<0
o_kn0?ooo`3oool00P3oool00`010@4000000000000200000200oooo0`00003o0?ooool0oooo:P3o
ool001@0oooo1`0000000`20P800oooo0?ooo`0L0?ooo`<00000o`3ooooo0?ooobX0oooo000B0?oo
o`040410@000000000000820P0<0oooo0P20P8000`000000P8200?ooo`0L0?ooo`<00000o`3ooooo
0?ooobX0oooo000B0?ooo`8000001`3oool00`20P80000000000000L0?ooo`<00000o`3ooooo0?oo
obX0oooo000A0?ooo`03000000010@4000000080oooo00<0o_kn0?ooo`3oool00P3oool00`20P800
00000000000L0?ooo`<00000o`3ooooo0?ooobX0oooo000@0?ooo`80000000<00@410?ooo`3oool0
1`3oool2000000030820P03oool0oooo01T0oooo0`00003o0?ooool0oooo:P3oool00100oooo0`00
00090?ooo`<000006`3oool300000?l0ooooo`3ooolZ0?ooo`003`3oool0101oOgl0000000000020
P8090?ooo`<000006`3oool300000?l0ooooo`3ooolZ0?ooo`003`3oool01020P800000000000020
P8090?ooo`80000000<00@410?ooo`3oool06@3oool300000?l0ooooo`3ooolZ0?ooo`003`3oool0
1020P8000@4100000020P8090?ooo`80000000<00@410?ooo`3oool06@3ooolH00000?l0ooooo`3o
oolE0?ooo`003`3oool01020P800000000000020P8080?ooo`040820P00000000000000001/0oooo
6000003o0?ooool0oooo5@3oool000l0oooo00@0P820000000000000P820203oool01010@4000000
00000010@40K0?ooo`<0000000<00@410000000000002@0000000`010@4000000000000600000?l0
ooooo`3ooolE0?ooo`003`3oool01020P800000000000020P8080?ooo`<0000000<0Ogmo0?ooo`3o
ool03P3oool00`3no_h0oooo0?ooo`060?ooo`030?knoP3oool0000000800000o`3ooooo0?ooobX0
oooo000@0?ooo`<000001`3oool4000001D0oooo00<0P8200000000000003@00003o0?ooool0oooo
903oool00100oooo0`0000000`20P80000000820P0020820P0050410@0000000000000000020P800
4`3oool01020P8000000000000010@43000000800@411000000200410@<0000000@00@4100000000
000000000P20P83o0?ooool0oooo7`3oool00140oooo0P0000030?ooo`0300410@00000000000080
0000503ooolI00000?l0ooooo`3ooolO0?ooo`004@3oool3000001`0oooo1P0000000`010@400000
000000070000000300410@000000000000<0000000<00@410?ooo`3oool0o`3ooooo0?oooah0oooo
000A0?ooo`040820P0010@4000000820P1/0oooo5`00003o0?ooool0oooo803oool00180oooo00<0
P8200000000000006`3oool00`20P80000000000000B0000000300410@20P800oooo0?l0ooooo`3o
oolO0?ooo`004P3oool01020P800000000000020P80J0?ooo`030820P0000000000001<0000000<0
P8200?ooo`3no_h0o`3ooooo0?oooah0oooo000C0?ooo`040820P000000000000820P1T0oooo00<0
`<3000410@0000004`0000000`30`<00oooo0?ooo`3o0?ooool0oooo7P3oool001D0oooo0`00000I
0?oooaD00000o`3ooooo0?ooob40oooo000F0?ooo`80000000<0P8200?ooo`3oool05P3ooolE0000
0?l0ooooo`3ooolQ0?ooo`005`3oool00`20P800@410000000020820P1H0oooo4`00003o0?ooool0
oooo8P3oool001/0oooo0`0000000`20P800oooo0?ooo`0A0?oooa<00000o`3ooooo0?ooob80oooo
000c0?oooa400000o`3ooooo0?ooob<0oooo000c0?ooo`h0000000<00@4100000010@400o`3ooooo
0?ooob<0oooo000c0?ooo`030820P0000000000000d0000000<0P8200?ooo`3oool0o`3ooooo0?oo
ob40oooo000I0?ooo`030?knoP3oool0oooo01L0oooo00<0Ogmo0000000000002P00000200410@03
00000020P800oooo0?l0ooooo`3ooolR0?ooo`00<`3oool00`30`<0000000000000<000000030041
0@3oool0oooo0?l0ooooo`3ooolR0?ooo`00=03oool>00000?l0ooooo`3ooolU0?ooo`00=03oool<
0000000300410@000000oooo0?l0ooooo`3ooolT0?ooo`00=@3oool<000000030820P03oool0oooo
0?l0ooooo`3ooolS0?ooo`00=@3oool00`3no_h0000000000009000000030?ooo`3no_h0oooo0?l0
ooooo`3ooolS0?ooo`00=P3oool:000000030820P03oool0oooo0?l0ooooo`3ooolT0?ooo`00=P3o
ool00`10@400000000000007000000030820P03oool0oooo0?l0ooooo`3ooolT0?ooo`00=P3oool0
0`20P80000000000000700000?l0ooooo`3ooolW0?ooo`00=P3oool00`20P8000000000000070000
0?l0ooooo`3ooolW0?ooo`00=`3oool8000000030820P03oool0oooo0?l0ooooo`3ooolU0?ooo`00
<P3oool00`3no_h0oooo0?ooo`020?ooo`P000000P3oool00`3no_h0oooo0?ooo`3o0?ooool0oooo
8`3oool003P0oooo1P00003o0?ooool0oooo:@3oool003P0oooo1P00003o0?ooool0oooo:@3oool0
03T0oooo100000000`20P800oooo0?ooo`3o0?ooool0oooo9`3oool003T0oooo100000000`20P800
oooo0?ooo`3o0?ooool0oooo9`3oool003T0oooo00D0P82000000000000000000<30`03o0?ooool0
oooo:@3oool003X0oooo0`00003o0?ooool0oooo:P3oool003X0oooo0`00003o0?ooool0oooo:P3o
ool003X0oooo00<0P82000000020P800o`3ooooo0?ooobX0oooo000j0?ooo`030820P0000000oooo
0?l0ooooo`3ooolZ0?ooo`00>`3oool00`000000oooo0?ooo`3o0?ooool0oooo:@3oool00?l0oooo
o`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?oo
o`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo
0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00;`3oool00`000000P820
0?ooo`3o0?ooool0oooo=@3oool002l0oooo0P00003o0?ooool0oooo=P3oool00300oooo00<0_kno
00000020P800o`3ooooo0?oooc@0oooo000b0?ooo`0300000020P800oooo0080oooo00<0o_kn0?oo
o`3oool0o`3ooooo0?ooobd0oooo000/0?ooo`030?knoP3oool0oooo00@0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooc40oooo000c0?ooo`030;no_`000000P8200?l0ooooo`3ooola0?ooo`00=@3o
ool00`000000P8200?ooo`3o0?ooool0oooo;`3oool003D0oooo0P00003o0?ooool0oooo<03oool0
03D0oooo0`00003o0?ooool0oooo;`3oool003D0oooo00@0000000410@010@40P820o`3ooooo0?oo
obh0oooo000e0?ooo`<0000000<0o_kn0000003oool0o`3ooooo0?ooob`0oooo000e0?ooo`<00000
00<0oooo00000020P800o`3ooooo0?ooob`0oooo000e0?ooo`80000000@00@410?ooo`3oool0@410
o`3ooooo0?ooob`0oooo000d0?ooo`040?knoP000000000000000080oooo00<0P8200000003oool0
o`3ooooo0?ooobX0oooo000d0?ooo`@000000`3oool200000?l0ooooo`3ooolZ0?ooo`00=03oool3
000000D0oooo00<0P8200<30`03oool0o`3ooooo0?ooobP0oooo000d0?ooo`<000001P3oool00`00
0000oooo0?ooo`3o0?ooool0oooo9`3oool003@0oooo0`0000060?ooo`030820P03oool0oooo0?l0
ooooo`3ooolW0?ooo`00=03oool3000000H0oooo00<0`<300000003oool0o`3ooooo0?ooobL0oooo
000d0?ooo`<000001`3oool200000?l0ooooo`3ooolW0?ooo`00=03oool3000000P0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooobD0oooo000c0?ooo`040820P00000000000000000L0oooo00<0P820
00000020P800o`3ooooo0?ooobH0oooo000c0?ooo`060820P000000000000820P03oool0o_kn0P3o
ool00`3no_h0oooo0820P002000000030820P03oool0oooo0?l0ooooo`3ooolT0?ooo`00<`3oool3
000000030820P03oool0o_kn00@0oooo00@0P82000410@000000P820o`3ooooo0?ooobH0oooo000`
0?ooo`040<30`01oOgl0P8200410@080000000<0`<300?ooo`3oool0103oool01030`<0000000000
0030`<3o0?ooool0oooo9P3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?oo
ool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3o
ool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0oooo
o`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?oo
o`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo
0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo
003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0
ooooI`3oool00?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool0
0?l0ooooo`3ooomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3o
oomW0?ooo`00o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00?l0ooooo`3ooomW0?ooo`00
o`3ooooo0?ooofL0oooo003o0?ooool0ooooI`3oool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{204.375, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 9.2 Addition of three vectors ",
  StyleBox["u",
    FontWeight->"Bold"],
  ", ",
  StyleBox["v",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["w",
    FontWeight->"Bold"],
  "."
}], "Caption",
  CellTags->"Fig. 9.2"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows us to add and subtract vectors just as we would scalars. In ",
  StyleBox["Mathematica, ",
    FontSlant->"Italic"],
  "we can determine the total displacement thusly :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(u = {3, 2}; \ v = {\(-3\), 3}; w = {2, \(-1\)};\), "\n", 
    \(z = u + v + w\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.45"],

Cell[BoxData[
    \({2, 4}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here I have also shown you a useful trick that can save time. You can put \
more than one command in a cell by separating each command with a semicolon  \
",
  StyleBox[";",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . Inserting the semicolons also turns off the output from the given \
commands, so that only the last command ",
  StyleBox["z = u + v + w",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  is returned in the above cell  (since it is without a semicolon)."
}], "Text"],

Cell["\<\
Question: what do you think would happen if you put a semicolon at \
the end of the last command as well? Try it!\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dot Product", "Section",
  CellTags->{"i:31", "c:20"}],

Cell[TextData[{
  "If two vectors, ",
  StyleBox["a",
    FontWeight->"Bold"],
  " and ",
  StyleBox["b",
    FontWeight->"Bold"],
  ",  have the same dimension ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", we can take their dot product. The dot product is ",
  "defined as",
  " "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["a",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["b",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox["a",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "[", \([1]\), "]"}], 
                  RowBox[{
                    StyleBox["b",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "[", \([1]\), "]"}]}], "+", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "[", \([2]\), "]"}], "+", 
                RowBox[{
                  StyleBox["b",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "[", \([2]\), "]"}], "+"}], "..."}], 
            "+", 
            RowBox[{
              RowBox[{
                StyleBox["a",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "[", \([N]\), "]"}], 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "[", \([N]\), "]"}]}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(9.5.1)"],

Cell[TextData[{
  "You have probably seen a second way to write this sum, using the sum \
symbol, an oversize Greek letter ",
  StyleBox["\[CapitalSigma]",
    FontFamily->"Symbol"],
  ", and subscript notation for the elements of the vectors,  as in"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["a",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", 
          StyleBox["b",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], "=", 
        RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
          RowBox[{
            SubscriptBox["a", 
              StyleBox["i",
                FontWeight->"Plain",
                FontSlant->"Italic"]], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            StyleBox[
              SubscriptBox["b", 
                StyleBox["i",
                  FontWeight->"Plain",
                  FontSlant->"Italic"]],
              FontSlant->"Italic"]}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(9.5.2)"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the dot product operation can be performed using the notation ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Courier"],
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "For example, using our previously defined four-dimensional vectors ",
  StyleBox["a",
    FontWeight->"Bold"],
  " and ",
  StyleBox["b",
    FontWeight->"Bold"],
  ", we can find their dot product by typing a period . between the two \
vectors:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a . b\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.46"],

Cell[BoxData[
    \(\(\(105.22842712474619`\)\(\[InvisibleSpace]\)\) + 
      4\ \((x + 2\ y)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The dot product of a vector ",
  StyleBox["a ",
    FontWeight->"Bold"],
  "with itself is the square of the length of that vector, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"|", 
          StyleBox["a",
            FontWeight->"Bold",
            FontSlant->"Plain"], \( | \^2\)}], TraditionalForm]]],
  " : "
}], "Text",
  CellTags->"i:42"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a . a\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.47"],

Cell[BoxData[
    \(57\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "(Don't confuse the ",
  StyleBox["Length",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function with the length of the vector as defined above. The ",
  StyleBox["Length",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function gives the number of elements of the vector (its dimension). For \
example, ",
  StyleBox["Length[a]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns 4, not  ",
  Cell[BoxData[
      \(TraditionalForm\`\@57\)]],
  ". )"
}], "Text"],

Cell[TextData[{
  "Two vectors are said to be ",
  StyleBox["orthogonal",
    FontSlant->"Italic"],
  " when their dot product is zero. Pictorially, this indicates that there is \
a right angle between the vectors.  For example, in ",
  ButtonBox["Fig. 9.2",
    ButtonData:>"Fig. 9.2",
    ButtonStyle->"Hyperlink"],
  ", it appears that ",
  StyleBox["w",
    FontWeight->"Bold"],
  " and ",
  StyleBox["z",
    FontWeight->"Bold"],
  " are orthogonal.  This can easily be verified by hand:\n"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["w",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], 
        "=", \(\((2, \(-1\))\)\[CenterDot]\((2, 4)\) = \(4 - 4 = 0. \)\)}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(9.5.3)"],

Cell["\<\

More generally, the dot product of two vectors is related to their length and \
the angle between them: \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", 
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], "=", 
        RowBox[{"|", 
          RowBox[{
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"], "||", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], "|", "cos\[Theta]"}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(9.5.4)"],

Cell[TextData[{
  "where ",
  StyleBox[" ",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is the angle between the vectors, as shown in ",
  ButtonBox["Fig. 9.2",
    ButtonData:>"Fig. 9.2",
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Matrix Multiplication", "Section",
  CellTags->{"i:32", "c:21"}],

Cell[TextData[{
  "Matrix multiplication can also be carried out using the dot product \
notation. For example, if a vector ",
  StyleBox["a",
    FontWeight->"Bold"],
  " has dimension ",
  StyleBox["N",
    FontSlant->"Italic"],
  " and a matrix ",
  StyleBox["d",
    FontWeight->"Bold"],
  " has ",
  StyleBox["N",
    FontSlant->"Italic"],
  " columns and ",
  StyleBox["M",
    FontSlant->"Italic"],
  " rows, then the dot product of ",
  StyleBox["d ",
    FontWeight->"Bold"],
  "with ",
  StyleBox["a ",
    FontWeight->"Bold"],
  "is a vector ",
  StyleBox["e",
    FontWeight->"Bold"],
  " with ",
  StyleBox["M",
    FontSlant->"Italic"],
  " elements.  The ",
  StyleBox["i",
    FontSlant->"Italic"],
  "th element of ",
  StyleBox["e ",
    FontWeight->"Bold"],
  "is the dot product of row  ",
  StyleBox["d",
    FontWeight->"Bold"],
  "[[",
  StyleBox["i",
    FontSlant->"Italic"],
  "]] with ",
  StyleBox["a:",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["e",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontWeight->"Plain",
              FontSlant->"Italic"], 
            StyleBox[\([i]\),
              FontWeight->"Plain",
              FontSlant->"Italic"], 
            StyleBox["]",
              FontWeight->"Plain",
              FontSlant->"Italic"]}], 
          StyleBox["=",
            FontWeight->"Plain",
            FontSlant->"Italic"], 
          RowBox[{
            RowBox[{
              StyleBox["d",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["[",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox[\([i]\),
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Plain",
                FontSlant->"Italic"]}], "\[CenterDot]", 
            StyleBox["a",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          FormBox[
            RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
              RowBox[{
                RowBox[{
                  StyleBox["d",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["[",
                    FontSlant->"Plain"], 
                  RowBox[{
                    StyleBox["[",
                      FontSlant->"Plain"], 
                    StyleBox[\(i, j\),
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontSlant->"Plain"]}], 
                  StyleBox["]",
                    FontSlant->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Bold",
                  FontSlant->"Italic"], 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["[",
                    FontWeight->"Plain",
                    FontSlant->"Plain"], 
                  RowBox[{
                    StyleBox["[",
                      FontWeight->"Plain",
                      FontSlant->"Plain"], 
                    StyleBox["j",
                      FontWeight->"Plain",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontWeight->"Plain",
                      FontSlant->"Plain"]}], 
                  StyleBox["]",
                    FontWeight->"Plain",
                    FontSlant->"Plain"]}]}]}],
            "TraditionalForm"]}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(9.5.5)"],

Cell[TextData[{
  "This equation can also be written without referring to the vector \
elements: ",
  StyleBox[" ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["e",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{
            StyleBox["d",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["a",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "For our example where ",
  StyleBox["d",
    FontWeight->"Bold"],
  " has two rows and four columns and ",
  StyleBox["a ",
    FontWeight->"Bold"],
  "has dimension 4, this equation is actually two equations for the two \
elements of ",
  StyleBox["e",
    FontWeight->"Bold"],
  ": "
}], "Text"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {
                RowBox[{
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "[", \([1]\), "]"}]},
              {
                RowBox[{
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "[", \([2]\), "]"}]}
              }], "\[NegativeThinSpace]", ")"}], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"(", "\[NegativeThinSpace]", 
              RowBox[{GridBox[{
                    {\(-1\), "4"},
                    {"x", \(x + 2  y\)}
                    }], GridBox[{
                    {"2", "6"},
                    {\(\@2\), "15.4"}
                    }]}], "\[NegativeThinSpace]", ")"}], "\[CenterDot]", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {\(-1\)},
                  {"4"},
                  {"2"},
                  {"6"}
                  },
                ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
          "\[IndentingNewLine]", "         ", "=", " ", 
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {\(\((\(-1\), 4, 2, 6)\)\[CenterDot]\((\(-1\), 4, 2, 6)\)\)},
                {\(\((x, x + 2  y, \@2, 15.4)\)\[CenterDot]\((\(-1\), 4, 2, 
                      6)\)\)}
                }], "\[NegativeThinSpace]", ")"}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {
                RowBox[{
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "[", \([1]\), "]"}]},
              {
                RowBox[{
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "[", \([2]\), "]"}]}
              }], "\[NegativeThinSpace]", ")"}], "=", " ", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {"57"},
              {\(\(-x\) + 4 \((x + 2  y)\) + 2 \@ 2 + 6\[CenterDot]15.4\)}
              }], "\[NegativeThinSpace]", ")"}]}], 
      TraditionalForm]}]]], "NumberedEquation",
  CellTags->"(9.5.6)"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " this matrix multiplication can be done in one step using dot product \
notation:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(e = d . a\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.48"],

Cell[BoxData[
    \({57, \(\(95.22842712474619`\)\(\[InvisibleSpace]\)\) - x + 
        4\ \((x + 2\ y)\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The operations of this subection are summarized in Table ",
  ButtonBox["9.8",
    ButtonData:>"Table 9.8",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[\(Table  9  .8\ Simple\ vector\ and\ matrix\ operations\),
            FontSize->9,
            FontWeight->"Plain"]},
        {
          StyleBox[GridBox[{
                {Cell[TextData[StyleBox["a+b",
                    FontWeight->"Bold"]]], \(Vector\ addition\)},
                {Cell[TextData[StyleBox["a.b",
                    
                    FontWeight->
                      "Bold"]]], \(Vector\ or\ matrix\ multiplication\ \((dot\
\ product)\)\)}
                },
              ColumnSpacings->2.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Other Matrix Operations", "Section",
  CellTags->"c:22"],

Cell[CellGroupData[{

Cell["1.  Transpose", "Subsubsection",
  FontWeight->"Bold",
  CellTags->"i:33"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " supports a full suite of intrinsic functions for operating on matrices \
and vectors. For example, the transpose of a matrix ",
  StyleBox["d",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Transpose[d]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", is the matrix obtained by exchanging the rows with the columns:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[Transpose[d]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.49"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "x"},
            {"4", \(x + 2\ y\)},
            {"2", \(\@2\)},
            {"6", "15.4`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2. Inverse, the Unit Matrix", "Subsubsection",
  FontWeight->"Bold",
  CellTags->"i:34"],

Cell["\<\
There are a number of operations that are useful for square \
matrices, which have the same number of rows and columns.  Consider for \
example the following simple 2x2 matrix: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = {{1, \(-1\)}, {1, 1}};\)\), "\n", 
    \(\ MatrixForm[f]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.50"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(-1\)},
            {"1", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The inverse of this matrix, ",
  StyleBox["Inverse[f]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(\(\ \)\(-1\)\)], TraditionalForm]]],
  "in traditional mathematical notation, is another matrix with the same \
dimensions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1\  = \ Inverse[f];\)\), "\n", 
    \(MatrixForm[f1]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.51"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2\), \(1\/2\)},
            {\(-\(1\/2\)\), \(1\/2\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This matrix has the typical property of an inverse: when the matrix ",
  StyleBox["f",
    FontWeight->"Bold"],
  " is multiplied by its inverse ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[\(\(f\)\(\ \)\),
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  ", the result is the ",
  StyleBox["unit matrix ",
    FontSlant->"Italic"],
  "called",
  " ",
  StyleBox["unit",
    FontWeight->"Bold"],
  " :"
}], "Text",
  CellTags->"i:104"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(unit = f . f1;\)\), "\n", 
    \(MatrixForm[unit]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.52"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {"0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["unit",
    FontWeight->"Bold"],
  " matrix consists of 1's on the diagonal and 0's everywhere else, and has \
the property that when it acts on any vector it returns that vector unchanged \
(like multiplying a number by 1):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(unit . {x, y}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.53"],

Cell[BoxData[
    \({x, y}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The matrix inverse comes in handy when solving coupled sets of ",
  StyleBox["N",
    FontSlant->"Italic"],
  " linear equations in ",
  StyleBox["N",
    FontSlant->"Italic"],
  " unknowns. Such equations can be written in matrix form. For example,  for \
the given matrix of constants, ",
  StyleBox["f",
    FontWeight->"Bold"],
  ", and a given constant vector ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, s)\)\)]],
  ", the linear equation(s)"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", \((x, y)\)}], 
        "=", \((r, s)\)}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(9.5.7)"],

Cell[TextData[{
  "can be solved for the unknown vector ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " by application of the matrix inverse on each side:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(-1\)], "\[CenterDot]", 
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", \((x, y)\)}], "=", 
          RowBox[{
            RowBox[{
              StyleBox["unit",
                FontWeight->"Bold"], "\[CenterDot]", \((x, y)\)}], "=", 
            RowBox[{\((x, y)\), "=", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["f",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(-1\)], 
                "\[CenterDot]", \((r, s)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(9.5.8)"],

Cell[TextData[{
  "Since we have previously defined ",
  StyleBox["f1",
    FontWeight->"Bold"],
  " as the inverse of the matrix ",
  StyleBox["f  ",
    FontWeight->"Bold"],
  "given in Cell ",
  ButtonBox["9.50",
    ButtonData:>"Cell 9.50",
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can use Eq. (",
  ButtonBox["9.5.8",
    ButtonData:>"(9.5.8)",
    ButtonStyle->"Hyperlink"],
  ") to determine the solution to Eq. ",
  ButtonBox["(9.5.7)",
    ButtonData:>"(9.5.7)",
    ButtonStyle->"Hyperlink"],
  "  for this particular matrix via "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({x, y} = f1 . {r, s}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.54"],

Cell[BoxData[
    \({r\/2 + s\/2, \(-\(r\/2\)\) + s\/2}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3. Eigenvalues and Eigenvectors", "Subsubsection",
  FontWeight->"Bold",
  CellTags->"i:35"],

Cell[TextData[{
  "An ",
  StyleBox["eigenvector",
    FontSlant->"Italic"],
  " ",
  StyleBox["e ",
    FontWeight->"Bold"],
  "of a square matrix ",
  StyleBox["f",
    FontWeight->"Bold"],
  "  is a  special vector that has the following property: when the matrix \
acts on it, the result is again the eigenvector, multiplied by a constant ",
  StyleBox["\[Lambda]",
    FontFamily->"Symbol"],
  ". This constant is the ",
  StyleBox["eigenvalue",
    FontSlant->"Italic"],
  ".  In mathematical terms, the eigenvector satisfies the equation"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", 
          StyleBox["e",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], "=", 
        RowBox[{"\[Lambda]", " ", 
          StyleBox["e",
            FontWeight->"Bold",
            FontSlant->"Plain"]}]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(9.5.9)"],

Cell[TextData[{
  "For an ",
  StyleBox["N",
    FontSlant->"Italic"],
  "-by-",
  StyleBox["N",
    FontSlant->"Italic"],
  " matrix, there are ",
  StyleBox["N",
    FontSlant->"Italic"],
  " eigenvectors and ",
  StyleBox["N",
    FontSlant->"Italic"],
  " corresponding eigenvalues. They can be determined in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " using the intrinsic functions ",
  StyleBox["Eigenvectors[f]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Eigenvalues[f]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  For the 2-by-2 matrix ",
  StyleBox["f",
    FontWeight->"Bold"],
  " defined previously, the eigenvectors and eigenvalues are "
}], "Text",
  CellTags->"i:105"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.55"],

Cell[BoxData[
    \({{\(-\[ImaginaryI]\), 1}, {\[ImaginaryI], 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.56"],

Cell[BoxData[
    \({1 - \[ImaginaryI], 1 + \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the eigenvectors and eigenvalues are not necessarily real. \
However, one can verify that they do satisfy the eigenvector equation ",
  ButtonBox["(9.5.9)",
    ButtonData:>"(9.5.9)",
    ButtonStyle->"Hyperlink"],
  ". For example,  the first listed eigenvector, ",
  Cell[BoxData[
      \(TraditionalForm\`{\(-\[ImaginaryI]\), 1}\)]],
  ",  should have the eigenvalue ",
  Cell[BoxData[
      \(TraditionalForm\`1 - \[ImaginaryI]\)]],
  ". This can be easily verified using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f . {\(-I\), 1}\  - \ \((1 - I)\) {\(-I\), 1}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.57"],

Cell[BoxData[
    \({0, 0}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["4. Determinants", "Subsubsection",
  FontWeight->"Bold",
  CellTags->"i:36"],

Cell[TextData[{
  "The determinant of a square ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "- by - ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " matrix is the product of the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " eigenvalues of that matrix. In",
  StyleBox[" Mathematica ",
    FontSlant->"Italic"],
  ", the determinant is evaluated by the function ",
  StyleBox["Det",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.58"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell["\<\
which can be verified by multiplying the two eigenvalues together \
by hand, \
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - \[ImaginaryI])\)\ \((1 + \[ImaginaryI])\) = \
\(1 - \[ImaginaryI] + \[ImaginaryI] + 1 = 2. \)\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["5. Nullspace", "Subsubsection",
  FontWeight->"Bold",
  CellTags->"i:37"],

Cell[TextData[{
  "If any of the eigenvalues of a matrix are zero, the determinant is also \
zero. Eigenvectors corresponding to zero eigenvalues are said to be in the ",
  StyleBox["nullspace",
    FontSlant->"Italic"],
  " of a matrix. The nullspace can be found using the function ",
  StyleBox["NullSpace",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.59"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is a list with zero elements, because ",
  StyleBox["f",
    FontWeight->"Bold"],
  " has no eigenvectors with zero eigenvalues.  However, the 3-by-3 matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["g",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "2", "3"},
                {"2", "4", "6"},
                {"4", "6", "9"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
        TraditionalForm]]],
  "   has two eigenvectors in the nullspace:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = {{1, 2, 3}, {2, 4, 6}, {3, 6, 9}};\)\), "\n", 
    \(NullSpace[g]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.60"],

Cell[BoxData[
    \({{\(-3\), 0, 1}, {\(-2\), 1, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One can verify that either of these eigenvectors , ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            SubscriptBox[
              StyleBox["e",
                FontWeight->"Bold",
                FontSlant->"Plain"], "1"],
            "TraditionalForm"], "=", \((\(-3\), 0, 1)\)}], 
        TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            SubscriptBox[
              StyleBox["e",
                FontWeight->"Bold",
                FontSlant->"Plain"], "2"],
            "TraditionalForm"], " ", "=", " ", \((\(-2\), 1, 0)\)}], 
        TraditionalForm]]],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "returns a vector of zero length; the ",
  StyleBox["zero vector ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["0",
            FontWeight->"Bold"], "=", \((0, 0, 0)\)}], TraditionalForm]]],
  ". For example,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g . {\(-3\), 0, 1}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.61"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Of course, any linear combination of these two eigenvectors is also in the \
nullspace of ",
  StyleBox["g",
    FontWeight->"Bold"],
  ", since "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["g",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(c\_1\), 
                SubscriptBox[
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "1"]}], "+", 
              RowBox[{\(c\_2\), 
                SubscriptBox[
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"]}]}], ")"}]}], "=", 
        RowBox[{
          RowBox[{
            RowBox[{\(c\_1\), 
              RowBox[{
                StyleBox["g",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                SubscriptBox[
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "1"]}]}], "+", 
            RowBox[{\(c\_1\), 
              RowBox[{
                StyleBox["g",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                SubscriptBox[
                  StyleBox["e",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "2"]}]}]}], "=", 
          RowBox[{
            RowBox[{
              RowBox[{\(c\_1\), 
                StyleBox["0",
                  FontWeight->"Bold"]}], "+", 
              RowBox[{\(c\_1\), 
                StyleBox["0",
                  FontWeight->"Bold"]}]}], "=", 
            RowBox[{
              StyleBox["0",
                FontWeight->"Bold"], " ", "."}]}]}]}], TraditionalForm]],
  CellTags->"(9.5.10)"]], "NumberedEquation",
  CellTags->"(9.5.10)"],

Cell[TextData[{
  "Thus, these two eigenvectors define a ",
  StyleBox["plane",
    FontSlant->"Italic"],
  " in 3-space.  This plane, in fact,  is the nullspace of the matrix  ",
  StyleBox["g",
    FontWeight->"Bold"],
  ".  Any vector in this plane is a linear combination of the two \
eigenvectors, and when acted upon by ",
  StyleBox["g",
    FontWeight->"Bold"],
  " therefore returns the zero vector (0,0,0) (see Fig. ",
  ButtonBox["9.3",
    ButtonData:>"Fig. 9.3",
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=>0003Gb000`400?l00000o`00003oo`3ooooo
0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00
o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA
0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0oooo
o`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?oo
ool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo
003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oo
oe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3o
oooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0
ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3o
ool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0
ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo
0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003O0?ooo`030?knoP3oool0oooo0?l0
ooooo`3ooom^0?ooo`00dP3oool2000000D0oooo0P3no_ko0?ooool0ooooM@3oool00=80oooo0P00
00050?ooo`80o_kno`3ooooo0?ooogD0oooo003@0?ooo`030?knoP3oool0000000800000o`3ooooo
0?ooog/0oooo003@0?ooo`040?knoP3oool00@4100410@8000000P3oool01@3no_h0oooo0?ooo`3o
ool0o_kn00H0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooofX0oooo003D0?ooo`@00000o`3ooooo
0?ooogP0oooo003D0?ooo`@00000o`3ooooo0?ooogP0oooo003D0?ooo`03000000010@4000000080
0000o`3ooooo0?ooogL0oooo003D0?ooo`L00000o`3ooooo0?ooogD0oooo003D0?ooo`L00000o`3o
oooo0?ooogD0oooo003D0?ooo`P000001@3oool20?kno_l0ooooo`3ooom]0?ooo`00e03oool70000
000300410@000000oooo00`0oooo00<0o_kn0?ooo`3oool0903oool20?knoQ@00000o`3ooooo0?oo
obT0oooo003E0?ooo`X000001@3oool00`3no_h0oooo0?ooo`0/0?oooa00000000@00@4100000000
00000000o`3ooooo0?ooobT0oooo003E0?ooo`X000001@3oool00`3no_h0oooo0?ooo`0/0?oooa00
000000@00@410000000000000000o`3ooooo0?ooobT0oooo003E0?ooo`/0000000<0o_kn0?ooo`3o
ool0<@3ooolE00000?l0ooooo`3ooolW0?ooo`00e@3oool<000000H0oooo00<0o_kn0?ooo`3oool0
103oool00`3no_h0oooo0?ooo`0T0?ooo`/000000P010@4700000?l0ooooo`3ooolW0?ooo`00e@3o
ool8000000800@411000000d0?ooo`8000003@3oool300000?l0ooooo`3ooolW0?ooo`00e@3oool8
000000800@411000000d0?ooo`8000003@3oool300000?l0ooooo`3ooolW0?ooo`00e@3oool70000
000300410@000000000000D00000=03oool3000000`0oooo0`00003o0?ooool0oooo9P3oool00<h0
oooo0P3no_h50?ooo`0400410@0000000000000000800@41200000000`010@4000000?ooo`0Z0?oo
o`030?knoP3oool0oooo00@0oooo00<0o_kn0?ooo`0000000P00000=0?ooo`030000003oool0oooo
0?l0ooooo`3ooolT0?ooo`00cP3oool20?knoPD0oooo00@00@4100000000000000000P010@480000
000300410@000000oooo02X0oooo00<0o_kn0?ooo`3oool0103oool00`3no_h0oooo000000020000
00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo003>0?ooo`80o_kn1@3oool600000003
00410@000000000000T000001@3oool20?knoRd0oooo0`0000050?ooo`040?knoP3oool0oooo0?kn
o_l0ooooo`3ooolY0?ooo`00eP3ooolB000003@0oooo0`00003o0?ooool0oooo<@3oool00=H0oooo
5@00000c0?ooo`030000003no_h0o_kn0080o_kno`3ooooo0?ooobd0oooo003F0?oooaD00000<`3o
ool00`000000o_kn0?knoP020?kno_l0ooooo`3oool]0?ooo`00eP3oool>0000000300410@000000
000000D00000<`3oool00`000000oooo0?ooo`3o0?ooool0oooo;P3oool00=H0oooo6000000b0?oo
o`800000o`3ooooo0?ooobh0oooo003F0?oooaT00000<`3oool00`000000oooo0?ooo`3o0?ooool0
oooo:`3oool00=H0oooo6@00000c0?ooo`030000003oool0oooo0?l0ooooo`3oool[0?ooo`00eP3o
oolJ00000380oooo0P0000020?kno_l0ooooo`3ooolZ0?ooo`00eP3oool>000000<00@412@000002
00410B`0oooo00<0o_kn0?ooo`3oool00P3oool300000?l0ooooo`3ooolZ0?ooo`00eP3ooolM0000
02D0oooo00@000000?ooo`3oool0oooo0P3no_h60?ooo`<00000o`3ooooo0?ooobT0oooo003F0?oo
oad000009@3oool010000000oooo0?ooo`3oool20?knoPH0oooo0`00003o0?ooool0oooo:@3oool0
0=H0oooo7`00000S0?ooo`0400410@00000000000?ooo`80o_kn203oool3000000@0oooo00<0o_kn
0?ooo`3oool0o`3ooooo0?ooob00oooo003H0?oooah000008`3oool3000000/0oooo0`00003o0?oo
ool0oooo9P3oool00=P0oooo7P00000S0?ooo`<000002`3oool300000?l0ooooo`3ooolV0?ooo`00
f03ooolO00000280oooo4P00003o0?ooool0oooo9@3oool00=P0oooo00<00@410000000000006P00
000010010@40000000000000000P0?ooo`X0000000<00@410000000000001`00003o0?ooool0oooo
8`3oool00=P0oooo8P00000O0?oooa@0000000<00@410?knoP3oool0o`3ooooo0?ooob00oooo003H
0?ooob8000007`3ooolD0000000300410@3no_h0oooo0?l0ooooo`3ooolP0?ooo`00f03ooolS0000
0200oooo1`0000000`010@4000000000000900000?l0ooooo`3ooolR0?ooo`00f03ooolS00000080
0@41o`3ooooo0?oooe<0oooo003A0?ooo`030?knoP3oool0oooo0080oooo0P3no_hV00000?l0oooo
o`3ooomB0?ooo`00d@3oool00`3no_h0oooo0?ooo`020?ooo`80o_kn9P00003o0?ooool0ooooDP3o
ool00=P0oooo9`00003o0?ooool0ooooD@3oool00=T0oooo:000003o0?ooool0ooooC`3oool00=T0
oooo:000003o0?ooool0ooooC`3oool00=T0oooo:00000000`010@40oooo0?ooo`3o0?ooool0oooo
C03oool00=T0oooo:@00003o0?ooool0ooooCP3oool00=T0oooo8P00000200410@800000o`3ooooo
0?oooe40oooo003I0?ooob8000000P010@4200000?l0ooooo`3ooomA0?ooo`00f@3ooolV00000?l0
ooooo`3ooomA0?ooo`00f@3ooolU00000?l0ooooo`3ooomB0?ooo`00f@3ooolT00000?l0ooooo`3o
oomC0?ooo`00f@3ooolT00000?l0ooooo`3ooomC0?ooo`00f@3ooolN000000800@410P00003o0?oo
ool0ooooE@3oool00=T0oooo3P0000000`010@4000000000000?000000030?knoP3oool0oooo0?l0
ooooo`3ooomD0?ooo`00f@3oool4000000800@41400000000`010@4000000000000500000?l0oooo
o`3ooomI0?ooo`00f@3oool4000000800@41400000000`010@4000000000000500000?l0ooooo`3o
oomI0?ooo`00f@3ooolL00000?l0ooooo`3ooomK0?ooo`00f@3ooolL00000?l0ooooo`3ooomK0?oo
o`00f@3ooolL00000?l0ooooo`3ooomK0?ooo`00f@3oool:0000000300410@000000000000l00000
o`3ooooo0?oooe/0oooo003K0?oooa000000103oool700000?l0ooooo`3ooomJ0?ooo`00f`3oool4
0000000400410@0000000000000000800@410`0000070?ooo`L000000`3oool00`3no_h0oooo0?oo
o`3o0?ooool0ooooE03oool00=/0oooo1000000010010@40000000000000000200410@<000001`3o
ool7000000<0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?oooe@0oooo003K0?ooo`T00000303oool7
00000?l0ooooo`3ooomI0?ooo`00l03oool700000?l0ooooo`3ooomI0?ooo`00lP3oool7000000D0
oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooodl0oooo003b0?ooo`L000001@3oool00`3no_h0oooo
0?ooo`3o0?ooool0ooooC`3oool00?80oooo0`00000010010@40000000000000003o0?ooool0oooo
E`3oool00=T0oooo0P3no_hH0?ooo`L00000o`3ooooo0?oooeH0oooo003I0?ooo`80o_kn603oool7
00000?l0ooooo`3ooomF0?ooo`00l`3oool20000000300410@0000000000008000002P3oool00`3n
o_h0oooo0?ooo`3o0?ooool0ooooB@3oool00>40oooo0P3no_hB0?ooo`H00000o`3ooooo0?oooeD0
oooo003P0?ooo`030?knoP3oool0oooo0180oooo00<00@410000000000000`0000040?ooo`80o_kn
0`3oool00`3no_h0oooo0?ooo`3o0?ooool0ooooB@3oool00>00oooo00<0o_kn0?ooo`3oool04P3o
ool00`010@40000000000003000000@0oooo0P3no_h30?ooo`030?knoP3oool0oooo0?l0ooooo`3o
oom90?ooo`00mP3oool700000?l0ooooo`3ooomC0?ooo`00mP3oool30000000400410@0000000000
000000@0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?oood`0oooo003g0?ooo`L00000o`3ooooo0?oo
oe80oooo003g0?ooo`L00000o`3ooooo0?oooe80oooo003g0?ooo`80000000<00@41000000000000
0P0000040?ooo`80o_kno`3ooooo0?oood`0oooo003i0?ooo`H00000o`3ooooo0?oooe40oooo003i
0?ooo`H00000o`3ooooo0?oooe40oooo003i0?ooo`H00000o`3ooooo0?oooe40oooo003j0?ooo`L0
0000o`3ooooo0?ooodl0oooo003j0?ooo`L000000`3oool00`3no_h0oooo0?ooo`3o0?ooool0oooo
B@3oool00?X0oooo1`0000030?ooo`030?knoP3oool0oooo0?l0ooooo`3ooom90?ooo`00n`3oool7
00000?l0ooooo`3ooom>0?ooo`00n`3oool700000?l0ooooo`3ooom>0?ooo`00o@3oool7000000D0
oooo00<0o_kn0?ooo`3oool0o`3ooooo0?oood@0oooo003m0?ooo`L000001@3oool00`3no_h0oooo
0?ooo`3o0?ooool0ooooA03oool00?d0oooo0P00000200410@<00000o`3ooooo0?oood`0oooo003n
0?ooo`L00000o`3ooooo0?oood/0oooo003n0?ooo`03000000010@400@4100@000002P3oool00`3n
o_h0oooo0?ooo`3o0?ooool0oooo?P3oool00?h0oooo00<0000000410@010@401000000:0?ooo`03
0?knoP3oool0oooo0?l0ooooo`3oooln0?ooo`00o`3oool700000?l0ooooo`3ooom:0?ooo`00o`3o
ool200410@D00000103oool20?knoP<0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?oooch0oooo003o
0?ooo`800@411@0000040?ooo`80o_kn0`3oool00`3no_h0oooo0?ooo`3o0?ooool0oooo?P3oool0
0?l0oooo0P3oool700000?l0ooooo`3ooom80?ooo`00o`3oool20?ooo`<0000000@00@4100000000
00000000103oool00`3no_h0oooo0?ooo`3o0?ooool0oooo@@3oool00?l0oooo0`3oool700000?l0
ooooo`3ooom70?ooo`00o`3oool30?ooo`L00000o`3ooooo0?ooodL0oooo003o0?ooo`<0oooo0P00
00000`010@40000000000002000000@0oooo0P3no_ko0?ooool0oooo@@3oool00?l0oooo1@3oool6
00000?l0ooooo`3ooom60?ooo`00o`3oool50?ooo`H00000o`3ooooo0?ooodH0oooo003o0?ooo`D0
oooo1P00003o0?ooool0ooooAP3oool00?l0oooo1P3oool700000?l0ooooo`3ooom40?ooo`00o`3o
ool60?ooo`L000000`3oool00`3no_h0oooo0?ooo`3o0?ooool0oooo?P3oool00?l0oooo1P3oool7
000000<0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?oooch0oooo003o0?ooo`L0oooo1`00003o0?oo
ool0oooo@`3oool00?l0oooo1`3oool700000?l0ooooo`3ooom30?ooo`00o`3oool90?ooo`L00000
1@3oool00`3no_h0oooo0?ooo`3o0?ooool0oooo>@3oool00?l0oooo2@3oool7000000D0oooo00<0
o_kn0?ooo`3oool0o`3ooooo0?ooocT0oooo003o0?ooo`T0oooo0P00000200410@<00000o`3ooooo
0?oood40oooo003o0?ooo`X0oooo1`00003o0?ooool0oooo@03oool00?l0oooo2P3oool00`000000
0@4100410@04000000T0oooo0P3no_ko0?ooool0oooo=@3oool00?l0oooo2P3oool00`0000000@41
00410@04000000T0oooo0P3no_ko0?ooool0oooo=@3oool00?l0oooo2`3oool700000?l0ooooo`3o
oolo0?ooo`00o`3oool;0?ooo`800@411@0000040?ooo`80o_kn0P3oool20?kno_l0ooooo`3ooole
0?ooo`00o`3oool;0?ooo`800@411@0000040?ooo`80o_kn0P3oool20?kno_l0ooooo`3ooole0?oo
o`00o`3oool=0?ooo`L00000o`3ooooo0?ooocd0oooo003o0?ooo`d0oooo0`00000010010@400000
0000000000040?ooo`030?knoP3oool0oooo0?l0ooooo`3ooolf0?ooo`00o`3oool>0?ooo`L00000
o`3ooooo0?oooc`0oooo003o0?ooo`h0oooo1`00003o0?ooool0oooo?03oool00?l0oooo3P3oool2
0000000300410@000000000000800000103oool00`3no_h0oooo0?ooo`3o0?ooool0oooo=@3oool0
0?l0oooo403oool600000?l0ooooo`3ooolk0?ooo`00o`3oool@0?ooo`H00000o`3ooooo0?oooc/0
oooo003o0?oooa00oooo1P00003o0?ooool0oooo>`3oool00?l0oooo4@3oool700000?l0ooooo`3o
ooli0?ooo`00o`3ooolA0?ooo`L000000P3oool20?kno_l0ooooo`3ooole0?ooo`00o`3ooolB0?oo
o`L00000o`3ooooo0?ooocP0oooo003o0?oooa80oooo1`00003o0?ooool0oooo>03oool00?l0oooo
4P3oool700000?l0ooooo`3ooolh0?ooo`00o`3ooolD0?ooo`H000001P3oool00`3no_h0oooo0?oo
o`3o0?ooool0oooo;P3oool00?l0oooo503oool6000000H0oooo00<0o_kn0?ooo`3oool0o`3ooooo
0?ooobh0oooo003o0?oooa@0oooo0P00000200410@800000o`3ooooo0?ooocL0oooo003o0?oooaD0
oooo1`00003o0?ooool0oooo=@3oool00?l0oooo5@3oool00`0000000@4100410@04000000T0oooo
0P3no_ko0?ooool0oooo:P3oool00?l0oooo5@3oool00`0000000@4100410@04000000T0oooo0P3n
o_ko0?ooool0oooo:P3oool00?l0oooo5P3oool700000?l0ooooo`3ooold0?ooo`00o`3ooolF0?oo
o`800@411@0000040?ooo`80o_kn0P3oool20?kno_l0ooooo`3ooolZ0?ooo`00o`3ooolH0?ooo`L0
0000o`3ooooo0?oooc80oooo003o0?oooaP0oooo1`00003o0?ooool0oooo<P3oool00?l0oooo603o
ool2000000800@410`0000040?ooo`030?knoP3oool0oooo0?l0ooooo`3oool[0?ooo`00o`3ooolI
0?ooo`L00000o`3ooooo0?oooc40oooo003o0?oooaT0oooo1`00003o0?ooool0oooo<@3oool00?l0
oooo6@3oool00`0000000@4100410@04000000@0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooobX0
oooo003o0?oooaX0oooo1`00003o0?ooool0oooo<03oool00?l0oooo6P3oool700000?l0ooooo`3o
ool`0?ooo`00o`3ooolJ0?ooo`L00000o`3ooooo0?oooc00oooo003o0?oooa`0oooo1`00003o0?oo
ool0oooo;P3oool00?l0oooo703oool700000080oooo0P3no_ko0?ooool0oooo:P3oool00>D0oooo
0P3no_he0?ooo`L00000o`3ooooo0?ooobd0oooo003U0?ooo`80o_kn=@3oool700000?l0ooooo`3o
ool]0?ooo`00j03oool=000002L0oooo1`00003o0?ooool0oooo;@3oool00>`0oooo100000020?oo
o`030?knoP3oool0oooo02T0oooo1P0000060?ooo`030?knoP3oool0oooo0?l0ooooo`3ooolS0?oo
o`00k03oool400000080oooo00<0o_kn0?ooo`3oool0:@3oool6000000H0oooo00<0o_kn0?ooo`3o
ool0o`3ooooo0?ooob<0oooo003/0?ooo`@00000;P3oool2000000800@410P00003o0?ooool0oooo
;03oool00>`0oooo100000020?ooo`030?knoP3oool0oooo02X0oooo1`00003o0?ooool0oooo:P3o
ool00>X0oooo0P3no_h4000000L0oooo0P3no_hV0?ooo`03000000010@400@4100@000002@3oool2
0?kno_l0ooooo`3ooolO0?ooo`00jP3oool20?knoP@000001`3oool20?knoRH0oooo00<000000041
0@010@40100000090?ooo`80o_kno`3ooooo0?oooal0oooo003/0?ooo`@00000<03oool700000?l0
ooooo`3ooolY0?ooo`00k03oool400000300oooo0P010@45000000@0oooo0P3no_h20?ooo`80o_kn
o`3ooooo0?oooal0oooo003/0?ooo`@00000<P3oool700000?l0ooooo`3ooolW0?ooo`00k03oool4
00000380oooo1`00003o0?ooool0oooo9`3oool00>`0oooo1000000b0?ooo`8000000P010@430000
00@0oooo00<0o_kn0?ooo`3oool0o`3ooooo0?ooob00oooo003/0?ooo`@00000<`3oool700000?l0
ooooo`3ooolV0?ooo`00k03oool4000003<0oooo00<0000000410@010@40100000040?ooo`030?kn
oP3oool0oooo0?l0ooooo`3ooolO0?ooo`00k03oool4000003<0oooo00<0000000410@010@401000
00040?ooo`030?knoP3oool0oooo0?l0ooooo`3ooolO0?ooo`00k03oool4000003@0oooo1`00003o
0?ooool0oooo9@3oool00>`0oooo1000000d0?ooo`L00000o`3ooooo0?ooobD0oooo003/0?ooo`@0
0000=03oool700000?l0ooooo`3ooolU0?ooo`00k03oool4000003H0oooo1`00003o0?ooool0oooo
8`3oool00<d0oooo2@00000F0?ooo`@00000=P3oool700000080oooo0P3no_ko0?ooool0oooo7`3o
ool00<X0oooo2`00000010010@40000000000000000<0?ooo`80o_kn1@3oool4000003L0oooo1`00
003o0?ooool0oooo8P3oool00<X0oooo2`00000010010@40000000000000000<0?ooo`80o_kn1@3o
ool4000003L0oooo1`00003o0?ooool0oooo8P3oool00<T0oooo4P0000040?ooo`030?knoP3oool0
oooo00X0oooo1000000g0?ooo`L00000o`3ooooo0?ooob80oooo00370?ooo`800@41100000000`01
0@40000000000004000000D0oooo0`00000@0?ooo`@00000>@3oool6000000H0oooo00<0o_kn0?oo
o`3oool0o`3ooooo0?oooaP0oooo00370?ooo`/000001P3oool00`3no_h0oooo0?ooo`02000000<0
oooo00<0o_kn0?ooo`3oool02@3oool4000003T0oooo0P00000200410@800000o`3ooooo0?ooob40
oooo00370?ooo`/000001P3oool00`3no_h0oooo0?ooo`02000000<0oooo00<0o_kn0?ooo`3oool0
2@3oool4000003T0oooo0P00000200410@800000o`3ooooo0?ooob40oooo00360?ooo`/00000103o
ool00`3no_h0oooo0?ooo`040?ooo`<00000203oool00`3no_h0oooo0?ooo`020?ooo`@00000>P3o
ool700000?l0ooooo`3ooolO0?ooo`00aP3oool;000000`0oooo0P0000040?ooo`050?knoP3oool0
oooo0?ooo`3no_h0103oool4000003X0oooo00<0000000410@010@40100000090?ooo`80o_kno`3o
oooo0?oooa@0oooo00360?ooo`/00000303oool2000000@0oooo00D0o_kn0?ooo`3oool0oooo0?kn
oP040?ooo`@00000>P3oool00`0000000@4100410@04000000T0oooo0P3no_ko0?ooool0oooo503o
ool00<H0oooo2P00000L0?ooo`@00000>`3oool700000?l0ooooo`3ooolN0?ooo`00a@3oool;0000
0100oooo00<0o_kn0?ooo`3oool0103oool3000000030?ooo`000000000000<00000>`3oool20041
0@D00000103oool20?knoP80oooo0P3no_ko0?ooool0oooo503oool00<D0oooo00<00@4100000000
00000P00000010010@40000000000000000L0?ooo`H000001@3oool01@3no_h0oooo0?ooo`3oool0
o_kn03<0oooo1`00003o0?ooool0oooo703oool00<D0oooo00<00@410000000000000P0000001001
0@40000000000000000L0?ooo`H000001@3oool01@3no_h0oooo0?ooo`3oool0o_kn03<0oooo1`00
003o0?ooool0oooo703oool00<D0oooo2@00000P0?ooo`800000?@3oool2000000800@410`000004
0?ooo`030?knoP3oool0oooo0?l0ooooo`3ooolE0?ooo`00a@3oool9000000<0oooo00<0o_kn0?oo
o`3oool0303oool00`3no_h0oooo0?ooo`0F0?ooo`030?knoP3oool0oooo0380oooo1`00003o0?oo
ool0oooo6`3oool00<D0oooo2@00000I0?ooo`030?knoP3oool0oooo04@0oooo00<0000000410@01
0@40100000040?ooo`030?knoP3oool0oooo0?l0ooooo`3ooolD0?ooo`00a@3oool9000001T0oooo
00<0o_kn0?ooo`3oool0A03oool00`0000000@4100410@04000000@0oooo00<0o_kn0?ooo`3oool0
o`3ooooo0?oooa@0oooo00330?ooo`80o_kn6P00001@0?ooo`L00000o`3ooooo0?oooaX0oooo0035
0?oooaX000003`3oool00`3no_h0oooo0?ooo`020?ooo`80o_kn>P3oool700000?l0ooooo`3ooolJ
0?ooo`00a@3oool9000000L0oooo2P00001B0?ooo`L00000o`3ooooo0?oooaP0oooo00350?ooo`T0
00001`3oool:00000580oooo1`00003o0?ooool0oooo603oool00<H0oooo200000030?ooo`040?kn
oP3oool0oooo0?ooo`X00000DP3oool700000080oooo0P3no_ko0?ooool0oooo503oool00<H0oooo
200000070?ooo`P00000E@3oool700000?l0ooooo`3ooolG0?ooo`00aP3oool8000000L0oooo2000
001E0?ooo`L00000o`3ooooo0?oooaL0oooo001@0?ooo`<0o_knM03oool7000000L0oooo2000001E
0?ooo`L00000o`3ooooo0?oooaL0oooo000m0?ooo`030?knoP3oool0oooo00l0oooo2000001`0?oo
o`L000001`3oool7000005P0oooo1P0000060?ooo`030?knoP3oool0oooo0?l0ooooo`3oool=0?oo
o`00?@3oool30?knoPP0oooo3`00001b0?ooo`L00000103oool8000000L0oooo00<0o_kn0?ooo`3o
ool0CP3oool2000000800@410P00003o0?ooool0oooo5P3oool003d0oooo0`3no_h80?ooo`l00000
LP3oool7000000@0oooo200000070?ooo`030?knoP3oool0oooo04h0oooo0P00000200410@800000
o`3ooooo0?oooaH0oooo000_0?ooo`<0o_kn4@3oool8000000<00@412@00001c0?ooo`L000000`3o
ool7000005X0oooo1`00003o0?ooool0oooo503oool003`0oooo4000000200410@T00000LP3oool0
103no_h0oooo00410@010@4<000000L0oooo00<0o_kn0?ooo`3oool0DP3oool00`0000000@410041
0@04000000T0oooo0P3no_ko0?ooool0oooo2@3oool003D0oooo0`00000200410Ad00000LP3oool0
0`3no_h0oooo0?ooo`020?ooo`P000001`3oool20?knoUL0oooo1`00003o0?ooool0oooo4`3oool0
03D0oooo0`00000200410Ad00000LP3oool00`3no_h0oooo0?ooo`020?ooo`P000001`3oool20?kn
oUL0oooo1`00003o0?ooool0oooo4`3oool002h0oooo:@00003O0?ooo`800@411@0000040?ooo`80
o_kn0P3oool20?kno_l0ooooo`3oool90?ooo`009`3oool`00000>40oooo1P00003o0?ooool0oooo
4P3oool002L0oooo<000003Q0?ooo`H00000o`3ooooo0?oooa80oooo000K0?ooo`030?knoP3oool0
oooo00@0oooo=@00003Q0?ooo`8000000P010@42000000D0oooo00<0o_kn0?ooo`3oool0o`3ooooo
0?ooo`X0oooo000K0?ooocd00000h@3oool700000?l0ooooo`3oool@0?ooo`00503ooom400000>40
oooo00<0000000410@010@40100000040?ooo`030?knoP3oool0oooo0?l0ooooo`3oool90?ooo`00
503ooom400000>40oooo00<0000000410@010@40100000040?ooo`030?knoP3oool0oooo0?l0oooo
o`3oool90?ooo`005`3ooom100000>80oooo1`00003o0?ooool0oooo3`3oool001T0oooo?`00003R
0?ooo`L00000o`3ooooo0?ooo`l0oooo000L0?ooo`H0000000<00@41000000000000<`00003T0?oo
o`L00000o`3ooooo0?ooo`d0oooo000L0?ooo`H0000000<00@41000000000000<`00003T0?ooo`L0
0000o`3ooooo0?ooo`d0oooo000N0?ooo`@0000000<00@41000000000000<`00003T0?ooo`L00000
0P3oool20?kno_l0ooooo`3oool90?ooo`007P3oool50000000300410@0000000000038000000P01
0@43000000/0oooo00<0o_kn0?ooo`3oool03@3oool00`3no_h0oooo0?ooo`070?ooo`030?knoP3o
ool0oooo01d0oooo0P3no_h00`3oool0o_kn0?ooo`2F0?ooo`L00000o`3ooooo0?ooo``0oooo000N
0?ooo`D0000000<00@41000000000000<P00000200410@<000002`3oool00`3no_h0oooo0?ooo`0=
0?ooo`030?knoP3oool0oooo00L0oooo00<0o_kn0?ooo`3oool07@3oool20?knoP030?ooo`3no_h0
oooo09H0oooo1`00003o0?ooool0oooo303oool001l0oooo1@00000200410@L0000000<00@410000
00000000:P0000000`010@40000000000002000000800@411`00000E0?ooo`80o_kn0`3oool00`3n
o_h0oooo0?ooo`0E0?ooo`80o_knX@3oool700000?l0ooooo`3oool<0?ooo`00803ooolB00000003
00410@000000000002d0000000<00@41000000000000300000060?ooo`030?knoP3oool0oooo01@0
oooo00<0o_kn0?ooo`3oool03@3oool20?knoYh0oooo1`0000060?ooo`030?knoP3oool0oooo0?l0
ooooo`3oool20?ooo`008P3oool80000000300410@000000000004l000001`3oool00`3no_h0oooo
0?ooo`060?ooo`<0o_kn4`3oool20?knoYX0oooo0`00000200410@800000o`3ooooo0?ooo`/0oooo
000R0?ooo`P0000000<00@41000000000000C`0000070?ooo`030?knoP3oool0oooo00H0oooo0`3n
o_hC0?ooo`80o_knVP3oool3000000800@410P00003o0?ooool0oooo2`3oool00280oooo1`000000
0`3GemL000000000000/000000<0emOG0`0000000`010@4000000000000U000002<0oooo0P3no_jE
0?ooo`L00000o`3ooooo0?ooo`T0oooo000S0?ooo`L000000`3GemLZ000000P0emOG0P3Fe]H00`3G
emL0f=SH0=OGe`020=OGea40000000<00@410000000000002@00000010010@400000000000010@4:
000000H0oooo0P3no_jW0?ooo`03000000010@400@4100@000002@3oool20?kno_l0ooooo@3oool0
02@0oooo1`0000020=OGe`030=SHf03GemL0000002L000001P3GemL0103Hf=P0emOG0=SHf03Hf=P?
0=OGeb8000000`010@4500000:L0oooo1`00003o0?ooool0oooo203oool002@0oooo1`0000020=OG
e`030=SHf03GemL0000002L000001P3GemL0103Hf=P0emOG0=SHf03Hf=P?0=OGeb8000000`010@45
00000:L0oooo1`00003o0?ooool0oooo203oool002@0oooo2@0000050=OGebD000007P3GemL20=KF
eP@0emOG:P00002L0?ooo`800@411@0000040?ooo`80o_kn0P3oool20?kno_l0ooooo@3oool002@0
oooo0P3no_h7000000P0emOG8@00000^0=OGe`/000000P010@4?0000000300410@000000000000H0
00000P010@4400000280oooo00@0o_kn0?ooo`3oool0o_knKP3oool600000?l0ooooO@3oool00`3n
o_h0oooo0?ooo`1O0?ooo`80o_kn9@3oool002L0oooo0P010@45000000<0emOG00<0e]KF0=OGe`3G
emL0103GemLN000003D0emOG00@0e]KF0=OGe`3GemL0emOG3`00000200410A00000000<00@410000
000000001`00000;0?ooo`030?knoP3oool0oooo07/0oooo0P00000200410@8000001@3oool00`3n
o_h0oooo0?ooo`3o0?ooofL0oooo00<0o_kn0?ooo`3oool0203oool00`3no_h0oooo0?ooo`1J0?oo
o`<0o_kn;03oool002L0oooo0P010@45000000<0emOG00<0e]KF0=OGe`3GemL0103GemLN000003D0
emOG00@0e]KF0=OGe`3GemL0emOG3`00000200410A00000000<00@410000000000001`00000;0?oo
o`030?knoP3oool0oooo07/0oooo0P00000200410@8000001@3oool00`3no_h0oooo0?ooo`3o0?oo
ofL0oooo00<0o_kn0?ooo`3oool0203oool00`3no_h0oooo0?ooo`1J0?ooo`<0o_kn;03oool002T0
oooo1P0000020=SHf0030=OGe`3Fe]H0emOG0080emOG0P3Fe]H20=OGea`00000?03GemL00`3Fe]H0
emOG0=OGe`040=OGea80000000<00@410000000000005@0000040?ooo`80o_knN`3oool700000?l0
ooooO`3oool00`3no_h0oooo0?ooo`220?ooo`00:@3oool6000000l0emOG5P00001@0=OGe`d00000
0P010@400`0000000@4100410@0H00000140oooo00<0o_kn0?ooo`3oool0HP3oool00`0000000@41
00410@04000000@0oooo00<0o_kn0?ooo`3oool0o`3ooomV0?ooo`@000003P3oool00`3no_h0oooo
0?ooo`1C0?ooo`030?knoP3oool0oooo02`0oooo000Y0?ooo`H000003`3GemLF00000500emOG3@00
000200410@03000000010@400@4101P000004@3oool00`3no_h0oooo0?ooo`1R0?ooo`0300000001
0@400@4100@00000103oool00`3no_h0oooo0?ooo`3o0?ooofH0oooo1000000>0?ooo`030?knoP3o
ool0oooo05<0oooo00<0o_kn0?ooo`3oool0;03oool002X0oooo1`0000050=OGe`80f=SH2@3GemLC
00000380emOG00<0f=SH0=OGe`3GemL05`3GemL00`3Fe]H0emOG0=OGe`0:0=OGe`800@41:@000009
0?ooo`80o_knHP3oool700000?l0ooooJ`3oool8000000D0oooo0P3no_h00`3oool0o_kn0?ooo`1K
0?ooo`030?knoP3oool0oooo02P0oooo000[0?ooo`@000000P010@400`000000emOG0=OGe`0@0=OG
e`03000000010@400@4100d000000P3Hf=P/0=OGe`040=KFeP3GemL0f=SH0=SHf2T0emOG00<0e]KF
0=OGe`3GemL01P3GemL[00000680oooo1`00003o0?ooof/0oooo3@00001B0?ooo`D00000303oool4
000002@0oooo000[0?ooo`P000000`3GemL20=SHf080emOG0P3Fe]H;0=OGe``00000B`3GemL20=SH
f0H0emOG0`3Hf=P80=OGe`80e]KF3`3GemLZ000005/0oooo1`00003o0?ooofT0oooo4@00001=0?oo
o`@000000P010@400`000000oooo0?ooo`070?ooo`H0000000<00@410?ooo`3oool08@3oool002/0
oooo200000030=OGe`80f=SH0P3GemL20=KFeP/0emOG3000001;0=OGe`80f=SH1P3GemL30=SHf0P0
emOG0P3Fe]H?0=OGebX00000F`3oool700000?l0ooooJ@3ooolA000004d0oooo1000000200410@03
0000003oool0oooo00L0oooo1P0000000`010@40oooo0?ooo`0Q0?ooo`00;@3oool6000000T0emOG
00<0f=SH0=OGe`3GemL01@3GemL00`3Hf=P0emOG0=OGe`020=OGe`X00000AP3GemL00`3Hf=P0emOG
0=OGe`090=OGe`030=KFeP3GemL0emOG02D0emOG00<0000000410@010@409`00001@0?ooo`L00000
0P3oool20?kno_l0ooooH`3oool>0000000400410@000000000000410@@00000BP3oool8000000L0
oooo2P00000Q0?ooo`00;P3oool7000000030=OGe`3Hf=P0f=SH01@0emOG1P0000240=OGe`d00000
00<00@410000000000006`00000;0?ooo`030?knoP3oool0oooo00d0oooo0P3no_h80?ooo`030?kn
oP3oool0oooo01l0oooo1`00003o0?ooofH0oooo6P0000160?ooo`@000000`3oool3000000D0oooo
1P0000040?ooo`030000003oool0oooo01h0oooo000_0?ooo`@000000P010@401@000000emOG0=OG
e`3GemL0f=SH01@0emOG100000000`3Hf=P0emOG0=OGe`2<0=OGeb/000005P3oool01@3no_h0oooo
0?ooo`3oool0o_kn01L0oooo0P3no_h80?ooo`L00000o`3ooomV0?oooad00000B`3oool2000000D0
oooo1P0000050?ooo`030000003oool0oooo01d0oooo000_0?ooo`@000000P010@401@000000emOG
0=OGe`3GemL0f=SH01@0emOG100000000`3Hf=P0emOG0=OGe`2<0=OGeb/000005P3oool01@3no_h0
oooo0?ooo`3oool0o_kn01L0oooo0P3no_h80?ooo`L00000o`3ooomV0?oooad00000B`3oool20000
00D0oooo1P0000050?ooo`030000003oool0oooo01d0oooo000_0?ooo`L00000]@3GemLK00000080
0@413@0000060?ooo`030?knoP3oool0oooo01@0oooo0P3no_h?0?ooo`030?knoP3oool0oooo00<0
oooo1`0000060?ooo`030?knoP3oool0oooo0?l0ooooG03ooolR00000140oooo00<0o_kn0?ooo`3o
ool0<P3oool3000000<0oooo1`0000050?ooo`<000007@3oool00340oooo1`0000000`3GemL0f=SH
0=OGe`0@0=OGe`030=KFeP3GemL0emOG00@0emOG00<0e]KF0=OGe`3GemL0TP3GemL00`3Hf=P0emOG
0=OGe`0<0=OGe`D000000P010@470000000300410@000000000001T000001`3oool20?knoPP0oooo
0`3no_hE0?ooo`L00000o`3ooomU0?oooaD0000000<00@410000000000004000000i0?ooo`80o_kn
1`3oool200000080oooo00<0000000410@0000000P00000W0?ooo`00<@3oool7000000030=OGe`3H
f=P0emOG0100emOG00<0e]KF0=OGe`3GemL0103GemL00`3Fe]H0emOG0=OGe`2B0=OGe`030=SHf03G
emL0emOG00`0emOG1@00000200410@L0000000<00@410000000000006@0000070?ooo`80o_kn203o
ool30?knoQD0oooo1`00003o0?ooofD0oooo5@0000000`010@4000000000000@000003T0oooo0P3n
o_h70?ooo`8000000P3oool00`0000000@4100000002000002L0oooo000]0?ooo`030?knoP3oool0
oooo0080oooo1`0000000`3GemL0e]KF0=KFeP0H0=OGe`80f=SHOP3GemL00`3Fe]H0emOG0=OGe`0=
0=OGe`030=SHf03GemL0emOG01P0emOG:`00000Q0?ooo`L00000o`3ooomR0?oooad0000000<00@41
0000000000003@0000070?ooo`030?knoP3oool0oooo03D0oooo00<000000?ooo`3oool01@00000W
0?ooo`00<P3oool8000000<0emOG00<0f=SH0=OGe`3GemL0U@3GemL0103Fe]H0emOG0=OGe`3Hf=P>
0=OGe`050=KFeP3GemL0emOG0=OGe`3Fe]H03`3GemL20=SHf0L0emOG00@0f=SH0=OGe`3Hf=P0f=SH
0P3GemLA0000000300410@000000000000T000000P010@400`0000000@4100000009000000L0oooo
00<0o_kn0?ooo`3oool0303oool7000000T0oooo0P3no_ko0?oooeL0oooo<00000020?ooo`80o_kn
=`3oool00`3no_h0oooo00000006000002L0oooo000c0?ooo`L000005@3GemL00`3Fe]H0emOG0=OG
e`2[0=OGe`030=SHf03GemL0emOG01@0emOG8P00000300410@D000003P3oool700000?l0ooooH@3o
ool/0000000300410@000000000000D00000;03oool00`3no_h0oooo0?ooo`0:0?ooo`80000000<0
0@410000000000000P00000W0?ooo`00<`3oool7000001D0emOG00<0e]KF0=OGe`3GemL0Z`3GemL0
0`3Hf=P0emOG0=OGe`0D0=OGeb8000000`010@45000000h0oooo1`00003o0?ooof40oooo;0000000
0`010@40000000000005000002`0oooo00<0o_kn0?ooo`3oool02P3oool20000000300410@000000
0000008000009`3oool003D0oooo00<00@410000000000001000002g0=OGe`80e]KF903GemL20=KF
eP@0emOG:P0000030?ooo`L00000103oool0103no_h0oooo0?ooo`3oool20?kno_l0ooooE`3ooolJ
0000000400410@000000000000410AX00000=03oool00`3no_h0000000000004000002P0oooo000f
0?ooo`L00000k03GemL;0000000300410@000000000000d0000000<00@410000000000002`000000
0`010@4000000?ooo`3o0?oooel0oooo>000000010010@40000000000000000a0?ooo`H00000:03o
ool003H0oooo0P010@4500000?80emOG0P3Fe]H30=OGeol00000_@00000200410Bd0oooo1`00000X
0?ooo`00=P3oool200410@D00000lP3GemL20=KFeP<0emOGo`00002m000000800@41;@3oool70000
02P0oooo000h0?ooo`H00000n03GemL20=KFePD0emOGo`00002i000002X0oooo1`00000X0?ooo`00
>@3oool00`0000000@4100410@0400000?l0emOG2@3GemL70000000300410@00000000000?l00000
YP0000040?ooo`80o_kn8P3oool7000000@0oooo00<0o_kn0?ooo`3oool08@3oool003T0oooo00<0
000000410@010@401000003o0=OGe`T0emOG1`0000000`010@4000000000003o00000:H00000103o
ool20?knoR80oooo1`0000040?ooo`030?knoP3oool0oooo0240oooo000i0?ooo`P00000203GemL2
0=KFe]l0emOG00<0f=SH0=OGe`3GemL0603GemOo00000:l00000;03oool8000002L0oooo000j0?oo
o`L00000i@3GemL0103Fe]H0emOG0=OGe`3Hf=PG0=OGe`80f=SH500000040?ooo`80o_kno`3ooomG
0?ooocT000000`010@4_0?ooo`D000000`3oool3000002D0oooo000l0?ooo`L00000o@3GemL>0000
00030?ooo`000000000000<000000P010@4200000?l0ooooG03ooolh000003<0oooo1@0000040?oo
o`<00000903oool003`0oooo1`00003m0=OGe`h0000000<0oooo0000000000000`00000200410@80
0000o`3ooomL0?ooocP00000<`3oool5000000@0oooo0`00000T0?ooo`00=P3oool20?knoPD0oooo
1`0000000`3GemL0e]KF0=KFeP3e0=OGe`030=SHf0000000000000`00000103oool900000?l0oooo
G03oool70000000300410@000000000002X000001@3oool20?knoP/0oooo00@0o_kn0?ooo`3no_h0
o_kn8@3oool5000000@0oooo100000030?ooo`@00000703oool003H0oooo0P3no_h50?ooo`L00000
lP3GemL20=SHf080emOG3P0000070?ooo`/00000o`3ooomJ0?oooa@000000P010@4J00000300oooo
00<0o_kn0?ooo`3oool0103oool00`3no_h0oooo00000005000000L0oooo2`00000J0?ooo`00?P3o
ool700000?<0emOG3@00000:0?ooo`T000000P010@7o0?oooeX0oooo9@0000001@010@4000000000
000000000@4100800000?03oool7000000P0oooo2P00000J0?ooo`00?P3oool700000?<0emOG3@00
000:0?ooo`T000000P010@7o0?oooeX0oooo9@0000001@010@4000000000000000000@4100800000
?03oool7000000P0oooo2P00000J0?ooo`00@03oool5000000800@4100<0e]KF0=OGe`3GemL0j`3G
emL00`0000000@4100410@0;000000`0oooo300000060?ooo`030?knoP3oool0oooo0?l0ooooD03o
oolK000000800@412`00000l0?ooo`/000002@3oool9000001X0oooo00100?ooo`P00000jP3GemL>
000000l0oooo3000003o0?oooeX0oooo900000130?ooo`D000001P3oool00`3no_h0oooo0?ooo`05
0?ooo`@00000703oool003D0oooo00<0o_kn0?ooo`3oool0103oool00`3no_h0oooo0?ooo`020?oo
o`L0000000<0f=SH0=OGe`3GemL0i03GemL:0000000400410@000000000000000180oooo1@000002
0?ooo`L00000o`3ooomH0?ooob000000@`3oool00`3no_h0oooo0?ooo`0d0?ooo`00=@3oool00`3n
o_h0oooo0?ooo`040?ooo`030?knoP3oool0oooo0080oooo1`0000000`3Hf=P0emOG0=OGe`3T0=OG
e`X0000000@00@4100000000000000004P3oool500000080oooo1`00003o0?oooeP0oooo80000013
0?ooo`030?knoP3oool0oooo03@0oooo00130?ooo`H00000h@3GemL00`3Fe]H0emOG0=OGe`0=0000
01D0oooo1@0000020?ooo`L000002@3oool20?kno_l0ooooBP3oool20?knoP030?ooo`0000000000
01X000002@3oool20?knoS`0oooo00<0o_kn0?ooo`3oool0=03oool003h0oooo0P3no_h40?ooo`03
000000010@400@4100@00000g`3GemL>000001L0oooo00<00@410000000000000P0000030?ooo`L0
0000o`3ooomC0?ooo`040?knoP3oool0oooo0?oooaL00000P`3oool003h0oooo0P3no_h40?ooo`03
000000010@400@4100@00000g`3GemL>000001L0oooo00<00@410000000000000P0000030?ooo`L0
0000o`3ooomC0?ooo`040?knoP3oool0oooo0?oooaL00000P`3oool003T0oooo00<0o_kn0?ooo`3o
ool0203oool700000=`0emOG3P00000B0?ooo`030?knoP3oool0oooo00D0oooo1@0000030?ooo`L0
0000103oool0103no_h0oooo0?ooo`3oool20?kno_l0ooooC`3ooolA000005P0oooo00<0o_kn0?oo
o`3oool0;03oool004D0oooo0P0000000`010@4000000000000200000=@0emOG0P3Hf=P20=OGe`h0
00007@3oool500000080oooo00<0o_kn0?ooo`0000001P00003o0?oooeP0oooo3@00002;0?ooo`00
A`3oool700000=@0emOG3@00000P0?ooo`D00000103oool7000000@0oooo0P3no_ko0?oooe<0oooo
2000002?0?ooo`00A`3oool700000=@0emOG3@00000P0?ooo`D00000103oool7000000@0oooo0P3n
o_ko0?oooe<0oooo2000002?0?ooo`00A`3oool800000=00emOG00<0000000410@010@402`00000R
0?ooo`D000000P3no_h40?ooo`L00000o`3ooomG0?ooo`@00000T`3oool004P0oooo1`0000000`3F
e]H0emOG0=OGe`3:0=OGe`h000009@3oool5000000H0oooo1`0000040?ooo`030?knoP3oool0oooo
0?l0ooooi`3oool004T0oooo0P00000300410@8000000P3GemL00`3Fe]H0emOG0=OGe`340=OGe`X0
000000@00@410000000000000000:03oool5000000L0oooo1`00003o0?ooond0oooo00190?ooo`80
00000`010@4200000080emOG00<0e]KF0=OGe`3GemL0a03GemL:0000000400410@00000000000000
02P0oooo1@0000070?ooo`L00000o`3oooo]0?ooo`00@03oool00`3no_h0oooo0?ooo`080?ooo`L0
0000`P3GemL00`3Fe]H0emOG0=OGe`0=000002/0oooo1@0000070?ooo`L00000o`3ooom@0?ooo`80
o_knV`3oool004/0oooo00<00@41000000000000100000000`3GemL0e]KF0=OGe`2o0=OGe`h00000
;@3oool5000000L0oooo0P3no_h600000?l0ooooD@3oool00`3no_h0oooo0?ooo`0=0?ooo`80o_kn
R@3oool004/0oooo00<00@41000000000000100000000`3GemL0e]KF0=OGe`2o0=OGe`h00000;@3o
ool5000000L0oooo0P3no_h600000?l0ooooD@3oool00`3no_h0oooo0?ooo`0=0?ooo`80o_knR@3o
ool004`0oooo1`00002n0=OGe`h00000<03oool5000000T0oooo1P0000030?ooo`80o_kno`3ooooW
0?ooo`00CP3oool600000;H0emOG0P3Hf=P30=OGe`d00000<`3oool5000000X0oooo1`00003o0?oo
onX0oooo001>0?ooo`P000001`3GemL00`3Fe]H0emOG0=OGe`2/0=OGe`d00000=P3oool5000000X0
oooo1`00003o0?ooonX0oooo001>0?ooo`P000001`3GemL00`3Fe]H0emOG0=OGe`2/0=OGe`d00000
=P3oool5000000X0oooo1`00003o0?ooonX0oooo001?0?ooo`L000000P3GemL20=SHf:l0emOG00<0
000000410@010@402`00000h0?ooo`D000002`3oool7000000H0oooo00<0o_kn0?ooo`3oool0o`3o
oooP0?ooo`00D03oool7000000<0emOG00D0f=SH0=OGe`3GemL0emOG0=KFeP2W0=OGe`h00000>`3o
ool5000000/0oooo0`00000010010@40000000000000003o0?ooonT0oooo001B0?ooo`0300410@00
0000000000<000000P3GemL00`3Fe]H0emOG0=OGe`2W0=OGe`T000000P010@42000003h0oooo1@00
000=0?ooo`L00000o`3ooooW0?ooo`00DP3oool00`010@4000000000000300000080emOG00<0e]KF
0=OGe`3GemL0Y`3GemL9000000800@410P00000n0?ooo`D000003@3oool700000?l0ooooi`3oool0
0580oooo1P0000060=OGe`030=KFeP3GemL0emOG09d0emOG00<0e]KF0=OGe`3GemL03P0000100?oo
o`D000003@3oool00`0000000@4100000004000000T0oooo00<0o_kn0?ooo`3oool0o`3ooooK0?oo
o`00D`3oool7000000@0emOG00<0e]KF0=OGe`3GemL0W@3GemL>000004<0oooo1@00000>0?ooo`L0
0000o`3ooooV0?ooo`00D`3oool7000000@0emOG00<0e]KF0=OGe`3GemL0W@3GemL>000004<0oooo
1@00000>0?ooo`L00000o`3ooooV0?ooo`00E03oool700000:00emOG3P0000160?ooo`D000003P3o
ool00`010@40000000000004000000@0oooo00D0o_kn0?ooo`3oool0oooo0?knoP3o0?ooomd0oooo
001D0?ooo`T00000V03GemL0103Hf=P0emOG0=OGe`3GemL=000004T0oooo1@00000?0?ooo`L00000
o`3ooooU0?ooo`00EP3oool7000009T0emOG3P00001;0?ooo`D000003`3oool3000000800@410P00
00040?ooo`80o_kno`3ooooO0?ooo`00EP3oool7000009T0emOG3P00001;0?ooo`D000003`3oool3
000000800@410P0000040?ooo`80o_kno`3ooooO0?ooo`00E`3oool7000009D0emOG0P0000000`01
0@40000000000009000004h0oooo1@00000A0?ooo`L00000o`3ooooS0?ooo`00F03oool700000080
emOG00<0e]KF0=OGe`3GemL0S03GemL>00000540oooo1@00000A0?ooo`03000000010@400@4100@0
0000103oool00`3no_h0oooo0?ooo`3o0?ooom`0oooo001H0?ooo`L00000S`3GemL9000000800@41
0P00001D0?ooo`D000004P3oool700000?l0oooohP3oool005P0oooo1`00002?0=OGe`T000000P01
0@42000005@0oooo1@00000B0?ooo`L00000o`3ooooR0?ooo`00FP3oool7000008L0emOG0P3Fe]H0
0`3GemL000000000000<000005H0oooo1@00000B0?ooo`L00000o`3ooooR0?ooo`00F`3oool70000
08H0emOG3P00001I0?ooo`D00000503oool600000?l0ooooh@3oool005/0oooo200000030=OGe`80
e]KFO@3GemL>000005`0oooo1@00000D0?ooo`H000000`3oool00`3no_h0oooo0?ooo`3o0?ooom/0
oooo001K0?ooo`P000000`3GemL20=KFeWd0emOG3P00001L0?ooo`D00000503oool6000000<0oooo
00<0o_kn0?ooo`3oool0o`3ooooK0?ooo`00F`3oool20?knoPH00000O03GemL0103Hf=P0emOG0=OG
e`3GemL=000005l0oooo1@00000E0?ooo`L00000o`3ooooO0?ooo`00GP3oool00`010@4000000000
0004000000<0emOG00<0e]KF0=OGe`3GemL0M@3GemL>00000640oooo1@00000E0?ooo`L00000o`3o
oooO0?ooo`00GP3oool00`010@40000000000004000000<0emOG00<0e]KF0=OGe`3GemL0M@3GemL>
00000640oooo1@00000E0?ooo`L00000o`3ooooO0?ooo`00G`3oool700000080f=SH00<0emOG0=KF
eP3GemL0LP3GemL20000000300410@000000000000T00000I03oool5000001H0oooo1`0000060?oo
o`030?knoP3oool0oooo0?l0ooooe@3oool005l0oooo1`00001e0=OGe`d00000I`3oool5000001H0
oooo0`00000010010@40000000000000003o0?ooomh0oooo001Q0?ooo`L00000L03GemL900000080
0@410P00001Z0?ooo`D00000603oool600000?l0oooog@3oool00640oooo1`00001`0=OGe`T00000
0P010@42000006X0oooo1@00000H0?ooo`H00000o`3ooooM0?ooo`00HP3oool4000000800@4100<0
00000=OGe`3GemL0?@3GemL00`3Hf=P0emOG0=OGe`0W0=OGe`80e]KF00<0emOG0000000000003000
001/0?ooo`D00000603oool00`0000000@4100000003000000X0oooo00<0o_kn0?ooo`3oool0o`3o
ooo@0?ooo`00HP3oool8000003l0emOG0`00000V0=OGe`h00000K`3oool5000001T0oooo1`00003o
0?ooom/0oooo001S0?ooo`L00000?P3GemL5000002<0emOG3@00001b0?ooo`D000006@3oool00`01
0@40000000000004000000@0oooo00D0o_kn0?ooo`3oool0oooo0?knoP3o0?ooom80oooo001S0?oo
o`L00000?P3GemL5000002<0emOG3@00001b0?ooo`D000006@3oool00`010@400000000000040000
00@0oooo00D0o_kn0?ooo`3oool0oooo0?knoP3o0?ooom80oooo001U0?ooo`L0000000<0emOG0=SH
f03GemL0;`3GemL20=KFePH0emOG2@00000J0=OGe`040=SHf03GemL0emOG0=OGe`h00000=03oool0
0`3no_h0oooo0?ooo`0<0?ooo`030?knoP3oool0oooo02h0oooo1@00000J0?ooo`L00000o`3ooooJ
0?ooo`00IP3oool4000000800@4100D000000=OGe`3GemL0emOG0=SHf00d0=OGe`/000006P3GemL>
00000380oooo2P0000000`010@4000000000000800000300oooo1@00000J0?ooo`<0000000@00@41
0000000000000000103oool20?kno_l0ooooe03oool006H0oooo1000000200410@050000003GemL0
emOG0=OGe`3Hf=P0=03GemL;000001X0emOG3P00000b0?ooo`X0000000<00@410000000000002000
000`0?ooo`D000006P3oool30000000400410@0000000000000000@0oooo0P3no_ko0?ooom@0oooo
001V0?ooo`L00000<`3GemL0103Fe]H0emOG0=OGe`3GemL=000001H0emOG0P0000000`010@400000
0000000900000340oooo0P3no_h40?oooa@00000;`3oool5000001`0oooo1`00003o0?ooomP0oooo
001X0?ooo`H000000P3GemL00`3Hf=P0emOG0=OGe`0Y0=OGe`030=SHf03GemL0emOG00<0emOG4@00
000B0=OGe`d00000>`3ooolC000002l0oooo1@00000L0?ooo`03000000010@40000000@00000103o
ool00`3no_h0oooo0?ooo`3o0?ooom40oooo001S0?ooo`80o_kn103oool7000000030=OGe`3Fe]H0
emOG02h0emOG4P00000?0=OGe`T000000P010@43000003l0oooo0P00000=0?ooo`0300410@000000
oooo02h0oooo1@00000M0?ooo`L00000o`3ooooG0?ooo`00H`3oool20?knoP@0oooo1`0000000`3G
emL0e]KF0=OGe`0^0=OGea8000003`3GemL9000000800@410`00000o0?ooo`8000003@3oool00`01
0@4000000?ooo`0^0?ooo`D000007@3oool700000?l0ooooe`3oool006T0oooo200000030=OGe`03
0=SHf03GemL0emOG0200emOG0P3Fe]H40=OGe`030=KFeP3GemL0emOG01@00000203GemL20=KFeP03
0=OGe`000000000000`00000>@3oool20?knoPP0oooo0`00000=0?ooo`800000;@3oool5000001d0
oooo1`00003o0?ooomL0oooo001Z0?ooo`L00000:@3GemL20=KFeP80emOG600000060=OGe`h00000
B@3oool00`000000oooo0?ooo`0i0?ooo`D000007P3oool700000?l0ooooeP3oool006`0oooo00<0
0@410000000000000`00000[0=OGeaX000000`3GemL=000003h0oooo00<0o_kn0?ooo`3oool0303o
ool00`000000oooo0?ooo`0h0?ooo`D000007P3oool7000000<0oooo00<0o_kn0?ooo`3oool0o`3o
ooo@0?ooo`00K03oool00`010@40000000000003000002/0emOG6P0000030=OGe`d00000?P3oool0
0`3no_h0oooo0?ooo`0<0?ooo`030000003oool0oooo03P0oooo1@00000N0?ooo`L000000`3oool0
0`3no_h0oooo0?ooo`3o0?ooom00oooo001]0?ooo`L000006`3GemL20=SHf0/0emOG:@00001@0?oo
o`800000>03oool500000200oooo1`00003o0?ooom@0oooo001]0?ooo`0300410@000000000000@0
00009P3GemLX000005D0oooo00<000000?ooo`3no_h00P3no_h70?ooo`030?knoP3oool0oooo02T0
oooo1@00000P0?ooo`L00000o`3ooooD0?ooo`00KP3oool7000002@0emOG9P00000j0?ooo`030?kn
oP3oool0oooo01/0oooo0P00000f0?ooo`D000008@3oool7000000H0oooo00<0o_kn0?ooo`3oool0
o`3oooo:0?ooo`00KP3oool7000002@0emOG9P00000j0?ooo`030?knoP3oool0oooo01/0oooo0P00
000f0?ooo`D000008@3oool7000000H0oooo00<0o_kn0?ooo`3oool0o`3oooo:0?ooo`00L03oool0
0`0000000@410000000400000200emOG900000000`010@40oooo0?ooo`1J0?ooo`<00000=03oool5
00000240oooo0`00000010010@40000000000000003o0?ooom<0oooo001`0?ooo`P00000203GemL2
0=KFeQ@0emOG900000080?ooo`030?knoP3oool0oooo03@0oooo00<0o_kn0?ooo`3oool05@3oool2
0?knoPH0oooo0P0000000`010@40oooo0?ooo`0a0?ooo`D000008`3oool600000?l0oooodP3oool0
0700oooo200000080=OGe`80e]KF503GemLT000000P0oooo00<0o_kn0?ooo`3oool0=03oool00`3n
o_h0oooo0?ooo`0E0?ooo`80o_kn1P3oool20000000300410@3oool0oooo0340oooo1@00000S0?oo
o`H00000o`3ooooB0?ooo`00L@3oool7000001d0emOG9P00001P0?ooo`<00000103oool00`3no_h0
oooo0?ooo`0Z0?ooo`D000008`3oool00`0000000@4100000003000000X0oooo00<0o_kn0?ooo`3o
ool0o`3oooo50?ooo`00LP3oool7000001<0emOG0P3Fe]H70=OGebH00000F@3oool00`3no_h0oooo
0?ooo`040?ooo`<00000<@3oool5000002@0oooo1`00003o0?ooom00oooo001]0?ooo`030?knoP3o
ool0oooo00@0oooo1`0000000`3GemL0e]KF0=OGe`0E0=OGebD000000P010@400`000000oooo0?oo
o`0i0?ooo`T000007@3oool3000000@0oooo00<0o_kn0?ooo`3oool0:@3oool5000002@0oooo00<0
0@41000000000000100000040?ooo`050?knoP3oool0oooo0?ooo`3no_h0o`3oooo70?ooo`00K@3o
ool00`3no_h0oooo0?ooo`040?ooo`L0000000<0emOG0=KFeP3GemL05@3GemLU000000800@4100<0
00000?ooo`3oool0>@3oool9000001d0oooo0`0000040?ooo`030?knoP3oool0oooo02T0oooo1@00
000T0?ooo`0300410@000000000000@00000103oool01@3no_h0oooo0?ooo`3oool0o_kn0?l0oooo
a`3oool006d0oooo00<0o_kn0?ooo`3oool0103oool7000001L0emOG:P00000g0?ooo`P000000P01
0@45000000X0oooo0`3no_h=0?ooo`<00000<03oool5000002D0oooo1`00001K0?ooo`8000000P01
0@4600000?l0ooooJP3oool007D0oooo1`00000E0=OGe`8000000P010@4W000003H0oooo00@00000
00410@010@400@413P00000H0?ooo`@00000;`3oool5000002D0oooo0`00000010010@4000000000
000000040?ooo`80o_knD`3oool7000000D0oooo0`00003o0?ooofL0oooo001g0?ooo`D0000000<0
0@410=KFeP3Fe]H02`3GemL00`3Hf=P0emOG0=OGe`020=OGe`80000000<00@410000000000000P00
00000`010@4000000000000S000003@0oooo3@0000020?ooo`80o_kn00@0oooo0000000000000000
5`3oool4000002l0oooo1@00000W0?ooo`L00000E`3oool4000000/0oooo0P00003o0?ooofD0oooo
001g0?ooo`D0000000<00@410=KFeP3Fe]H02`3GemL00`3Hf=P0emOG0=OGe`020=OGe`80000000<0
0@410000000000000P0000000`010@4000000000000S000003@0oooo3@0000020?ooo`80o_kn00@0
oooo00000000000000005`3oool4000002l0oooo1@00000W0?ooo`L00000E`3oool4000000/0oooo
0P00003o0?ooofD0oooo001g0?ooo`P000003`3GemLZ000000800@411000000b0?ooo`/000002@3o
ool2000000H0oooo00<000000?ooo`3oool03@3oool4000002l0oooo1@00000W0?ooo`0300000001
0@40000000@00000103oool00`3no_h0oooo0?ooo`1O0?ooo`<00000o`3ooomT0?ooo`00K03oool0
0`3no_h0oooo0?ooo`030?ooo`80o_kn103oool7000000030=SHf03GemL0emOG00P0emOG0P3Hf=Pb
000000@0oooo00<0o_kn0?ooo`3oool0:P3oool:0000000300410@3oool0oooo0080oooo00<0o_kn
0?ooo`3oool00`3oool0103no_h000000000000000040?ooo`<00000303oool5000002l0oooo1@00
000X0?ooo`L00000I`3oool200000?l0ooooH`3oool006`0oooo00<0o_kn0?ooo`3oool00`3oool2
0?knoP@0oooo1`0000000`3Hf=P0emOG0=OGe`080=OGe`80f=SH<P0000040?ooo`030?knoP3oool0
oooo02X0oooo2P0000000`010@40oooo0?ooo`020?ooo`030?knoP3oool0oooo00<0oooo00@0o_kn
0000000000000000103oool3000000`0oooo1@00000_0?ooo`D00000:03oool7000006L0oooo0P00
003o0?ooof<0oooo001i0?ooo`L00000203GemL20=SHf0050=OGe`0000000000000000010@40;`00
00040?ooo`030?knoP3oool0oooo02X0oooo2`00000<0?ooo`80000000<0o_kn0?ooo`3oool00P3o
ool2000000X0oooo1`00000_0?ooo`D00000:03oool7000005`0oooo00<0o_kn0?ooo`3oool0203o
ool200000?l0ooooH`3oool007D0oooo0P3no_h40?ooo`03000000010@40000000@000000P3GemL2
0=SHf0040=OGe`3Hf=P0emOG0=OGec@00000<@3oool:000000040?ooo`3no_h0o_kn0?knoP`0oooo
00@0o_kn0?ooo`3oool0oooo0`0000000`010@40oooo0?ooo`050?ooo`0300410@000000000000<0
000000<00@410?ooo`3oool0;P3oool5000002T0oooo1`00001V0?ooo`@00000o`3ooomQ0?ooo`00
L03oool00`3no_h0oooo0?ooo`080?ooo`L000001@3GemL00`3Hf=P0000000000005000000800@41
;@00000`0?ooo`/000003@3oool20?knoPL0oooo3`00000a0?ooo`D00000:@3oool7000000<0oooo
00<0o_kn0?ooo`3oool0CP3oool00`3no_h0oooo0?ooo`0?0?ooo`@000001`3oool00`3no_h0oooo
0?ooo`3o0?oooeL0oooo001`0?ooo`030?knoP3oool0oooo00P0oooo1`0000050=OGe`030=SHf000
0000000000D000000P010@4]00000300oooo2`00000=0?ooo`80o_kn1`3oool?00000340oooo1@00
000Y0?ooo`L000000`3oool00`3no_h0oooo0?ooo`1>0?ooo`030?knoP3oool0oooo00l0oooo1000
00070?ooo`030?knoP3oool0oooo0?l0ooooE`3oool007`0oooo1`0000040=OGebX000000P010@40
0`0000000@4100410@0800000300oooo00<00@410000000000001P0000040?ooo`80o_kn4`3oool<
000003<0oooo1@00000[0?ooo`L00000?@3oool20?knoPD0oooo00<0o_kn0?ooo`3oool06`3oool6
00000?l0ooooH@3oool007d0oooo1`0000020=OGecP000009`3oool20?knoPL0oooo2@00000L0?oo
o`P00000=03oool5000002/0oooo1`00001R0?ooo`H00000o`3ooomQ0?ooo`00O@3ooom1000002H0
oooo00<0o_kn0?ooo`3oool01`3oool00`0000000@4100000006000000@0oooo0P3no_h90?ooo`80
o_knA`3oool5000002`0oooo1`0000050?ooo`80o_kn>@3oool20?knoQh0oooo100000001@010@40
00000000003oool0o_kn0?l0ooooG`3oool007d0oooo@@00000V0?ooo`030?knoP3oool0oooo00L0
oooo00<0000000410@0000001P0000040?ooo`80o_kn2@3oool20?knoTL0oooo1@00000/0?ooo`L0
00001@3oool20?knoST0oooo0P3no_hN0?ooo`@0000000D00@41000000000000oooo0?knoP3o0?oo
oel0oooo001o0?ooobL000000P010@4@000003H0oooo2@00001H0?ooo`D00000;03oool300000004
00410@0000000000000005d0oooo2000003o0?ooof<0oooo00200?ooob@0000000<00@4100000000
00002000000o0?oooaX00000A`3oool5000002h0oooo1P00001G0?ooo``00000o`3ooomT0?ooo`00
P03ooolT0000000300410@000000000000P00000?`3ooolJ000004L0oooo1@00000^0?ooo`H00000
E`3oool<00000?l0ooooI03oool00800oooo9000001:0?oooaX00000A`3oool5000002h0oooo00<0
000000410@0000000`00000:0?ooo`030?knoP3oool0oooo02`0oooo0P3no_hN0?ooo`T00000o`3o
oomU0?ooo`00O`3ooolH000005L0oooo2@0000070?ooo`X00000A`3oool5000002l0oooo1`00000i
0?ooo`X00000603oool2000000/0oooo0`3no_ko0?oooeX0oooo001m0?ooo`l00000:`3oool00`3n
o_h0oooo0?ooo`0^0?ooo`80o_kn1@3oool8000000<0o_kn103oool30000000300410@0000000000
00@00000A`3oool5000002l0oooo00<00@41000000000000100000040?ooo`050?knoP3oool0oooo
0?ooo`3no_h0;P3oool?000001L0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`00O@3oool?0000
02/0oooo00<0o_kn0?ooo`3oool0;P3oool20?knoPD0oooo200000030?knoP@0oooo0`0000000`01
0@40000000000004000004L0oooo1@00000_0?ooo`0300410@000000000000@00000103oool01@3n
o_h0oooo0?ooo`3oool0o_kn02h0oooo3`00000G0?ooo`030000003oool0oooo0?l0ooooI@3oool0
07`0oooo2000001[0?ooo`P000001`3oool8000000@0oooo0P3no_h30?ooo`030?knoP3oool0oooo
03d0oooo1@00000`0?ooo`L00000=03oool200410A000000103oool00`3no_h0oooo0?ooo`0?0?oo
o`<00000o`3ooomU0?ooo`00l03oool7000000<0o_kn103oool8000004T0oooo1@00000`0?ooo`<0
000000@00@410000000000000000103oool20?knoRL0oooo0P3no_h40?ooo``000001P3oool00`00
00000@410?ooo`0:0?ooo`80o_kn2@3oool300000?l0ooooI03oool00?00oooo1`0000030?ooo`04
0?knoP3oool0oooo0?ooo`L000002P3oool00`3no_h0oooo0?ooo`0m0?ooo`D00000<P3oool60000
0380oooo2`0000080?ooo`<00000503oool400000?l0ooooH`3oool00?00oooo1`0000030?ooo`04
0?knoP3oool0oooo0?ooo`L000002P3oool00`3no_h0oooo0?ooo`0m0?ooo`D00000<P3oool60000
0380oooo2`0000080?ooo`<00000503oool400000?l0ooooH`3oool008P0oooo0P3no_iX0?ooo`@0
000000<00@41000000000000103oool00`010@40000000000005000004X0oooo1@00000b0?ooo`03
000000010@40000000<000001@3oool00`3no_h0oooo0?ooo`0X0?ooo`/000002`3oool3000000`0
oooo0P3no_h50?ooo`@00000o`3ooomS0?ooo`00PP3oool00`3no_h0oooo0?ooo`1^0?ooo`L00000
0`3oool7000004/0oooo1@00000c0?ooo`L00000;P3oool;00000080oooo00<0o_kn0?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`8000003@3oool400000?l0ooooH`3oool00?D0oooo3@00
00070?ooo`030?knoP3oool0oooo04<0oooo1@00000c0?ooo`L00000;P3oool:000001D0oooo00<0
00000?ooo`3oool02@3oool500000?l0ooooH`3oool00?D0oooo3@0000070?ooo`030?knoP3oool0
oooo04<0oooo1@00000c0?ooo`L00000;P3oool:000001D0oooo00<000000?ooo`3oool02@3oool5
00000?l0ooooH`3oool00?L0oooo2000001@0?ooo`D00000=03oool7000002`0oooo2`00000F0?oo
o`<000001P3oool50000000300410@3oool0oooo0?l0ooooHP3oool00880oooo00@0o_kn0?ooo`3n
o_h0o_knL`3oool0103no_h0oooo0?knoP3no_iB0?ooo`D00000=03oool7000000<0oooo00<0o_kn
0?ooo`3oool08P3oool0103no_h0oooo0?ooo`3no_h:000000T0oooo0P3no_h=0?ooo`d00000o`3o
oomU0?ooo`00PP3oool0103no_h0oooo0?knoP3no_ic0?ooo`040?knoP3oool0o_kn0?knoU80oooo
1@00000d0?ooo`L000000`3oool00`3no_h0oooo0?ooo`0R0?ooo`040?knoP3oool0oooo0?knoPX0
00002@3oool20?knoPd0oooo3@00003o0?ooofD0oooo003o0?oooe00oooo1@00000f0?ooo`L00000
:P3oool:000000`0oooo00<0o_kn0?ooo`3oool0303oool800000?l0ooooI`3oool00?l0ooooD03o
ool5000003H0oooo1`00000Z0?ooo`X00000o`3ooon:0?ooo`00o`3ooom@0?ooo`D00000=`3oool7
000000D0oooo0P3no_hR0?ooo`03000000010@400@4100L00000o`3ooon:0?ooo`00o`3ooom@0?oo
o`D00000=`3oool7000000D0oooo0P3no_hR0?ooo`03000000010@400@4100L00000o`3ooon:0?oo
o`00o`3ooom@0?ooo`D00000=`3oool30000000400410@0000000000000002T0oooo6P00003o0?oo
ogX0oooo003o0?oooe00oooo1@00000h0?ooo`L00000:03ooolJ00000?l0ooooNP3oool00?l0oooo
D03oool5000003P0oooo0P0000000`010@40000000000002000000X0oooo00<0o_kn0?ooo`3oool0
6`3oool:000000H0oooo2P00003o0?ooogX0oooo003o0?oooe00oooo1@00000h0?ooo`80000000<0
0@410000000000000P00000:0?ooo`030?knoP3oool0oooo01/0oooo2P0000060?ooo`X00000o`3o
oomj0?ooo`00o`3ooom@0?ooo`D00000>P3oool7000002L0oooo2@0000060?ooo`X00000o`3ooomj
0?ooo`00o`3ooom@0?ooo`D00000>P3oool00`010@40000000000004000000@0oooo00D0o_kn0?oo
o`3oool0oooo0?knoP0N0?ooo`T000001P3oool900000?l0ooooN`3oool00?l0ooooD03oool50000
03X0oooo00<00@41000000000000100000040?ooo`050?knoP3oool0oooo0?ooo`3no_h07P3oool9
000000H0oooo2@00003o0?ooog/0oooo003o0?oooe00oooo1@00000k0?ooo`L000007P3oool20?kn
oP80oooo0P3no_h40?ooo`L000001P3oool60000000300410@00000000000?l0ooooN`3oool00?l0
ooooD03oool5000003/0oooo0`00000010010@4000000000000000040?ooo`80o_kn8P3oool70000
00H0oooo1`00003o0?ooogd0oooo003o0?oooe00oooo1@00000m0?ooo`H000007@3oool20?knoPT0
oooo1P0000000`010@40oooo0?ooo`020?ooo`P00000o`3ooomm0?ooo`00o`3ooom@0?ooo`D00000
?@3oool6000001d0oooo0P3no_h90?ooo`H0000000<00@410?ooo`3oool00P3oool800000?l0oooo
O@3oool00?l0ooooD03oool5000003d0oooo00<0000000410@0000000`0000050?ooo`030?knoP3o
ool0oooo0280oooo1P0000030?ooo`@000000P010@400`000000oooo0?ooo`3o0?ooog`0oooo003o
0?oooe00oooo1@00000n0?ooo`L00000:@3oool>00000?l0ooooO`3oool00?l0ooooD03oool50000
03h0oooo1`00000Q0?ooo`030?knoP3oool0oooo00P0oooo2000003o0?oooh80oooo003o0?oooe00
oooo1@00000n0?ooo`L000008@3oool00`3no_h0oooo0?ooo`080?ooo`P00000o`3ooon20?ooo`00
o`3ooom@0?ooo`D00000?`3oool7000002d0oooo0P3no_ko0?ooohH0oooo003o0?oooe00oooo1@00
000o0?ooo`L000000`3oool00`3no_h0oooo0?ooo`0d0?ooo`030?knoP3oool0oooo0?l0ooooN03o
ool00?l0ooooD03oool5000003l0oooo1`0000030?ooo`030?knoP3oool0oooo03@0oooo00<0o_kn
0?ooo`3oool0o`3ooomh0?ooo`00o`3ooom@0?ooo`D00000@@3oool700000?l0oooo/`3oool00?l0
ooooD03oool500000440oooo1`00003o0?oook<0oooo003o0?oooe00oooo1@0000120?ooo`L00000
1@3oool20?kno_l0ooooZ`3oool00?l0ooooD03oool500000480oooo1`0000050?ooo`80o_kno`3o
oon[0?ooo`00o`3ooom@0?ooo`D00000@P3oool30000000400410@000000000000000?l0oooo/P3o
ool00?l0ooooD03oool5000004<0oooo1`00003o0?oook40oooo003o0?oooe00oooo1@0000130?oo
o`80000000<00@410000000000000P00000:0?ooo`030?knoP3oool0oooo0?l0ooooY03oool00?l0
ooooD03oool5000004<0oooo0P0000000`010@40000000000002000000X0oooo00<0o_kn0?ooo`3o
ool0o`3ooonT0?ooo`00o`3ooom@0?ooo`D00000A@3oool700000?l0oooo[`3oool00?l0ooooD03o
ool5000004D0oooo00<00@41000000000000100000040?ooo`050?knoP3oool0oooo0?ooo`3no_h0
0`3oool800000?l0ooooV`3oool00?l0ooooD03oool5000004H0oooo1000000200410@030000003o
ool0oooo00D0oooo300000080?ooo`80o_kno`3ooonA0?ooo`00o`3ooom@0?ooo`D00000AP3oool4
000000800@4100<000000?ooo`3oool01@3oool<000000P0oooo0P3no_ko0?oooi40oooo003o0?oo
oe00oooo1@0000110?ooo`030?knoP3oool0oooo0080oooo1`0000030?oooa800000103oool00`3n
o_h0oooo0?ooo`3o0?oooi80oooo003o0?oooe00oooo1@0000180?oooaX00000o`3ooonI0?ooo`00
o`3ooom@0?ooo`D00000B03ooolJ00000?l0ooooV@3oool00?l0ooooD03oool5000004H0oooo0P3n
o_hJ00000?l0ooooV@3oool00?l0ooooD03oool5000004P0oooo6P00003o0?oooiT0oooo003o0?oo
oe00oooo1@0000120?ooo`040?knoP3oool0oooo0?ooo`H0000000<00@410000000000004`00003o
0?oooiT0oooo003o0?oooe00oooo1@0000120?ooo`040?knoP3oool0oooo0?ooo`H0000000<00@41
0000000000004`00003o0?oooiT0oooo003o0?oooe00oooo1@0000130?oooal00000o`3ooonI0?oo
o`00o`3ooom@0?ooo`D00000@P3oool?000000800@414000003o0?oooiP0oooo003o0?oooe00oooo
1@00000o0?ooob@00000o`3ooonH0?ooo`00o`3ooom@0?ooo`D00000?`3ooolT00000?l0ooooV03o
ool00?l0ooooD03oool5000003h0oooo9@00003o0?oooiP0oooo003o0?oooe00oooo1@00000k0?oo
obP00000o`3ooonH0?ooo`00o`3ooom@0?ooo`D00000>`3ooolX00000?l0ooooV03oool00?l0oooo
D03oool5000003/0oooo0P010@4V00000?l0ooooV03oool00?l0ooooD03oool5000003L0oooo00@0
o_kn0?ooo`3oool00@410P0000000`010@4000000000000S00000?l0ooooV03oool00?l0ooooD03o
ool5000003P0oooo:`0000040?ooo`030?knoP3oool0oooo0?l0ooooT@3oool00?l0ooooD03oool5
000003P0oooo:`0000040?ooo`030?knoP3oool0oooo0?l0ooooT@3oool00?l0ooooD03oool50000
03X0oooo0`0000000`010@4000000000000T00000?l0ooooU`3oool00?l0ooooD03oool5000003H0
oooo00<0o_kn0?ooo`3oool00P3ooolY00000?l0ooooU`3oool00?l0ooooD03oool5000003H0oooo
00<0o_kn0?ooo`3oool0103oool;0000000300410@000000000001T000000`3oool00`3no_h0oooo
0?ooo`3o0?oooi40oooo003o0?oooe00oooo1@00000f0?ooo`030?knoP3oool0oooo00@0oooo2`00
00000`010@4000000000000I000000<0oooo00<0o_kn0?ooo`3oool0o`3ooonA0?ooo`00o`3ooom@
0?ooo`D00000?P3oool00`0000000@4100410@080000000300410@000000000001P00000o`3ooonG
0?ooo`00o`3ooom@0?ooo`D00000?`3oool7000000800@41700000060?ooo`030?knoP3oool0oooo
0?l0ooooSP3oool00?l0ooooD03oool5000003l0oooo1`00000200410A`000001P3oool00`3no_h0
oooo0?ooo`3o0?ooohh0oooo003o0?oooe00oooo1@0000110?ooo`@0000000<00@41000000000000
7000003o0?oooiL0oooo003o0?oooe00oooo1@00000d0?ooo`80o_kn1@3oool20?knoPD0oooo8P00
003o0?oooiL0oooo003o0?oooe00oooo1@0000120?ooo`030?knoP000000000001l000000P3oool0
0`3no_h0oooo0?ooo`3o0?oooi80oooo003o0?oooe00oooo1@0000120?ooo`030?knoP0000000000
01l000000P3oool00`3no_h0oooo0?ooo`3o0?oooi80oooo003o0?oooe00oooo1@00000n0?ooo`03
0?knoP3oool0oooo00@0oooo8@0000000`3oool0o_kn0?ooo`3o0?oooi80oooo003o0?oooe00oooo
1@00000h0?ooo`80o_kn303oool20000000300410@000000000001/00000o`3ooonE0?ooo`00o`3o
oom@0?ooo`D00000@@3oool00`3no_h0oooo0?ooo`040?oooah00000o`3ooonE0?ooo`00o`3ooom@
0?ooo`D00000@@3oool00`3no_h0oooo0?ooo`040?oooah00000o`3ooonE0?ooo`00o`3ooom@0?oo
o`D00000B@3ooolM00000?l0ooooU@3oool00?l0ooooD03oool5000004X0oooo7000003o0?oooiD0
oooo003o0?oooe00oooo1@00001<0?ooo`L0000000<00@410000000000004000003o0?oooiD0oooo
003o0?oooe00oooo1@00001<0?ooo`L0000000<00@410000000000004000003o0?oooiD0oooo003o
0?oooe00oooo1@00000o0?ooo`80o_kn1@3oool20?knoPD0oooo00<0000000410@010@405P00003o
0?oooiD0oooo003o0?oooe00oooo1@00001>0?oooaP00000o`3ooonE0?ooo`00o`3ooom@0?ooo`D0
0000CP3ooolH00000?l0ooooU@3oool00?l0ooooD03oool5000004T0oooo00@0o_kn0?ooo`3oool0
o_kn103ooolF00000?l0ooooU03oool00?l0ooooD03oool5000004<0oooo0P3no_h90?ooo`80o_kn
0`3oool00`0000000@410000000A00000?l0ooooU03oool00?l0ooooD03oool5000005@0oooo4`00
003o0?oooi@0oooo003o0?oooe00oooo1@00001D0?oooa<00000o`3ooonD0?ooo`00o`3ooom@0?oo
o`D00000E@3ooolB00000?l0ooooU03oool00?l0ooooD03oool5000005L0oooo400000000`3oool0
o_kn0?knoP3o0?oooi40oooo003o0?oooe00oooo1@00001H0?ooo`0300410@000000000000`00000
o`3ooonD0?ooo`00o`3ooom@0?ooo`D00000F03oool00`010@4000000000000<00000?l0ooooU03o
ool00?l0ooooD03oool5000005T0oooo3P00003o0?oooi@0oooo003o0?oooe00oooo1@00001H0?oo
o`040?knoP3oool0oooo00410@/00000o`3ooonD0?ooo`00o`3ooom@0?ooo`D00000F03oool0103n
o_h0oooo0?ooo`010@4;00000?l0ooooU03oool00?l0ooooD03oool5000005`0oooo3000003o0?oo
oi<0oooo003o0?oooe00oooo1@00001M0?ooo`/00000o`3ooonC0?ooo`00o`3ooom@0?ooo`D00000
G`3oool900000?l0ooooT`3oool00?l0ooooD03oool5000005l0oooo2@00003o0?oooi<0oooo003o
0?oooe00oooo1@00001P0?ooo`P00000o`3ooonC0?ooo`00o`3ooom@0?ooo`D00000HP3oool60000
0?l0ooooT`3oool00?l0ooooD03oool5000006<0oooo1@00003o0?oooi<0oooo003o0?oooe00oooo
1@00001S0?ooo`D00000o`3ooonC0?ooo`00o`3ooom@0?ooo`D00000I03oool400000?l0ooooT`3o
ool00?l0ooooD03oool5000006<0oooo00D0o_kn0?ooo`3oool00@410000003o0?oooi<0oooo003o
0?oooe00oooo1@00001W0?ooo`030000003oool0oooo0?l0ooooT@3oool00?l0ooooD03oool50000
06L0oooo00<000000?ooo`3oool0o`3ooonA0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook
0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00
o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@
0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D0
0000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3o
oook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?oo
o`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3o
oom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?oo
o`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom@0?ooo`D00000
o`3ooook0?ooo`00o`3ooom@0?ooo`D00000o`3ooook0?ooo`00o`3ooom?0?ooo`030?knoP000000
000000<000000P3no_ko0?ooooT0oooo003o0?oood@0oooo00<0o_kn0?ooo`3oool02@3oool50000
0?l0oooon`3oool00?l0ooooA03oool00`3no_h0oooo0?ooo`090?ooo`D00000o`3ooook0?ooo`00
o`3ooom10?ooo`050?knoP3oool0oooo0?ooo`010@406P00003o0?oooo00oooo003o0?oood40oooo
9@00003o0?ooonX0oooo003o0?oooch0oooo;000003o0?ooonH0oooo003o0?oooch0oooo;000003o
0?ooonH0oooo003o0?ooocd0oooo;@0000040?ooo`030?knoP3oool0oooo0?l0oooog`3oool00?l0
oooo?P3oool00`0000000@4100410@0;0000000300410@000000000000T0000000<00@4100000000
00003P00003o0?ooonL0oooo003o0?oooch0oooo00<0000000410@010@402`0000000`010@400000
000000090000000300410@000000000000h00000o`3ooooW0?ooo`00o`3oooln0?ooo`<00@411000
000300410B400000o`3ooooW0?ooo`00o`3oooln0?ooob40000000<00@410000000000001`00003o
0?ooonL0oooo003o0?ooocl0oooo:000003o0?ooonT0oooo003o0?ooocl0oooo:000003o0?ooonT0
oooo003o0?ooocl0oooo:000003o0?ooonT0oooo003o0?oooch0oooo00@0o_kn0000000000000000
0P010@4S00000?l0ooooj@3oool00?l0oooo@@3ooolU00000?l0oooojP3oool00?l0oooo@@3ooolU
00000?l0oooojP3oool00?l0oooo@@3ooolU00000?l0oooojP3oool00?l0oooo@@3ooolU00000?l0
oooojP3oool00?l0oooo@@3ooolU00000?l0oooojP3oool00?l0oooo@P3oool30000000300410@00
0000000001`00000o`3oooo/0?ooo`00o`3ooom20?ooob800000o`3oooo/0?ooo`00o`3ooom20?oo
oa`0000000<00@410000000000000`00003o0?ooon`0oooo003o0?oood80oooo700000000`010@40
00000000000300000?l0ooook03oool00?l0ooooA03ooolO00000?l0ooook@3oool00?l0ooooA03o
oolO00000?l0ooook@3oool00?l0ooooA03ooolN000000D0oooo0P3no_ko0?ooonL0oooo003o0?oo
od@0oooo7P0000050?ooo`80o_kno`3ooooW0?ooo`00o`3ooom50?oooad00000o`3oooo^0?ooo`00
o`3ooom50?oooad00000o`3oooo^0?ooo`00o`3ooolo0?ooo`80o_kn103ooolJ0000000300410@3o
ool0oooo0?l0ooookP3oool00?l0oooo?`3oool20?knoP@0oooo6P0000000`010@40oooo0?ooo`3o
0?ooonh0oooo003o0?ooodH0oooo6P00003o0?oooo00oooo003o0?ooodH0oooo1P0000000`010@40
00000000000@00000?l0ooool@3oool00?l0ooooAP3oool60000000300410@000000000001000000
o`3ooooa0?ooo`00o`3ooom60?oooaT00000o`3ooooa0?ooo`00o`3ooom80?oooaL00000o`3ooooa
0?ooo`00o`3ooom20?ooo`80o_kn103oool9000000800@412`00003o0?oooo80oooo003o0?oood80
oooo0P3no_h40?ooo`T000000P010@4;00000?l0oooolP3oool00?l0ooooB@3ooolE00000?l0oooo
lP3oool00?l0ooooB@3oool4000000800@410P00000200410@T00000o`3ooood0?ooo`00o`3ooom9
0?oooa<00000o`3ooood0?ooo`00o`3ooom90?oooa<00000o`3ooood0?ooo`00o`3ooom:0?oooa80
0000o`3ooood0?ooo`00o`3ooom80?ooo`030?knoP3oool0000001000000o`3ooooe0?ooo`00o`3o
oom80?ooo`030?knoP3oool0000001000000o`3ooooe0?ooo`00o`3ooom:0?ooo`l000000P010@7o
0?ooooD0oooo003o0?oood`0oooo3`00003o0?ooooD0oooo003o0?oood`0oooo2`0000000`010@40
00000?ooo`3o0?ooooH0oooo003o0?oood`0oooo2`0000000`010@4000000?ooo`3o0?ooooH0oooo
003o0?oood`0oooo3@00003o0?ooooL0oooo003o0?ooodd0oooo2`00003o0?ooooP0oooo003o0?oo
odd0oooo2`00003o0?ooooP0oooo003o0?ooodd0oooo2`00003o0?ooooP0oooo003o0?ooodd0oooo
2`00003o0?ooooP0oooo003o0?ooodl0oooo00<0000000410@0000000P0000000`010@4000000000
003o0?ooooT0oooo003o0?ooodl0oooo00<0000000410@0000000P0000000`010@4000000000003o
0?ooooT0oooo003o0?ooodX0oooo0P3no_h30?ooo`P000000P3oool20?kno_l0oooom@3oool00?l0
ooooC`3oool800000?l0oooon@3oool00?l0ooooD03oool500000?l0oooon`3oool00?l0ooooD03o
ool500000?l0oooon`3oool00?l0ooooB03oool00`3no_h0oooo0?ooo`050?ooo`D000001`3oool2
0?kno_l0oooolP3oool00?l0ooooD03oool500000?l0oooon`3oool00?l0ooooBP3oool20?knoP03
0?ooo`3no_h0o_kn0080oooo100000040?ooo`80o_kno`3ooooe0?ooo`00o`3ooom:0?ooo`80o_kn
00<0oooo0?knoP3no_h00P3oool4000000@0oooo0P3no_ko0?ooooD0oooo003o0?oooe40oooo0`00
003o0?oooo`0oooo003o0?oooe40oooo0`00003o0?oooo`0oooo003o0?ooodd0oooo0P3no_h40?oo
o`030000003oool0oooo0?l0oooonP3oool00?l0ooooC@3oool20?knoP@0oooo00<000000?ooo`3o
ool0o`3ooooj0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooE`3oool00`3no_h0oooo0?oo
o`3o0?ooooH0oooo003o0?oooeL0oooo00<0o_kn0?ooo`3oool0o`3oooof0?ooo`00o`3ooooo0?oo
ool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3o
oooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?oo
o`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3o
oomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0
ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o
0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0oooo?@3oool200000?l0
ooooo`3ooolB0?ooo`00o`3ooolm0?ooo`@00000o`3ooooo0?oooa00oooo003o0?ooocd0oooo1000
003o0?ooool0oooo403oool00?l0oooo?`3oool300000?l0ooooo`3oool?0?ooo`00o`3ooom10?oo
o`<0000000<0o_kn0?ooo`3oool0o`3ooooo0?ooo`X0oooo003o0?oood80oooo0`00003o0?ooool0
oooo303oool00?l0oooo@P3oool300000?l0ooooo`3oool<0?ooo`00o`3ooom40?ooo`800000o`3o
oooo0?ooo`/0oooo003o0?oooch0oooo00<0o_kn0?ooo`3oool0103oool300000?l0ooooo`3oool9
0?ooo`00o`3oooln0?ooo`030?knoP3oool0oooo00@0oooo0`00003o0?ooool0oooo2@3oool00?l0
ooooAP3oool300000?l0ooooo`3oool80?ooo`00o`3ooom80?ooo`03000000010@40oooo00D0oooo
00<0o_kn0?ooo`3oool0o`3oooom0?ooo`00o`3ooom80?ooo`@00000o`3ooooo0?ooo`D0oooo003o
0?ooodP0oooo1000003o0?ooool0oooo1@3oool00?l0oooo?@3oool00`3no_h0oooo0?ooo`040?oo
o`040?knoP3oool0oooo0?ooo`D00000o`3ooooo0?ooo`@0oooo003o0?ooodP0oooo1@00003o0?oo
ool0oooo103oool00?l0ooooAP3oool20?knoP03000000010@40000000@00000o`3ooooo0?ooo`80
oooo003o0?ooodH0oooo0P3no_h00`0000000@410000000400000?l0ooooo`3oool20?ooo`00o`3o
oom10?ooo`030?knoP3oool0oooo00@0oooo1@0000020?ooo`030000003oool0oooo0?l0oooooP3o
ool00?l0ooooB03oool500000080oooo0P00003o0?ooool0oooo003o0?ooodP0oooo1@0000020?oo
o`800000o`3ooooo0?ooo`00o`3ooom80?ooo`@0000000@00@410?ooo`3oool0oooo0`00003o0?oo
ood0oooo003o0?ooodP0oooo00<00@410000000000000P0000040?ooo`800000203oool00`3no_h0
oooo0?ooo`3o0?oooo80oooo003o0?ooodP0oooo1@0000040?ooo`<00000o`3ooool0?ooo`00o`3o
oom80?ooo`D00000103oool300000?l0ooooo03oool00?l0ooooAP3oool7000000H0oooo0P00003o
0?oooo/0oooo003o0?ooodH0oooo1P0000080?ooo`030000003oool0oooo0?l0oooon@3oool00?l0
ooooAP3oool6000000T0oooo0P00003o0?ooooT0oooo003o0?ooodH0oooo1P0000090?ooo`800000
o`3ooooi0?ooo`00o`3ooom60?ooo`80000000D00@4100000000000000000?ooo`020?knoPH0oooo
0`00003o0?ooooP0oooo003o0?ooodH0oooo1000000200410@P0oooo00@0o_kn0?ooo`3oool00000
o`3ooooh0?ooo`00o`3ooom60?ooo`@000000P010@480?ooo`040?knoP3oool0oooo00000?l0oooo
n03oool00?l0ooooAP3oool6000000L0oooo00@0o_kn0?ooo`3oool0oooo0P00003o0?ooooL0oooo
003o0?ooodH0oooo0P010@44000000`0oooo00<000000?ooo`3oool0o`3ooooe0?ooo`00o`3ooom2
0?ooo`80o_kn0P3oool6000000`0oooo0`00003o0?ooooD0oooo003o0?oood80oooo0P3no_h20?oo
o`H00000303oool300000?l0oooom@3oool00?l0ooooA03oool00`3no_h0oooo00000005000000d0
oooo0P00003o0?ooooD0oooo003o0?oood80oooo0P3no_h0103oool0000000410@010@44000000d0
oooo0`00003o0?oooo@0oooo003o0?ooodD0oooo1`00000<0?ooo`@00000o`3ooood0?ooo`00o`3o
oom50?ooo`L00000303oool400000?l0oooom03oool00?l0ooooA@3oool5000000d0oooo1@00003o
0?oooo@0oooo003o0?oooch0oooo00<0o_kn0?ooo`3oool00`3oool6000000X0oooo00<0o_kn0?oo
o`3oool01@00003o0?oooo@0oooo003o0?ooocl0oooo2`00000=0?ooo`D00000o`3ooood0?ooo`00
o`3ooolo0?ooo`/000003@3oool500000?l0oooom03oool00?l0ooooA@3oool4000000l0oooo0`00
00000`3no_h0oooo0?ooo`3o0?oooo80oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?oo
ool0ooooD@3oool00?l0oooo?P3oool00`3no_h0oooo0?ooo`3o0?ooool0oooo403oool00?l0oooo
o`3ooooo0?oooe40oooo003o0?oooe/0oooo00<0o_kn0?ooo`3oool0o`3oooob0?ooo`00o`3ooomK
0?ooo`030?knoP3oool0oooo0?l0oooolP3oool00?l0oooo?`3oool20?kno_l0ooooo`3oool@0?oo
o`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3o
oomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0
ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o
0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40
oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo
0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0oooo
o`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool0
0?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0oooo
D@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?oo
ool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?ooo`00o`3o
oooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3ooomA0?oo
o`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0ooooo`3o
oomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o0?ooool0
ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40oooo003o
0?ooool0ooooo`3ooomA0?ooo`00o`3ooooo0?ooool0ooooD@3oool00?l0ooooo`3ooooo0?oooe40
oooo003o0?ooool0ooooo`3ooomA0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{189.5, 193.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 9.3   NullSpace of ",
  StyleBox["g",
    FontWeight->"Bold"],
  " is the plane formed by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["e",
            FontWeight->"Bold",
            FontSlant->"Plain"], "1"], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["e",
            FontWeight->"Bold",
            FontSlant->"Plain"], "2"], TraditionalForm]]],
  ", part of which is shown in gray. Eigenvector ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["e",
            FontWeight->"Bold",
            FontSlant->"Plain"], "3"], TraditionalForm]]],
  " is not in the nullspace."
}], "Caption",
  CellTags->"Fig. 9.3"],

Cell[TextData[{
  "\tThe existence of a nonempty nullspace (or alternatively a zero \
determinant) implies that the matrix ",
  StyleBox["g ",
    FontWeight->"Bold"],
  "has no inverse. This can easily be seen by considering the equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox["g",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(-1\)], "\[CenterDot]", 
            StyleBox["g",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], "=", 
          StyleBox["unit",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " , where ",
  StyleBox["unit",
    FontWeight->"Bold"],
  " is the unit matrix introduced previously. If we act on each side with a \
member of the null space of ",
  StyleBox["g",
    FontWeight->"Bold"],
  ", we arrive at a contradiction:"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox[
            RowBox[{
              SuperscriptBox[
                StyleBox["g",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \(-1\)], "\[CenterDot]", 
              StyleBox["g",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              SubscriptBox[
                StyleBox["e",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "1"]}], GridBox[{
                {
                  StyleBox["\[DoubleDownArrow]",
                    FontSize->16]},
                {
                  RowBox[{" ", 
                    RowBox[{
                      RowBox[{
                        StyleBox[
                          SuperscriptBox[
                            StyleBox["g",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], \(-1\)],
                          FontSize->10], 
                        StyleBox["\[CenterDot]",
                          FontSize->10], 
                        StyleBox["0",
                          FontSize->10,
                          FontWeight->"Bold"]}], 
                      StyleBox[" ",
                        FontSize->10,
                        FontWeight->"Bold"], 
                      StyleBox["=",
                        FontSize->10], 
                      StyleBox["  ",
                        FontSize->10], 
                      StyleBox["0",
                        FontSize->10,
                        FontWeight->"Bold"]}]}]}
                }]], "=", 
          RowBox[{
            RowBox[{
              StyleBox["unit",
                FontWeight->"Bold"], "\[CenterDot]", 
              SubscriptBox[
                StyleBox["e",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "1"]}], "=", 
            SubscriptBox[
              StyleBox["e",
                FontWeight->"Bold",
                FontSlant->"Plain"], "1"]}]}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(9.5.11)"],

Cell[TextData[{
  "Therefore, the inverse of ",
  StyleBox["g",
    FontWeight->"Bold"],
  " cannot exist if it has a nonempty nullspace (or a zero determinant). "
}], "Text"],

Cell[TextData[{
  "\tWhen the matrix has no inverse, the solution of matrix equations like ",
  ButtonBox["Eq. (9.5.7)",
    ButtonData:>"(9.5.7)",
    ButtonStyle->"Hyperlink"],
  " cannot be written in the form  of ",
  ButtonBox["Eq. (9.5.8)",
    ButtonData:>"(9.5.8)",
    ButtonStyle->"Hyperlink"],
  " . Sometimes no solution exists, and sometimes there is more than one \
solution. Some techniques for dealing with this situation may be found in ",
  ButtonBox["Sec. 9.10\t",
    ButtonData:>"Sec. 9.10",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  "\tMatrix operations are summarized in Table ",
  ButtonBox["9.9",
    ButtonData:>"Table 9.9",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[\(Table\ 9  .9\ Some\ matrix\ Operations\),
            FontSize->9]},
        {GridBox[{
              {
                RowBox[{
                  StyleBox["Transpose",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["m",
                    FontWeight->"Bold"], 
                  StyleBox["]",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[\(Transpose\ of\ a\ matrix\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Inverse",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["m",
                    FontWeight->"Bold"], 
                  StyleBox["]",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[\(Inverse\ of\ a\ square\ matrix\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Det",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["m",
                    FontWeight->"Bold"], 
                  StyleBox["]",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[\(Determinant\ of\ a\ square\ matrix\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Eigenvectors",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["m",
                    FontWeight->"Bold"], 
                  StyleBox["]",
                    FontWeight->"Bold",
                    FontSlant->"Italic"]}], 
                StyleBox[\(Eigenvectors\ of\ a\ square\ matrix\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Eigenvalues",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["m",
                    FontWeight->"Bold"], 
                  StyleBox["]",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[\(Eigenvalues\ of\ a\ square\ matrix\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["NullSpace",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["m",
                    FontWeight->"Bold"], 
                  StyleBox["]",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[\(Nullspace\ of\ a\ matrix\),
                  FontFamily->"Times"]}
              },
            ColumnSpacings->2.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.9"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
9.5.3 Creating Lists, Vectors and Matrices with the Table command\
\
\>", "Subsubtitle",
  CellTags->"c:23"],

Cell[TextData[{
  "It is sometimes the case that lists have elements that can be determined \
by simple algebraic relations. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can create such objects with the ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. For example, the vector ",
  StyleBox["v",
    FontWeight->"Bold"],
  "=(2,4,6,8,10,12,14) , a seven-dimensional vector of even integers, can be \
created using"
}], "Text",
  CellTags->"i:38"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v = Table[2  i, {i, 1, 7}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.62"],

Cell[BoxData[
    \({2, 4, 6, 8, 10, 12, 14}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first argument in the ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is the expression determining the elements of the vector, in \
terms of a dummy variable ",
  StyleBox["i",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The second argument is a list stating the name of the dummy variable and \
the range over which it  runs. "
}], "Text"],

Cell["\<\
\tOptionally, one can also specify the step size, so one need not \
iterate by an integer amount. For example,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v = Table[i, {i, 0, Pi, 0.1  Pi}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.63"],

Cell[BoxData[
    \({0, 0.3141592653589793`, 0.6283185307179586`, 0.9424777960769379`, 
      1.2566370614359172`, 1.5707963267948966`, 1.8849555921538759`, 
      2.199114857512855`, 2.5132741228718345`, 2.827433388230814`, 
      3.141592653589793`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "creates a vector whose elements differ by ",
  Cell[BoxData[
      \(TraditionalForm\`0.1\ \[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tMatrices can also be created with the ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. Now there are two iterators, to specify both the row and the \
column. For example, the following creates a 2- by -3 matrix:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = Table[i\  + \ j^2, {i, 1, 2}, {j, 1, 3}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.64"],

Cell[BoxData[
    \({{2, 5, 10}, {3, 6, 11}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.5.4 Operations on Lists", "Subsubtitle",
  CellTags->"c:24"],

Cell[TextData[{
  " \tAs we saw in Sec. ",
  ButtonBox["9.5.1",
    ButtonData:>"c:17",
    ButtonStyle->"Hyperlink"],
  ", lists are more general objects than vectors or matrices: their elements \
need not be numbers, and need not have the same dimension. For example, the \
list ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["a",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "="}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"1", ",", 
            RowBox[{"{", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["x",
                    FontSlant->"Plain"], "2"], ",", \(-17\)}], "}"}], ","}]}],
         TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["\"a word\"}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " contains a number, another list, and even a character string. "
}], "Text"],

Cell[TextData[{
  "\tThis section describes two useful operations that can be performed on \
such general lists. The first operation is to add new elements to an already \
existing list. To add an element to the end of the list, use the command ",
  StyleBox["Append",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:39"],

Cell[BoxData[
    \(\(a = {1, {x^2, 17}, "\<a word\>"};\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.65"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Append[a, Pi/4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.66"],

Cell[BoxData[
    \({1, {x\^2, 17}, "a word", \[Pi]\/4}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To add the element to the beginning of the list, use the command ",
  StyleBox["Prepend",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prepend[a, Pi/4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.67"],

Cell[BoxData[
    \({\[Pi]\/4, 1, {x\^2, 17}, "a word"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Another operation that we will sometimes use is to ",
  StyleBox["concatenate",
    FontSlant->"Italic"],
  " two lists, or join them together. This is done with the command ",
  StyleBox["Join",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In this example, we will first define a second list ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "and then join it to list",
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:40"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = {\(-1\), 3, 2};\)\), "\n", 
    \(Join[a, b]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.68"],

Cell[BoxData[
    \({1, {x\^2, 17}, "a word", \(-1\), 3, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe list ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has a sublist  in its second element, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            SuperscriptBox[
              StyleBox["x",
                FontSlant->"Plain"], "2"], ",", \(-17\)}], "}"}], 
        TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". It will sometimes be useful to transform a list with sublists into a \
simple list. This operation is performed with the",
  StyleBox[" Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command:"
}], "Text",
  CellTags->"i:41"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Flatten[a]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.69"],

Cell[BoxData[
    \({1, x\^2, 17, "a word"}\)], "Output"]
}, Open  ]],

Cell["\<\
The result is a list with the same elements as before, but without \
any sublists: the interior brackets are all removed.\
\>", "Text"],

Cell[TextData[{
  "\tOperations involving lists are summarized in Table ",
  ButtonBox["9.10",
    ButtonData:>"Table 9.10",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox[\(Table  9  .10\ Operations\ Involving\ Lists\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  StyleBox[
                    RowBox[{"Table", "[", 
                      RowBox[{"f", 
                        StyleBox[",",
                          FontSlant->"Plain"], 
                        RowBox[{
                          StyleBox["{",
                            FontSlant->"Plain"], \(i, imin, imax, step\), 
                          "}"}]}], "]"}],
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                    "Give", " ", "a", " ", "list", " ", "of", " ", "the", " ",
                       "values", " ", "of", " ", 
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], " ", "as", " ", 
                      StyleBox["i",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "runs", " ", "from", " ", 
                      StyleBox["imin",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["  ",
                        FontSlant->"Italic"], "to", " ", 
                      StyleBox["imax",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], "\[IndentingNewLine]", 
                    RowBox[{"in", " ", "steps", " ", "of", " ", "size", " ", 
                      StyleBox["step",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], \((optional)\)}]}]},
                {
                  StyleBox[
                    RowBox[{"\[IndentingNewLine]", 
                      RowBox[{"Table", "[", 
                        RowBox[{"f", 
                          StyleBox[",",
                            FontSlant->"Italic"], 
                          RowBox[{
                            StyleBox["{",
                              FontSlant->"Italic"], 
                            StyleBox[\(i, imin, imax\),
                              FontSlant->"Plain"], 
                            StyleBox["}",
                              FontSlant->"Italic"]}], 
                          StyleBox[",",
                            FontSlant->"Italic"], 
                          RowBox[{
                            StyleBox["{",
                              FontSlant->"Italic"], 
                            StyleBox[\(j, jmin, jmax\),
                              FontSlant->"Plain"], 
                            StyleBox["}",
                              FontSlant->"Italic"]}]}], "]"}]}],
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(\(\[IndentingNewLine]\)\(Generate\ a\ matrix\
\)\)},
                {
                  StyleBox[\(\(\[IndentingNewLine]\)\(Join[a, b]\)\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(\(\[IndentingNewLine]\)\(Join\ two\ \
lists\)\)},
                {
                  
                  StyleBox[\(\(\[IndentingNewLine]\)\(Append[list, 
                      element]\)\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"\[IndentingNewLine]", 
                    RowBox[{"Add", " ", 
                      StyleBox["element",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "to", " ", "the", " ", "end", 
                      " ", "of", " ", 
                      StyleBox["list",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}]}]},
                {
                  StyleBox[
                    RowBox[{"\[IndentingNewLine]", 
                      RowBox[{"Prepend", "[", \(list, element\), 
                        StyleBox["]",
                          FontSlant->"Plain"]}]}],
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"\[IndentingNewLine]", 
                    RowBox[{"Add", " ", 
                      StyleBox["element",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "to", " ", "the", " ", 
                      "beginning", " ", "of", " ", 
                      StyleBox["list",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}]}]},
                {
                  StyleBox[
                    RowBox[{"\[IndentingNewLine]", 
                      RowBox[{"Insert", "[", \(list, element, i\), 
                        StyleBox["]",
                          FontSlant->"Italic"]}]}],
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"\[IndentingNewLine]", 
                    RowBox[{"Insert", " ", 
                      StyleBox["element",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "at", " ", "the", " ", 
                      StyleBox[
                        RowBox[{
                          StyleBox["i",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], "th"}]], " ", "position", 
                      " ", "of", " ", 
                      StyleBox["list",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}]}]},
                {
                  StyleBox[\(\(\[IndentingNewLine]\)\(Flatten[list]\)\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"\[IndentingNewLine]", 
                    RowBox[{
                      
                      RowBox[{\(Remove\ all\ interior\ curly\ brackets\), ",",
                         
                        RowBox[{"writing", " ", 
                          StyleBox["list",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], 
                          StyleBox[" ",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], "as", " ", "a"}]}], 
                      "\[IndentingNewLine]", \(simple\ list\ with\ no\ \
sublists, \[IndentingNewLine]but\ preserving\ the\ order\ of\ the\ \
elements\)}]}]}
                },
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.10"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.5", "Subsubtitle",
  CellTags->"c:25"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Find the magnitude of the vector",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\(-2\), 4, 12, \(-3\), 6)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A man walks 10 feet north, 12 feet southeast, 9 feet west, and 6 feet \
northeast.  How far from his initial position did the man move?"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Find the determinant, the eigenvalues and the eigenvectors of the \
following matrices. In each case show directly that the first eigenvalue and \
eigenvector satisfy ",
  ButtonBox["Eq. (9.5.9)",
    ButtonData:>"(9.5.9)",
    ButtonStyle->"Hyperlink"],
  ".  (Hint: You may want to evaluate them numerically so that they are not \
so complicated-looking.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"1", "2"},
              {\(-1\), "1"}
              },
            ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
        TraditionalForm]]],
  ".\n"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"4", "1", "2"},
              {"3", "1", "1"},
              {"0", "1", "0"}
              },
            ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
        TraditionalForm]]],
  ".\n"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"3", "1", "4", "2"},
              {\(-1\), "5", "2", "3"},
              {\(-4\), \(-4\), "5", "2"},
              {\(-12\), "2", "1", "2"}
              },
            ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  "  Find the nullspace for the following matrix:  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"18", "6", "12"},
              {"6", "2", "4"},
              {"12", "4", "8"}
              },
            ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
Show directly that any vector in the nullspace yields zero when \
multiplied by the matrix.\
\>", "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Solve the matrix problem  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["A",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], "=", 
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " for the unknown vector ",
  StyleBox["x",
    FontWeight->"Bold"],
  ",  where"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(-1\), "1"},
                {"3", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((3, 1)\)}], TraditionalForm]]],
  ";  "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["A",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"4", "2", "1"},
                {"2", "4", "1"},
                {"1", "4", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
        TraditionalForm]]],
  "  and ",
  StyleBox["u",
    FontWeight->"Bold"],
  " = (0,0,1)."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " A 3-by-3 matrix ",
  StyleBox["m ",
    FontWeight->"Bold"],
  "has elements defined by the equation  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["m",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[LeftDoubleBracket]", \(i, j\), 
            "\[RightDoubleBracket]"}], "=", \(i\^2 + j\^2\)}], 
        TraditionalForm]]],
  ", except for ",
  StyleBox["m",
    FontWeight->"Bold"],
  "[[1,2]], which satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["m",
              FontWeight->"Bold",
              FontSlant->"Plain"], "[", \([1, 2]\), "]"}], " ", "=", " ", 
          "x"}], TraditionalForm]]],
  StyleBox[",",
    FontSlant->"Italic"],
  " where ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is an unknown.  Find a value of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " for which ",
  StyleBox["m",
    FontWeight->"Bold"],
  " has a finite nullspace."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.6 Plotting Results", "Subtitle",
  CellTags->{"Sec. 9.6", "c:26"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "9.6.1 The ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Command"
}], "Subsubtitle",
  CellTags->{"i:43", "c:27"}],

Cell[TextData[{
  "In order to plot a function of one variable,  use the ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command.  The most basic form of this command has the form"
}], "Text"],

Cell[TextData[{
  StyleBox["\t\tPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["function",
    FontSlant->"Italic"],
  ",",
  StyleBox["range",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "where ",
  StyleBox["function",
    FontSlant->"Italic"],
  " is the function to be plotted, and ",
  StyleBox["range",
    FontSlant->"Italic"],
  " is a list giving the dependent variable and the range of the plot. For \
example, ",
  StyleBox["Plot[Sin[x],{x,0,2Pi}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "produces a plot of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x)\)]],
  " over the range from ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\)]],
  ", as shown in Cell ",
  ButtonBox["9.70",
    ButtonData:>"Cell 9.70",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Sin[x], {x, 0, 2  Pi}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.70"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo
000R0?ooo`030000003oool0oooo0?l0ooooA03oool001P0oooo100000000`0A4A40oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?oood@0oooo000?0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool01@3oool300000>D0oooo
3000001B0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0>80oooo0`00
000<0?ooo`<00000C`3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3O
0?ooo`<000004P3oool3000004`0oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0g03oool3000001P0oooo0`0000190?ooo`00603oool205EEE@030000003oool0oooo00D0
oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04H0
oooo000R0?ooo`030000003oool0oooo0=T0oooo0P00000P0?ooo`030000003oool0oooo04D0oooo
000R0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`140?ooo`008P3oool00`000000oooo0?ooo`3F0?ooo`8000009@3oool00`000000oooo0?ooo`13
0?ooo`008P3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo02H0oooo0P0000130?oo
o`008P3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0@03oool00280oooo0P00003D0?ooo`030000003oool0oooo02/0oooo0P0000100?ooo`008P3o
ool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0?@3o
ool00280oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo03`0oooo000R0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0k0?ooo`008P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0>`3oool00280oooo00<000000?ooo`3oool0c`3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo03X0oooo000R0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0i0?ooo`008P3oool00`000000oooo0?ooo`3=
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00280oooo00<000000?oo
o`3oool0c03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03L0oooo000R0?ooo`80
0000c03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03L0oooo000R0?ooo`030000
003oool0oooo0<X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0f0?ooo`008P3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0=@3o
ool00280oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo03@0oooo000R0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0c0?ooo`008P3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0<`3oool00280oooo00<000000?ooo`3oool0aP3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo0380oooo000R0?ooo`030000003oool0oooo0<D0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0a0?ooo`008P3oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00280oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02l0oooo000R0?ooo`80
0000``3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02l0oooo000R0?ooo`030000
003oool0oooo0<80oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0^0?ooo`008P3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0;@3o
ool00280oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo02d0oooo000R0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0/0?ooo`008P3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0:`3oool00280oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo02/0oooo000R0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Z0?ooo`008P3oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0:@3oool00280oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo02T0oooo000R0?ooo`80
0000_@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02P0oooo000R0?ooo`030000
003oool0oooo0;`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0W0?ooo`008P3o
ool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool09`3o
ool00280oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo02H0oooo000R0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0U0?ooo`008P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool09@3oool00280oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo02@0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
1@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo0;P0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0S0?ooo`001`3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02<0oooo000500000080oooo
00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0280oooo00070?ooo`050000
003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`040?ooo`<00000]P3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo0240oooo00070?ooo`050000003oool0oooo0?ooo`00
0000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0]P3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo0240oooo00070?ooo`05014A4@3oool0oooo0?oo
o`0A4A40303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`0P0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
06P0oooo00<000000?ooo`3oool0803oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?oo
o`@000001P3oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool07`3oool00280oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo01h0oooo000R0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
K03oool00`000000oooo0?ooo`0N0?ooo`008P3oool00`000000oooo0?ooo`2b0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool07@3oool00280oooo00<000000?ooo`3oool0/P3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01d0oooo000R0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0L0?ooo`008P3oool200000;40
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0L0?ooo`008P3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06`3oool00280oooo00<0
00000?ooo`3oool0[`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01X0oooo000R
0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0J
0?ooo`008P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool06@3oool00280oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo01T0oooo000R0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0H0?ooo`008P3oool00`000000oooo0?ooo`2/0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0603oool00280oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01L0oooo000R0?ooo`800000[03oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo01L0oooo000R0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0F0?ooo`008P3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05@3oool00280oooo00<0
00000?ooo`3oool0Z@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01D0oooo000R
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0D
0?ooo`008P3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0503oool00280oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo01<0oooo000R0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0C0?ooo`008P3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool04P3oool00280oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0180oooo000R0?ooo`800000Y`3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00l0oooo000R
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0?
0?ooo`008P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool03P3oool00280oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo00h0oooo000R0?ooo`030000003oool0oooo02d0oooo100000000`0A4A40oooo
0?ooo`0[0?ooo`D00000;@3oool01@2IVIT04A4A0000000c<c<0c<c<00`0oooo00<000000?ooo`3o
ool0803oool200000003014A4@3oool0oooo02d0oooo00D0A4A4000000000000<c<c0=gMg@0/0?oo
o`050>k^kP0c<c<00000014A4@3<c<`01P3oool00`000000oooo0?ooo`0=0?ooo`008P3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo02d0oooo00D0VIVI028R8P3^k^h0oooo04A4A00]
0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<0303oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0340oooo00<0MgMg03<c<`3oool0:`3oool01@1EEED0MgMg0?ooo`2IVIT08R8R00H0oooo
00<000000?ooo`3oool03@3oool00280oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0^0?ooo`0309VIV@0R8R80k^k^0380oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0O0?ooo`D00000<`3oool00`000000oooo0?ooo`0Z0?ooo`050000003oool0oooo0?ooo`000000
1`3oool00`000000oooo0?ooo`0<0?ooo`008P3oool200000300oooo00<000000?ooo`3oool0;`3o
ool00`2IVIT08R8R0>k^kP0`0?ooo`030:ZZZP0A4A40oooo00X0oooo00<000000?ooo`3oool07`3o
ool01014A4@0gMgM0?ooo`00000c0?ooo`0307MgM`0c<c<0oooo02/0oooo00D0000009VIV@3oool0
VIVI028R8P070?ooo`030000003oool0oooo00`0oooo000R0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0<03oool00`1gMgL0IVIV0?ooo`0^0?ooo`03014A4@000000^k^k00X0oooo
00<000000?ooo`3oool0803oool0103MgMd0EEEE0?ooo`00000`0?ooo`050000000R8R80000003<c
<`3<c<`0;03oool01@000000EEEE0000000A4A40c<c<00P0oooo00<000000?ooo`3oool02`3oool0
0280oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
02h0oooo00<0^k^k028R8P3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`0307MgM`3<c<`00000
0300oooo00<000000?ooo`3oool0;P3oool00`1EEED0R8R80?ooo`0:0?ooo`030000003oool0oooo
00/0oooo000R0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;@3oool01@000000
^k^k0?ooo`2IVIT04A4A02d0oooo00D04A4A09VIV@3oool0^k^k000000090?ooo`030000003oool0
oooo0280oooo00<0k^k^04A4A0000000<03oool00`000000oooo0?ooo`0^0?ooo`030=gMg@0A4A40
VIVI00/0oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0;@3oool205EE
E@030000003oool0oooo02d0oooo00D0VIVI014A4@0000008R8R0<c<c00]0?ooo`050:ZZZP0A4A40
0000014A4@2ZZZX02@3oool00`000000oooo0?ooo`0S0?ooo`0307MgM`000000oooo02l0oooo1000
000^0?ooo`040<c<c014A4@00000014A4@X0oooo00<000000?ooo`3oool02@3oool00280oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00T0oooo000R
0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`08
0?ooo`008P3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0203oool00280oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`070?ooo`006P3ooooo000004l00000000R0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010?ooo`008P3oool2
00000300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool05@3oool00280oooo0P00002K0?ooo`030000003oool0oooo
0:H0oooo000R0?ooo`030000003oool0000009X0oooo00<000000?ooo`3oool0YP3oool00280oooo
00<000000?ooo`000000V@3oool00`000000oooo0?ooo`2W0?ooo`008P3oool010000000oooo0?oo
o`00002H0?ooo`030000003oool0oooo0:L0oooo000R0?ooo`040000003oool0oooo000009L0oooo
00<000000?ooo`3oool0Z03oool00280oooo00D000000?ooo`3oool0oooo0000002F0?ooo`030000
003oool0oooo0:P0oooo000R0?ooo`050000003oool0oooo0?ooo`000000U@3oool00`000000oooo
0?ooo`2Y0?ooo`008P3oool2000000<0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`2Y0?ooo`008P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0ZP3oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo0:X0oooo000R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`2[0?ooo`008P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0[03oool00280oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:`0oooo000R0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2]0?ooo`008P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0[@3oool00280
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0:h0
oooo000R0?ooo`800000203oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0:h0oooo
000R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`2_0?ooo`008P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08H0oooo00<00000
0?ooo`3oool0[`3oool00280oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo0;00oooo000R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`2`0?ooo`008P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo08<0oooo00<000000?ooo`3oool0/@3oool00280oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0;40oooo000R0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2b0?ooo`008P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0/P3oool00280
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0;<0
oooo000R0?ooo`8000003@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0;<0oooo
000R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`2d0?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool0]@3oool00280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0;D0oooo000R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`2f0?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool0]P3oool00280oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;L0oooo000R0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`2h0?ooo`008P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0^03oool00280
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0;T0
oooo000R0?ooo`8000004`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0;T0oooo
000R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`2j0?ooo`008P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0^P3oool00280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo0;/0oooo000R0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`2l0?ooo`008P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool0_03oool00280oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0;d0oooo00070?ooo`050>k^kP0c<c<0
000003<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`2m0?ooo`001`3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0;h0oooo
00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2o0?ooo`001`3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool3000001L0oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2o0?ooo`001`3oool01@000000oooo0?oo
o`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`300?ooo`001`3oool01@0A4A40oooo
0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0`03oool000L0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0<40oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^
k^h0303oool4000000H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo0<80oooo000R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`320?ooo`008P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool0``3oool00280oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0<@0oooo000R0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`340?ooo`008P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0a@3oool00280oooo
0P00000O0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0aP3oool00280oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0<L0oooo000R
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`37
0?ooo`008P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0b03oool00280oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0<T0oooo000R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`390?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0bP3oool00280oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0</0oooo000R0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3;0?ooo`008P3oool2000002@0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`3<0?ooo`008P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0c@3oool00280oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0<d0oooo000R
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`3>
0?ooo`008P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0c`3oool00280oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo0=00oooo000R0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`3A0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0d@3oool00280oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0=80oooo000R0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`3C0?ooo`008P3oool2000002`0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3D0?ooo`008P3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0e@3oool00280oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0=H0oooo000R
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3F
0?ooo`008P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0e`3oool00280oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0=P0oooo000R0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`3I0?ooo`008P3oool00`000000oooo0?ooo`0a0?ooo`800000<P3o
ool200000=`0oooo000R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`3L0?ooo`008P3oool00`000000oooo0?ooo`0d0?ooo`800000;@3oool00`00
0000oooo0?ooo`3M0?ooo`008P3oool2000003L0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`3N0?ooo`008P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0g`3oool00280oooo00<000000?ooo`3oool0>03oool2000002D0oooo0P00
003R0?ooo`008P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0200oooo0P00003T
0?ooo`008P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0i03oool00280oooo00<000000?ooo`3oool0?03oool2000001`0oooo0P00003W0?ooo`00
8P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01L0oooo0P00003Y0?ooo`00603o
ool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0?`3oool3000001D0oooo00<0
00000?ooo`3oool0j@3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`12
0?ooo`8000004@3oool200000>`0oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0A03oool5000000L0oooo1@00003^0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`<0
0000B03oool800000?<0oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3ooom40?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA03o
ool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood@0oooo000H0?oo
o`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`03
0000003oool0oooo0?l0ooooA03oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, -1, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the function to be plotted ",
  StyleBox["must ",
    FontSlant->"Italic"],
  " evaluate to a real number over the range of the plot.",
  "  No unknown constants can appear in the function. For instance, the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`a\ x\)]],
  " cannot be plotted vs. ",
  StyleBox["x",
    FontSlant->"Italic"],
  " unless the constant ",
  StyleBox["a",
    FontSlant->"Italic"],
  " has already been defined as some real number."
}], "Text"],

Cell["\<\
Also, functions that evaluate to complex numbers cannot be plotted \
(although one can plot the real and imaginary parts separately).\
\>", "Text"],

Cell[TextData[StyleBox["Forgetting these two simple facts is one of the most \
common sources of errors when making a plot. The error can be avoided by the \
following tactic: before you plot a function, evaluate it once at some \
arbitrary point. If unknown constants appear in the result, define them \
before continuing with the plot.",
  FontWeight->"Bold"]], "Text"],

Cell[TextData[{
  StyleBox["\t",
    FontWeight->"Bold"],
  "There are a large number of options available to modify the appearance of \
the plot. For example, to change the y-range of the plot from -2 to 2, add \
the following option ",
  StyleBox["PlotRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", as shown in Cell ",
  ButtonBox["9.71",
    ButtonData:>"Cell 9.71",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:44"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Sin[x], {x, 0, 2  Pi}, PlotRange \[Rule] {\(-2\), 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.71"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 0.154508 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -24 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -12 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -24 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -18 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -6 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -18 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-2)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-1.5)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-1)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.5)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.5)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(1)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(1.5)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .34797 L
.10458 .38751 L
.14415 .4192 L
.18221 .44266 L
.20178 .45153 L
.21267 .45544 L
.22272 .45839 L
.23293 .46071 L
.23832 .46166 L
.24402 .46245 L
.24641 .46272 L
.24897 .46296 L
.25119 .46314 L
.25361 .46329 L
.25507 .46337 L
.25643 .46342 L
.25773 .46347 L
.2584 .46348 L
.25912 .4635 L
.25983 .46351 L
.26048 .46352 L
.26176 .46353 L
.26293 .46352 L
.26416 .46351 L
.26538 .46348 L
.26607 .46347 L
.26671 .46345 L
.26912 .46335 L
.27131 .46323 L
.27364 .46306 L
.27847 .4626 L
.2838 .46192 L
.29326 .46023 L
.30213 .45812 L
.32232 .45142 L
.34082 .44305 L
.38045 .41864 L
.41855 .3881 L
.45912 .35019 L
.49816 .31089 L
.53966 .26905 L
.57964 .23152 L
.61811 .20044 L
.63759 .18725 L
.65902 .17506 L
.67938 .16596 L
.69843 .15977 L
.70884 .15738 L
.71396 .15646 L
Mistroke
.71872 .15577 L
.72301 .15527 L
.72758 .15488 L
.7302 .15472 L
.73148 .15466 L
.73266 .15461 L
.73371 .15457 L
.73487 .15454 L
.73603 .15452 L
.73725 .15451 L
.73856 .15451 L
.73977 .15452 L
.7404 .15453 L
.7411 .15454 L
.74251 .15457 L
.74375 .15462 L
.74508 .15467 L
.74748 .1548 L
.74985 .15497 L
.75235 .15519 L
.7568 .15568 L
.76198 .15642 L
.7668 .15727 L
.77773 .15976 L
.78828 .1629 L
.79823 .16651 L
.81683 .17489 L
.85534 .19847 L
.89632 .23131 L
.93577 .2683 L
.97371 .30649 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`005`3oool500000?l0ooooC@3oool001L0oooo00D0VIVI028R8P3^k^h0oooo04A4A03o0?oo
odd0oooo000?0?ooo`H000000`3oool00`2IVIT08R8R0>k^kP070?ooo`<00000o`3ooom40?ooo`00
6@3oool00`2IVIT08R8R0>k^kP060?ooo`030000003oool0oooo0?l0ooooA03oool001X0oooo00<0
MgMg06IVIP3oool01@3oool00`000000oooo0?ooo`3o0?oood@0oooo000K0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`005`3oool01@000000^k^k0?ooo`2IVIT0
4A4A00H0oooo00<000000?ooo`3oool0o`3ooom40?ooo`005`3oool01@2IVIT04A4A0000000R8R80
c<c<00H0oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280
oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo
000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R0?oo
o`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03o
ool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280
oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo
000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom4
0?ooo`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
203oool400000003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3M
gMd01@3oool00`000000oooo0?ooo`3o0?oood@0oooo000:0?ooo`030000003oool0oooo00@0oooo
0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`001@00
00050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?oood@0oooo000:0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0103oool3
00000?l0ooooA03oool000X0oooo00<000000?ooo`3oool02`3oool01@0000008R8R0000000c<c<0
c<c<00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`002P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom40?ooo`002P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
203oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`00603oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA03oool000l0oooo1P00
00050?ooo`030000003oool0oooo00D0oooo0`00003X0?ooo`H00000E@3oool001X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3O0?ooo`T000001@3oool:000004`0oooo000J0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0g03oool3000001P0oooo100000180?oo
o`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=T0oooo0`00000O0?ooo`<0
0000A@3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3F0?ooo`<00000
9@3oool2000004<0oooo000H0?ooo`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3C0?ooo`<00000:P3oool300000400oooo000R0?ooo`800000dP3oool200000300oooo0P00000n
0?ooo`008P3oool00`000000oooo0?ooo`3?0?ooo`800000=03oool2000003`0oooo000R0?ooo`03
0000003oool0oooo0<d0oooo0P00000h0?ooo`030000003oool0oooo03T0oooo000R0?ooo`030000
003oool0oooo0<`0oooo00<000000?ooo`3oool0>@3oool2000003T0oooo000R0?ooo`030000003o
ool0oooo0<X0oooo0P00000n0?ooo`030000003oool0oooo03H0oooo000R0?ooo`800000b@3oool2
00000440oooo0P00000f0?ooo`008P3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0<`3oool00280oooo00<000000?ooo`3oool0a@3oool2000004L0
oooo0P00000c0?ooo`008P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0<03oool00280oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`1;0?ooo`800000<03oool00280oooo0P0000320?ooo`800000D03oool00`000000oooo0?ooo`0]
0?ooo`008P3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0;03oool00280oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo02/0oooo000R0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
E@3oool2000002/0oooo000R0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0X0?ooo`008P3oool200000;`0oooo0P00001L0?ooo`030000003oool0
oooo02L0oooo000R0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0G@3oool20000
02L0oooo000R0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0T0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`05
04A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool08`3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0R0?ooo`001@0000020?ooo`05014A4@3oool0oooo0?oo
o`0A4A40403oool00`000000oooo0?ooo`030?ooo`<00000]@3oool2000006P0oooo0P00000R0?oo
o`001`3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07`3oool000L0
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`01@3oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool07P3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0/P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01d0oooo00070?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0L0?ooo`001`3oool01@3^
k^h0<c<c0000000c<c<0k^k^00`0oooo100000060?ooo`800000/@3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo01/0oooo000R0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01P0oooo000R0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0G0?ooo`008P3oool2
00000:`0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0F0?ooo`008P3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05@3oool00280
oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo01@0
oooo000R0?ooo`030000003oool0oooo02d0oooo100000000`0A4A40oooo0?ooo`0[0?ooo`D00000
;@3oool01@2IVIT04A4A0000000c<c<0c<c<0180oooo00<000000?ooo`3oool06P3oool200000003
014A4@3oool0oooo02d0oooo00D0A4A4000000000000<c<c0=gMg@0/0?ooo`060>k^kP0c<c<00000
014A4@3<c<`000005@3oool00280oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0]
0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0;@3oool01@0A4A40^k^k0?ooo`1gMgL0<c<c0140oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0a0?ooo`0307MgM`0c<c<0oooo02/0oooo
00L0EEEE07MgM`3oool0VIVI028R8P3oool0000001@0oooo000R0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0;P3oool00`2IVIT08R8R0>k^kP0b0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool06P3oool5000003<0oooo00<000000?ooo`3oool0:P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool04@3oool00280oooo0P00000`0?ooo`03
0000003oool0oooo02l0oooo00<0VIVI028R8P3^k^h0<03oool00`2ZZZX04A4A0?ooo`0>0?ooo`03
0000003oool0oooo01/0oooo00@0A4A40=gMg@3oool00000<`3oool00`1gMgL0<c<c0?ooo`0[0?oo
o`050000002IVIT0oooo09VIV@0R8R800`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo00<0MgMg06IVIP3oool0;P3oool00`0A
4A4000000;^k^`0>0?ooo`030000003oool0oooo01`0oooo00@0gMgM05EEE@3oool00000<03oool0
1@0000008R8R0000000c<c<0c<c<02`0oooo00D0000005EEE@0000004A4A0<c<c0040?ooo`030000
003oool0oooo00l0oooo000R0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0^0?ooo`030;^k^`0R8R80oooo00`0oooo00<000000?ooo`3oool07P3o
ool00`1gMgL0c<c<0000000`0?ooo`030000003oool0oooo02h0oooo00<0EEEE08R8R03oool01`3o
ool00`000000oooo0?ooo`0>0?ooo`008P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo02d0oooo00D000000;^k^`3oool0VIVI014A4@0]0?ooo`05014A4@2IVIT0oooo0;^k^`000000
303oool00`000000oooo0?ooo`0O0?ooo`030>k^kP14A4@000000300oooo00<000000?ooo`3oool0
;P3oool00`3MgMd04A4A09VIV@080?ooo`030000003oool0oooo00d0oooo000R0?ooo`030000003o
ool0oooo02d0oooo0P1EEED00`000000oooo0?ooo`0]0?ooo`0509VIV@0A4A400000028R8P3<c<`0
;@3oool01@2ZZZX04A4A0000000A4A40ZZZZ00/0oooo00<000000?ooo`3oool08@3oool00`1gMgL0
00000?ooo`0_0?ooo`@00000;P3oool0103<c<`0A4A40000000A4A470?ooo`030000003oool0oooo
00`0oooo000R0?ooo`800000X@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo00/0
oooo000R0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool02@3oool00280oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo00P0oooo000R0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`070?ooo`006P3ooooo000004l00000000R0?ooo`800000
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0040oooo000R0?ooo`030000
003oool0000002l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool00280oooo00@000000?ooo`3oool00000
V03oool00`000000oooo0?ooo`2W0?ooo`008P3oool01@000000oooo0?ooo`3oool0000009H0oooo
00<000000?ooo`3oool0Z03oool00280oooo0P0000030?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0Z@3oool00280oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo0:X0oooo000R0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`2[0?ooo`008P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0[03oool00280oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0:d0oooo000R0?ooo`800000203o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0:h0oooo000R0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`2_0?ooo`008P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0/03oool00280
oooo00<000000?ooo`3oool02P3oool2000008<0oooo00<000000?ooo`3oool0/@3oool00280oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1n0?ooo`800000]03oool00280oooo0P00
000>0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0]03oool00280oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;D0oooo000R0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`2f0?oo
o`008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0]`3oool00280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0;P0oooo000R0?ooo`8000004`3oool00`000000oooo0?ooo`1a0?ooo`800000^`3o
ool00280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo0;/0oooo000R0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`2l0?ooo`001`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool0_@3oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`05
0?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`2n0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool0
4A4A0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0_`3oool000L0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`0307MgM`0c<c<0oooo00@0oooo0`00000H0?ooo`800000I@3oool200000<80oooo00070?oo
o`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0<80oooo0007
0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`330?ooo`001`3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05`0oooo0P0000360?ooo`001`3oool01@3^k^h0<c<c0000000c
<c<0k^k^00`0oooo100000060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`360?ooo`008P3oool2000001l0oooo0P00001I0?ooo`030000003oool0
oooo0<L0oooo000R0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`380?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0580
oooo0P00003;0?ooo`008P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool0b`3oool00280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo0<`0oooo000R0?ooo`8000009@3oool00`000000oooo0?ooo`1;
0?ooo`800000c`3oool00280oooo00<000000?ooo`3oool09@3oool2000004X0oooo00<000000?oo
o`3oool0c`3oool00280oooo00<000000?ooo`3oool09`3oool2000004H0oooo0P00003B0?ooo`00
8P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0440oooo0P00003D0?ooo`008P3o
ool00`000000oooo0?ooo`0Z0?ooo`800000@03oool00`000000oooo0?ooo`3D0?ooo`008P3oool2
000002d0oooo0P00000l0?ooo`800000e`3oool00280oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0g0?ooo`800000f@3oool00280oooo00<000000?ooo`3oool0;`3oool2000003H0
oooo00<000000?ooo`3oool0f@3oool00280oooo00<000000?ooo`3oool0<@3oool200000380oooo
0P00003L0?ooo`008P3oool00`000000oooo0?ooo`0c0?ooo`<00000;@3oool200000=h0oooo000R
0?ooo`800000=`3oool2000002T0oooo0P00003P0?ooo`008P3oool00`000000oooo0?ooo`0h0?oo
o`800000903oool300000>80oooo000R0?ooo`030000003oool0oooo03X0oooo0P00000O0?ooo`<0
0000i@3oool001P0oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo03`0oooo
0`00000I0?ooo`<00000j03oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0o0?ooo`D000004@3oool300000>/0oooo000J0?ooo`030000003oool0oooo00D0oooo0`000014
0?oooa400000kP3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oo
od@0oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA03oool001X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood@0oooo000H0?ooo`80EEEE00<00000
0?ooo`3oool01@3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood@0oooo000R0?ooo`800000o`3ooom50?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3o
oom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`800000o`3ooom50?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood@0oooo000R0?ooo`800000o`3ooom50?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo00080?ooo`@0000000<04A4A0?ooo`3oool00P3oool2028R8PD0oooo00D0A4A4000000000000
<c<c0=gMg@050?ooo`030000003oool0oooo0?l0ooooA03oool000X0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3o0?oood@0oooo
000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?oood@0oooo000:0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3oool0103oool3
00000?l0ooooA03oool000X0oooo00<000000?ooo`3oool02`3oool01@0000008R8R0000000c<c<0
c<c<00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`002P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom40?ooo`002P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
203oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo0P00003o0?ooodD0oooo000R
0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo000R0?ooo`030000003oool0oooo0?l0oooo
A03oool00280oooo0P00003o0?ooodD0oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool0
0280oooo00<000000?ooo`3oool0o`3ooom40?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0
oooo000R0?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?ooo`3oool0o`3o
oom40?ooo`008P3oool200000?l0ooooA@3oool00280oooo00<000000?ooo`3oool0o`3ooom40?oo
o`005`3oool5000000H0oooo00<000000?ooo`3oool0o`3ooom40?ooo`005`3oool01@2IVIT08R8R
0>k^kP3oool0A4A400H0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00603oool00`2IVIT08R8R
0>k^kP070?ooo`030000003oool0oooo0?l0ooooA03oool001T0oooo00<0VIVI028R8P3^k^h01P3o
ool300000?l0ooooA03oool001X0oooo00<0MgMg06IVIP3oool0o`3ooom<0?ooo`006`3oool00`00
0000oooo0?ooo`3o0?oood/0oooo000G0?ooo`050000002k^k/0oooo09VIV@0A4A40o`3ooom=0?oo
o`005`3oool01@2IVIT04A4A0000000R8R80c<c<0?l0ooooC@3oool00?l0ooooJ@3oool00?l0oooo
J@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, -2, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The arrow ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rule]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " in this cell was obtained by typing ",
  StyleBox["->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (\"minus-greater than-space\"). ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " automatically reformats this key sequence. Several other common symbols \
can also be created in this manner, such as ",
  StyleBox["\[LessEqual]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (keyed as ",
  StyleBox["<= ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), ",
  StyleBox["\[GreaterEqual]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (keyed as ",
  StyleBox[">= ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") and ",
  StyleBox["\[NotEqual]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (keyed as ",
  StyleBox["!= ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ").  Keyboard equivalents for many other symbols also exist; see Sec. ",
  ButtonBox["9.4.3",
    ButtonData:>"c:15",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:133"],

Cell[TextData[{
  "\tOther options can be added as extra arguments to the function ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, to create axis labels and a plot label, use the options "
}], "Text"],

Cell[TextData[{
  "\t\t",
  StyleBox["AxesLabel \[Rule] {\"x\",\"Sin[x]\"}",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "\t\t",
  StyleBox["PlotLabel \[Rule] \"A plot of Sin[x]\"",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "\tOne can also change the color of the lines in the plot, or change from \
solid to dashed or dotted lines. To change the color, use ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["PlotStyle",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["\[Rule]",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["RGBColor",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["r",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["g",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["b",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " where ",
  StyleBox["r",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["g",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are real numbers between 0 and 1 giving the intensity of red, green and \
blue respectively. To change to a dashed line, use the ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PlotStyle \[Rule] Dashing[{line, space}]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", where ",
  StyleBox["line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["space",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "are the lengths of lines and spaces in the dashing. If you want to use \
both a colored and a dashed line,  make a list of ",
  StyleBox["PlotStyle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options: for example, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  StyleBox["PlotStyle ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rule]",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["{RGBColor[1,0,0],Dashing[{0.05,0.05}]}",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "produces a bright red dashed line. The use of these and other options is \
illustrated in Cell ",
  ButtonBox["9.72",
    ButtonData:>"Cell 9.72",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prettyplot = 
      Plot[Sin[x], {x, 0, 2  Pi}, 
        FrameTicks \[Rule] {{0, Pi, 2  Pi}, Automatic, None, Automatic}, 
        Frame \[Rule] True, Axes \[Rule] False, \ 
        PlotStyle \[Rule] {RGBColor[1, 0, 1], Dashing[{0.05, 0.03}]}, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>", "\<The Sine Function\>", \
"\<\>"}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.72"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.5 -0.0125 -5 -12 ]
[.5 -0.0125 5 0 ]
[.97619 -0.0125 -9.3125 -12 ]
[.97619 -0.0125 9.3125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -24 ]
[.5 -0.0125 5 -12 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36 -5 ]
[-0.01875 .30902 -24 5 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.3125 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
71.625 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .13243 m
.00375 .13243 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -96 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.000 13.000 moveto
(Sine) show
117.000 13.000 moveto
(Function) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .13243 m
1 .13243 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
[ .05 .03 ] 0 setdash
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00aoooool2
o`0000;ooooo0_l0002Kooooo`00aoooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgI_ooooo0038
ooooo`04omgMgOl0003o410@olc<c9cooooo0038ooooo`04onk^k_lQ8B7o410@onk^kYcooooo0038
ooooo`04ob4Q8OmgMgOoMgMgoc8b<Ycooooo0037ooooo`;o00000_ooool2o`0009_ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0036ooooo`03oeEEEOnYZJWo
oooo00;ooooo00?o^[ZjodA4A?ooool0M_ooool5o`0000Gooooo00?oEEEEojVYZOooool00_ooool0
0onj^[[oA4A4ooooo`0Booooo`00A?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^07kooooo00KoEEEE
oiRHV?oooooooooooa0@4?nj^[Ygooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool01_mEEEGo
V9RHoooooooooooo410@okZj^Q?ooooo0014ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Ooooool0
1?l@413ogMgMooooool0001iooooo`03oiRHV?lQ8B7ok^k^00Sooooo00Co410@omgMgOoooooo0000
5?ooool004Cooooo00Go410@oooooooooooooooooa0@401oooooo`04ohN7QomVIVKoooooo`0007[o
oooo00?oV9RHob4Q8Oo^k^h01oooool01?n7QhOoIVIVooooool0000Dooooo`00A?ooool01Ol0003o
oooooooooooooooo000007oooooo00CogMgMoa0@4?oooooo0000Noooool00omgMgOoIVIVooooo`06
ooooo`04omgMgOl@413oooooo`0001Cooooo0014ooooo`05o`000?ooooooooooooooool00000O_oo
ool7o`0007[ooooo00?o0000ooooooooool01?ooool7o`0001;ooooo0014ooooo`05oa0@4?oooooo
ooooooooool@4100noooool01Ol0003o^[ZjoooooonHV9So410@01oooooo0014ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0noooool01OnHV9So410@o`000?lQ8B7oc<c<01oooooo0014ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0oooooolPooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00@?ooooooo`0001Go00005?ooool003Oooooo1?l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool003Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000
ooooooooool04_ooool002kooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooolAooooo`03o`000?oooooooooo01;ooooo000iooooo`03o`000?oooooooooo00Co
oooo0ol00032ooooo`Goo`3oAoooool3o`0001Cooooo000iooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0`Oooool00ooo0?ooooooooooo`0:ooooo`Goo`3o?Oooool00ol0003ooooo
ooooo`0Booooo`00>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;cooooo0ooo
0?lDooooo`;oo`3o>oooool00ol0003oooooooooo`0Booooo`00>Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0;_ooooo00?oo`3oooooooooool05oooool00ooo0?ooooooooooo`0h
ooooo`03o`000?oooooooooo01;ooooo000gooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool0^_ooool00ooo0?ooooooooooo`0Iooooo`03ool0oooooooooooo03Oooooo00?o0000oooo
ooooool04_ooool0043ooooo00?o0000ooooooooool0^Oooool00ooo0?ooooooooooo`0Kooooo`03
ool0oooooooooooo03Kooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0
]oooool2ool0oaoooooo0_oo0?lfooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oo
oooooooo0;Kooooo00?oo`3oooooooooool08Oooool00ooo0?ooooooooooo`0cooooo`03o`000?oo
oooooooo01;ooooo0010ooooo`;o0000]Oooool2ool0oeWooooo0_l0000Dooooo`00@?ooool00ol0
003oooooooooo`2cooooo`03ool0oooooooooooo05[ooooo00?o0000ooooooooool04_ooool0043o
oooo00?o0000ooooooooool0/_ooool00ooo0?ooooooooooo`1Kooooo`03o`000?oooooooooo01;o
oooo0010ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0Booooo`00@?oo
ool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000
ooooooooool0h?ooool00ooo0?ooooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo0010oooo
o`03o`000?oooooooooo0>3ooooo00?oo`3oooooooooool0;Oooool00ol0003oooooooooo`0Boooo
o`00@?ooool00ol0003oooooooooo`3Qooooo`03ool0oooooooooooo02cooooo00?o0000oooooooo
ool04_ooool0043ooooo0_l0002^ooooo`03ool0oooooooooooo03;ooooo00?oo`3oooooooooool0
:_ooool2o`0001Cooooo0010ooooo`03o`000?oooooooooo0:cooooo00?oo`3oooooooooool0=?oo
ool00ooo0?ooooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooo
oooo0:cooooo00?oo`3oooooooooool0=Oooool00ooo0?ooooooooooo`0Yooooo`03o`000?oooooo
oooo01;ooooo0010ooooo`03o`000?oooooooooo0:_ooooo00?oo`3oooooooooool0=_ooool00ooo
0?ooooooooooo`0Yooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0:[o
oooo00?oo`3oooooooooool0>?ooool00ooo0?ooooooooooo`0Xooooo`03o`000?oooooooooo01;o
oooo0010ooooo`03o`000?oooooooooo0:Wooooo00?oo`3oooooooooool0>_ooool00ooo0?oooooo
ooooo`0Wooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0:Wooooo00?o
o`3oooooooooool0>oooool00ooo0?ooooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo0010
ooooo`03o`000?oooooooooo0:Sooooo00?oo`3oooooooooool0?Oooool00ooo0?ooooooooooo`0U
ooooo`03o`000?oooooooooo01;ooooo0010ooooo`;o0000Z?ooool00ooo0?ooooooooooo`0ooooo
o`03ool0oooooooooooo02?ooooo0_l0000Dooooo`00@?ooool00ol0003oooooooooo`2Wooooo`03
ool0oooooooooooo06Kooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0
Y_ooool00ooo0?ooooooooooo`1Wooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oo
oooooooo0:Gooooo00?oo`3oooooooooool0J?ooool00ol0003oooooooooo`0Booooo`00@?ooool0
0ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooo
ooooool0oooooolAooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0>go
oooo00?oo`3oooooooooool08?ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003ooooo
ooooo`3]ooooo`03ool0oooooooooooo023ooooo00?o0000ooooooooool04_ooool0043ooooo0_l0
003_ooooo`03ool0oooooooooooo01kooooo0_l0000Dooooo`00@?ooool00ol0003oooooooooo`3_
ooooo`03ool0oooooooooooo01kooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooo
ooooool0X?ooool00ooo0?ooooooooooo`1<ooooo`03ool0oooooooooooo01kooooo00?o0000oooo
ooooool04_ooool0043ooooo00?o0000ooooooooool0X?ooool00ooo0?ooooooooooo`1=ooooo`03
ool0oooooooooooo01gooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0
Woooool00ooo0?ooooooooooo`1>ooooo`03ool0oooooooooooo01gooooo00?o0000ooooooooool0
4_ooool002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0W_ooool00ooo0?ooooooooooo`1@ooooo`03
ool0oooooooooooo01cooooo00?o0000ooooooooool04_ooool002Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo09ko
oooo00?oo`3oooooooooool0DOooool00ooo0?ooooooooooo`0Kooooo`03o`000?oooooooooo01;o
oooo000Nooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Mooooo`03ool0oooooooooooo05;ooooo00?oo`3ooooooooo
ool06oooool00ol0003oooooooooo`0Booooo`009_ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool3o`0009cooooo00?oo`3oooooooooool0E?ooool00ooo0?oo
ooooooooo`0Hooooo`?o00005?ooool002Kooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`2Looooo`03ool0oooooooooooo
05Cooooo00?oo`3oooooooooool06_ooool00ol0003oooooooooo`0Booooo`009_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Koooo
o`03ool0oooooooooooo05Kooooo00?oo`3oooooooooool06Oooool00ol0003oooooooooo`0Boooo
o`009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Kooooo`03ool0oooooooooooo07;ooooo00?o0000ooooooooool04_ooool002Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`2Joooo
o`03ool0oooooooooooo07?ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooooooo
ool0V_ooool00ooo0?ooooooooooo`1cooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`00
0?oooooooooo09Wooooo00?oo`3oooooooooool0M?ooool00ol0003oooooooooo`0Booooo`00@?oo
ool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo0_l0003o
oooooa7ooooo0_l0000Dooooo`00@?ooool00ol0003oooooooooo`3hooooo`03ool0oooooooooooo
01Gooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0n?ooool00ooo0?oo
ooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0?Wooooo
00?oo`3oooooooooool05?ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003ooooooooo
o`3jooooo`03ool0oooooooooooo01?ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000
ooooooooool0UOooool00ooo0?ooooooooooo`1Rooooo`03ool0oooooooooooo01?ooooo00?o0000
ooooooooool04_ooool0043ooooo00?o0000ooooooooool0UOooool00ooo0?ooooooooooo`1Soooo
o`03ool0oooooooooooo01;ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooooooo
ool0U?ooool00ooo0?ooooooooooo`1Tooooo`03ool0oooooooooooo01;ooooo00?o0000oooooooo
ool04_ooool0043ooooo0_l0002Dooooo`03ool0oooooooooooo06Kooooo00?oo`3oooooooooool0
4?ooool2o`0001Cooooo0010ooooo`03o`000?oooooooooo09?ooooo00?oo`3oooooooooool0Iooo
ool00ooo0?ooooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooo
oooo09;ooooo00?oo`3oooooooooool0J?ooool00ooo0?ooooooooooo`0@ooooo`03o`000?oooooo
oooo01;ooooo0010ooooo`03o`000?oooooooooo097ooooo00?oo`3oooooooooool0J_ooool00ooo
0?ooooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo097o
oooo00?oo`3oooooooooool0J_ooool00ooo0?ooooooooooo`0?ooooo`03o`000?oooooooooo01;o
oooo0010ooooo`03o`000?oooooooooo093ooooo00?oo`3oooooooooool0K?ooool00ooo0?oooooo
ooooo`0>ooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo093ooooo00?o
o`3oooooooooool0OOooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`2@
ooooo`03ool0oooooooooooo07gooooo00?o0000ooooooooool04_ooool0043ooooo0_l0002@oooo
o`03ool0oooooooooooo07gooooo0_l0000Dooooo`00@?ooool00ol0003oooooooooo`2?ooooo`03
ool0oooooooooooo07kooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0
oooooolAooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0?oooooo4Ooo
ool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`3oooooo`Cooooo00?oo`3o
ooooooooool02_ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`3ooooo
o`Cooooo00?oo`3oooooooooool02_ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003o
ooooooooo`3oooooo`Gooooo00?oo`3oooooooooool02Oooool00ol0003oooooooooo`0Booooo`00
@?ooool00ol0003oooooooooo`3oooooo`Gooooo00?oo`3oooooooooool02Oooool00ol0003ooooo
ooooo`0Booooo`00@?ooool2o`0008cooooo00?oo`3oooooooooool0Moooool00ooo0?oooooooooo
o`07ooooo`;o00005?ooool0043ooooo00?o0000ooooooooool0Roooool00ooo0?ooooooooooo`1g
ooooo`03ool0oooooooooooo00Sooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooo
ooooool0R_ooool00ooo0?ooooooooooo`1iooooo`03ool0oooooooooooo00Oooooo00?o0000oooo
ooooool04_ooool001[ooooo0ol000000ol@413oooooooooo`0Pooooo`03o`000?oooooooooo08[o
oooo00?oo`3oooooooooool0NOooool00ooo0?ooooooooooo`07ooooo`03o`000?oooooooooo01;o
oooo000Looooo`03oa0@4?nj^[[ooooo027ooooo00?o0000ooooooooool0ROooool00ooo0?oooooo
ooooo`1jooooo`03ool0oooooooooooo00Oooooo00?o0000ooooooooool04_ooool001cooooo00?o
V9RHoc8b<_ooool08Oooool00ol0003oooooooooo`28ooooo`03ool0oooooooooooo07cooooo00?o
o`3oooooooooool01_ooool00ol0003oooooooooo`0Booooo`007?ooool00ooMgMgo0000okZj^P0G
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`28ooooo`03ool0oooo
oooooooo07cooooo00?oo`3oooooooooool01_ooool00ol0003oooooooooo`0Booooo`007?ooool0
0omEEEGoMgMgodA4A00Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`27ooooo`03ool0oooooooooooo07kooooo00?oo`3oooooooooool01Oooool00ol0003ooooooooo
o`0Booooo`006oooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo00Go410@oooooooooooooooo
oa0@4005ooooo`?o00001?ooool00ooo0?ooooooooooo`20ooooo`03ool0oooooooooooo07oooooo
00?oo`3oooooooooool00_ooool3o`0001Cooooo000Kooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
5_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ooo0?oo
ooooooooo`1oooooo`03ool0oooooooooooo08Oooooo00?o0000ooooooooool04_ooool001[ooooo
00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`05ooooo`03ool0oooooooooooo07kooooo00?oo`3ooooooooo
ool0Qoooool00ol0003oooooooooo`0Booooo`006_ooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo01?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
00Gooooo00?oo`3oooooooooool0OOooool00ooo0?ooooooooooo`28ooooo`03o`000?oooooooooo
01;ooooo000fooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`05oooo
o`03ool0oooooooooooo07cooooo00?oo`3oooooooooool0ROooool00ol0003oooooooooo`0Boooo
o`00=_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool01_ooool00ooo
0?ooooooooooo`3oooooo`Sooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooooooo
ool0oooooolAooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0?oooooo
4Oooool00ol0003oooooooooo`0Booooo`00@?ooool2o`000?oooooo4Oooool2o`0001Cooooo0010
ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0
003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooooooo
ool0oooooolAooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo00[ooooo
00?oo`3oooooooooool0M?ooool00ooo0?ooooooooooo`2<ooooo`03o`000?oooooooooo01;ooooo
0010ooooo`03o`000?oooooooooo00[ooooo00?oo`3oooooooooool0M?ooool00ooo0?oooooooooo
o`2<ooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo00_ooooo00?oo`3o
ooooooooool0L_ooool00ooo0?ooooooooooo`2=ooooo`03o`000?oooooooooo01;ooooo0010oooo
o`03o`000?oooooooooo00_ooooo00?oo`3oooooooooool0LOooool00ooo0?ooooooooooo`2>oooo
o`03o`000?oooooooooo01;ooooo0010ooooo`;o00003Oooool00ooo0?ooooooooooo`1`ooooo`03
ool0oooooooooooo08gooooo0_l0000Dooooo`00@?ooool00ol0003oooooooooo`0=ooooo`03ool0
oooooooooooo06kooooo00?oo`3oooooooooool0Soooool00ol0003oooooooooo`0Booooo`00@?oo
ool00ol0003oooooooooo`0=ooooo`03ool0oooooooooooo06kooooo00?oo`3oooooooooool0Sooo
ool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0>ooooo`03ool0oooooooo
oooo06cooooo00?oo`3oooooooooool0T?ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0
003oooooooooo`0>ooooo`03ool0oooooooooooo06_ooooo00?oo`3oooooooooool0TOooool00ol0
003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0?ooooo`03ool0oooooooooooo06[o
oooo00?oo`3oooooooooool0TOooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003ooooo
ooooo`0?ooooo`03ool0oooooooooooo06Wooooo00?oo`3oooooooooool0T_ooool00ol0003ooooo
ooooo`0Booooo`00@?ooool00ol0003oooooooooo`0@ooooo`03ool0oooooooooooo06Sooooo00?o
o`3oooooooooool0T_ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0@
ooooo`03ool0oooooooooooo06Oooooo00?oo`3oooooooooool0Toooool00ol0003oooooooooo`0B
ooooo`00@?ooool2o`000?oooooo4Oooool2o`0001Cooooo0010ooooo`03o`000?oooooooooo0?oo
oooo4Oooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`3ooooooa7ooooo
00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0oooooolAooooo`03o`000?oo
oooooooo01;ooooo0010ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0B
ooooo`00@?ooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043o
oooo00?o0000ooooooooool05?ooool00ooo0?ooooooooooo`1Oooooo`03ool0oooooooooooo09Oo
oooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool05?ooool00ooo0?oooooo
ooooo`1Oooooo`03ool0oooooooooooo09Oooooo00?o0000ooooooooool04_ooool0043ooooo0_l0
000Fooooo`03ool0oooooooooooo05gooooo00?oo`3oooooooooool0Uoooool2o`0001Cooooo0010
ooooo`03o`000?oooooooooo01Kooooo00?oo`3oooooooooool0G?ooool00ooo0?ooooooooooo`2H
ooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo01Kooooo00?oo`3ooooo
ooooool0Foooool00ooo0?ooooooooooo`2Iooooo`03o`000?oooooooooo01;ooooo0010ooooo`03
o`000?oooooooooo01Oooooo00?oo`3oooooooooool0F_ooool00ooo0?ooooooooooo`2Iooooo`03
o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo01Oooooo00?oo`3oooooooooool0
FOooool00ooo0?ooooooooooo`2Jooooo`03o`000?oooooooooo01;ooooo000Vooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo01Sooooo00?oo`3oooooooooool0Eoooool00ooo0?ooooooooooo`2Kooooo`03
o`000?oooooooooo01;ooooo000Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Iooooo`03ool0oooooooooooo05Ko
oooo00?oo`3oooooooooool0Voooool00ol0003oooooooooo`0Booooo`009_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03
ool0oooooooooooo05Gooooo00?oo`3oooooooooool0W?ooool00ol0003oooooooooo`0Booooo`00
9_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`0001[o
oooo00?oo`3oooooooooool0E?ooool00ooo0?ooooooooooo`2Jooooo`?o00005?ooool002Kooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`0Jooooo`03ool0oooooooooooo05?ooooo00?oo`3oooooooooool0WOooool00ol0
003oooooooooo`0Booooo`009_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Kooooo`03ool0oooooooooooo057ooooo00?oo`3ooooo
ooooool0W_ooool00ol0003oooooooooo`0Booooo`009_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000oooo
ooooool04_ooool002Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000oooooooo
ool0oooooolAooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo0?oooooo
4Oooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`3ooooooa7ooooo00?o
0000ooooooooool04_ooool0043ooooo0_l0003ooooooa7ooooo0_l0000Dooooo`00@?ooool00ol0
003oooooooooo`0Pooooo`03ool0oooooooooooo04Sooooo00?oo`3oooooooooool0X_ooool00ol0
003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0Pooooo`03ool0oooooooooooo04So
oooo00?oo`3oooooooooool0X_ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003ooooo
ooooo`0Qooooo`03ool0oooooooooooo04Kooooo00?oo`3oooooooooool0Xoooool00ol0003ooooo
ooooo`0Booooo`00@?ooool00ol0003oooooooooo`0Rooooo`03ool0oooooooooooo04Cooooo00?o
o`3oooooooooool0Y?ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0R
ooooo`03ool0oooooooooooo04Cooooo00?oo`3oooooooooool0Y?ooool00ol0003oooooooooo`0B
ooooo`00@?ooool00ol0003oooooooooo`0Sooooo`03ool0oooooooooooo04;ooooo00?oo`3ooooo
ooooool0YOooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0Sooooo`03
ool0oooooooooooo04;ooooo00?oo`3oooooooooool0YOooool00ol0003oooooooooo`0Booooo`00
@?ooool2o`0002Gooooo00?oo`3oooooooooool0@?ooool00ooo0?ooooooooooo`2Uooooo`;o0000
5?ooool0043ooooo00?o0000ooooooooool09Oooool00ooo0?ooooooooooo`0nooooo`03ool0oooo
oooooooo0:Oooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool09_ooool0
0ooo0?ooooooooooo`0looooo`03ool0oooooooooooo0:Sooooo00?o0000ooooooooool04_ooool0
043ooooo00?o0000ooooooooool09oooool00ooo0?ooooooooooo`0jooooo`03ool0oooooooooooo
0:Wooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0:?ooool00ooo0?oo
ooooooooo`0hooooo`03ool0oooooooooooo0:[ooooo00?o0000ooooooooool04_ooool0043ooooo
00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oo
oooooooo0?oooooo4Oooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`3o
oooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo0_l0003ooooooa7ooooo0_l0000Doooo
o`00@?ooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool04_ooool0043ooooo
00?o0000ooooooooool0;Oooool00ooo0?ooooooooooo`0^ooooo`03ool0oooooooooooo0:oooooo
00?o0000ooooooooool04_ooool0043ooooo00?o0000ooooooooool0;Oooool00ooo0?oooooooooo
o`0]ooooo`03ool0oooooooooooo0;3ooooo00?o0000ooooooooool04_ooool0043ooooo00?o0000
ooooooooool0;_ooool00ooo0?ooooooooooo`0[ooooo`03ool0oooooooooooo0;7ooooo00?o0000
ooooooooool04_ooool0043ooooo00?o0000ooooooooool0;oooool2ool0ob[ooooo00?oo`3ooooo
ooooool0/_ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0aooooo`03
ool0oooooooooooo02Kooooo00?oo`3oooooooooool0/oooool00ol0003oooooooooo`0Booooo`00
@?ooool00ol0003oooooooooo`0booooo`03ool0oooooooooooo02Cooooo00?oo`3oooooooooool0
]?ooool00ol0003oooooooooo`0Booooo`00@?ooool2o`0003Cooooo00?oo`3oooooooooool08_oo
ool00ooo0?ooooooooooo`2dooooo`;o00005?ooool0043ooooo00?o0000ooooooooool0=?ooool0
0ooo0?ooooooooooo`0Pooooo`03ool0oooooooooooo0;Kooooo00?o0000ooooooooool04_ooool0
043ooooo00?o0000ooooooooool0=Oooool00ooo0?ooooooooooo`0Mooooo`;oo`3o^Oooool00ol0
003oooooooooo`0Booooo`00@?ooool00ol0003oooooooooo`0fooooo`03ool0oooooooooooo01[o
oooo0_oo0?nkooooo`03o`000?oooooooooo01;ooooo0010ooooo`03o`000?oooooooooo03Oooooo
00?oo`3oooooooooool0e_ooool00ol0003oooooooooo`0Booooo`00@?ooool00ol0003ooooooooo
o`3ooooooa7ooooo00?o0000ooooooooool04_ooool003Oooooo1?l000000ol@413oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0Booooo`00>Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo0_oo0?l:ooooo`;oo`3o`oooool00ol0
003oooooooooo`0Booooo`00>Oooool00ol0003oooooooooo`04ooooo`?o0000@Oooool:ool0ol?o
oooo0ol0000Dooooo`00>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
4Oooool00ol0003oooooooooo`0Booooo`00>Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo4Oooool00ol0003oooooooooo`0Booooo`00>Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0Booooo`00>Oooool00ol0
003oooooooooo`04oooooooo00005Ol0000Dooooo`00=oooool00omEEEGoIVIVo`00003ooooooboo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002;ooooo`05oa0@4?l0003o0000o`000?l@41000oooool01?l@413o0000
o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool01oooool01_l@
413o8B4Qo`000?l0003oA4A4omgMg@?ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o0000
00Co410@ooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`06ooooo`?o000000?o410@oooooooo
ool00oooool02?nHV9So0000o`000?mgMgOo0000oa0@4?oooooo410@0_l000001?oooooo0000o`00
0?l@4102ooooo`05ofIVI_l0003o0000odA4A?o<c<`00oooool01OnHV9So0000o`000?m4A4Co^[Zj
00?ooooo1Ol00002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo05Wooooo002=ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@2?ooool01_l0
003oQhN7ooooooooooooQhN7ob4Q8@Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4108ooooo`03o`000?oooooooooo
00Gooooo00Go0000ojVYZOooooooQhN7o`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go410@okZj^_o^k^koMgMgoa0@4005oooo
o`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05o`000?oo
ooooooooooooool00000G?ooool008gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool02oooool01_lQ8B7oooooooooooooooook^k^o`00
00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0F_ooool008gooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l00009ooooo`05omgMgOnHV9SoMgMgoa0@
4?mVIVH01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool6
o`0000Sooooo00?o0000ooooool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo05[ooooo002=ooooo`03o`000?oooooooooo00Cooooo
00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2?ooool0
1OmVIVKo410@oeEEEOn7QhOo^[Zj00Kooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooo
oonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S88ooooo`?o00001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06ofIVI_mg
MgOooooooooooon7QhOo00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`05o`000?n7QhOoooooojVYZOl00000G?oo
ool008[ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooooooooooo0000ogMgM`;o
000000GoV9RHooooooooooook^k^oeEEE@02o`000003odA4A?o^k^kooooo00Oooooo00Ko0000onk^
k_ooooooooooolc<c?l00003ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l0
00001OnHV9Soooooooooooo^k^koEEEE00;o000000?oA4A4onk^k_ooool01oooool01Ol0003ooooo
oa0@4?oooooo410@00;ooooo00Co410@o`000?oooooooooo0_l00002ooooo`03oa0@4?l0003oMgMg
00;o000000GoV9RHooooooooooook^k^ofIVIP02o`000004odA4A?l0003ooooooa0@40Go00001?oo
ool00ol@413o0000o`000004ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool00ol@413o
0000ogMgM`02o`000003oiRHV?oooooooooo05[ooooo002:ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`00000Dooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo00008?oo
ool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0M_ooool008[ooooo1ol0
0003ooooo`03o`000?oooooooooo01;ooooo00Kok^k^odA4A?l0003o0000oc8b<_l@4105ooooo`03
o`000?oooooooooo01Oooooo1_l0000Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0K?ooool009?ooooo00?o410@o`000?ooool07_ooool00ol@413oooooooooo`12ooooo`03oa0@
4?oooooooooo06cooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.71749, -1.46412, \
0.0300662, 0.0154851}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.6.2 The ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Command"
}], "Subsubtitle",
  CellTags->{"i:45", "c:28"}],

Cell[TextData[{
  "In order to show the same plot again but with new options, one can use the \
",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. For example, to display the previous plot over a different range \
of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", use the command shown in Cell ",
  ButtonBox["9.73",
    ButtonData:>"Cell 9.73",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newplot\  = \ 
      Show[prettyplot, PlotRange \[Rule] {{0, 10}, {\(-2\), 2}}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.73"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0.309017 0.154508 [
[.31416 -0.0125 -5 -12 ]
[.31416 -0.0125 5 0 ]
[.62832 -0.0125 -9.3125 -12 ]
[.62832 -0.0125 9.3125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -24 ]
[.5 -0.0125 5 -12 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -12 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -6 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36 -5 ]
[-0.01875 .30902 -24 5 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.31416 0 m
.31416 .00625 L
s
gsave
.31416 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.62832 0 m
.62832 .00625 L
s
gsave
.62832 -0.0125 -70.3125 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
71.625 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(-1.5)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-1)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.5)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.5)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.5)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -96 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.000 13.000 moveto
(Sine) show
117.000 13.000 moveto
(Function) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
[ .05 .03 ] 0 setdash
0 .30902 m
.02549 .34797 L
.05329 .38751 L
.07939 .4192 L
.1045 .44266 L
.11741 .45153 L
.1246 .45544 L
.13123 .45839 L
.13797 .46071 L
.14152 .46166 L
.14528 .46245 L
.14685 .46272 L
.14855 .46296 L
.15001 .46314 L
.1516 .46329 L
.15257 .46337 L
.15347 .46342 L
.15433 .46347 L
.15477 .46348 L
.15524 .4635 L
.15571 .46351 L
.15614 .46352 L
.15699 .46353 L
.15776 .46352 L
.15857 .46351 L
.15937 .46348 L
.15983 .46347 L
.16025 .46345 L
.16184 .46335 L
.16329 .46323 L
.16482 .46306 L
.16801 .4626 L
.17152 .46192 L
.17776 .46023 L
.18362 .45812 L
.19694 .45142 L
.20914 .44305 L
.23529 .41864 L
.26043 .3881 L
.28719 .35019 L
.31295 .31089 L
.34032 .26905 L
.3667 .23152 L
.39208 .20044 L
.40493 .18725 L
.41907 .17506 L
.4325 .16596 L
.44507 .15977 L
.45194 .15738 L
.45532 .15646 L
Mistroke
.45845 .15577 L
.46129 .15527 L
.4643 .15488 L
.46603 .15472 L
.46687 .15466 L
.46765 .15461 L
.46835 .15457 L
.46911 .15454 L
.46987 .15452 L
.47068 .15451 L
.47155 .15451 L
.47235 .15452 L
.47276 .15453 L
.47322 .15454 L
.47415 .15457 L
.47497 .15462 L
.47584 .15467 L
.47743 .1548 L
.479 .15497 L
.48064 .15519 L
.48358 .15568 L
.487 .15642 L
.49018 .15727 L
.49739 .15976 L
.50435 .1629 L
.51091 .16651 L
.52318 .17489 L
.54859 .19847 L
.57562 .23131 L
.60165 .2683 L
.62668 .30649 L
.62832 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00bOooool2
o`0000;ooooo0_l0002Iooooo`00bOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgIWooooo003:
ooooo`04omgMgOl0003o410@olc<c9[ooooo003:ooooo`04onk^k_lQ8B7o410@onk^kY[ooooo003:
ooooo`04ob4Q8OmgMgOoMgMgoc8b<Y[ooooo0039ooooo`;o00000_ooool2o`0009Wooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Eooooo`03oeEEEOnYZJWo
oooo00;ooooo00?o^[ZjodA4A?ooool0B_ooool5o`0000Gooooo00?oEEEEojVYZOooool00_ooool0
0onj^[[oA4A4ooooo`1_ooooo`00U_ooool01_mEEEGoV9RHoooooooooooo410@okZj^T_ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`06oeEEEOnHV9Soooooooooool@413o^[ZjL?ooool009Oo
oooo00Co410@omgMgOoooooo0000COooool00onHV9So8B4Qonk^kP08ooooo`04oa0@4?oMgMgooooo
o`00077ooooo002Gooooo`04ohN7QomVIVKoooooo`0004kooooo00?oV9RHob4Q8Oo^k^h01oooool0
1?n7QhOoIVIVooooool0001aooooo`00Uoooool01?oMgMgo410@ooooool0001?ooooo`03ogMgMomV
IVKooooo00Kooooo00CogMgMoa0@4?oooooo0000LOooool009Kooooo1ol0001>ooooo`03o`000?oo
oooooooo00Cooooo1ol0001_ooooo`00ioooool01Ol0003o^[ZjoooooonHV9So410@07cooooo003W
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool004?oooooool0000Do`00
01;ooooo0013ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o
0000ooooooooool04?ooool004?ooooo0_l0003ooooooa3ooooo0_l0000Booooo`00@oooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`0@ooooo`00@oooool2o`000?oooooo4?ooool2o`0001;ooooo0013
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o0000
4_ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o0000
4_ooool002Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo
000[ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000Pooooo`Ko00001Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooool@
ooooo`03o`000?oooooooooo013ooooo000[ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool01?ooool3o`000?oooooo3_ooool3o`0001;ooooo000[ooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0
003oooooooooo`0@ooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000[ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooa3ooooo
00?o0000ooooooooool04?ooool002Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo0_l0
003ooooooa3ooooo0_l0000Booooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00
@oooool2o`000?oooooo4?ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?oo
ool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
013ooooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool004?ooooo00?o0000ooooooooool0
ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?oo
ool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
013ooooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool003Wooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00>ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003ooooooooo
o`0@ooooo`00<?ooool6o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooa3ooooo00?o0000ooooooooool04?ooool003_ooooo00?o0000ooooooooool01Oooool3o`00
07[ooooo1ooo0?n<ooooo`?o00004_ooool003_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1fooooo`?oo`3oU_ooool00ol0003oooooooooo`0@ooooo`00>oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07Cooooo0_oo0?lBooooo`03ool0oooooooooooo08Cooooo
00?o0000ooooooooool04?ooool003_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1cooooo`03ool0oooooooooooo01?ooooo00?oo`3oooooooooool0Poooool00ol0003ooooooooo
o`0@ooooo`00>Oooool00omEEEGoIVIVo`000007ooooo`;o0000Loooool00ooo0?ooooooooooo`0E
ooooo`03ool0oooooooooooo087ooooo0_l0000Booooo`00@oooool00ol0003oooooooooo`1aoooo
o`03ool0oooooooooooo01Oooooo00?oo`3oooooooooool0POooool00ol0003oooooooooo`0@oooo
o`00@oooool00ol0003oooooooooo`1_ooooo`;oo`3o6oooool2ool0oh7ooooo00?o0000oooooooo
ool04?ooool004?ooooo00?o0000ooooooooool0K_ooool00ooo0?ooooooooooo`0Mooooo`03ool0
oooooooooooo07kooooo00?o0000ooooooooool04?ooool004?ooooo0_l0001^ooooo`03ool0oooo
oooooooo01oooooo00?oo`3oooooooooool0O?ooool2o`0001;ooooo0013ooooo`03o`000?oooooo
oooo093ooooo00?oo`3oooooooooool0O?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0
003oooooooooo`2Aooooo`03ool0oooooooooooo07_ooooo00?o0000ooooooooool04?ooool004?o
oooo00?o0000ooooooooool0T_ooool00ooo0?ooooooooooo`1jooooo`03o`000?oooooooooo013o
oooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@ooo
ool2o`000?oooooo4?ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo06Oooooo00?oo`3o
ooooooooool0YOooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`1Woooo
o`03ool0oooooooooooo0:Gooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0I_ooool00ooo0?ooooooooooo`2Vooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000
I_ooool00ooo0?ooooooooooo`0`ooooo`03ool0oooooooooooo07?ooooo0_l0000Booooo`00@ooo
ool00ol0003oooooooooo`1Tooooo`03ool0oooooooooooo037ooooo00?oo`3oooooooooool0M?oo
ool00ol0003oooooooooo`0@ooooo`00:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Sooooo`03ool0
oooooooooooo03?ooooo00?oo`3oooooooooool0Loooool00ol0003oooooooooo`0@ooooo`00:?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0H_ooool00ooo0?ooooooooooo`0eooooo`03ool0oooooooooooo07;ooooo
00?o0000ooooooooool04?ooool0023ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`?o0000HOooool00ooo0?ooooooooooo`0gooooo`03ool0
oooooooooooo06oooooo0ol0000Booooo`00:?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Qooooo`03ool0oooooooooooo03Oooooo
00?oo`3oooooooooool0LOooool00ol0003oooooooooo`0@ooooo`00:?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo063o
oooo00?oo`3oooooooooool0>Oooool00ooo0?ooooooooooo`1`ooooo`03o`000?oooooooooo013o
oooo000Xooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo063ooooo00?oo`3oooooooooool0>_ooool00ooo0?ooooooooooo`1_ooooo`03
o`000?oooooooooo013ooooo000Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`07ooooo`;o0000H?ooool00ooo0?ooooooooooo`0looooo`03ool0oooooooooooo06go
oooo0_l0000Booooo`00:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03
o`000?oooooooooo09kooooo00?oo`3oooooooooool0K_ooool00ol0003oooooooooo`0@ooooo`00
@oooool00ol0003oooooooooo`2Oooooo`03ool0oooooooooooo06gooooo00?o0000ooooooooool0
4?ooool004?ooooo00?o0000ooooooooool0X?ooool00ooo0?ooooooooooo`1/ooooo`03o`000?oo
oooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@
ooooo`00@oooool2o`000?oooooo4?ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo0?oo
oooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`1Jooooo`03ool0
oooooooooooo0;;ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0F_oo
ool00ooo0?ooooooooooo`2booooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000F_ooool0
0ooo0?ooooooooooo`2booooo`;o00004_ooool004?ooooo00?o0000ooooooooool0F?ooool00ooo
0?ooooooooooo`19ooooo`03ool0oooooooooooo06Sooooo00?o0000ooooooooool04?ooool004?o
oooo00?o0000ooooooooool0F?ooool00ooo0?ooooooooooo`19ooooo`03ool0oooooooooooo06So
oooo00?o0000ooooooooool04?ooool001cooooo0ol000000ol@413oooooooooo`0Qooooo`03o`00
0?oooooooooo05Oooooo00?oo`3oooooooooool0Boooool00ooo0?ooooooooooo`1Wooooo`03o`00
0?oooooooooo013ooooo000Nooooo`03oa0@4?nj^[[ooooo02;ooooo0_l0001Gooooo`03ool0oooo
oooooooo04gooooo00?oo`3oooooooooool0IOooool2o`0001;ooooo000Nooooo`03oiRHV?lb<S;o
oooo02;ooooo00?o0000ooooooooool0E_ooool00ooo0?ooooooooooo`1>ooooo`03ool0oooooooo
oooo06Gooooo00?o0000ooooooooool04?ooool001kooooo00?ogMgMo`000?nj^[X05oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0EOooool00ooo0?ooooooooooo`1?
ooooo`03ool0oooooooooooo06Gooooo00?o0000ooooooooool04?ooool001kooooo00?oEEEEogMg
Mom4A4@05oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0EOooool0
0ooo0?ooooooooooo`1@ooooo`03ool0oooooooooooo06Cooooo00?o0000ooooooooool04?ooool0
01gooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Fooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ooo0?oo0000o`00001Dooooo`03ool0oooooooooooo05;ooooo00?oo`3oooooooooool0HOoo
ool3o`0001;ooooo000Mooooo`05ofIVI_n7QhOooooooiRHV?mEEED05_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?oo`3oooooooooool0D_ooool2ool0ok_ooooo00?o0000ooooooooool0
4?ooool001cooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Dooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oo`3oooooo`3ooooooa3ooooo00?o0000ooooooooool0
4?ooool001cooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Cooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooool0o`3ooooooa3ooooo00?o0000oooooooo
ool04?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?ooooooo`3o0?oo
oooo4?ooool00ol0003oooooooooo`0@ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo0_l000000oooooooo`3oooooo`3oooooo`gooooo0_l0000Booooo`00@oooool00ol0003ooooo
ooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0oooo
ool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo04kooooo00?oo`3o
ooooooooool0__ooool00ol0003oooooooooo`0@ooooo`00@oooool2o`0004oooooo00?oo`3ooooo
ooooool0_Oooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo04gooooo00?oo`3ooooooooo
ool0_oooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`1=ooooo`03ool0
oooooooooooo0;oooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool01Ooo
ool00ooo0?ooooooooooo`14ooooo`03ool0oooooooooooo0<3ooooo00?o0000ooooooooool04?oo
ool004?ooooo0_l00006ooooo`03ool0oooooooooooo04Cooooo00?oo`3oooooooooool0_oooool2
o`0001;ooooo0013ooooo`03o`000?oooooooooo00Kooooo00?oo`3oooooooooool0@_ooool00ooo
0?ooooooooooo`31ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo00Oo
oooo00?oo`3oooooooooool0@?ooool00ooo0?ooooooooooo`32ooooo`03o`000?oooooooooo013o
oooo0013ooooo`03o`000?oooooooooo00Oooooo00?oo`3oooooooooool0?oooool00ooo0?oooooo
ooooo`33ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o00002Oooool00ooo0?oooooooooo
o`0mooooo`03ool0oooooooooooo0<?ooooo0_l0000Booooo`00@oooool00ol0003oooooooooo`08
ooooo`03ool0oooooooooooo03cooooo00?oo`3oooooooooool0aOooool00ol0003oooooooooo`0@
ooooo`00:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`03ool0oooooooooooo03[ooooo00?o
o`3oooooooooool0a_ooool00ol0003oooooooooo`0@ooooo`00:?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_oo
ool00ooo0?ooooooooooo`3oooooo`?ooooo00?o0000ooooooooool04?ooool002Sooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ooo0?ooooooooooo`3oooooo`?ooooo00?o0000ooooooooool04?ooool002Sooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000;ooooo`;oo`3ooooo
ool1ooooo`?o00004_ooool002Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0=ooooo`03ool0oooooooooooo0?oooooo
00?o0000ooooooooool04?ooool002Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo
000Xooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00:?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000@_ooool00ooo0?ooooooooooo`3:ooooo`;o0000
4_ooool004?ooooo00?o0000ooooooooool0@?ooool00ooo0?ooooooooooo`3<ooooo`03o`000?oo
oooooooo013ooooo0013ooooo`03o`000?oooooooooo03oooooo00?oo`3oooooooooool0cOooool0
0ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`0nooooo`03ool0oooooooooooo
0<kooooo00?o0000ooooooooool04?ooool004?ooooo0_l0000Cooooo`03ool0oooooooooooo02So
oooo00?oo`3oooooooooool0c_ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo01?ooooo
0_oo0?lXooooo`03ool0oooooooooooo0<oooooo00?o0000ooooooooool04?ooool004?ooooo00?o
0000ooooooooool05Oooool00ooo0?ooooooooooo`0Tooooo`03ool0oooooooooooo0=3ooooo00?o
0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool05_ooool00ooo0?ooooooooooo`0R
ooooo`03ool0oooooooooooo0=7ooooo00?o0000ooooooooool04?ooool004?ooooo0_l0000Hoooo
o`03ool0oooooooooooo023ooooo00?oo`3oooooooooool0dOooool2o`0001;ooooo0013ooooo`03
o`000?oooooooooo01Sooooo00?oo`3oooooooooool07_ooool00ooo0?ooooooooooo`3Cooooo`03
o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo01Wooooo00?oo`3oooooooooool0
7?ooool00ooo0?ooooooooooo`3Dooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oo
oooooooo01[ooooo00?oo`3oooooooooool0l_ooool00ol0003oooooooooo`0@ooooo`00@oooool2
o`0001cooooo00?oo`3oooooooooool0l?ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo
01cooooo00?oo`3oooooooooool0l?ooool00ol0003oooooooooo`0@ooooo`00>Oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0<?ooool2ool0omgooooo00?o0000oooooooo
ool04?ooool003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03ool0
oooooooooooo0=gooooo00?o0000ooooooooool04?ooool003_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Tooooo`;oo`3o1Oooool4ool0on3ooooo00?o0000ooooooooool04?oo
ool003_ooooo00?o0000ooooooooool01Oooool3o`0002Kooooo1Ooo0?oRooooo`?o00004_ooool0
03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooo
ooooool04?ooool003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa3o
oooo00?o0000ooooooooool04?ooool003_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool003Wooooo00?oEEEEofIVI_l000001ooo
ool2o`000?oooooo4?ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool0
0ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooo
ooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013o
oooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool004?ooooo00?o0000ooooooooool0oooo
ool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool0
0ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooo
ooooool04?ooool004?ooooo0_l0003ooooooa3ooooo0_l0000Booooo`00@oooool00ol0003ooooo
ooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0oooo
ool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool0
0ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooo
ooooool04?ooool004?ooooo0_l0003ooooooa3ooooo0_l0000Booooo`00:Oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool002_ooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`3ooooooa3ooooo
00?o0000ooooooooool04?ooool002_ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00:oooool0
0ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0003oooooo`kooooo0ol0000B
ooooo`00:oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0
003oooooooooo`0@ooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000Yooooo`03oeEE
EOmVIVKo000000gooooo1?l00006ooooo`;o0000ooooool@ooooo`;o00004_ooool004?ooooo00?o
0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooo
oooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooo
oa3ooooo00?o0000ooooooooool04?ooool004?ooooo0_l0003ooooooa3ooooo0_l0000Booooo`00
@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o
0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooo
oooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooo
oa3ooooo00?o0000ooooooooool04?ooool004?ooooo0_l0003ooooooa3ooooo0_l0000Booooo`00
@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o
0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooo
oooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool2o`000?oooooo4?ooool2o`00
01;ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00
>?ooool5o`0000Kooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo
000hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3ooooooa3ooooo
00?o0000ooooooooool04?ooool003Wooooo00?oV9RHob4Q8Oo^k^h01oooooooo`0001Co00004_oo
ool003[ooooo00?oV9RHob4Q8Oo^k^h0ooooool/ooooo`00>oooool00omgMgOoIVIVooooo`3ooooo
ob_ooooo000looooo`03o`000?oooooooooo0?oooooo:_ooool003Sooooo00Go0000okZj^_oooooo
V9RHoa0@403oooooobcooooo000hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0ooooool/ooooo`00
oooooomYooooo`00oooooomYooooo`00SOooool01Ol@413o0000o`000?l0003o410@00?ooooo00Co
410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00Oo
oooo00Ko410@ob4Q8Ol0003o0000odA4A?oMgMd3ooooo`Go00000_ooool01?l@413o0000o`000?oo
ool2o`000004oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool01oooool3o`000003oa0@
4?oooooooooo00?ooooo00SoV9RHo`000?l0003oMgMgo`000?l@413ooooooa0@40;o000000Cooooo
o`000?l0003o410@0_ooool01OmVIVKo0000o`000?m4A4Coc<c<00?ooooo00GoV9RHo`000?l0003o
A4A4okZj^P03ooooo`Go00000_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`1Fooooo`00Soooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40So
oooo00Ko0000ohN7QoooooooooooohN7QolQ8B45ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@2Oooool00ol0003o
ooooooooo`05ooooo`05o`000?nYZJWoooooohN7Qol000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00KoIVIVogMgMoooooooooooohN7Qol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41001Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool0
1Ol0003ooooooooooooooooo000005Wooooo002?ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00_ooooo00Ko8B4Qoooooooooooooooo
onk^k_l00005ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo05Oooooo002?ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00002Oooool01OoMgMgoV9RH
ogMgMol@413oIVIV00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo1_l00009ooooo`03o`000?oooooo000000Gooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`1Gooooo`00Soooool00ol0003ooooooooo
o`04ooooo`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<PSooooo00GoIVIVoa0@4?mEEEGoQhN7okZj^P06ooooo`03o`000?oooooooooo00?ooooo00Go0000
ohN7QoooooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2Oooool3o`0000Go
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool0
1_mVIVKoMgMgooooooooooooQhN7o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0003oQhN7oooooonYZJWo
000005Wooooo002<ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000ooooooooooooooooo`00
0?mgMgL2o`000005oiRHV?ooooooooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`07ooooo`06
o`000?o^k^koooooooooooo<c<co00000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003o
MgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000003odA4A?o^k^kooooo00Sooooo00Go
0000ooooool@413ooooooa0@4002ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool00ol@413o
0000ogMgM`02o`000005oiRHV?ooooooooooonk^k_mVIVH00_l000001?m4A4Co0000ooooool@4105
o`0000Cooooo00?o410@o`000?l000001?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo
00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`1Gooooo`00S?ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000005?ooool01_lb<S;oQhN7ooooooo^k^koIVIV
o`00027ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo07?ooooo002<
ooooo`Oo00000oooool00ol0003oooooooooo`0Booooo`06onk^k_m4A4Co0000o`000?lb<S;o410@
1Oooool00ol0003oooooooooo`0Hooooo`Ko00006oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo06Wooooo002Eooooo`03oa0@4?l0003ooooo01kooooo00?o410@ooooooooool0@ooo
ool00ol@413oooooooooo`1Yooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.45551, -2.78882, \
0.0455731, 0.0294956}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.6.3 Plotting Several Curves on the Same Graph", "Subsubtitle",
  CellTags->{"i:46", "c:29"}],

Cell[TextData[{
  "More than one curve can be plotted at the same time using either ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \nFor example, to plot the cos and tanh functions over the same range of \
",
  StyleBox["x",
    FontSlant->"Italic"],
  ", use the ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command specifying a list of functions,",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            StyleBox["{",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox[
              RowBox[{
                RowBox[{
                  StyleBox["Cos",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["x",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                StyleBox[",",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["Tanh",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["x",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["]",
                    FontWeight->"Bold"]}]}],
              FontFamily->"Courier"], 
            StyleBox["}",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ". Here's where it comes in handy to add colors and dashing in order to \
separate out the curves, as seen in Cell ",
  ButtonBox["9.74",
    ButtonData:>"Cell 9.74",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CTPlot\  = \ 
      Plot[{Cos[x], Tanh[x]}, {x, 0, 2  Pi}, 
        PlotStyle \[Rule] {{RGBColor[1, 0, 0], Dashing[{0.05, 0.05}]}, 
            RGBColor[0, 1, 0]}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.74"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309016 0.294303 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ .05 .05 ] 0 setdash
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03465 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01923 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01564 L
.49002 .01535 L
.4923 .01509 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38343 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
0 1 0 r
[ ] 0 setdash
.02381 .30902 m
.06244 .38245 L
.10458 .45251 L
.14415 .50344 L
.18221 .53853 L
.20178 .55199 L
.22272 .56354 L
.24402 .57278 L
.26416 .57962 L
.28244 .58454 L
.30258 .58881 L
.32241 .59209 L
.34344 .59477 L
.36285 .59668 L
.38373 .59827 L
.40486 .59949 L
.42495 .60037 L
.44476 .60105 L
.46315 .60154 L
.48367 .60196 L
.50228 .60225 L
.52152 .60249 L
.54234 .60269 L
.56228 .60284 L
.58335 .60295 L
.60299 .60304 L
.62132 .6031 L
.64167 .60315 L
.66023 .60319 L
.67931 .60322 L
.70007 .60324 L
.71985 .60326 L
.74085 .60327 L
.76033 .60328 L
.77861 .60329 L
.79879 .6033 L
.81729 .6033 L
.83622 .60331 L
.85692 .60331 L
.87653 .60331 L
.89748 .60331 L
.91882 .60331 L
.93898 .60332 L
.95834 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool001Sooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooA?ooool001[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodCooooo000?ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooA?ooool001[ooooo00?o0000ooooooooool01Oooool3o`000:3ooooo
0_oo002Qooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0ooo
002Nooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo093ooooo00?oo`00
ooooooooool04_ooool4ool009[ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0S_ooool2ool001Wooooo0_oo002Hooooo`006?ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo08cooooo0_oo000Mooooo`03ool00?oooooooooo09Gooooo000Rooooo`03o`00
0?oooooooooo08[ooooo0_oo000Pooooo`03ool00?oooooooooo09Cooooo000Rooooo`03o`000?oo
oooooooo08Wooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`2Cooooo`008_ooool0
0ol0003oooooooooo`27ooooo`;oo`009Oooool00ooo003oooooooooo`2Booooo`008_ooool00ol0
003oooooooooo`26ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0TOooool002;o
oooo00?o0000ooooooooool0QOooool00ooo003oooooooooo`2kooooo`008_ooool2o`0008Gooooo
00?oo`00ooooooooool0_?ooool002;ooooo00?o0000ooooooooool0Poooool00ooo003ooooooooo
o`2mooooo`008_ooool00ol0003oooooooooo`22ooooo`03ool00?oooooooooo0;kooooo000Roooo
o`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`00
8_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?oo
ool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3ooooo
odCooooo000Rooooo`;o0000_?ooool00ooo003oooooooooo`25ooooo`008_ooool00ol0003ooooo
ooooo`2kooooo`03ool00?oooooooooo08Gooooo000Rooooo`03o`000?oooooooooo0;cooooo00?o
o`00ooooooooool0Q?ooool002;ooooo00?o0000ooooooooool0_Oooool00ooo003oooooooooo`23
ooooo`008_ooool00ol0003oooooooooo`2nooooo`03ool00?oooooooooo08;ooooo000Rooooo`03
o`000?oooooooooo07Oooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`21ooooo`00
8_ooool00ol0003oooooooooo`1gooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool0
POooool002;ooooo00?o0000ooooooooool0M_ooool00ooo003oooooooooo`17ooooo`03ool00?oo
oooooooo083ooooo000Rooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool0BOooool0
0ooo003oooooooooo`1oooooo`008_ooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo
04_ooooo00?oo`00ooooooooool0O_ooool002;ooooo0_l0001eooooo`03ool00?oooooooooo04co
oooo00?oo`00ooooooooool0OOooool002;ooooo00?o0000ooooooooool0Loooool00ooo003ooooo
ooooo`1=ooooo`03ool00?oooooooooo07gooooo000Rooooo`03o`000?oooooooooo07;ooooo00?o
o`00ooooooooool0Coooool00ooo003oooooooooo`1looooo`008_ooool00ol0003oooooooooo`1b
ooooo`03ool00?oooooooooo053ooooo00?oo`00ooooooooool0Noooool002;ooooo00?o0000oooo
ooooool0LOooool00ooo003oooooooooo`3?ooooo`008_ooool00ol0003oooooooooo`1`ooooo`03
ool00?oooooooooo0=3ooooo000Rooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0
dOooool002;ooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`3Aooooo`008_ooool0
0ol0003oooooooooo`1^ooooo`03ool00?oooooooooo0=;ooooo000Rooooo`03o`000?oooooooooo
06gooooo00?oo`00ooooooooool0doooool002;ooooo0_l0003oooooodGooooo000Rooooo`03o`00
0?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool0
0ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo0<kooooo00?oo`00ooooooooool0L_ooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo0<kooooo00?oo`00ooooooooool0L_ooool000Go00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3?ooooo`03
ool00?oooooooooo077ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`?o0000d?ooool00ooo003oooooooooo`1`ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
0=3ooooo00?oo`00ooooooooool0L?ooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0dOooool00ooo003oooooooooo`1_oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Uooooo`03ool00?oooooooooo06Wooooo00?oo`00ooooooooool0Koooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1Uoooo
o`03ool00?oooooooooo06[ooooo00?oo`00ooooooooool0K_ooool002;ooooo00?o0000oooooooo
ool0I?ooool00ooo003oooooooooo`1/ooooo`03ool00?oooooooooo06gooooo000Rooooo`03o`00
0?oooooooooo06?ooooo00?oo`00ooooooooool0KOooool00ooo003oooooooooo`1]ooooo`008_oo
ool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0K?oo
ool002;ooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`1_ooooo`03ool00?oooooo
oooo06cooooo000Rooooo`03o`000?oooooooooo067ooooo00?oo`00ooooooooool0LOooool00ooo
003oooooooooo`1[ooooo`008_ooool2o`0006;ooooo00?oo`00ooooooooool0L_ooool00ooo003o
ooooooooo`1Zooooo`008_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo07?ooooo
00?oo`00ooooooooool0J_ooool002;ooooo00?o0000ooooooooool0H?ooool00ooo003ooooooooo
o`1dooooo`03ool00?oooooooooo06Wooooo000Rooooo`03o`000?oooooooooo05oooooo00?oo`00
ooooooooool0hOooool002;ooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`3Roooo
o`008_ooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo0>;ooooo000Rooooo`03o`00
0?oooooooooo05gooooo00?oo`00ooooooooool0hoooool002;ooooo00?o0000ooooooooool0G?oo
ool00ooo003oooooooooo`3Tooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Roooo
o`;o0000oooooom5ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`00
0?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool0
0ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;o
oooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3Oooooo`03ool0
0?oooooooooo067ooooo000Rooooo`03o`000?oooooooooo0=oooooo00?oo`00ooooooooool0HOoo
ool002;ooooo00?o0000ooooooooool0h?ooool00ooo003oooooooooo`1Pooooo`008_ooool2o`00
0>7ooooo00?oo`00ooooooooool0H?ooool002;ooooo00?o0000ooooooooool0hOooool00ooo003o
ooooooooo`1Oooooo`008_ooool00ol0003oooooooooo`3Qooooo`03ool00?oooooooooo05oooooo
000Rooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool0R_ooool00ooo003ooooooooo
o`1Nooooo`008_ooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo08[ooooo00?oo`00
ooooooooool0G_ooool002;ooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`2<oooo
o`03ool00?oooooooooo05gooooo000Rooooo`03o`000?oooooooooo05Cooooo00?oo`00oooooooo
ool0S?ooool00ooo003oooooooooo`1Mooooo`008_ooool00ol0003oooooooooo`0]ooooo`Co0000
00?o410@ooooooooool07oooool00ooo003oooooooooo`09ooooo`Go0000;Oooool01OnHV9So410@
o`000?lb<S;oc<c<02oooooo0_l000000ol@413oooooooooo`0Iooooo`03ool00?oooooooooo017o
oooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`05_ooool0
02;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A00]ooooo`05oa0@4?nj^[[oooooogMgMolb<S80<?oo
ool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo01?ooooo00?oMgMgoc8b<_ooool0:ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q01Kooooo000Rooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool08?ooool00ooo003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^03;ooooo00?o
0000ooooooooool0:oooool5o`0001cooooo00?oo`00ooooooooool05?ooool00ol0003ooooooooo
o`0Zooooo`05o`000?ooooooooooooooool000005_ooool002;ooooo0_l0000`ooooo`03o`000?oo
oooooooo023ooooo00?oo`00ooooooooool03?ooool00onHV9So8B4Qonk^kP0`ooooo`03ojVYZOl@
413ooooo02cooooo00CoA4A4omgMgOoooooo00007_ooool00ooo003oooooooooo`0Booooo`03ogMg
Molb<S;ooooo02_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Fooooo`008_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool03_ooool00omgMgOoIVIV
ooooo`0^ooooo`03oa0@4?l0003o^[Zj02gooooo00CogMgMoeEEEOoooooo00007_ooool00ooo003o
ooooooooo`0?ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0;?ooool01Ol0003oEEEEo`000?l@413o
c<c<01Kooooo000Rooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07_ooool00ooo
003oooooooooo`0@ooooo`03o`000?oooooooooo02kooooo00?o^[Zjob4Q8Oooool0;Oooool00omg
MgOoc<c<o`00000Oooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool0;_ooool00omE
EEGoQhN7ooooo`0Hooooo`008_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01ko
oooo00?oo`00ooooooooool03?ooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00Go410@oiRH
V?oooooo^[Zjo`00000^ooooo`03onk^k_m4A4Co0000033ooooo00?o0000ooooooooool0;_ooool0
0ooMgMgo410@oiRHV00Hooooo`008_ooool00ol0003oooooooooo`0]ooooo`03oeEEEOmVIVKo0000
01oooooo00?oo`00ooooooooool03Oooool01OnHV9So410@o`000?lQ8B7oc<c<02gooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@0_ooooo`03ogMgMol0003ooooo02oooooo1?l0000^ooooo`04olc<c?m4
A4Co0000oa0@41Kooooo000Rooooo`03o`000?oooooooooo04oooooo00?oo`00ooooooooool0lOoo
ool002;ooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`3booooo`008_ooool00ol0
003oooooooooo`1>ooooo`03ool00?oooooooooo0?;ooooo000Rooooo`03o`000?oooooooooo04go
oooo00?oo`00ooooooooool0loooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`006_oo
ool8o`000003o`3o0?l0003o00000?oo0000A?l0000002;ooooo00?o0?l0ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Rooooo`03o`000?l0o`3ooooo
02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01Gooooo000Rooooo`03o`000?l0o`3ooooo0?ooooooA?ooool002;ooooo00?o0000ooooool0o`00
oooooom4ooooo`008_ooool00ol0003oooooo`3o003oooooodCooooo000Rooooo`04o`000?oooooo
ooooo`3o0?oooooo@oooool002;ooooo00Go0000ooooooooooooooooo`3o003/ooooo`03ool00?oo
oooooooo05;ooooo000Rooooo`05o`000?ooooooooooooooool0o`00k?ooool00ooo003ooooooooo
o`1Booooo`008_ooool00ol0003oooooooooo`02ooooo`03o`3o0?oooooooooo0>[ooooo00?oo`00
ooooooooool0DOooool002;ooooo0_l00003ooooo`03o`3o0?oooooooooo0>[ooooo00?oo`00oooo
ooooool0DOooool002;ooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`3Zooooo`03
ool00?oooooooooo053ooooo000Rooooo`03o`000?oooooooooo00?ooooo00?o0?l0ooooooooool0
j_ooool00ooo003oooooooooo`1@ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`3o0?oo
oooooooo03kooooo00?oo`00ooooooooool0ZOooool00ooo003oooooooooo`1?ooooo`008_ooool0
0ol0003oooooooooo`04ooooo`03o`3o0?oooooooooo03kooooo00?oo`00ooooooooool0ZOooool0
0ooo003oooooooooo`1?ooooo`008_ooool00ol0003oooooooooo`05ooooo`03o`3o0?oooooooooo
03cooooo00?oo`00ooooooooool0Zoooool00ooo003oooooooooo`1>ooooo`008_ooool00ol0003o
ooooooooo`05ooooo`03o`3o0?oooooooooo03cooooo00?oo`00ooooooooool0[?ooool00ooo003o
ooooooooo`1=ooooo`008_ooool00ol0003oooooooooo`06ooooo`03o`3o0?oooooooooo03[ooooo
00?oo`00ooooooooool0[Oooool00ooo003oooooooooo`1=ooooo`008_ooool00ol0003ooooooooo
o`06ooooo`03o`3o0?oooooooooo03[ooooo00?oo`00ooooooooool0[_ooool00ooo003ooooooooo
o`1<ooooo`008_ooool2o`0000Sooooo00?o0?l0ooooooooool0>?ooool00ooo003oooooooooo`2_
ooooo`03ool00?oooooooooo04cooooo000Rooooo`03o`000?oooooooooo00Sooooo00?o0?l0oooo
ooooool0=oooool00ooo003oooooooooo`2`ooooo`03ool00?oooooooooo04_ooooo000Rooooo`03
o`000?oooooooooo00Sooooo00?o0?l0ooooooooool0=_ooool00ooo003oooooooooo`2aooooo`03
ool00?oooooooooo04_ooooo000Rooooo`03o`000?oooooooooo00Wooooo00?o0?l0ooooooooool0
=Oooool00ooo003oooooooooo`2booooo`03ool00?oooooooooo04[ooooo000Rooooo`03o`000?oo
oooooooo00Wooooo00?o0?l0ooooooooool0=?ooool00ooo003oooooooooo`3oooooo`7ooooo000R
ooooo`03o`000?oooooooooo00[ooooo00?o0?l0ooooooooool0<oooool00ooo003oooooooooo`3o
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00[ooooo00?o0?l0ooooooooool0<_ooool00ooo
003oooooooooo`3oooooo`;ooooo000Rooooo`03o`000?oooooooooo00_ooooo00?o0?l0oooooooo
ool0<?ooool00ooo003oooooooooo`3oooooo`?ooooo000Rooooo`03o`000?oooooooooo00_ooooo
00?o0?l0ooooooooool0;oooool00ooo003oooooooooo`3oooooo`Cooooo000Rooooo`03o`000?oo
oooooooo00cooooo00?o0?l0ooooooooool0ooooooleooooo`008_ooool2o`0000kooooo00?o0?l0
ooooooooool0ooooooldooooo`008_ooool00ol0003oooooooooo`0=ooooo`03o`3o0?oooooooooo
0?oooooo=?ooool002;ooooo00?o0000ooooooooool03_ooool00ol0o`3oooooooooo`3ooooooc?o
oooo000Rooooo`03o`000?oooooooooo00kooooo00?o0?l0ooooooooool0oooooolcooooo`008_oo
ool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo0?oooooo<_ooool002;ooooo00?o0000
ooooooooool04?ooool00ol0o`3oooooooooo`3ooooooc7ooooo000Rooooo`03o`000?oooooooooo
013ooooo00?o0?l0ooooooooool0oooooolaooooo`008_ooool00ol0003oooooooooo`0Aooooo`03
o`3o0?oooooooooo0>[ooooo00?oo`00ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
4Oooool00ol0o`3oooooooooo`3Zooooo`03ool00?oooooooooo04;ooooo000Rooooo`03o`000?oo
oooooooo01;ooooo00?o0?l0ooooooooool0j_ooool00ooo003oooooooooo`11ooooo`008_ooool2
o`0001?ooooo00?o0?l0ooooooooool0j_ooool00ooo003oooooooooo`11ooooo`008_ooool00ol0
003oooooooooo`0Cooooo`03o`3o0?oooooooooo0>[ooooo00?oo`00ooooooooool0@?ooool002;o
oooo00?o0000ooooooooool05?ooool00ol0o`3oooooooooo`3Yooooo`03ool00?oooooooooo043o
oooo000Rooooo`03o`000?oooooooooo01Cooooo00?o0?l0ooooooooool07_ooool00ooo003ooooo
ooooo`39ooooo`03ool00?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo01Gooooo00?o
0?l0ooooooooool07Oooool00ooo003oooooooooo`3:ooooo`03ool00?oooooooooo03kooooo000R
ooooo`03o`000?oooooooooo01Gooooo00?o0?l0ooooooooool07?ooool00ooo003oooooooooo`3;
ooooo`03ool00?oooooooooo03kooooo000Rooooo`03o`000?oooooooooo01Kooooo00?o0?l0oooo
ooooool06oooool00ooo003oooooooooo`3<ooooo`03ool00?oooooooooo03gooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01Oooooo00?o0?l0ooooooooool06Oooool00ooo003oooooooooo`3=
ooooo`03ool00?oooooooooo03gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Gooooo`03o`3o0?oooooo
oooo01Sooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0looooo`001oooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0H
ooooo`03o`3o0?oooooooooo01Oooooo00?oo`00ooooooooool0coooool00ooo003oooooooooo`0l
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3
o`0001Sooooo00?o0?l0ooooooooool05_ooool00ooo003oooooooooo`3Aooooo`03ool00?oooooo
oooo03_ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool06Oooool00ol0o`3oooooooooo`0Eooooo`03ool00?oo
oooooooo0=7ooooo00?oo`00ooooooooool0>oooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0o`3ooooooooo
o`0Cooooo`03ool00?oooooooooo0=?ooooo00?oo`00ooooooooool0>_ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06ooo
ool00ol0o`3oooooooooo`0Booooo`03ool00?oooooooooo0?oooooo4Oooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Kooooo`03o`3o0?oo
oooooooo017ooooo00?oo`00ooooooooool0oooooolBooooo`008_ooool00ol0003oooooooooo`0L
ooooo`03o`3o0?oooooooooo00oooooo00?oo`00ooooooooool0oooooolCooooo`008_ooool00ol0
003oooooooooo`0Mooooo`03o`3o0?oooooooooo00kooooo00?oo`00ooooooooool0oooooolCoooo
o`008_ooool00ol0003oooooooooo`0Nooooo`03o`3o0?oooooooooo00cooooo00?oo`00oooooooo
ool0oooooolDooooo`008_ooool00ol0003oooooooooo`0Oooooo`03o`3o0?oooooooooo0?oooooo
8_ooool002;ooooo00?o0000ooooooooool07oooool00ol0o`3oooooooooo`3oooooob;ooooo000R
ooooo`;o00008Oooool00ol0o`3oooooooooo`3oooooob7ooooo000Rooooo`03o`000?oooooooooo
027ooooo00?o0?l0ooooooooool0oooooolPooooo`008_ooool00ol0003oooooooooo`0Rooooo`03
o`3o0?oooooooooo0?oooooo7oooool002;ooooo00?o0000ooooooooool08_ooool00ol0o`3ooooo
ooooo`3ooooooaoooooo000Rooooo`03o`000?oooooooooo02?ooooo00?o0?l0ooooooooool0oooo
oolNooooo`008_ooool00ol0003oooooooooo`0Tooooo`03o`3o0?oooooooooo0?oooooo7Oooool0
02;ooooo00?o0000ooooooooool09Oooool2o`3o0>Sooooo00?oo`00ooooooooool0<Oooool002;o
oooo00?o0000ooooooooool09oooool00ol0o`3oooooooooo`3Uooooo`03ool00?oooooooooo037o
oooo000Rooooo`03o`000?oooooooooo02Sooooo00?o0?l0ooooooooool0iOooool00ooo003ooooo
ooooo`0`ooooo`008_ooool2o`0002[ooooo00?o0?l0ooooooooool0iOooool00ooo003ooooooooo
o`0_ooooo`008_ooool00ol0003oooooooooo`0Zooooo`03o`3o0?oooooooooo0>Gooooo00?oo`00
ooooooooool0;_ooool002;ooooo00?o0000ooooooooool09?ooool00ooo003oooooooooo`04oooo
o`03o`3o0?oooooooooo0>Cooooo00?oo`00ooooooooool0;_ooool002;ooooo00?o0000oooooooo
ool09?ooool00ooo003oooooooooo`05ooooo`03o`3o0?oooooooooo0>Cooooo00?oo`00oooooooo
ool0;Oooool002;ooooo00?o0000ooooooooool08oooool00ooo003oooooooooo`07ooooo`03o`3o
0?oooooooooo0>Cooooo00?oo`00ooooooooool0;?ooool002;ooooo00?o0000ooooooooool08_oo
ool00ooo003oooooooooo`09ooooo`03o`3o0?oooooooooo0>Cooooo00?oo`00ooooooooool0:ooo
ool002;ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0;ooooo`03o`3o0?oooooo
oooo0>?ooooo00?oo`00ooooooooool0:oooool002;ooooo00?o0000ooooooooool08?ooool00ooo
003oooooooooo`0=ooooo`03o`3o0?oooooooooo0>?ooooo00?oo`00ooooooooool0:_ooool002;o
oooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0?ooooo`;o0?l0i?ooool00ooo003o
ooooooooo`0Yooooo`008_ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo01;ooooo
00?o0?l0ooooooooool0h_ooool00ooo003oooooooooo`0Xooooo`008_ooool2o`0001oooooo00?o
o`00ooooooooool04oooool2o`3o0>?ooooo00?oo`00ooooooooool09oooool002;ooooo00?o0000
ooooooooool07Oooool00ooo003oooooooooo`0Fooooo`03o`3o0?oooooooooo0?oooooo2oooool0
02;ooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`0Hooooo`03o`3o0?oooooooooo
0?oooooo2_ooool002;ooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0Jooooo`;o
0?l0ooooool:ooooo`008_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo01gooooo
0_l0o`3oooooo`Sooooo000Rooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool08?oo
ool00ol0o`3oooooooooo`3oooooo`Gooooo000Rooooo`03o`000?oooooooooo03gooooo0_l0o`3o
ooooo`Gooooo000Rooooo`03o`000?oooooooooo03oooooo0_l0o`3oooooo`?ooooo000Rooooo`03
o`000?oooooooooo047ooooo0ol0o`3oooooo`008_ooool00ol0003oooooooooo`14ooooo`;o0?l0
oOooool002;ooooo0_l00017ooooo`?o0?l0n_ooool002;ooooo00?o0000ooooooooool0BOooool3
o`3o0=Wooooo00?oo`00ooooooooool06oooool002;ooooo00?o0000ooooooooool0C?ooool5o`3o
0=Cooooo00?oo`00ooooooooool06oooool002;ooooo00?o0000ooooooooool0DOooool5o`3o0=3o
oooo0_oo000Kooooo`008_ooool00ol0003oooooooooo`1Fooooo`?o0?l0coooool2ool001Wooooo
000Rooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0B_ooool5o`3o0<cooooo0_oo
000Gooooo`008_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo053ooooo1ol0o`37
ooooo`03ool00?oooooooooo01Cooooo000Hooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`08ooooo`?oo`00F_ooool6o`3o0<;ooooo0ooo000Cooooo`006_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo0_oo001SoooooaGo0?l0/?ooool3ool0013o
oooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo001jooooobOo0?l0
S?ooool00ooo003oooooooooo`0=ooooo`006_ooool00ol0003oooooooooo`05ooooo`Coo`00Y_oo
oonDo`3o00Sooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom4
ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool001[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodCooooo000Hooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.67728, -1.13025, \
0.0247827, 0.0127639}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first element in the list of ",
  StyleBox["PlotStyle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options in this cell, ",
  StyleBox["{RGBColor[1,0,0],Dashing[{0.05,0.05}]}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  applies to the first function in the list of functions (i.e. ",
  StyleBox["Cos[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "). The second element , ",
  StyleBox["RGBColor[0,1,0]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", applies to the second function ",
  StyleBox["Tanh[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc."
}], "Text"],

Cell[TextData[{
  "\tIf you have already made two separate plots with two ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands, you can overlay them using the ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command.  For an example, see Cell ",
  ButtonBox["9.75",
    ButtonData:>"Cell 9.75",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[newplot, CTPlot]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.75"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0.309017 0.154508 [
[.31416 -0.0125 -5 -12 ]
[.31416 -0.0125 5 0 ]
[.62832 -0.0125 -9.3125 -12 ]
[.62832 -0.0125 9.3125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -24 ]
[.5 -0.0125 5 -12 ]
[-0.0125 .07725 -24 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -12 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -24 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -18 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -6 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36 -5 ]
[-0.01875 .30902 -24 5 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.31416 0 m
.31416 .00625 L
s
gsave
.31416 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.62832 0 m
.62832 .00625 L
s
gsave
.62832 -0.0125 -70.3125 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
71.625 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .07725 m
.00625 .07725 L
s
[(-1.5)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-1)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.5)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.5)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.5)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(2)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -96 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(The) show
87.000 13.000 moveto
(Sine) show
117.000 13.000 moveto
(Function) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 0 m
1 0 L
s
.99375 .07725 m
1 .07725 L
s
.99375 .15451 m
1 .15451 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38627 m
1 .38627 L
s
.99375 .46353 m
1 .46353 L
s
.99375 .54078 m
1 .54078 L
s
.125 Mabswid
.99625 .01545 m
1 .01545 L
s
.99625 .0309 m
1 .0309 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .13906 m
1 .13906 L
s
.99625 .16996 m
1 .16996 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .20086 m
1 .20086 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26266 m
1 .26266 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .29357 m
1 .29357 L
s
.99625 .32447 m
1 .32447 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .35537 m
1 .35537 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .41717 m
1 .41717 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .44807 m
1 .44807 L
s
.99625 .47898 m
1 .47898 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .50988 m
1 .50988 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57168 m
1 .57168 L
s
.99625 .58713 m
1 .58713 L
s
.99625 .60258 m
1 .60258 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
[ .05 .03 ] 0 setdash
0 .30902 m
.02549 .34797 L
.05329 .38751 L
.07939 .4192 L
.1045 .44266 L
.11741 .45153 L
.1246 .45544 L
.13123 .45839 L
.13797 .46071 L
.14152 .46166 L
.14528 .46245 L
.14685 .46272 L
.14855 .46296 L
.15001 .46314 L
.1516 .46329 L
.15257 .46337 L
.15347 .46342 L
.15433 .46347 L
.15477 .46348 L
.15524 .4635 L
.15571 .46351 L
.15614 .46352 L
.15699 .46353 L
.15776 .46352 L
.15857 .46351 L
.15937 .46348 L
.15983 .46347 L
.16025 .46345 L
.16184 .46335 L
.16329 .46323 L
.16482 .46306 L
.16801 .4626 L
.17152 .46192 L
.17776 .46023 L
.18362 .45812 L
.19694 .45142 L
.20914 .44305 L
.23529 .41864 L
.26043 .3881 L
.28719 .35019 L
.31295 .31089 L
.34032 .26905 L
.3667 .23152 L
.39208 .20044 L
.40493 .18725 L
.41907 .17506 L
.4325 .16596 L
.44507 .15977 L
.45194 .15738 L
.45532 .15646 L
Mistroke
.45845 .15577 L
.46129 .15527 L
.4643 .15488 L
.46603 .15472 L
.46687 .15466 L
.46765 .15461 L
.46835 .15457 L
.46911 .15454 L
.46987 .15452 L
.47068 .15451 L
.47155 .15451 L
.47235 .15452 L
.47276 .15453 L
.47322 .15454 L
.47415 .15457 L
.47497 .15462 L
.47584 .15467 L
.47743 .1548 L
.479 .15497 L
.48064 .15519 L
.48358 .15568 L
.487 .15642 L
.49018 .15727 L
.49739 .15976 L
.50435 .1629 L
.51091 .16651 L
.52318 .17489 L
.54859 .19847 L
.57562 .23131 L
.60165 .2683 L
.62668 .30649 L
.62832 .30902 L
Mfstroke
1 0 0 r
[ .05 .05 ] 0 setdash
0 .46353 m
.00078 .46352 L
.00148 .46351 L
.0023 .46348 L
.00307 .46345 L
.00444 .46337 L
.00592 .46325 L
.00756 .46308 L
.00929 .46286 L
.01241 .46234 L
.01562 .46164 L
.01863 .46085 L
.02549 .45853 L
.03248 .45545 L
.03888 .45199 L
.05329 .4421 L
.07948 .41723 L
.10468 .38632 L
.1315 .34812 L
.15731 .30866 L
.18474 .26682 L
.21118 .22945 L
.23661 .19868 L
.24951 .18569 L
.26366 .17379 L
.27714 .16498 L
.28316 .16187 L
.28971 .1591 L
.2933 .15786 L
.29661 .15688 L
.29971 .15612 L
.30314 .15545 L
.30461 .15521 L
.3062 .155 L
.30758 .15484 L
.30908 .15471 L
.31068 .1546 L
.31155 .15456 L
.31237 .15453 L
.31313 .15452 L
.31383 .15451 L
.31463 .15451 L
.31538 .15452 L
.31614 .15454 L
.31696 .15457 L
.31773 .15461 L
.31844 .15465 L
.32016 .15479 L
.3218 .15496 L
.32505 .15542 L
Mistroke
.32859 .15611 L
.3349 .15782 L
.34076 .15994 L
.35433 .16681 L
.36661 .17528 L
.39308 .20018 L
.41855 .23132 L
.44563 .26988 L
.47172 .30976 L
.4968 .34809 L
.52351 .38615 L
.54921 .41765 L
.56231 .43107 L
.57653 .44327 L
.59021 .45244 L
.59674 .45588 L
.60285 .45854 L
.60869 .46056 L
.61497 .46215 L
.61836 .46276 L
.62007 .463 L
.62194 .46321 L
.62354 .46335 L
.62443 .46341 L
.62524 .46345 L
.626 .46348 L
.62683 .46351 L
.6276 .46352 L
.62832 .46353 L
Mfstroke
0 1 0 r
[ ] 0 setdash
0 .30902 m
.02549 .34757 L
.05329 .38435 L
.07939 .41109 L
.1045 .42951 L
.11741 .43658 L
.13123 .44264 L
.14528 .4475 L
.15857 .45109 L
.17063 .45367 L
.18391 .45591 L
.197 .45763 L
.21087 .45904 L
.22368 .46004 L
.23745 .46087 L
.2514 .46151 L
.26465 .46198 L
.27772 .46233 L
.28985 .46259 L
.30339 .46281 L
.31566 .46297 L
.32836 .46309 L
.3421 .4632 L
.35525 .46327 L
.36915 .46333 L
.3821 .46338 L
.3942 .46341 L
.40762 .46344 L
.41987 .46346 L
.43246 .46347 L
.44615 .46348 L
.4592 .46349 L
.47306 .4635 L
.48591 .46351 L
.49796 .46351 L
.51128 .46351 L
.52349 .46352 L
.53597 .46352 L
.54963 .46352 L
.56257 .46352 L
.57639 .46352 L
.59047 .46352 L
.60377 .46352 L
.61654 .46352 L
.62832 .46352 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00bOooool2
o`0000;ooooo0_l0002Iooooo`00bOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgIWooooo003:
ooooo`04omgMgOl0003o410@olc<c9[ooooo003:ooooo`04onk^k_lQ8B7o410@onk^kY[ooooo003:
ooooo`04ob4Q8OmgMgOoMgMgoc8b<Y[ooooo0039ooooo`;o00000_ooool2o`0009Wooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Eooooo`03oeEEEOnYZJWo
oooo00;ooooo00?o^[ZjodA4A?ooool0B_ooool5o`0000Gooooo00?oEEEEojVYZOooool00_ooool0
0onj^[[oA4A4ooooo`1_ooooo`00U_ooool01_mEEEGoV9RHoooooooooooo410@okZj^T_ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`06oeEEEOnHV9Soooooooooool@413o^[ZjL?ooool009Oo
oooo00Co410@omgMgOoooooo0000COooool00onHV9So8B4Qonk^kP08ooooo`04oa0@4?oMgMgooooo
o`00077ooooo002Gooooo`04ohN7QomVIVKoooooo`0004kooooo00?oV9RHob4Q8Oo^k^h01oooool0
1?n7QhOoIVIVooooool0001aooooo`00Uoooool01?oMgMgo410@ooooool0001?ooooo`03ogMgMomV
IVKooooo00Kooooo00CogMgMoa0@4?oooooo0000LOooool009Kooooo1ol0001>ooooo`03o`000?oo
oooooooo00Cooooo1ol0001_ooooo`00ioooool01Ol0003o^[ZjoooooonHV9So410@07cooooo003W
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0O?ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool004?oooooool0000Do`00
01;ooooo0013ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o
0000ooooooooool04?ooool004?ooooo0_l0003ooooooa3ooooo0_l0000Booooo`00@oooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`0@ooooo`00@oooool2o`000?oooooo4?ooool2o`0001;ooooo0013
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o0000
4_ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013
ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o0000
4_ooool002Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo
000[ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000Pooooo`Ko00001Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooool@
ooooo`03o`000?oooooooooo013ooooo000[ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b
<_ooool01?ooool3o`000?oooooo3_ooool3o`0001;ooooo000[ooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0
003oooooooooo`0@ooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000[ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooa3ooooo
00?o0000ooooooooool04?ooool002Wooooo00?oEEEEofIVI_l000003Oooool4o`0000Kooooo0_l0
003ooooooa3ooooo0_l0000Booooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00
@oooool2o`000?oooooo4?ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?oo
ool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
013ooooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool004?ooooo00?o0000ooooooooool0
ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?oo
ool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000
ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
013ooooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool003Wooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00>ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003ooooooooo
o`0@ooooo`00<?ooool6o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooa3ooooo00?o0000ooooooooool04?ooool003_ooooo00?o0000ooooooooool01Oooool3o`00
04oooooo2?oo000Sooooo`Ooo`3oS?ooool3o`0001;ooooo000kooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0COooool2ool002Oooooo0ooo0?nFooooo`03o`000?oooooooooo013o
oooo000kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?ooool2ool0oa;ooooo
00?oo`3oooooooooool0Q?ooool00ol0003oooooooooo`0@ooooo`00>oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo07?ooooo00?oo`3oooooooooool04oooool00ooo0?oooooooooo
o`23ooooo`03o`000?oooooooooo013ooooo000iooooo`03oeEEEOmVIVKo000000Oooooo0_l0001O
ooooo`;oo`004_ooool00ooo0?ooooooooooo`0Eooooo`03ool0oooooooooooo087ooooo0_l0000B
ooooo`00@oooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo00kooooo00?oo`3ooooo
ooooool05oooool00ooo0?ooooooooooo`21ooooo`03o`000?oooooooooo013ooooo0013ooooo`03
o`000?oooooooooo067ooooo0_oo000<ooooo`;oo`3o6oooool2ool0oh7ooooo00?o0000oooooooo
ool04?ooool004?ooooo00?o0000ooooooooool0Hoooool00ooo003oooooooooo`08ooooo`03ool0
oooooooooooo01gooooo00?oo`3oooooooooool0O_ooool00ol0003oooooooooo`0@ooooo`00@ooo
ool2o`0004;ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`06ooooo`03ool0oooo
oooooooo01oooooo00?oo`3oooooooooool0O?ooool2o`0001;ooooo0013ooooo`03o`000?oooooo
oooo047ooooo00?oo`00ooooooooool08Oooool2ool002Wooooo00?oo`3oooooooooool0O?ooool0
0ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo
02Cooooo00?oo`00ooooooooool09oooool00ooo0?ooooooooooo`1kooooo`03o`000?oooooooooo
013ooooo0013ooooo`03o`000?oooooooooo03oooooo00?oo`00ooooooooool09_ooool00ooo003o
ooooooooo`0Wooooo`03ool0oooooooooooo07[ooooo00?o0000ooooooooool04?ooool004?ooooo
00?o0000ooooooooool0?_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo0:?ooooo
00?o0000ooooooooool04?ooool004?ooooo0_l0000oooooo`03ool00?oooooooooo02Sooooo00?o
o`00ooooooooool0X_ooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo03gooooo00?oo`00
ooooooooool09oooool00ooo0?ooooooooooo`2Uooooo`03o`000?oooooooooo013ooooo0013oooo
o`03o`000?oooooooooo03cooooo00?oo`00ooooooooool0:?ooool00ooo0?ooooooooooo`2Uoooo
o`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo03_ooooo00?oo`00oooooooo
ool0:?ooool00ooo0?ooooooooooo`2Vooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000
>oooool00ooo003oooooooooo`0Xooooo`03ool0oooooooooooo033ooooo00?oo`3oooooooooool0
Loooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool0:?oo
ool00ooo0?ooooooooooo`0aooooo`03ool0oooooooooooo07Cooooo00?o0000ooooooooool04?oo
ool002Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`0Xooooo`03ool0
oooooooooooo03?ooooo00?oo`3oooooooooool0Loooool00ol0003oooooooooo`0@ooooo`00:?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0H_ooool00ooo0?ooooooooooo`0eooooo`03ool0oooooooooooo07;ooooo
00?o0000ooooooooool04?ooool0023ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`?o0000HOooool00ooo0?ooooooooooo`0gooooo`03ool0
oooooooooooo06oooooo0ol0000Booooo`00:?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1Qooooo`03ool0oooooooooooo03Oooooo
00?oo`3oooooooooool0LOooool00ol0003oooooooooo`0@ooooo`00:?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo063o
oooo00?oo`3oooooooooool03_ooool00ooo003oooooooooo`0Xooooo`03ool0oooooooooooo073o
oooo00?o0000ooooooooool04?ooool002Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?ooool00ooo0?ooooooooooo`0>ooooo`03
ool00?oooooooooo02Wooooo00?oo`3oooooooooool0Koooool00ol0003oooooooooo`0@ooooo`00
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool2o`00063o
oooo00?oo`3oooooooooool04?ooool00ooo003oooooooooo`0Yooooo`03ool0oooooooooooo06go
oooo0_l0000Booooo`00:?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03
o`000?oooooooooo07?ooooo00?oo`00ooooooooool0:?ooool00ooo0?ooooooooooo`1^ooooo`03
o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo07?ooooo00?oo`00ooooooooool0
:Oooool00ooo0?ooooooooooo`1]ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oo
oooooooo07Cooooo00?oo`00ooooooooool0:Oooool00ooo0?ooooooooooo`1/ooooo`03o`000?oo
oooooooo013ooooo0013ooooo`03o`000?oooooooooo07Gooooo00?oo`00ooooooooool0Uoooool0
0ol0003oooooooooo`0@ooooo`00@oooool2o`00037ooooo00?oo`00ooooooooool0@_ooool00ooo
003oooooooooo`2Fooooo`;o00004_ooool004?ooooo00?o0000ooooooooool0<?ooool00ooo003o
ooooooooo`13ooooo`03ool00?oooooooooo09Kooooo00?o0000ooooooooool04?ooool004?ooooo
00?o0000ooooooooool0<?ooool00ooo003oooooooooo`0Wooooo`03ool0oooooooooooo01[ooooo
00?oo`00ooooooooool0UOooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003ooooooooo
o`0_ooooo`03ool00?oooooooooo02Sooooo00?oo`3oooooooooool06_ooool00ooo003ooooooooo
o`2Eooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000;oooool00ooo003oooooooooo`0X
ooooo`03ool0oooooooooooo01cooooo00?oo`00ooooooooool0Toooool2o`0001;ooooo0013oooo
o`03o`000?oooooooooo02kooooo00?oo`00ooooooooool09oooool00ooo0?ooooooooooo`0Noooo
o`03ool00?oooooooooo02Sooooo00?oo`3oooooooooool0J?ooool00ol0003oooooooooo`0@oooo
o`00@oooool00ol0003oooooooooo`0]ooooo`03ool00?oooooooooo02Sooooo00?oo`3ooooooooo
ool0BOooool00ooo0?ooooooooooo`1Xooooo`03o`000?oooooooooo013ooooo000Looooo`?o0000
00?o410@ooooooooool08Oooool00ol0003oooooooooo`0/ooooo`03ool00?oooooooooo02Sooooo
00?oo`3oooooooooool0Boooool00ooo0?ooooooooooo`1Wooooo`03o`000?oooooooooo013ooooo
000Nooooo`03oa0@4?nj^[[ooooo02;ooooo0_l0000/ooooo`03ool00?oooooooooo02Sooooo00?o
o`3oooooooooool0COooool00ooo0?ooooooooooo`1Uooooo`;o00004_ooool001kooooo00?oV9RH
oc8b<_ooool08_ooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo02Sooooo00?oo`3o
ooooooooool0C_ooool00ooo0?ooooooooooo`1Uooooo`03o`000?oooooooooo013ooooo000Noooo
o`03omgMgOl0003o^[Zj01Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo02[ooooo00?oo`00ooooooooool0:?ooool00ooo0?ooooooooooo`1?ooooo`03ool0oooooooo
oooo06Gooooo00?o0000ooooooooool04?ooool001kooooo00?oEEEEogMgMom4A4@05oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0:Oooool00ooo003oooooooooo`0Y
ooooo`03ool0oooooooooooo053ooooo00?oo`3oooooooooool0I?ooool00ol0003oooooooooo`0@
ooooo`007Oooool01OoMgMgo410@oooooolQ8B7ogMgM01Kooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`3o0?l0003o000005Cooooo00?oo`3oooooooooool0D_ooool00ooo0?oooooooooo
o`1Qooooo`?o00004_ooool001gooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Fooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0o`3oooooooooo`1Booooo`;oo`3o^oooool00ol0003ooooo
ooooo`0@ooooo`007?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo01Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?l0o`3ooooo0?oooooo4?ooool00ol0003ooooo
ooooo`0@ooooo`007?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo0?l00?oooooo4?ooool00ol0003o
ooooooooo`0@ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooool0
o`00P?ooool00ooo003oooooooooo`2<ooooo`03o`000?oooooooooo013ooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool2o`000003ooooool0o`3ooooo07kooooo00?oo`00oooooooo
ool0Roooool2o`0001;ooooo0013ooooo`05o`000?ooooooooooooooool0o`00Ooooool00ooo003o
ooooooooo`2;ooooo`03o`000?oooooooooo013ooooo0013ooooo`05o`000?ooooooooooooooool0
o`00P?ooool00ooo003oooooooooo`2:ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`00
0?oooooooooo00;ooooo00?o0?l0ooooooooool0BOooool00ooo0?ooooooooooo`0booooo`03ool0
0?oooooooooo08Wooooo00?o0000ooooooooool04?ooool004?ooooo0_l00003ooooo`03o`3o0?oo
oooooooo04Wooooo00?oo`3oooooooooool0<_ooool00ooo003oooooooooo`28ooooo`;o00004_oo
ool004?ooooo00?o0000ooooooooool00oooool00ol0o`3oooooooooo`17ooooo`03ool0oooooooo
oooo03Cooooo00?oo`00ooooooooool0R?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0
003oooooooooo`04ooooo`03o`3o0?oooooooooo01[ooooo00?oo`00ooooooooool0:Oooool00ooo
0?ooooooooooo`0eooooo`03ool00?oooooooooo08Oooooo00?o0000ooooooooool04?ooool004?o
oooo00?o0000ooooooooool01?ooool00ol0o`3oo`3oooooo`0Jooooo`03ool00?oooooooooo02So
oooo00?oo`3oooooooooool0=_ooool00ooo003oooooooooo`27ooooo`03o`000?oooooooooo013o
oooo0013ooooo`;o00001_ooool00ol0o`3oooooooooo`0Hooooo`03ool00?oooooooooo02Wooooo
00?oo`3oooooooooool0=oooool00ooo003oooooooooo`25ooooo`;o00004_ooool004?ooooo00?o
0000ooooooooool01_ooool00ol0o`3oooooooooo`0Fooooo`03ool00?oooooooooo02Wooooo00?o
o`3oooooooooool0>Oooool00ooo003oooooooooo`25ooooo`03o`000?oooooooooo013ooooo0013
ooooo`03o`000?oooooooooo00Kooooo00?o0?l0ool0ooooool05_ooool00ooo003oooooooooo`0X
ooooo`03ool0oooooooooooo03_ooooo00?oo`00ooooooooool0Q?ooool00ol0003oooooooooo`0@
ooooo`00@oooool00ol0003oooooooooo`07ooooo`03o`3o0?oooooooooo01Cooooo00?oo`00oooo
ooooool0:?ooool00ooo0?ooooooooooo`33ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o
00002Oooool00ol0o`3oooooooooo`0Booooo`03ool00?oooooooooo02Sooooo00?oo`3ooooooooo
ool0`oooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo00Sooooo00?oo`3oo`3o0?ooool0
4_ooool00ooo003oooooooooo`0Wooooo`03ool0oooooooooooo0<Gooooo00?o0000ooooooooool0
4?ooool002Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02Oooool00ol0o`3oooooooooo`0@ooooo`03
ool00?oooooooooo02Oooooo00?oo`3oooooooooool0a_ooool00ol0003oooooooooo`0@ooooo`00
:?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool02_ooool00ol0o`3oooooooooo`0?ooooo`03ool00?oooooooooo0?3o
oooo00?o0000ooooooooool04?ooool002Sooooo00Go410@oooooooooooooooooa0@400@ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ooo0?oo0?l0o`3o000>ooooo`03
ool00?oooooooooo0?7ooooo00?o0000ooooooooool04?ooool002Sooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000;ooooo`;oo`3o00?o0?l0oooooooo
ool02Oooool2ool00?;ooooo0ol0000Booooo`00:?ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo00?oo`3oo`3o
0?ooool0ooooool00ol0003oooooooooo`0@ooooo`00:?ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`3o0?oooooooooo
0?gooooo00?o0000ooooooooool04?ooool002Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0o`3oooooooooo`3loooo
o`03o`000?oooooooooo013ooooo000Xooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Kooooo0_l0000Booooo`03o`3o0?oooooooooo02gooooo00?oo`3oooooooooool0C?ooool00ooo
003oooooooooo`1kooooo`;o00004_ooool004?ooooo00?o0000ooooooooool04_ooool00ol0o`3o
ooooooooo`0[ooooo`03ool0oooooooooooo04gooooo00?oo`00ooooooooool0O?ooool00ol0003o
ooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`0Cooooo`;o0?l0:_ooool00ooo0?oooooo
ooooo`1?ooooo`03ool00?oooooooooo07_ooooo00?o0000ooooooooool04?ooool004?ooooo00?o
0000ooooooooool05Oooool00ol0o`3oooooooooo`0Vooooo`03ool0oooooooooooo057ooooo00?o
o`00ooooooooool0N_ooool00ol0003oooooooooo`0@ooooo`00@oooool2o`0001?ooooo00Coo`3o
oooooooooooooooo0_l0o`0Uooooo`03ool0oooooooooooo05?ooooo00?oo`00ooooooooool0N?oo
ool2o`0001;ooooo0013ooooo`03o`000?oooooooooo01?ooooo0_oo0?l3ooooo`03o`3o0?oooooo
oooo02;ooooo00?oo`3oooooooooool0E?ooool00ooo003oooooooooo`1hooooo`03o`000?oooooo
oooo013ooooo0013ooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool00_ooool01Ooo
0?oooooooooooooooooo0?l002;ooooo00?oo`3oooooooooool0E_ooool00ooo003oooooooooo`1g
ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo00oooooo00?oo`00oooo
ooooool01?ooool01?oo0?ooooooooooooooool2o`3o01oooooo00?oo`3oooooooooool0F?ooool0
0ooo003oooooooooo`1fooooo`03o`000?oooooooooo013ooooo0013ooooo`;o00003oooool00ooo
003oooooooooo`06ooooo`03ool0oooooooooooo00;ooooo00?o0?l0ooooooooool06oooool00ooo
0?ooooooooooo`1Jooooo`;oo`00MOooool2o`0001;ooooo0013ooooo`03o`000?oooooooooo00go
oooo00?oo`00ooooooooool02?ooool00ooo0?ooooooooooo`02ooooo`;o0?l06_ooool00ooo0?oo
ooooooooo`1Mooooo`03ool00?oooooooooo07?ooooo00?o0000ooooooooool04?ooool004?ooooo
00?o0000ooooooooool03?ooool00ooo003oooooooooo`0:ooooo`03ool0oooooooooooo00?ooooo
0_l0o`0Gooooo`03ool0oooooooooooo05oooooo00?oo`00ooooooooool0L_ooool00ol0003ooooo
ooooo`0@ooooo`00@oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00cooooo00?o
o`3oooooooooool01?ooool3o`3o0>_ooooo00?o0000ooooooooool04?ooool004?ooooo0_l0000;
ooooo`03ool00?oooooooooo00kooooo00?oo`3oooooooooool01_ooool4o`3o0>Kooooo0_l0000B
ooooo`00@oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo013ooooo00?oo`3ooooo
ooooool02Oooool3o`3o0>Cooooo00?o0000ooooooooool04?ooool003Wooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0ooo000Rooooo`Co0?l000?oooooool0oooo
0?l0gOooool00ol0003oooooooooo`0@ooooo`00>oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool09oooool;o`3o0=Gooooo00?o0000ooooooooool0
4?ooool003_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`;oo`3o1Ooo
ool4ool0o`_ooooo6Ol0o`1Cooooo`03ool00?oooooooooo06Kooooo00?o0000ooooooooool04?oo
ool003_ooooo00?o0000ooooooooool01Oooool3o`0002Kooooo1Ooo0?lXoooooeOo0?l0Hoooool3
o`0001;ooooo000kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo013ooooo000kooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo013ooooo000kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000iooooo`03oeEEEOmV
IVKo000000Oooooo0_l0003ooooooa3ooooo0_l0000Booooo`00@oooool00ol0003oooooooooo`3o
oooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003o
ooooooooo`0@ooooo`00@oooool2o`000?oooooo4?ooool2o`0001;ooooo0013ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3o
oooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool004?ooooo
00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool00ol0003oooooooooo`3o
oooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o00004_ooool002Wooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000[ooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
ooooool@ooooo`03o`000?oooooooooo013ooooo000[ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?oo
ool002_ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o0000ooooool>
ooooo`?o00004_ooool002_ooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo000[oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooo
oa3ooooo00?o0000ooooooooool04?ooool002_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00
:Oooool00omEEEGoIVIVo`00000=ooooo`Co00001_ooool2o`000?oooooo4?ooool2o`0001;ooooo
0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool0
0ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooo
ooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o
00004_ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo
0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool0
0ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo00?o0000oooo
ooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo0013ooooo`;o0000ooooool@ooooo`;o
00004_ooool004?ooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo013ooooo
0013ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0@ooooo`00@oooool0
0ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool04?ooool004?ooooo0_l0003ooooo
oa3ooooo0_l0000Booooo`00@oooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooooooo
ool04?ooool003Sooooo1Ol00006ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003ooooo
ooooo`0@ooooo`00>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
ooooool@ooooo`03o`000?oooooooooo013ooooo000iooooo`03oiRHV?lQ8B7ok^k^00Ooooooool0
000Do`0001;ooooo000jooooo`03oiRHV?lQ8B7ok^k^0?oooooo;?ooool003_ooooo00?oMgMgofIV
I_ooool0ooooool[ooooo`00??ooool00ol0003oooooooooo`3oooooob[ooooo000hooooo`05o`00
0?nj^[[ooooooiRHV?l@4100ooooool/ooooo`00>?ooool01OnHV9So410@o`000?lQ8B7oc<c<0?oo
oooo;?ooool00?ooooooJOooool00?ooooooJOooool008gooooo00Go410@o`000?l0003o0000oa0@
4003ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`07ooooo`06oa0@4?lQ8B7o0000o`000?m4A4CogMgM0oooool5o`0000;ooooo00Co410@
o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00Oooooo
0ol000000ol@413oooooooooo`03ooooo`08oiRHV?l0003o0000ogMgMol0003o410@ooooool@4102
o`000004ooooool0003o0000oa0@40;ooooo00GoIVIVo`000?l0003oA4A4olc<c003ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2
ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0E_ooool008oooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4108ooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q1Oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Wo
oooo00?o0000ooooooooool01Oooool01Ol0003oZJVYoooooon7QhOo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool01_mEEEGoMgMgooooooooooooMgMg
oeEEE@?ooooo00Go0000ooooooooooooooooo`00001Iooooo`00Soooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0;ooooo`06ob4Q8Ooo
ooooooooooooooo^k^ko00001Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Gooooo`00Sooo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000Wooooo
00GogMgMoiRHV?mgMgOo410@ofIVIP05ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`Ko00002Oooool00ol0003oooooo`000005ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Eoooool008oooooo00?o
0000ooooooooool01?ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^ko
ooooohN7Qolb<S88ooooo`05ofIVI_l@413oEEEEohN7Qonj^[X01_ooool00ol0003oooooooooo`03
ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PWo
oooo0ol00005ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oQhN7oooooonYZJWo
000000;ooooo00KoIVIVogMgMoooooooooooohN7Qol00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ohN7
QoooooooZJVYo`00001Iooooo`00S?ooool01?l0003oooooooooool00002ooooo`06o`000?oooooo
ooooooooool0003oMgMg0_l000001OnHV9Soooooooooooo^k^koEEEE00;o000000?oA4A4onk^k_oo
ool01oooool01_l0003ok^k^ooooooooooooc<c<o`0000?ooooo00?o410@o`000?l000001?ooool0
0ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^k_mEEED00_l000000om4A4Cok^k^oooo
o`08ooooo`05o`000?oooooo410@ooooool@41000_ooool01?l@413o0000ooooooooool2o`0000;o
oooo00?o410@o`000?mgMgL00_l000001OnHV9Soooooooooooo^k^koIVIV00;o000000CoA4A4o`00
0?oooooo410@1Ol00004ooooo`03oa0@4?l0003o000000Cooooo00Kok^k^oeEEEOl0003o0000oeEE
EOo^k^h2ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0Eoooool008cooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000001Cooooo00Ko<S8bohN7Qooo
ooook^k^ofIVI_l0000Qooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`1cooooo`00S?ooool7o`0000?ooooo00?o0000ooooooooool04_ooool01_o^k^koA4A4o`000?l0
003o<S8boa0@40Gooooo00?o0000ooooooooool06?ooool6o`0001_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Yooooo`00UOooool00ol@413o0000ooooo`0Nooooo`03oa0@4?oo
oooooooo04?ooooo00?o410@ooooooooool0JOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{76, 363}, {264.938, 88}} -> {-5.92699, -0.191033, \
0.0456256, 0.0295296}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the options chosen for the first plot take precedence over those \
of the second, determining the plot and axis labels and the range of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " plotted.\n\t",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are summarized in Table ",
  ButtonBox["9.11",
    ButtonData:>"Table 9.11",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          StyleBox[\(Table  9  .11\ Basic\ Plots\),
            FontSize->9]},
        {GridBox[{
              {
                RowBox[{
                  StyleBox["Plot",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      StyleBox[\(x, xmin, xmax\),
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["}",
                        FontFamily->"Times"]}], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    StyleBox[\(option -> value\),
                      FontFamily->"Times",
                      FontSlant->"Italic"]}], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                RowBox[{
                  RowBox[{
                    StyleBox["Plot",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["f",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["as",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["a",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["function",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox[
                      RowBox[{
                        StyleBox["of",
                          FontFamily->"Times"], 
                        StyleBox["x",
                          FontFamily->"Times",
                          FontSlant->"Italic"]}]], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["from",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["xmin",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["to",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["xmax",
                      FontFamily->"Times",
                      FontSlant->"Italic"]}], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox[",",
                    FontFamily->"Times"], 
                  StyleBox["\[IndentingNewLine]",
                    FontFamily->"Times"], 
                  StyleBox[
                    RowBox[{"and", " ", "add", " ", "an", " ", 
                      StyleBox["option",
                        FontSlant->"Italic"]}],
                    FontFamily->"Times"]}]},
              {
                RowBox[{
                  StyleBox["Plot",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      RowBox[{
                        StyleBox["f1",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox[",",
                          FontFamily->"Times"], 
                        StyleBox["f2",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox[",",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox[",",
                          FontFamily->"Times"], 
                        StyleBox["\[Ellipsis]",
                          FontFamily->"Times"]}], 
                      StyleBox["}",
                        FontFamily->"Times"]}], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      StyleBox[\(x, xmin, xmax\),
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["}",
                        FontFamily->"Times"]}]}], 
                  StyleBox["]",
                    FontFamily->"Times",
                    FontWeight->"Bold"]}], 
                StyleBox[\(Plot\ several\ functions\ on\ the\ same\ graph\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Show",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox["plot",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["]",
                    FontFamily->"Times",
                    FontWeight->"Bold"]}], 
                StyleBox[\(Redraw\ a\ plot\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Show",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Times",
                    FontWeight->"Bold"], 
                  StyleBox[\(plot1, plot2, \[Ellipsis]\),
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["]",
                    FontFamily->"Times",
                    FontWeight->"Bold"]}], 
                StyleBox[\(Show\ several\ plots\),
                  FontFamily->"Times"]}
              },
            ColumnSpacings->2.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.11"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.6.4 The ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " Function"
}], "Subsubtitle",
  CellTags->{"i:47", "c:30"}],

Cell[TextData[{
  "Experimental data often comes in the form of lists of ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\ , \ y)\)\)]],
  " positions. The ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is useful for plotting such data. To see an example, let's first \
artificially generate a list of data using the ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data\  = \ Table[{i, Sqrt[i]}, {i, 0, 10. , 1. }]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.76"],

Cell[BoxData[
    \({{0, 0}, {1.`, 1.`}, {2.`, 1.4142135623730951`}, {3.`, 
        1.7320508075688772`}, {4.`, 2.`}, {5.`, 2.23606797749979`}, {6.`, 
        2.449489742783178`}, {7.`, 2.6457513110645907`}, {8.`, 
        2.8284271247461903`}, {9.`, 3.`}, {10.`, 
        3.1622776601683795`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We then plot the data using",
  StyleBox[" ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", as shown in  Cell ",
  ButtonBox["9.77",
    ButtonData:>"Cell 9.77",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[data, PlotStyle \[Rule] PointSize[0.02]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.77"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.186133 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10778 -18 -4.5 ]
[.01131 .10778 0 4.5 ]
[.01131 .20085 -6 -4.5 ]
[.01131 .20085 0 4.5 ]
[.01131 .29391 -18 -4.5 ]
[.01131 .29391 0 4.5 ]
[.01131 .38698 -6 -4.5 ]
[.01131 .38698 0 4.5 ]
[.01131 .48005 -18 -4.5 ]
[.01131 .48005 0 4.5 ]
[.01131 .57311 -6 -4.5 ]
[.01131 .57311 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10778 m
.03006 .10778 L
s
[(0.5)] .01131 .10778 1 0 Mshowa
.02381 .20085 m
.03006 .20085 L
s
[(1)] .01131 .20085 1 0 Mshowa
.02381 .29391 m
.03006 .29391 L
s
[(1.5)] .01131 .29391 1 0 Mshowa
.02381 .38698 m
.03006 .38698 L
s
[(2)] .01131 .38698 1 0 Mshowa
.02381 .48005 m
.03006 .48005 L
s
[(2.5)] .01131 .48005 1 0 Mshowa
.02381 .57311 m
.03006 .57311 L
s
[(3)] .01131 .57311 1 0 Mshowa
.125 Mabswid
.02381 .03333 m
.02756 .03333 L
s
.02381 .05194 m
.02756 .05194 L
s
.02381 .07055 m
.02756 .07055 L
s
.02381 .08917 m
.02756 .08917 L
s
.02381 .12639 m
.02756 .12639 L
s
.02381 .14501 m
.02756 .14501 L
s
.02381 .16362 m
.02756 .16362 L
s
.02381 .18223 m
.02756 .18223 L
s
.02381 .21946 m
.02756 .21946 L
s
.02381 .23807 m
.02756 .23807 L
s
.02381 .25669 m
.02756 .25669 L
s
.02381 .2753 m
.02756 .2753 L
s
.02381 .31253 m
.02756 .31253 L
s
.02381 .33114 m
.02756 .33114 L
s
.02381 .34975 m
.02756 .34975 L
s
.02381 .36837 m
.02756 .36837 L
s
.02381 .40559 m
.02756 .40559 L
s
.02381 .42421 m
.02756 .42421 L
s
.02381 .44282 m
.02756 .44282 L
s
.02381 .46143 m
.02756 .46143 L
s
.02381 .49866 m
.02756 .49866 L
s
.02381 .51727 m
.02756 .51727 L
s
.02381 .53589 m
.02756 .53589 L
s
.02381 .5545 m
.02756 .5545 L
s
.02381 .59173 m
.02756 .59173 L
s
.02381 .61034 m
.02756 .61034 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .01472 Mdot
.11905 .20085 Mdot
.21429 .27795 Mdot
.30952 .33711 Mdot
.40476 .38698 Mdot
.5 .43092 Mdot
.59524 .47065 Mdot
.69048 .50718 Mdot
.78571 .54118 Mdot
.88095 .57311 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00F03oool5000003h0oooo0P0000000`0A4A40oooo
0?ooo`0j0?ooo`050>k^kP0c<c<00000014A4@3<c<`0?03oool01@3<c<`08R8R0000000R8R80c<c<
03P0oooo10000000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^103oool005P0oooo00D0
VIVI028R8P3^k^h0oooo04A4A00o0?ooo`030000003oool0oooo03/0oooo00D0EEEE07MgM`3oool0
VIVI028R8P0l0?ooo`05028R8P2IVIT0oooo09VIV@0R8R80>P3oool00`000000oooo0?ooo`020?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL0103oool005T0oooo00<0VIVI028R8P3^k^h0?@3oool50000
03`0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`000000>P3o
ool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40103oool005X0oooo00<0
VIVI028R8P3^k^h0?03oool01014A4@0gMgM0?ooo`00000m0?ooo`050000002IVIT0oooo09VIV@0R
8R80?03oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c03X0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo001K0?ooo`0307MgM`1VIVH0oooo03/0oooo00@0gMgM05EE
E@3oool00000?@3oool01@000000EEEE0000000A4A40c<c<03`0oooo00D0c<c<0000000000000000
0<c<c00j0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`00
G03oool00`000000oooo0?ooo`0k0?ooo`0307MgM`3<c<`0000003d0oooo00<0EEEE08R8R03oool0
?P3oool01@0A4A40^k^k0?ooo`2k^k/04A4A03X0oooo00<000000?ooo`3oool00P3oool01@0A4A40
oooo0?ooo`3oool04A4A00@0oooo001H0?ooo`050000002k^k/0oooo09VIV@0A4A40?@3oool00`3^
k^h0A4A40000000m0?ooo`030=gMg@0A4A40VIVI03h0oooo00D000000;^k^`3oool0^k^k0000000j
0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`040?ooo`00F03oool0
1@2IVIT04A4A0000000R8R80c<c<03h0oooo00<0MgMg0000003oool0?@3oool0103<c<`0A4A40000
000A4A4l0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0>03oool205EEE@030000003oool0oooo0080
oooo00D0k^k^03<c<`000000<c<c0>k^kP040?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`00603oool400000?l0ooooC@3oool001L0oooo1P00003o0?oood`0oooo000B0?ooool0
0000E`00000001L0oooo1P00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool001L0oooo1P00000n0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool01`3o
ool001P0oooo1000003o0?ooodd0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool300000?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo0`00003o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool300000?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`<00000o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`0000@0<c<c0000000c<c<0k^k^1@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gM
g@050?ooo`030000003oool0oooo0?l0ooooC03oool0000409VIV@3oool0VIVI07MgM`D0oooo0P0R
8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`000`3oool0
0`0A4A40oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`000`3oool00`000000oooo0?ooo`0=0?ooo`0307MgM`0c<c<0oooo00@0oooo0`00003o0?oo
od`0oooo00030?ooo`030000003oool0oooo00X0oooo00D00000028R8P000000<c<c0<c<c0050?oo
o`030000003oool0oooo0?l0ooooC03oool000<0oooo00<04A4A0?ooo`3oool02P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooC03oool0000409VIV@3oool0VIVI07MgM``0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood`0oooo0000100c<c<00000
03<c<`3^k^h<0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo0`00003o0?oood`0oooo000J0?ooo`030000003oool0
oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`006P3oool300000?l0ooooC03oool001X0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo0`00003o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool300000?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool00100
oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo1000003o0?ooob`0
oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06`3oool600000?l0oooo
:`3oool00180oooo00<000000?ooo`3oool01@3oool3000001/0oooo1P00003o0?ooob/0oooo000B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06`3oool600000?l0oooo:`3oool0
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`H00000o`3oool[0?oo
o`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo1000003o0?ooob`0
oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00403o
ool205EEE@030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`<00000o`3ooom<0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo0`00003o0?oood`0oooo000J0?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool300000?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`0l0?ooo`@00000o`3oool<0?ooo`006P3oool00`000000oooo0?oo
o`0k0?ooo`H00000o`3oool;0?ooo`006P3oool3000003/0oooo1P00003o0?ooo`/0oooo000J0?oo
o`030000003oool0oooo03/0oooo1P00003o0?ooo`/0oooo000J0?ooo`030000003oool0oooo03/0
oooo1P00003o0?ooo`/0oooo000400000003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`0l0?ooo`@00000o`3oool<0?ooo`00
0P3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000
003oool0oooo0?l0ooooC03oool00080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0?l0ooooC03oool00080oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000o`3ooom<0?ooo`000P3oool00`000000oooo0?ooo`0;0?oo
o`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo0?ooo`3o0?oood`0oooo00020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oo
od`0oooo00020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`3o0?oood`0oooo000205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool3
00000?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000
oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<0
00000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo0`00001M0?ooo`@00000jP3oool001X0oooo
00<000000?ooo`3oool0G03oool600000>T0oooo000J0?ooo`030000003oool0oooo05`0oooo1P00
003Y0?ooo`006P3oool00`000000oooo0?ooo`1L0?ooo`H00000j@3oool001X0oooo00<000000?oo
o`3oool0G03oool600000>T0oooo000J0?ooo`030000003oool0oooo05d0oooo1000003Z0?ooo`00
6P3oool300000?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`<00000o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
3`3oool5000000H0oooo00<000000?ooo`3oool0O@3oool400000<X0oooo000?0?ooo`0509VIV@0R
8R80k^k^0?ooo`14A4@01P3oool00`000000oooo0?ooo`1l0?ooo`H00000b@3oool00100oooo00<0
VIVI028R8P3^k^h01`3oool00`000000oooo0?ooo`1l0?ooo`H00000b@3oool00140oooo00<0VIVI
028R8P3^k^h01P3oool3000007`0oooo1P0000390?ooo`004P3oool00`1gMgL0IVIV0?ooo`050?oo
o`030000003oool0oooo07`0oooo1P0000390?ooo`004`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo07d0oooo1000003:0?ooo`003`3oool01@000000^k^k0?ooo`2IVIT04A4A00H0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`003`3oool01@2IVIT04A4A0000000R8R80c<c<00H0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`<00000o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo0`00002M0?ooo`@00000ZP3oool001X0oooo00<000000?ooo`3oool0W03oool60000
0:T0oooo000J0?ooo`030000003oool0oooo09`0oooo1P00002Y0?ooo`006P3oool00`000000oooo
0?ooo`2L0?ooo`H00000Z@3oool001X0oooo00<000000?ooo`3oool0W03oool600000:T0oooo000J
0?ooo`030000003oool0oooo09d0oooo1000002Z0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`<00000o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0
ooooC03oool001X0oooo0`00003o0?oood`0oooo000J0?ooo`030000003oool0oooo0;h0oooo1000
00290?ooo`006P3oool00`000000oooo0?ooo`2m0?ooo`H00000R03oool001X0oooo00<000000?oo
o`3oool0_@3oool6000008P0oooo0004000000D0oooo0P0R8R850?ooo`0504A4A0000000000003<c
<`3MgMd01@3oool00`000000oooo0?ooo`2m0?ooo`H00000R03oool00004028R8P3^k^h0oooo04A4
A0D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0_@3oool60000
08P0oooo00000`2IVIT08R8R0>k^kP0A0?ooo`030000003oool0oooo00<0oooo0`00002n0?ooo`@0
0000R@3oool000040?ooo`2IVIT08R8R0>k^kPl0oooo00<0MgMg03<c<`3oool0103oool00`000000
oooo0?ooo`3o0?oood`0oooo00020?ooo`0307MgM`1VIVH0oooo00/0oooo00D00000028R8P000000
<c<c0<c<c0050?ooo`030000003oool0oooo0?l0ooooC03oool000<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooC03oool000040;^k^`3o
ool0VIVI014A4@`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oood`0oooo
0000100A4A400000028R8P3<c<`<0?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oood`0oooo
000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0`00003N0?ooo`@00000J@3oool0
01X0oooo00<000000?ooo`3oool0g@3oool6000006P0oooo000J0?ooo`030000003oool0oooo0=d0
oooo1P00001X0?ooo`006P3oool00`000000oooo0?ooo`3M0?ooo`H00000J03oool001X0oooo00<0
00000?ooo`3oool0g@3oool6000006P0oooo000J0?ooo`030000003oool0oooo0=h0oooo1000001Y
0?ooo`006P3oool300000?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03o
ool001X0oooo00<000000?ooo`3oool0o`3ooom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
od`0oooo000J0?ooo`<00000o`3oool4000004P0oooo000J0?ooo`030000003oool0oooo0?h0oooo
1P0000170?ooo`006P3oool00`000000oooo0?ooo`3n0?ooo`H00000A`3oool001X0oooo00<00000
0?ooo`3oool0oP3oool6000004L0oooo000J0?ooo`030000003oool0oooo0?h0oooo1P0000170?oo
o`006P3oool00`000000oooo0?ooo`3o0?ooo`@00000B03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`006P3oool300000?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000?0?ooo`0509VIV@0A4A40000003<c
<`3<c<`01P3oool00`000000oooo0?ooo`3o0?oood`0oooo000?0?ooo`05014A4@2k^k/0oooo07Mg
M`0c<c<01P3oool00`000000oooo0?ooo`3o0?ooob00oooo1000000X0?ooo`004`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo7`3oool6000002L0oooo000B0?ooo`030:ZZ
ZP0A4A40oooo00D0oooo0`00003o0?oooal0oooo1P00000W0?ooo`004@3oool00`0A4A4000000;^k
^`060?ooo`030000003oool0oooo0?l0oooo7`3oool6000002L0oooo000B0?ooo`030;^k^`0R8R80
oooo00D0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`H000009`3oool000l0oooo00D04A4A09VI
V@3oool0^k^k000000060?ooo`030000003oool0oooo0?l0oooo803oool4000002P0oooo000?0?oo
o`050:ZZZP0A4A400000014A4@2ZZZX01P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool001X0oooo0`00003o0?oood`0oooo000J0?ooo`030000
003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3ooom10?ooo`@000001`3o
ool001X0oooo00<000000?ooo`3oool0o`3ooom00?ooo`H000001P3oool001X0oooo00<000000?oo
o`3oool0o`3ooom00?ooo`H000001P3oool001X0oooo00<000000?ooo`3oool0o`3ooom00?ooo`H0
00001P3oool001X0oooo00<000000?ooo`3oool0o`3ooom00?ooo`H000001P3oool001X0oooo0`00
003o0?oood40oooo100000070?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?oo
o`030000003oool0oooo0?l0ooooC03oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, 0, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note the use of a ",
  StyleBox["PlotStyle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option here to make the size of the points larger. Another useful option \
is the \n",
  StyleBox["PlotJoined->True ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "option, which joins points with line segments, as in Cell ",
  ButtonBox["9.78",
    ButtonData:>"Cell 9.78",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[data, PlotJoined \[Rule] True]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.78"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.186133 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10778 -18 -4.5 ]
[.01131 .10778 0 4.5 ]
[.01131 .20085 -6 -4.5 ]
[.01131 .20085 0 4.5 ]
[.01131 .29391 -18 -4.5 ]
[.01131 .29391 0 4.5 ]
[.01131 .38698 -6 -4.5 ]
[.01131 .38698 0 4.5 ]
[.01131 .48005 -18 -4.5 ]
[.01131 .48005 0 4.5 ]
[.01131 .57311 -6 -4.5 ]
[.01131 .57311 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10778 m
.03006 .10778 L
s
[(0.5)] .01131 .10778 1 0 Mshowa
.02381 .20085 m
.03006 .20085 L
s
[(1)] .01131 .20085 1 0 Mshowa
.02381 .29391 m
.03006 .29391 L
s
[(1.5)] .01131 .29391 1 0 Mshowa
.02381 .38698 m
.03006 .38698 L
s
[(2)] .01131 .38698 1 0 Mshowa
.02381 .48005 m
.03006 .48005 L
s
[(2.5)] .01131 .48005 1 0 Mshowa
.02381 .57311 m
.03006 .57311 L
s
[(3)] .01131 .57311 1 0 Mshowa
.125 Mabswid
.02381 .03333 m
.02756 .03333 L
s
.02381 .05194 m
.02756 .05194 L
s
.02381 .07055 m
.02756 .07055 L
s
.02381 .08917 m
.02756 .08917 L
s
.02381 .12639 m
.02756 .12639 L
s
.02381 .14501 m
.02756 .14501 L
s
.02381 .16362 m
.02756 .16362 L
s
.02381 .18223 m
.02756 .18223 L
s
.02381 .21946 m
.02756 .21946 L
s
.02381 .23807 m
.02756 .23807 L
s
.02381 .25669 m
.02756 .25669 L
s
.02381 .2753 m
.02756 .2753 L
s
.02381 .31253 m
.02756 .31253 L
s
.02381 .33114 m
.02756 .33114 L
s
.02381 .34975 m
.02756 .34975 L
s
.02381 .36837 m
.02756 .36837 L
s
.02381 .40559 m
.02756 .40559 L
s
.02381 .42421 m
.02756 .42421 L
s
.02381 .44282 m
.02756 .44282 L
s
.02381 .46143 m
.02756 .46143 L
s
.02381 .49866 m
.02756 .49866 L
s
.02381 .51727 m
.02756 .51727 L
s
.02381 .53589 m
.02756 .53589 L
s
.02381 .5545 m
.02756 .5545 L
s
.02381 .59173 m
.02756 .59173 L
s
.02381 .61034 m
.02756 .61034 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.11905 .20085 L
.21429 .27795 L
.30952 .33711 L
.40476 .38698 L
.5 .43092 L
.59524 .47065 L
.69048 .50718 L
.78571 .54118 L
.88095 .57311 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00F03oool5000003h0oooo0P0000000`0A4A40oooo
0?ooo`0j0?ooo`050>k^kP0c<c<00000014A4@3<c<`0?03oool01@3<c<`08R8R0000000R8R80c<c<
03P0oooo10000000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^103oool005P0oooo00D0
VIVI028R8P3^k^h0oooo04A4A00o0?ooo`030000003oool0oooo03/0oooo00D0EEEE07MgM`3oool0
VIVI028R8P0l0?ooo`05028R8P2IVIT0oooo09VIV@0R8R80>P3oool00`000000oooo0?ooo`020?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL0103oool005T0oooo00<0VIVI028R8P3^k^h0?@3oool50000
03`0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`050000003oool0oooo0?ooo`000000>P3o
ool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40103oool005X0oooo00<0
VIVI028R8P3^k^h0?03oool01014A4@0gMgM0?ooo`00000m0?ooo`050000002IVIT0oooo09VIV@0R
8R80?03oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c03X0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo001K0?ooo`0307MgM`1VIVH0oooo03/0oooo00@0gMgM05EE
E@3oool00000?@3oool01@000000EEEE0000000A4A40c<c<03`0oooo00D0c<c<0000000000000000
0<c<c00j0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`00
G03oool00`000000oooo0?ooo`0k0?ooo`0307MgM`3<c<`0000003d0oooo00<0EEEE08R8R03oool0
?P3oool01@0A4A40^k^k0?ooo`2k^k/04A4A03X0oooo00<000000?ooo`3oool00P3oool01@0A4A40
oooo0?ooo`3oool04A4A00@0oooo001H0?ooo`050000002k^k/0oooo09VIV@0A4A40?@3oool00`3^
k^h0A4A40000000m0?ooo`030=gMg@0A4A40VIVI03h0oooo00D000000;^k^`3oool0^k^k0000000j
0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`040?ooo`00F03oool0
1@2IVIT04A4A0000000R8R80c<c<03h0oooo00<0MgMg0000003oool0?@3oool0103<c<`0A4A40000
000A4A4l0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0>03oool205EEE@030000003oool0oooo0080
oooo00D0k^k^03<c<`000000<c<c0>k^kP040?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`006P3oool00`000000oooo0?ooo`3o0?oood`0oooo000J0?ooo`030000003oool0oooo
0?l0ooooC03oool00180ooooo`00001G000000006P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool001X0oooo0P00000o0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool01`3oool001X0oooo0P00003o0?ooodd0oooo000J0?oo
o`030000003oool000000?l0ooooC03oool001X0oooo00<000000?ooo`000000o`3ooom<0?ooo`00
6P3oool400000?l0ooooB`3oool001X0oooo00@000000?ooo`3oool00000o`3ooom;0?ooo`006P3o
ool01@000000oooo0?ooo`3oool000000?l0ooooBP3oool001X0oooo00D000000?ooo`3oool0oooo
0000003o0?ooodX0oooo000J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
oom70?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooAP3oool0
01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000J0?ooo`<0
0000103oool00`000000oooo0?ooo`3o0?ooodD0oooo000J0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooom50?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o
0?oood@0oooo000J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooom30?oo
o`006P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo@`3oool001X0oooo
0`0000070?ooo`030000003oool0oooo0?l0oooo@P3oool001X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oood80oooo000J0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0o`3ooom10?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0?l0oooo@@3oool001X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oood00
oooo000J0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom00?ooo`006P3o
ool3000000X0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`006P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0?l0oooo?`3oool001X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`3o0?oooch0oooo000J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3oooln0?ooo`0000@0<c<c0000000c<c<0k^k^1@3oool2028R8PD0oooo00D0A4A400000000
0000<c<c0=gMg@050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooolm0?oo
o`0000@0VIVI0?ooo`2IVIT0MgMg1@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo?@3oool000<0oooo00<04A4A0?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0o`3oooll0?ooo`000`3oool00`000000oooo0?ooo`0=0?ooo`0307MgM`0c<c<0oooo00@0oooo
0`00000>0?ooo`030000003oool0oooo0?l0oooo>`3oool000<0oooo00<000000?ooo`3oool02P3o
ool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3o0?oooc/0oooo00030?ooo`03014A4@3oool0oooo00X0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo>P3oool0000409VIV@3oool0
VIVI07MgM``0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0oooo>P3oool0000403<c<`000000<c<c0>k^kP`0oooo100000060?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0o`3oooli0?ooo`006P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0?l0oooo>@3oool001X0oooo0`00000A0?ooo`030000003oool0oooo
0?l0oooo>03oool001X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooocP0
oooo000J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooolg0?ooo`006P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo=`3oool001X0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooocH0oooo000J0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0o`3ooolf0?ooo`006P3oool3000001@0oooo00<000000?ooo`3o
ool0o`3ooole0?ooo`006P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo
=@3oool001X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?oooc@0oooo000J
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3ooold0?ooo`006P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo<`3oool001X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`3o0?oooc<0oooo000J0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0o`3ooolb0?ooo`006P3oool3000001L0oooo00<000000?ooo`3oool0o`3o
oolb0?ooo`006P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0oooo<@3oool0
01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oooc00oooo000J0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3oool`0?ooo`006P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0?l0oooo;`3oool001X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`3o0?ooobl0oooo000J0?ooo`<000006`3oool00`000000oooo0?ooo`3o
0?ooobh0oooo000J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3oool^0?oo
o`006P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo;@3oool001X0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?ooobd0oooo000@0?ooo`@0000000<0
4A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo;03o
ool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0?l0oooo;03oool00180oooo00<000000?ooo`3oool01@3oool3000001h0oooo0P00003o0?oo
ob`0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`3o0?ooobT0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`3o0?ooobP0oooo000B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooobL0oooo000B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool08`3oool200000?l0oooo9`3oool00100oooo0P1EEED00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooolT0?oo
o`006P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo8`3oool001X0oooo
0`00000W0?ooo`030000003oool0oooo0?l0oooo8P3oool001X0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`3o0?ooob40oooo000J0?ooo`030000003oool0oooo02T0oooo0P00003o
0?ooob40oooo000J0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0o`3ooolN0?oo
o`006P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0oooo7@3oool001X0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooa`0oooo000J0?ooo`<00000;P3o
ool200000?l0oooo703oool001X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3o
0?oooaT0oooo000J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`006P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0oooo5`3oool001X0oooo
00<000000?ooo`3oool0<`3oool200000?l0oooo5`3oool001X0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`3o0?oooa@0oooo000J0?ooo`<00000=P3oool00`000000oooo0?ooo`3o
0?oooa<0oooo000J0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0o`3ooolB0?oo
o`006P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0oooo4@3oool001X0oooo
00<000000?ooo`3oool0>@3oool200000?l0oooo4@3oool001X0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`3o0?ooo`h0oooo000J0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0o`3oool=0?ooo`006P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0?l0oooo303oool001X0oooo0`00000n0?ooo`800000o`3oool<0?ooo`006P3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0?l0oooo2@3oool001X0oooo00<000000?ooo`3oool0@@3o
ool200000?l0oooo2@3oool000@0000000<04A4A0?ooo`3oool00P3oool2028R8PD0oooo00D0A4A4
000000000000<c<c0=gMg@050?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0o`3o
ool60?ooo`000P3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`04
0?ooo`030000003oool0oooo04@0oooo0P00003o0?ooo`H0oooo00020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0?l0oooo0`3oool00080oooo00<000000?ooo`3oool03P3oool00`1gMgL0<c<c0?ooo`040?ooo`<0
0000A`3oool200000?l0oooo0`3oool00080oooo00<000000?ooo`3oool02`3oool01@0000008R8R
0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3o0?ooo`00
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
BP3oool200000?l0oooo00020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?`0oooo000205EEE@030000003oool0
oooo00/0oooo100000060?ooo`030000003oool0oooo04d0oooo0P00003l0?ooo`006P3oool00`00
0000oooo0?ooo`1?0?ooo`800000nP3oool001X0oooo0`00001A0?ooo`030000003oool0oooo0?L0
oooo000J0?ooo`030000003oool0oooo0580oooo0P00003g0?ooo`006P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0?@0oooo000J0?ooo`030000003oool0oooo05D0oooo0P00003d
0?ooo`006P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0?40oooo000J0?ooo`03
0000003oool0oooo05P0oooo0P00003a0?ooo`006P3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo0>h0oooo000J0?ooo`<00000F`3oool200000>h0oooo000J0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0j`3oool001X0oooo00<000000?ooo`3oool0GP3oool20000
0>/0oooo000J0?ooo`030000003oool0oooo0600oooo0P00003Y0?ooo`006P3oool00`000000oooo
0?ooo`1R0?ooo`800000i`3oool001X0oooo00<000000?ooo`3oool0I03oool200000>D0oooo000J
0?ooo`<00000IP3oool200000><0oooo000J0?ooo`030000003oool0oooo06P0oooo0P00003Q0?oo
o`006P3oool00`000000oooo0?ooo`1Z0?ooo`800000g`3oool001X0oooo00<000000?ooo`3oool0
K03oool200000=d0oooo000J0?ooo`030000003oool0oooo06h0oooo0P00003K0?ooo`006P3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0=P0oooo000J0?ooo`<00000L@3oool20000
0=P0oooo000J0?ooo`030000003oool0oooo07<0oooo0P00003F0?ooo`006P3oool00`000000oooo
0?ooo`1e0?ooo`800000e03oool001X0oooo00<000000?ooo`3oool0M`3oool200000=80oooo000?
0?ooo`D000001P3oool00`000000oooo0?ooo`1i0?ooo`800000d03oool000l0oooo00D0VIVI028R
8P3^k^h0oooo04A4A0060?ooo`030000003oool0oooo07/0oooo0P00003>0?ooo`00403oool00`2I
VIT08R8R0>k^kP070?ooo`030000003oool0oooo07d0oooo0P00003<0?ooo`004@3oool00`2IVIT0
8R8R0>k^kP060?ooo`<00000O`3oool200000<X0oooo000B0?ooo`0307MgM`1VIVH0oooo00D0oooo
00<000000?ooo`3oool0P@3oool200000<P0oooo000C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0P`3oool200000<H0oooo000?0?ooo`050000002k^k/0oooo09VIV@0A4A401P3o
ool00`000000oooo0?ooo`250?ooo`800000a03oool000l0oooo00D0VIVI014A4@0000008R8R0<c<
c0060?ooo`030000003oool0oooo08L0oooo0`0000310?ooo`006P3oool00`000000oooo0?ooo`2:
0?ooo`800000_`3oool001X0oooo0`00002<0?ooo`800000_@3oool001X0oooo00<000000?ooo`3o
ool0SP3oool200000;/0oooo000J0?ooo`030000003oool0oooo0900oooo0P00002i0?ooo`006P3o
ool00`000000oooo0?ooo`2B0?ooo`800000]`3oool001X0oooo00<000000?ooo`3oool0U03oool2
00000;D0oooo000J0?ooo`030000003oool0oooo09H0oooo0`00002b0?ooo`006P3oool3000009T0
oooo0P00002`0?ooo`006P3oool00`000000oooo0?ooo`2K0?ooo`800000[P3oool001X0oooo00<0
00000?ooo`3oool0W@3oool200000:`0oooo000J0?ooo`030000003oool0oooo09l0oooo0P00002Z
0?ooo`006P3oool00`000000oooo0?ooo`2Q0?ooo`<00000Y`3oool001X0oooo00<000000?ooo`3o
ool0Y03oool200000:D0oooo000J0?ooo`030000003oool0oooo0:H0oooo0`00002R0?ooo`006P3o
ool300000:T0oooo0P00002P0?ooo`006P3oool00`000000oooo0?ooo`2[0?ooo`<00000W@3oool0
01X0oooo00<000000?ooo`3oool0[P3oool3000009X0oooo000J0?ooo`030000003oool0oooo0;40
oooo0P00002H0?ooo`006P3oool00`000000oooo0?ooo`2c0?ooo`<00000U@3oool001X0oooo00<0
00000?ooo`3oool0]P3oool2000009<0oooo000J0?ooo`<00000^03oool300000900oooo000J0?oo
o`030000003oool0oooo0;/0oooo0P00002>0?ooo`006P3oool00`000000oooo0?ooo`2m0?ooo`<0
0000R`3oool001X0oooo00<000000?ooo`3oool0`03oool2000008T0oooo0004000000D0oooo0P0R
8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`320?ooo`<00000
QP3oool00004028R8P3^k^h0oooo04A4A0D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo
00<000000?ooo`3oool0a@3oool2000008@0oooo00000`2IVIT08R8R0>k^kP0A0?ooo`030000003o
ool0oooo00<0oooo0`0000370?ooo`<00000P@3oool000040?ooo`2IVIT08R8R0>k^kPl0oooo00<0
MgMg03<c<`3oool0103oool00`000000oooo0?ooo`3:0?ooo`800000O`3oool00080oooo00<0MgMg
06IVIP3oool02`3oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0c03o
ool3000007`0oooo00030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3?0?ooo`800000NP3oool000040;^k^`3oool0VIVI014A4@`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`3A0?ooo`800000N03oool00004014A4@0000008R8R
0<c<c0`0oooo100000060?ooo`030000003oool0oooo0=<0oooo0`00001e0?ooo`006P3oool00`00
0000oooo0?ooo`3F0?ooo`800000L`3oool001X0oooo0`00003H0?ooo`<00000L03oool001X0oooo
00<000000?ooo`3oool0f`3oool2000006h0oooo000J0?ooo`030000003oool0oooo0=d0oooo0`00
001[0?ooo`006P3oool00`000000oooo0?ooo`3P0?ooo`<00000J03oool001X0oooo00<000000?oo
o`3oool0h`3oool3000006D0oooo000J0?ooo`030000003oool0oooo0>H0oooo0`00001R0?ooo`00
6P3oool300000>T0oooo0`00001O0?ooo`006P3oool00`000000oooo0?ooo`3/0?ooo`<00000G03o
ool001X0oooo00<000000?ooo`3oool0k`3oool3000005T0oooo000J0?ooo`030000003oool0oooo
0?80oooo0`00001F0?ooo`006P3oool00`000000oooo0?ooo`3e0?ooo`<00000D`3oool001X0oooo
00<000000?ooo`3oool0n03oool300000500oooo000J0?ooo`<00000n`3oool3000004d0oooo000J
0?ooo`030000003oool0oooo0?h0oooo0`00001:0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
o`80oooo0P0000180?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo0`0000150?ooo`00
6P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo0`0000120?ooo`006P3oool00`000000oooo0?oo
o`3o0?ooo`X0oooo0`00000o0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`d0oooo0`00000l
0?ooo`006P3oool300000?l0oooo403oool3000003T0oooo000J0?ooo`030000003oool0oooo0?l0
oooo4`3oool3000003H0oooo000J0?ooo`030000003oool0oooo0?l0oooo5P3oool3000003<0oooo
000?0?ooo`0509VIV@0A4A40000003<c<`3<c<`01P3oool00`000000oooo0?ooo`3o0?oooaT0oooo
0`00000`0?ooo`003`3oool01@0A4A40^k^k0?ooo`1gMgL0<c<c00H0oooo00<000000?ooo`3oool0
o`3ooolL0?ooo`<00000;@3oool001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?oooal0oooo0`00000Z0?ooo`004P3oool00`2ZZZX04A4A0?ooo`050?ooo`<00000o`3ooolR
0?ooo`<000009`3oool00140oooo00<04A4A0000002k^k/01P3oool00`000000oooo0?ooo`3o0?oo
obD0oooo0`00000T0?ooo`004P3oool00`2k^k/08R8R0?ooo`050?ooo`030000003oool0oooo0?l0
oooo:03oool300000240oooo000?0?ooo`05014A4@2IVIT0oooo0;^k^`0000001P3oool00`000000
oooo0?ooo`3o0?ooob/0oooo0`00000N0?ooo`003`3oool01@2ZZZX04A4A0000000A4A40ZZZZ00H0
oooo00<000000?ooo`3oool0o`3oool^0?ooo`<000006`3oool001X0oooo00<000000?ooo`3oool0
o`3ooola0?ooo`@000005`3oool001X0oooo0`00003o0?ooocD0oooo0`00000D0?ooo`006P3oool0
0`000000oooo0?ooo`3o0?ooocP0oooo0`00000A0?ooo`006P3oool00`000000oooo0?ooo`3o0?oo
oc/0oooo0`00000>0?ooo`006P3oool00`000000oooo0?ooo`3o0?oooch0oooo0`00000;0?ooo`00
6P3oool00`000000oooo0?ooo`3o0?oood40oooo0P0000090?ooo`006P3oool00`000000oooo0?oo
o`3o0?oood`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo0`00003o0?oo
od`0oooo000J0?ooo`030000003oool0oooo0?l0ooooC03oool001X0oooo00<000000?ooo`3oool0
o`3ooom<0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tUnlike the ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, where you can plot several functions simultaneously, you can \
only plot one set of data at a time using ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". To get more than one dataset on the same plot, it is easiest to plot \
each set using a separate ",
  StyleBox["ListPlot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "command, then overlay the plots with a ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. (There are also other ways to do this; see the discussion of the \
function ",
  StyleBox["MultipleListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["The",
    FontSlant->"Italic"],
  " ",
  StyleBox["Mathematica Book ",
    FontSlant->"Italic"],
  " or in the help browser.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.6.5 Parametric Plots", "Subsubtitle",
  CellTags->{"i:50", "c:31"}],

Cell[TextData[{
  "\tParametric plots are useful for plotting functions of a parameter.  For \
example, the position ",
  Cell[BoxData[
      \(TraditionalForm\`\((x(t), y(t))\)\)]],
  "  of a particle moving in two-dimensions is a function of  the parameter \
",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", the time. The orbit of this particle in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(-\)\(y\)\(\ \)\)\)]],
  "plane can be plotted using ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", with the notation ",
  StyleBox["ParametricPlot[{x[t],y[t]},{t,a,b}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  " are the initial and final times."
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  "\tFor instance, consider the case of a two-dimensional harmonic \
oscillator. Here the position vs. time has the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_o\ \(cos(\[Omega]\_x\ t)\), \ 
        y\_o\ \(sin(\[Omega]\_y\ t\  + \ \[Phi])\)\ )\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`x\_o\)]]]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_o\)]],
  " are oscillation amplitudes in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " directions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_y\)]],
  " are the oscillator frequencies in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is a phase.  ",
  StyleBox["ParametricPlot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "allows one to see the result of such an oscillation. In Cell ",
  ButtonBox["9.79",
    ButtonData:>"Cell 9.79",
    ButtonStyle->"Hyperlink"],
  ",  we show an example with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[Phi]",
            "TraditionalForm"], " ", "=", " ", "0"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\  = \ \(y\_o\  = \ 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_x\  = \ 2, \ \[Omega]\_y\  = \ 6\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ParametricPlot[{Cos[2  t], Sin[6\ t]}, {t, 0, Pi}, 
      AspectRatio \[Rule] 1]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.79"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499999 0.476191 0.5 0.476191 [
[.02381 .4875 -6 -9 ]
[.02381 .4875 6 0 ]
[.2619 .4875 -12 -9 ]
[.2619 .4875 12 0 ]
[.73809 .4875 -9 -9 ]
[.73809 .4875 9 0 ]
[.97619 .4875 -3 -9 ]
[.97619 .4875 3 0 ]
[.4875 .02381 -12 -4.5 ]
[.4875 .02381 0 4.5 ]
[.4875 .2619 -24 -4.5 ]
[.4875 .2619 0 4.5 ]
[.4875 .7381 -18 -4.5 ]
[.4875 .7381 0 4.5 ]
[.4875 .97619 -6 -4.5 ]
[.4875 .97619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .5 m
.02381 .50625 L
s
[(-1)] .02381 .4875 0 1 Mshowa
.2619 .5 m
.2619 .50625 L
s
[(-0.5)] .2619 .4875 0 1 Mshowa
.73809 .5 m
.73809 .50625 L
s
[(0.5)] .73809 .4875 0 1 Mshowa
.97619 .5 m
.97619 .50625 L
s
[(1)] .97619 .4875 0 1 Mshowa
.125 Mabswid
.07143 .5 m
.07143 .50375 L
s
.11905 .5 m
.11905 .50375 L
s
.16666 .5 m
.16666 .50375 L
s
.21428 .5 m
.21428 .50375 L
s
.30952 .5 m
.30952 .50375 L
s
.35714 .5 m
.35714 .50375 L
s
.40476 .5 m
.40476 .50375 L
s
.45238 .5 m
.45238 .50375 L
s
.54762 .5 m
.54762 .50375 L
s
.59524 .5 m
.59524 .50375 L
s
.64286 .5 m
.64286 .50375 L
s
.69048 .5 m
.69048 .50375 L
s
.78571 .5 m
.78571 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.88095 .5 m
.88095 .50375 L
s
.92857 .5 m
.92857 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .02381 m
.50625 .02381 L
s
[(-1)] .4875 .02381 1 0 Mshowa
.5 .2619 m
.50625 .2619 L
s
[(-0.5)] .4875 .2619 1 0 Mshowa
.5 .7381 m
.50625 .7381 L
s
[(0.5)] .4875 .7381 1 0 Mshowa
.5 .97619 m
.50625 .97619 L
s
[(1)] .4875 .97619 1 0 Mshowa
.125 Mabswid
.5 .07143 m
.50375 .07143 L
s
.5 .11905 m
.50375 .11905 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .21429 m
.50375 .21429 L
s
.5 .30952 m
.50375 .30952 L
s
.5 .35714 m
.50375 .35714 L
s
.5 .40476 m
.50375 .40476 L
s
.5 .45238 m
.50375 .45238 L
s
.5 .54762 m
.50375 .54762 L
s
.5 .59524 m
.50375 .59524 L
s
.5 .64286 m
.50375 .64286 L
s
.5 .69048 m
.50375 .69048 L
s
.5 .78571 m
.50375 .78571 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .88095 m
.50375 .88095 L
s
.5 .92857 m
.50375 .92857 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.97619 .5 m
.97618 .51108 L
.97614 .52115 L
.97606 .53277 L
.97597 .54374 L
.97572 .56317 L
.97536 .58415 L
.97483 .60706 L
.97414 .63106 L
.97253 .67319 L
.97039 .71509 L
.96795 .75254 L
.96081 .82967 L
.95621 .86465 L
.95129 .894 L
.94643 .91685 L
.94065 .93779 L
.93383 .9555 L
.92978 .96308 L
.92595 .96848 L
.92223 .97225 L
.92008 .97382 L
.91905 .97443 L
.91807 .97492 L
.91628 .9756 L
.91429 .97605 L
.91231 .97619 L
.9112 .97614 L
.91017 .97601 L
.90827 .97557 L
.90648 .97492 L
.90448 .97395 L
.90229 .9726 L
.89775 .96886 L
.89348 .96429 L
.88541 .95314 L
.87654 .93757 L
.85668 .89254 L
.83322 .82611 L
.73141 .47695 L
.67833 .30616 L
.61775 .15144 L
.60126 .11885 L
.58366 .08909 L
.56725 .06619 L
.55182 .04906 L
.53735 .03696 L
.52921 .03186 L
.52177 .02828 L
.51755 .02672 L
Mistroke
.51363 .02557 L
.50934 .02463 L
.50694 .02426 L
.50476 .02402 L
.50076 .02382 L
.49851 .02383 L
.49644 .02393 L
.49263 .02432 L
.48861 .02503 L
.48477 .026 L
.48059 .02737 L
.473 .03069 L
.46562 .03495 L
.45881 .03979 L
.44338 .05392 L
.42708 .07356 L
.40013 .11632 L
.3708 .17663 L
.3134 .331 L
.25503 .52391 L
.20421 .70277 L
.17931 .78659 L
.15441 .86259 L
.132 .91974 L
.12205 .94024 L
.11327 .95517 L
.1048 .96624 L
.1005 .97044 L
.09835 .97214 L
.09607 .97364 L
.09409 .97467 L
.09231 .97538 L
.09054 .97587 L
.08889 .97613 L
.08699 .97618 L
.08525 .97598 L
.08337 .97549 L
.0814 .97467 L
.07972 .97369 L
.0779 .97236 L
.07432 .96879 L
.0711 .96446 L
.0682 .95955 L
.06196 .94538 L
.0558 .92565 L
.05046 .90288 L
.04586 .87785 L
.03839 .82259 L
.03504 .78926 L
.03185 .74979 L
Mistroke
.02909 .70587 L
.02702 .66268 L
.02621 .64142 L
.02555 .62093 L
.02504 .6021 L
.0246 .58185 L
.02439 .57028 L
.02423 .55975 L
.02409 .54902 L
.02399 .53914 L
.0239 .52753 L
.02386 .52143 L
.02383 .51497 L
.02381 .50411 L
.02381 .49219 L
.02385 .47988 L
.02392 .46852 L
.02397 .46259 L
.02403 .45606 L
.02419 .44287 L
.02458 .41897 L
.02507 .39674 L
.0263 .35597 L
.02809 .31332 L
.03062 .26832 L
.0339 .22375 L
.03721 .18835 L
.04135 .15285 L
.0461 .12068 L
.05109 .09412 L
.05599 .07365 L
.06173 .05526 L
.0685 .03989 L
.07212 .03405 L
.07426 .03128 L
.07625 .02913 L
.07798 .02758 L
.07989 .02619 L
.08096 .02557 L
.08195 .02507 L
.08394 .02433 L
.08584 .02393 L
.08758 .02381 L
.08962 .02396 L
.09157 .02439 L
.09347 .02506 L
.09553 .02606 L
.09932 .02859 L
.10393 .03283 L
.10824 .03782 L
Mistroke
.11797 .05241 L
.12759 .07075 L
.16647 .17294 L
.26231 .5014 L
.31703 .68001 L
.34735 .76566 L
.38076 .8454 L
.41328 .90611 L
.42887 .92882 L
.44341 .94611 L
.45798 .95956 L
.4657 .9651 L
.47394 .96978 L
.47771 .9715 L
.4818 .97306 L
.4854 .97418 L
.48921 .97509 L
.49265 .97568 L
.49642 .97607 L
.49986 .97619 L
.50307 .9761 L
.50702 .97572 L
.50902 .97542 L
.51123 .975 L
.51512 .97403 L
.51878 .97286 L
.52699 .96931 L
.53585 .96408 L
.552 .95077 L
.56675 .93443 L
.59473 .8928 L
.62382 .83545 L
.68246 .68153 L
.73429 .51316 L
.83214 .17719 L
.85441 .11335 L
.8655 .08595 L
.87673 .06207 L
.88611 .04576 L
.89092 .0389 L
.89596 .03294 L
.90045 .02877 L
.90445 .02606 L
.90634 .02513 L
.90838 .0244 L
.91027 .02398 L
.91201 .02382 L
.91403 .02391 L
.91503 .02408 L
.91612 .02435 L
Mistroke
.91804 .02506 L
.91979 .026 L
.92184 .02743 L
.92367 .02905 L
.92767 .03376 L
.931 .03901 L
.9345 .04594 L
.9405 .06177 L
.94589 .08094 L
.95114 .10523 L
.95934 .15828 L
.96316 .192 L
.96623 .22544 L
.96909 .26385 L
.97165 .30827 L
.97343 .34887 L
.97469 .38775 L
.97523 .40964 L
.97561 .42968 L
.97578 .44085 L
.97593 .45298 L
.97604 .46446 L
.97612 .47505 L
.97617 .48693 L
.97619 .49369 L
.97619 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{240, 240},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001;2000`400?l00000o`00003oooooool]
ooooo`00UOooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003oooooooooo`2Dooooo`00
UOooool00ol0003oooooooooo`2Dooooo`00UOooool00ol0003oooooooooo`2Dooooo`00Roooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0U?ooool008gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2Dooooo`00P_ooool6o`0000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2Dooooo`006?ooool6o`0006oooooo00?o0000ooooooooool0
2_l0001dooooo`Ko00006?ooool001Oooooo0_l00005ooooo`03o`000?oooooooooo06cooooo0ol0
0005ooooo`03o`000?oooooooooo00;ooooo1?l0001_ooooo`03o`000?oooooooooo00?ooooo0_l0
000Gooooo`005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06[ooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Gooooo000Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0JOooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo000Eooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0Ioooool01?l0003oEEEEofIVI_l00007oooo
o`03o`000?oooooooooo00Sooooo0_l0001Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04oooool001Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Uooooo`;o
00002oooool00ol0003oooooooooo`0:ooooo`;o0000IOooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01?ooooo000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01;ooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
017ooooo000Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo000Aoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Boooo
o`;o00004oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04?ooool0017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool0017ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3oooool0013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool0013ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool0
013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03oooool000oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool000oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool03_ooool000oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool000oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03Oooool000oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool000oooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool03Oooool000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03Oooool000kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Ooo
ool000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01_ooooo0_l0000Looooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`003?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0;ooooo`003?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08Oooool2o`0002;ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00_ooooo000<ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo000;oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00_ooooo000;ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo000;ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00[ooooo000;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[o
oooo000;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000;
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo000:ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00[ooooo000:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Wooooo`;o0000:?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo017ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`09ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0002gooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0<_ooool2o`0003?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo0008oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00Kooooo0008ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0gooooo`;o0000>?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01_ooool000Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool01_ooool000Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool01_ooool000Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_oo
ool000Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_ooool000Oo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool000Oooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo0_l0000loooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06oooo
o`001oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`001ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`001oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`001oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`06ooooo`001oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06
ooooo`001oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`06ooooo`00
1oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`06ooooo`001oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@?ooool2
o`00047ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Kooooo0007ooooo`03o`000?oooooo000000?o000000?o410@ooooooooool0=oooool01Oo^
k^ko<S8bo`000?l0003ok^k^00Gooooo00?o8B4Qo`000?ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM03Sooooo00?o0000ooooooooool0>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00?o0000ooooooooool00_lQ8B43ooooo`03o`000?ooooooA4A400;o000000?o<S8bomgMgOooool0
>Oooool4o`000003oa0@4?oooooooooo00Cooooo0007ooooo`05o`000?ooooooooooooooool00000
>oooool01OmgMgOoV9RHooooool0003oMgMg00Gooooo00?o8B4Qo`000?ooool01oooool00omgMgOo
<S8booooo`0gooooo`03o`000?oooooooooo03Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`03o`000?oooooooooo00;o8B4Q0oooool00ol0003oooooooooo`02ooooo`03ogMgMolb<S;ooooo
03_ooooo00?o0000ooooooooool01_ooool000Ko000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`0aooooo`Ko00000_ooool01Ol@413ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Wooooo00Go410@oooo
oooooooooooooa0@4003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo0007ooooo`05o`000?oooooooooo
ooooool00000>oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01ooo
ool00omgMgOo<S8booooo`0gooooo`03o`000?oooooooooo03Wooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00omgMgOo<S8b
ooooo`0kooooo`03o`000?oooooooooo00Kooooo0007ooooo`05o`000?ooooooooooooooool00000
>oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<03Sooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool02?l0003oooooooooool0003o8B4Qo`000?lb<S;o
c<c<??ooool00ol0003oooooooooo`06ooooo`001oooool01Ol0003ooooooooooooooooo000003_o
oooo00Ko410@oooooooooooooooooa0@4?l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`05oa0@4?ooooooooooooooool@41001?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00043ooooo00?o0000ooooooooool0
1_ooool000Oooooo00Go0000ooooooooooooooooo`00000kooooo`06ogMgMonHV9SooooooiRHV?mg
MgOo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0>Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01_ooool000Oooooo00Go0000
oooooomEEEGoIVIVo`00000kooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00000oooool00ol0003o
ooooooooo`05ooooo`Co0000>Oooool00ol0003oooooooooo`0iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01?ooool01Ol0003ooooooooooooooooo000000?ooooo1?l0000kooooo`03oeEEEOmVIVKo
000000Sooooo0007ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000014
ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oo
oooooooo00Kooooo0007ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool00000AOooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool01_ooool0
00Oooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000015ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooool00000AOooool00ol0003oooooooooo`06ooooo`001oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool0@oooool00ol0003o
ooooo`000015ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo04Cooooo
0_l00015ooooo`03o`000?oooooooooo04Cooooo0_l00015ooooo`03o`000?oooooooooo00Kooooo
003oo`0002go00000007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool0A?ooool2o`0004Gooooo00?o0000ooooooooool01_ooool000Oo
oooo00?o0000ooooooooool0@oooool00ol0003oooooo`000015ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooool00000AOooool00ol0003oooooooooo`06ooooo`001oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooo000004Gooooo00?o0000ooooooooool0@oooool00ol0003ooooo
o`000015ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooool00000AOooool00ol0003oooooooooo`13ooooo`03o`000?oooooo000004Gooooo00?o
0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooo
oooo000004Cooooo00?o0000ooooooooool0@oooool01?l0003oooooooooool00014ooooo`03o`00
0?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo04;ooooo00Go0000oooooooooooooooo
o`000014ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000014ooooo`03
o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo04;ooooo00Go0000oooooooooooo
ooooo`000014ooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`000014oooo
o`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00Kooooo0007ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`10ooooo`;o0000@Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_ooool000Oooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool01_ooool000Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool01_ooool000Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01_oo
ool000Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool000Oo
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool000Oooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03_ooooo0_l0000moooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06oooo
o`001oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`001ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`001oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`06ooooo`002?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06
ooooo`002?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`00
2?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`002?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0=oooool2o`0003Sooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Ko
oooo0008ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Kooooo0008ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo0008ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
0009ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Oooooo0009ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0booooo`;o0000=?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool000Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool01oooool000Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1oooool000Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
00Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool000Wooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool000Wooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool01oooool000Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool000Wooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool01oooool000Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o0000;_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool04Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Xooooo`;o0000:Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool0
00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool000_ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02_ooool000_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool000cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo027ooooo0_l0000Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`003?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`003?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0;ooooo`003Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0;ooooo`003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`003_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool06oooool2o`0001cooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00gooooo000>ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo
000>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000?oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo000?ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00gooooo000?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00kooooo000@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00ko
oooo000@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00kooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo000A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00oooooo000Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`0Booooo`;o00005?ooool00ol0003oooooooooo`1Goooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool0017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03oooool0017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool001;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool001;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool001;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1Nooooo`;o00003oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`004_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Aooooo`004oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`;o0000H_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo017ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo000D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01;ooooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo000Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0JOooool2o`0000Sooooo00?o0000oooooooo
ool01oooool2o`0006[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`00
5_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo0ol0001]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05Oooool001Oooooo0_l00004ooooo`03o`000?oooooooooo06gooooo00Co
0000ooooool0003o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`006?ooool5o`00073ooooo00Co
0000oooooooooooooooo2_l0001cooooo`Go00006Oooool008gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2Dooooo`00SOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo09Cooooo002=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?ooool008go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`00Roooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo09Cooooo002Eooooo`03o`000?oooooooooo09Cooooo002E
ooooo`03o`000?oooooooooo09Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {299, 0}} -> {-1, -1, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a Lissajous figure. Note the use of an option,",
  StyleBox[" AspectRatio",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  StyleBox["1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which gives the plot the same dimension in ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["y.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:119"],

Cell[TextData[{
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also allows one to plot functions inpolar coordinates. To plot a function \
",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta])\)]],
  StyleBox[", ",
    FontFamily->"Symbol"],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is radius and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " is polar angle, write the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " positions of this curve as",
  Cell[BoxData[
      \(TraditionalForm\`\((\(r(\[Theta])\)\ cos\[Theta], \(r(\[Theta])\)\ \
sin\[Theta])\)\)]],
  ". For example, a curve ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta]) = \[Theta]\)]],
  "  is a spiral, as shown in Cell ",
  ButtonBox["9.80",
    ButtonData:>"Cell 9.80",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ParametricPlot[{\[Theta]\ Cos[\[Theta]], \[Theta]\ Sin[\[Theta]]}, {\
\[Theta], 0, 6\ Pi}, 
      PlotRange \[Rule] {{\(-6\)\ Pi, 6  Pi}, {\(-6\) Pi, 6  Pi}}, 
      AspectRatio \[Rule] 1]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.80"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0265258 0.5 0.0265258 [
[.10211 .4875 -9 -9 ]
[.10211 .4875 9 0 ]
[.23474 .4875 -9 -9 ]
[.23474 .4875 9 0 ]
[.36737 .4875 -6 -9 ]
[.36737 .4875 6 0 ]
[.63263 .4875 -3 -9 ]
[.63263 .4875 3 0 ]
[.76526 .4875 -6 -9 ]
[.76526 .4875 6 0 ]
[.89789 .4875 -6 -9 ]
[.89789 .4875 6 0 ]
[.4875 .10211 -18 -4.5 ]
[.4875 .10211 0 4.5 ]
[.4875 .23474 -18 -4.5 ]
[.4875 .23474 0 4.5 ]
[.4875 .36737 -12 -4.5 ]
[.4875 .36737 0 4.5 ]
[.4875 .63263 -6 -4.5 ]
[.4875 .63263 0 4.5 ]
[.4875 .76526 -12 -4.5 ]
[.4875 .76526 0 4.5 ]
[.4875 .89789 -12 -4.5 ]
[.4875 .89789 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10211 .5 m
.10211 .50625 L
s
[(-15)] .10211 .4875 0 1 Mshowa
.23474 .5 m
.23474 .50625 L
s
[(-10)] .23474 .4875 0 1 Mshowa
.36737 .5 m
.36737 .50625 L
s
[(-5)] .36737 .4875 0 1 Mshowa
.63263 .5 m
.63263 .50625 L
s
[(5)] .63263 .4875 0 1 Mshowa
.76526 .5 m
.76526 .50625 L
s
[(10)] .76526 .4875 0 1 Mshowa
.89789 .5 m
.89789 .50625 L
s
[(15)] .89789 .4875 0 1 Mshowa
.125 Mabswid
.12864 .5 m
.12864 .50375 L
s
.15516 .5 m
.15516 .50375 L
s
.18169 .5 m
.18169 .50375 L
s
.20822 .5 m
.20822 .50375 L
s
.26127 .5 m
.26127 .50375 L
s
.28779 .5 m
.28779 .50375 L
s
.31432 .5 m
.31432 .50375 L
s
.34085 .5 m
.34085 .50375 L
s
.3939 .5 m
.3939 .50375 L
s
.42042 .5 m
.42042 .50375 L
s
.44695 .5 m
.44695 .50375 L
s
.47347 .5 m
.47347 .50375 L
s
.52653 .5 m
.52653 .50375 L
s
.55305 .5 m
.55305 .50375 L
s
.57958 .5 m
.57958 .50375 L
s
.6061 .5 m
.6061 .50375 L
s
.65915 .5 m
.65915 .50375 L
s
.68568 .5 m
.68568 .50375 L
s
.71221 .5 m
.71221 .50375 L
s
.73873 .5 m
.73873 .50375 L
s
.79178 .5 m
.79178 .50375 L
s
.81831 .5 m
.81831 .50375 L
s
.84484 .5 m
.84484 .50375 L
s
.87136 .5 m
.87136 .50375 L
s
.07559 .5 m
.07559 .50375 L
s
.04906 .5 m
.04906 .50375 L
s
.02254 .5 m
.02254 .50375 L
s
.92441 .5 m
.92441 .50375 L
s
.95094 .5 m
.95094 .50375 L
s
.97746 .5 m
.97746 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10211 m
.50625 .10211 L
s
[(-15)] .4875 .10211 1 0 Mshowa
.5 .23474 m
.50625 .23474 L
s
[(-10)] .4875 .23474 1 0 Mshowa
.5 .36737 m
.50625 .36737 L
s
[(-5)] .4875 .36737 1 0 Mshowa
.5 .63263 m
.50625 .63263 L
s
[(5)] .4875 .63263 1 0 Mshowa
.5 .76526 m
.50625 .76526 L
s
[(10)] .4875 .76526 1 0 Mshowa
.5 .89789 m
.50625 .89789 L
s
[(15)] .4875 .89789 1 0 Mshowa
.125 Mabswid
.5 .12864 m
.50375 .12864 L
s
.5 .15516 m
.50375 .15516 L
s
.5 .18169 m
.50375 .18169 L
s
.5 .20822 m
.50375 .20822 L
s
.5 .26127 m
.50375 .26127 L
s
.5 .28779 m
.50375 .28779 L
s
.5 .31432 m
.50375 .31432 L
s
.5 .34085 m
.50375 .34085 L
s
.5 .3939 m
.50375 .3939 L
s
.5 .42042 m
.50375 .42042 L
s
.5 .44695 m
.50375 .44695 L
s
.5 .47347 m
.50375 .47347 L
s
.5 .52653 m
.50375 .52653 L
s
.5 .55305 m
.50375 .55305 L
s
.5 .57958 m
.50375 .57958 L
s
.5 .6061 m
.50375 .6061 L
s
.5 .65915 m
.50375 .65915 L
s
.5 .68568 m
.50375 .68568 L
s
.5 .71221 m
.50375 .71221 L
s
.5 .73873 m
.50375 .73873 L
s
.5 .79178 m
.50375 .79178 L
s
.5 .81831 m
.50375 .81831 L
s
.5 .84484 m
.50375 .84484 L
s
.5 .87136 m
.50375 .87136 L
s
.5 .07559 m
.50375 .07559 L
s
.5 .04906 m
.50375 .04906 L
s
.5 .02254 m
.50375 .02254 L
s
.5 .92441 m
.50375 .92441 L
s
.5 .95094 m
.50375 .95094 L
s
.5 .97746 m
.50375 .97746 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .5 m
.50062 .50001 L
.50118 .50005 L
.50182 .50013 L
.50243 .50022 L
.5035 .50047 L
.50464 .50083 L
.50586 .50135 L
.50711 .50204 L
.5092 .50359 L
.51015 .50452 L
.51109 .50562 L
.51257 .50786 L
.51331 .50938 L
.51389 .51093 L
.51431 .51238 L
.5145 .51323 L
.51464 .51404 L
.5147 .51448 L
.51476 .51495 L
.51483 .5158 L
.51486 .51628 L
.51488 .51673 L
.51488 .51723 L
.51488 .51777 L
.51486 .51823 L
.51484 .51875 L
.51476 .51968 L
.51464 .5206 L
.5145 .52146 L
.51415 .52308 L
.51363 .52488 L
.51214 .52851 L
.51103 .53054 L
.50986 .53236 L
.50662 .53628 L
.50312 .53945 L
.49882 .54239 L
.49431 .54467 L
.4898 .54631 L
.48716 .54702 L
.48573 .54733 L
.48419 .54761 L
.48282 .54782 L
.4813 .54801 L
.47989 .54813 L
.47855 .54821 L
.47722 .54826 L
.47575 .54827 L
.47436 .54824 L
Mistroke
.47305 .54817 L
.47174 .54807 L
.47056 .54796 L
.46787 .54759 L
.46495 .54703 L
.46178 .54624 L
.45602 .54428 L
.44992 .54143 L
.44436 .53807 L
.43852 .53361 L
.43267 .52794 L
.4271 .52105 L
.42251 .5137 L
.41904 .50647 L
.4175 .50246 L
.41606 .498 L
.41494 .49369 L
.4141 .48963 L
.41349 .48568 L
.41325 .48366 L
.41305 .48143 L
.41295 .48014 L
.41288 .47892 L
.4128 .47662 L
.41278 .47533 L
.41277 .47413 L
.41279 .47281 L
.41283 .47141 L
.41294 .46907 L
.4131 .46688 L
.41335 .46447 L
.41368 .46187 L
.41458 .45667 L
.41591 .451 L
.41929 .44072 L
.4238 .43089 L
.42902 .42208 L
.43498 .41398 L
.44241 .40576 L
.45836 .3926 L
.46896 .38622 L
.48107 .38066 L
.49209 .37696 L
.49858 .37531 L
.50476 .37409 L
.50797 .37358 L
.5114 .37313 L
.51436 .37283 L
.51763 .37257 L
.51948 .37246 L
Mistroke
.52117 .37238 L
.52313 .37232 L
.52501 .3723 L
.52834 .37231 L
.53023 .37236 L
.53199 .37243 L
.53544 .37264 L
.5387 .37292 L
.54163 .37324 L
.5448 .37367 L
.55194 .37492 L
.5585 .37642 L
.56996 .3799 L
.58232 .38494 L
.59486 .39157 L
.60609 .39899 L
.61764 .40838 L
.62926 .42007 L
.63852 .43158 L
.64722 .44496 L
.65393 .45789 L
.65998 .47304 L
.66217 .47994 L
.66418 .48752 L
.66576 .49484 L
.66691 .5016 L
.66744 .50542 L
.66791 .5096 L
.66829 .51403 L
.66854 .51824 L
.66868 .52221 L
.66873 .52643 L
.66869 .53004 L
.66855 .53403 L
.66842 .53644 L
.66827 .53872 L
.6679 .54302 L
.66737 .54766 L
.66666 .55271 L
.66498 .56178 L
.66299 .57016 L
.65709 .58843 L
.64996 .60456 L
.63967 .62247 L
.62804 .63838 L
.60167 .66484 L
.58626 .67629 L
.56792 .68716 L
.55115 .69493 L
.54155 .69856 L
Mistroke
.53226 .70156 L
.52343 .70396 L
.51368 .70612 L
.50468 .70768 L
.49628 .70877 L
.4911 .70927 L
.48616 .70963 L
.4817 .70984 L
.47682 .70997 L
.47152 .70999 L
.46854 .70993 L
.46584 .70985 L
.46058 .70959 L
.45561 .70922 L
.45093 .70877 L
.44598 .70817 L
.43712 .70682 L
.42762 .70493 L
.41723 .70236 L
.39581 .69528 L
.37351 .68515 L
.35337 .67324 L
.33597 .66045 L
.31952 .64574 L
.3035 .62826 L
.27913 .59255 L
.26839 .57066 L
.2603 .54898 L
.25658 .53616 L
.25378 .52417 L
.25138 .51079 L
.25046 .50399 L
.24965 .49649 L
.24914 .48994 L
.24882 .48386 L
.24871 .48068 L
.24863 .47717 L
.24861 .4735 L
.24863 .47006 L
.2488 .46373 L
.2491 .45793 L
.24932 .45473 L
.2496 .45124 L
.25025 .44487 L
.25189 .43303 L
.25425 .42045 L
.26011 .39802 L
.26467 .38463 L
.27043 .37037 L
.28308 .3453 L
Mistroke
.29792 .32224 L
.31398 .30202 L
.3517 .26645 L
.37452 .25047 L
.40086 .23585 L
.41477 .22954 L
.43032 .22353 L
.44438 .21897 L
.45961 .21491 L
.47354 .21198 L
.48102 .21069 L
.48912 .20953 L
.49659 .20866 L
.50346 .20804 L
.51006 .20759 L
.51702 .20729 L
.52424 .20714 L
.52832 .20714 L
.53209 .20719 L
.53901 .20741 L
.54635 .20781 L
.55292 .20833 L
.55906 .20896 L
.57302 .21085 L
.58805 .21365 L
.60168 .21689 L
.63189 .22656 L
.65698 .23738 L
.68328 .2518 L
.72754 .28473 L
.74907 .30589 L
.7675 .32776 L
.78689 .35602 L
.80205 .3839 L
.81439 .4131 L
.82432 .44529 L
.82818 .46249 L
.83095 .47874 L
.83218 .48816 L
.83306 .49678 L
.83345 .50156 L
.8338 .50677 L
.83406 .5117 L
.83423 .51625 L
.83438 .52455 L
.83433 .53245 L
.83413 .53955 L
.83373 .54731 L
.8331 .55571 L
.8322 .56467 L
Mistroke
.82996 .58075 L
.8269 .597 L
.82328 .6122 L
.81461 .64024 L
.80102 .67294 L
.7855 .70187 L
.76542 .73178 L
.74041 .76159 L
.71446 .78661 L
.68852 .80716 L
.66012 .82564 L
.63223 .84039 L
.59808 .85452 L
.57982 .86049 L
.55924 .86598 L
.54111 .86979 L
.52388 .87254 L
.51431 .87371 L
.5055 .87457 L
.49579 .87527 L
.4909 .87553 L
.48554 .87574 L
.47568 .87593 L
.46658 .87587 L
.46181 .87575 L
.45657 .87555 L
.45109 .87526 L
.44597 .87492 L
.43655 .87411 L
.42794 .87317 L
.40863 .87031 L
.39159 .86694 L
.37315 .86237 L
.34011 .85168 L
.30298 .83552 L
.26528 .81399 L
.20377 .76478 L
.17503 .73347 L
.15155 .70193 L
.12932 .6646 L
.11024 .62258 L
.10362 .6042 L
.0975 .58413 L
.09303 .5665 L
.08905 .5471 L
.08708 .53514 L
.08557 .52403 L
.0844 .51335 L
.08391 .50788 L
.08346 .50198 L
Mistroke
.08289 .49179 L
.08258 .48221 L
.0825 .47636 L
.0825 .47079 L
.0827 .46033 L
.08315 .45001 L
.08352 .4442 L
.08393 .43885 L
.08485 .4292 L
.08611 .41862 L
.08894 .4003 L
.09282 .38103 L
.10489 .33815 L
.12025 .2992 L
.13822 .2639 L
.15748 .23311 L
.21019 .16996 L
.24133 .14192 L
.2774 .11535 L
.31079 .09532 L
.34883 .07697 L
.39146 .06133 L
.41112 .05571 L
.43298 .05056 L
.45754 .04612 L
.47106 .04427 L
.48372 .0429 L
.49565 .04194 L
.50654 .04134 L
.51258 .04111 L
.51914 .04096 L
.53106 .04092 L
.54227 .04117 L
.55254 .04164 L
.56438 .04247 L
.57562 .04353 L
.59553 .04611 L
.61715 .04991 L
.64068 .05526 L
.66548 .06232 L
.70914 .07848 L
.75676 .10212 L
.79915 .12931 L
.83451 .15736 L
.87024 .19201 L
.92246 .25922 L
.94593 .2998 L
.9643 .33974 L
.97827 .37869 L
.98814 .41525 L
Mistroke
.9924 .43583 L
.99604 .45844 L
.99737 .46886 L
.99853 .47997 L
.99933 .48948 L
1 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{245.562, 245.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004b0001<R000`400?l00000o`00003oV?ooool0
0ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003o
ooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003ooooooooo
o`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool3o`0009Oooooo002Hooooo`03
o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oo
oooooooo09Oooooo002Hooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo
09Oooooo002EoooooaOo0000Q_ooool008kooooo1ol00003ooooo`03o`000?oooooooooo017ooooo
2?l0001nooooo`00R?ooool6o`0000[ooooo00?o0000ooooooooool06Oooool6o`0007Sooooo0022
ooooo`Ko00004?ooool3o`0001oooooo1ol0001aooooo`00Ooooool3o`0001Kooooo00?o0000oooo
ooooool09_ooool5o`0006cooooo001jooooo`Go00006Oooool00ol0003oooooooooo`0[ooooo`?o
0000JOooool007Kooooo1?l0000Nooooo`03o`000?oooooooooo02kooooo0_l0001Wooooo`00Looo
ool3o`0002;ooooo00?o0000ooooooooool0<?ooool2o`0006Gooooo001`ooooo`?o00009Oooool0
0ol0003oooooooooo`0booooo`?o0000H_ooool006kooooo0_l0000Xooooo`03o`000?oooooooooo
03Gooooo0ol0001Oooooo`00Joooool3o`0002[ooooo00?o0000ooooooooool0>?ooool2o`0005go
oooo001Yooooo`;o0000;Oooool3o`0003[ooooo0ol0001Jooooo`00Ioooool2o`0002oooooo00?o
0000ooooooooool0?Oooool2o`0005Sooooo001Uooooo`;o0000<Oooool00ol0003oooooooooo`0o
ooooo`;o0000E_ooool006Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`11oooo
o`;o0000E?ooool006;ooooo0_l0000dooooo`03o`000?oooooooooo04?ooooo0ol0001Aooooo`00
H?ooool2o`0002Gooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOoo
ool00oooool00ol0003oooooooooo`16ooooo`;o0000Coooool005kooooo0_l0000Yooooo`03o`00
0?oooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`18ooooo`;o0000
COooool005cooooo0_l0000Pooooo`Ko00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0B_ooool2o`0004_ooooo001Jooooo`;o0000;Oooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0001<ooooo`;o0000BOooool0
05Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04Kooooo001Goooo
o`;o0000<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Coooool2o`0004Kooooo001Eooooo`;o0000<_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool2o`0004Cooooo001Cooooo`;o0000
<_ooool00omEEEGoIVIVo`000005ooooo`Co00001Oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo047ooooo001Booooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0E?oo
ool2o`00047ooooo001Aooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0E_ooool2
o`0003oooooo001?ooooo`;o0000Aoooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
03cooooo001>ooooo`03o`000?oooooooooo04Oooooo0ol0001Iooooo`;o0000??ooool004cooooo
0_l0001:ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0>Oooool004_ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03Sooooo001:
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0g
ooooo`00BOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo05kooooo0_l0000goooo
o`00B?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool0=?ooool004Oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo03?ooooo0016ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0booooo`00AOooool00ol0003oooooooooo`1@ooooo`?o0000Hoooool0
0ol0003oooooooooo`0aooooo`00A?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
06Cooooo0_l0000aooooo`00@oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0;_ooool004;ooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo02gooooo0011ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`0/ooooo`00@?ooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0:oooool0043ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02[ooooo000oooooo`03
o`000?oooooooooo05Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Yooooo`00
?_ooool00ol0003oooooooooo`1Gooooo`?o0000K?ooool00ol0003oooooooooo`0Xooooo`00?Ooo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09ooo
ool003cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02Kooooo000kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Koooool00ol0
003oooooooooo`0Uooooo`00>oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo06oo
oooo00?o0000ooooooooool09Oooool003[ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo02Cooooo000iooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`0Sooooo`00>?ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool08_ooool003Oooooo00?o0000oooo
ooooool0G?oooolHo`0005oooooo00?o0000ooooooooool08_ooool003Kooooo00?o0000oooooooo
ool0EOooool8o`0000;ooooo00?o0000ooooooooool04oooool4o`0005cooooo00?o0000oooooooo
ool08Oooool003Gooooo00?o0000ooooooooool0Doooool3o`0000[ooooo00?o0000ooooooooool0
5oooool5o`0005Sooooo00?o0000ooooooooool08?ooool003Gooooo00?o0000ooooooooool0D?oo
ool3o`0000gooooo00?o0000ooooooooool07?ooool4o`0005Gooooo00?o0000ooooooooool07ooo
ool003Cooooo00?o0000ooooooooool0C_ooool3o`00013ooooo00?o0000ooooooooool08?ooool3
o`0005;ooooo00?o0000ooooooooool07oooool003?ooooo00?o0000ooooooooool0C?ooool3o`00
01?ooooo00?o0000ooooooooool08oooool3o`00053ooooo00?o0000ooooooooool07_ooool003;o
oooo00?o0000ooooooooool0B_ooool3o`0000Gooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool00ol0003oooooooooo`0Vooooo`;o0000Coooool00ol0003ooooooooo
o`0Mooooo`00<Oooool00ol0003oooooooooo`19ooooo`;o00002_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Xooooo`?o0000COoo
ool00ol0003oooooooooo`0Looooo`00<?ooool00ol0003oooooooooo`18ooooo`;o000000?ooooo
o`000?l000001?l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`?o0000:oooool2o`0004cooooo00?o0000ooooooooool06oooool0033ooooo00?o0000
ooooooooool0A_ooool2o`0000kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool0;Oooool2o`0004[ooooo00?o0000ooooooooool06ooo
ool002oooooo00?o0000ooooooooool0AOooool2o`00013ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0;oooool2o`0004Wooooo00?o
0000ooooooooool06_ooool002kooooo00?o0000ooooooooool0A?ooool2o`0001;ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0<Ooo
ool2o`0004Sooooo00?o0000ooooooooool06Oooool002kooooo00?o0000ooooooooool0@_ooool2
o`0001Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo000]
ooooo`03o`000?oooooooooo047ooooo0_l0000Dooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Cooooo0_l00016ooooo`03o`000?oo
oooooooo01Sooooo000/ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0fooooo`;o0000AOooool00ol0003oooooooooo`0Gooooo`00;?ooool00ol0
003oooooooooo`0oooooo`;o0000:?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool05_ooool002_ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Xooooo`?o0000>Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Go
oooo000Zooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0jooooo`;o0000@oooool00ol0003oooooooooo`0Eooooo`00:_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo01Cooooo000Yooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool05?ooool002Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Coooo
o`00:?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0?oooool2o`00047ooooo00?o0000ooooooooool04_ooool002Sooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Booooo`009oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo017ooooo000Vooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`13ooooo`;o0000?_ooool00ol0003oooooooooo`0Aooooo`009_ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo037ooooo0ol00015ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool04?ooool002Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0?ooooo`009Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo
000Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03_ooool002Cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`008oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00gooooo000Sooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool03Oooool002?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`008_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo0ol0001<ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool03?ooool002;ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0;ooooo`008_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
00_ooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02oooool0027ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0:ooooo`008Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo00[ooooo000Pooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02Oooool0023ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09oooo
o`008?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03kooooo0ol0001Booooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool0023ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`08ooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00Oooooo000Oooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool0
01oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`007_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo03Sooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`06oooo
o`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03_ooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01_ooool001kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0`ooooo`Ko0000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`06ooooo`007Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo03cooooo00?oMgMgoc8b<_ooool00oooool3o`0005Oooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`05ooooo`007Oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo03[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00Cooooo1?l0
001@ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool001gooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Gooooo2?l00003
ooooo`So0000BOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Gooooo000Loooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooo
o`;o000000?oooooo`000?ooool04?ooool3o`0004Oooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`04ooooo`007?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03_o
oooo1_l00003ooooo`03o`000?oooooooooo01;ooooo1?l00013ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool01?ooool001cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0mooooo`;o00001_ooool00ol0003oooooooooo`0Fooooo`?o0000@Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0>oooool2o`0000Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool001cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool06_ooool2o`0003oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`03
ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Wooooo0_l0000;oooo
o`?o00007?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool00oooool001_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
7_ooool2o`0003cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`006ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`02ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`006oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`02ooooo`006_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`01ooooo`006_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`01ooooo`006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool04Oooool3o`0002Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo007ooooo000Jooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo007ooooo000Ioooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo007ooooo000Iooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0booooo`7o00000Oooool1ooooo`006Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<Oooool1o`00007ooooo
0Oooool001Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo037ooooo0Ol00001ooooo`7ooooo000Iooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`7o00000Oooool1ooooo`006Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool1o`00
007ooooo0Oooool001Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01Gooooo0ol0000[ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0<?ooool1o`00007ooooo0Oooool001Wooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo037ooooo0Ol00001ooooo`006Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<Oooool1o`00007ooooo000I
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0`
ooooo`7o00000Oooool001Wooooo00Co0000oooooooooooooooo1?l000001Ol@413ooooooooooooo
ooooA4A400;o000000?o<S8bomgMgOooool06_ooool4o`000008oa0@4?ooooooooooo`000?lb<S;o
0000oc8b<_o^k^hQooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo01Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00ol0
003oooooooooo`0<ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgo
oooo01Kooooo0Ol00001ooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool07?ooool00ol0003oooooooooo`02ooooo`05o`000?nHV9Sooooo
oiRHV?mgMgL09?ooool00omgMgOo<S8booooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool09oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Kooooo0Ol00001ooooo`005?ooool6
o`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`Ko00001Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@41006?ooool6o`0000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`7o0000000Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`0Looooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Tooooo`03ogMgMolb<S;ooooo00Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Wooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool05oooool1o`000000
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Mooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Qoooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01oooool00ol0003oooooooooo`0Gooooo`?o00009?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Hooooo`7o0000000Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00;ooooo00Go0000oooooooooooooooooa0@400Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06_ooool1o`0000006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRH
V?mgMgL08Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0Ol0000001Wooooo00Oo0000oooo
oooooooooooooeEEEOmVIVKo000000Gooooo1?l0000Looooo`03oeEEEOmVIVKo000000Cooooo00Go
0000oc8b<_l0003o<S8bonk^kP0Qooooo`Co00002?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02Cooooo1?l00007ooooo`03o`000?oooooooooo01Oooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00kooooo00?o0000ooooooooool02oooool00omEEEGo
IVIVo`000005ooooo`Co00006Oooool1o`0000006Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0<?ooool1o`0000006Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool1o`0000006Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool1
o`0000006Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0<?ooool1o`0000006Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0<?ooool1o`000000ool0000co`0000001_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`006Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool2o`0002kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0`ooooo`006Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`00
6Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`006Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`006_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0`ooooo`006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`006_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04Oooool3o`000003
ooooool0003ooooo02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`00
6_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02o`0002oooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0`ooooo`006_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool03oooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0<?ooool001[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0fooooo`;o00003oooool00ol0003oooooo`00000aooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<?ooool001[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0h
ooooo`;o00003Oooool2o`0003;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`
ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03[ooooo0_l00009oooo
o`?o0000<oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo000Kooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0>oooool9o`0000;ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo000Kooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0<?ooool001_ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`16ooooo`?o0000<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo037ooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<Oooool0
01cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`007?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo037ooooo000Looooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool0<Oooool001cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0aooooo`007?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03;ooooo000Moooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<_ooool001gooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`12ooooo`?o0000;oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo03;ooooo000Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
<_ooool001gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0booooo`007_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03?ooooo000Nooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0cooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03?ooooo
000Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool001oooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0nooooo`?o0000:oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo03Cooooo000Pooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0=?ooool0023ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
037ooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`008_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo03?ooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool002;ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo0ol0000Vooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=Oooool002?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0aooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo000Sooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0;Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo
000Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0fooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0=oooool002Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Zoooo
o`Co00001Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0=oooool002Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0gooooo`00
9Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Sooooo000Vooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0<?ooool3o`0001oooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0hooooo`009_ooool00ol0003oooooooooo`0mooooo`;o0000<?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool0
02Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01cooooo0_l0000mooooo`03o`000?oooooooooo03Wooooo000Wooooo`03o`000?oooooooooo03oo
oooo0_l0000]ooooo`03o`000?oooooooooo01[ooooo0_l0000oooooo`03o`000?oooooooooo03Wo
oooo000Xooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0>_ooool002Wooooo00?o
0000ooooooooool0@?ooool2o`0002[ooooo00?o0000ooooooooool05oooool2o`00047ooooo00?o
0000ooooooooool0>_ooool002Wooooo00?o0000ooooooooool0@_ooool2o`0002Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo03_ooooo000Zoooo
o`03o`000?oooooooooo04?ooooo0_l0000Vooooo`03o`000?oooooooooo01Cooooo0_l00013oooo
o`03o`000?oooooooooo03_ooooo000[ooooo`03o`000?oooooooooo04Cooooo0_l0000Tooooo`?o
00004oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03cooooo000[ooooo`03o`00
0?oooooooooo04Kooooo0ol0000Qooooo`03o`000?oooooooooo017ooooo0_l00014ooooo`03o`00
0?oooooooooo03gooooo000/ooooo`03o`000?oooooooooo04Sooooo0_l0000Oooooo`03o`000?oo
oooooooo00kooooo0ol00016ooooo`03o`000?oooooooooo03gooooo000/ooooo`03o`000?oooooo
oooo04[ooooo0ol0000Looooo`03o`000?oooooooooo00cooooo0_l00018ooooo`03o`000?oooooo
oooo03kooooo000]ooooo`03o`000?oooooooooo04cooooo0ol0000Iooooo`03o`000?oooooooooo
00Wooooo0ol0001:ooooo`03o`000?oooooooooo03kooooo000^ooooo`03o`000?oooooooooo04ko
oooo0ol0000Fooooo`03o`000?oooooooooo00Kooooo0ol0001<ooooo`03o`000?oooooooooo03oo
oooo000^ooooo`03o`000?oooooooooo057ooooo0ol0000Cooooo`03o`000?oooooooooo00Cooooo
0_l0001?ooooo`03o`000?oooooooooo03oooooo000_ooooo`03o`000?oooooooooo05?ooooo1_l0
000<ooooo`So0000D?ooool00ol0003oooooooooo`10ooooo`00<?ooool00ol0003oooooooooo`1H
ooooo`co000000Coooooo`000?l0003o0000Doooool00ol0003oooooooooo`11ooooo`00<?ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0@Oooool0
037ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
04;ooooo000booooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`13ooooo`00<oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0@oooool003?ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo04Cooooo000dooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`15ooooo`00=Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0AOooool003Gooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04Kooooo000fooooo`03o`00
0?oooooooooo05oooooo0ol0001=ooooo`03o`000?oooooooooo04Oooooo000gooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`18ooooo`00>?ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0BOooool0
03Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
04Wooooo000jooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`1:ooooo`00>oooool00ol0003oooooooooo`19ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPGooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1;
ooooo`00??ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0C?ooool0
03gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`16ooooo`;o0000Coooool003kooooo0_l00019oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000AOooool0
0ol0003oooooooooo`1?ooooo`00@?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0D?ooool0047ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo057ooooo0012ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1B
ooooo`00@oooool2o`0004;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Cooooo`00AOooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0E?ooool004Ko
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0nooooo`;o0000Eoooool004Oooooo
0_l0001?ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Eoooool004Wooooo00?o
0000ooooooooool0C?ooool3o`0003cooooo00?o0000ooooooooool0F?ooool004[ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo05Wooooo001;oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Joooo
o`00C?ooool2o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Kooooo`00
C_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
G?ooool004oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0fooooo`;o0000Gooo
ool0053ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0dooooo`;o0000HOooool0
057ooooo0_l00015ooooo`03o`000?oooooooooo03;ooooo0_l0001Sooooo`00Doooool2o`0004?o
oooo0ol0000aooooo`03o`000?oooooooooo06?ooooo001Eooooo`;o0000@Oooool00ol0003ooooo
ooooo`0_ooooo`;o0000I_ooool005Oooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0]ooooo`;o0000J?ooool005Sooooo0_l0000nooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0J?ooool005[ooooo0_l0000looooo`03o`000?oooooooooo02[ooooo0_l0001[oooo
o`00G?ooool2o`0003[ooooo00?o0000ooooooooool0:?ooool2o`0006gooooo001Nooooo`?o0000
=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06gooooo001Qooooo`;o0000=Ooo
ool00ol0003oooooooooo`0Uooooo`;o0000L?ooool006?ooooo0_l0000cooooo`?o00008_ooool3
o`0007;ooooo001Uooooo`?o0000<?ooool00ol0003oooooooooo`0Oooooo`?o0000MOooool006So
oooo0ol0000]ooooo`03o`000?oooooooooo01cooooo0ol0001hooooo`00Joooool3o`0002[ooooo
00?o0000ooooooooool06_ooool2o`0007_ooooo001^ooooo`?o00009oooool00ol0003ooooooooo
o`0Gooooo`?o0000OOooool0077ooooo0ol0000Tooooo`03o`000?oooooooooo01?ooooo1?l00020
ooooo`00M?ooool3o`00027ooooo00?o0000ooooooooool03oooool4o`0008Cooooo001gooooo`Co
00007Oooool00ol0003oooooooooo`0<ooooo`?o0000R?ooool007_ooooo1_l0000Gooooo`?o0000
2?ooool4o`0008_ooooo0021ooooo`go00001Oooool@o`0008oooooo002>ooooo`Go00001Oooool0
0ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003o
ooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00Qoooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`03ooooo`03o`000?oooooooooo09Oooooo
0029ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`2Gooooo`00ROooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0ol0002G
ooooo`00ROooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0Uoooool008Wooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0Uoooool008Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo09Oooooo0029ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Gooooo`00Qoooool00omEEEGoIVIVo`00
0005ooooo`Co00001Oooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2G
ooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool3o`0009Oooooo002Hooooo`03o`00
0?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooo
oooo09Oooooo002Hooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo09Oo
oooo002Hooooo`03o`000?oooooooooo09Oooooo002Hooooo`03o`000?oooooooooo09Oooooo002H
ooooo`?o0000Uoooool009Sooooo00?o0000ooooooooool0Uoooool009Sooooo00?o0000oooooooo
ool0Uoooool009Sooooo00?o0000ooooooooool0Uoooool009Sooooo00?o0000ooooooooool0Uooo
ool009Sooooo00?o0000ooooooooool0Uoooool009Sooooo00?o0000ooooooooool0Uoooool009So
oooo00?o0000ooooooooool0Uoooool009Sooooo00?o0000ooooooooool0Uoooool009Sooooo0ol0
002Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Goooo
o`00V?ooool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00V?oo
ool00ol0003oooooooooo`2Gooooo`00V?ooool00ol0003oooooooooo`2Gooooo`00\
\>"],
  ImageRangeCache->{{{0, 305.938}, {305.938, 0}} -> {-18, -18, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are summarized in Table ",
  ButtonBox["9.12",
    ButtonData:>"Table 9.12",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox[\(Table  9  .12\ Two\ Useful\ Types\ of\ x - y\ Plots\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {GridBox[{
              {
                RowBox[{
                  StyleBox["ListPlot",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["data",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox["Plot",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["a",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["list",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["of",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["x",
                        FontFamily->"Times",
                        FontSlant->"Italic"]}], 
                    StyleBox[",",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["data",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["of",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["the",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["form",
                        FontFamily->"Times"]}]}], 
                  StyleBox["\[IndentingNewLine]",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox["data",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["=",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      RowBox[{
                        RowBox[{
                          StyleBox["{",
                            FontFamily->"Times"], 
                          StyleBox[\(x\_1, y\_1\),
                            FontFamily->"Times",
                            FontSlant->"Italic"], 
                          StyleBox["}",
                            FontFamily->"Times"]}], 
                        StyleBox[",",
                          FontFamily->"Times"], 
                        RowBox[{
                          StyleBox["{",
                            FontFamily->"Times"], 
                          StyleBox[\(x\_2, y\_2\),
                            FontFamily->"Times",
                            FontSlant->"Italic"], 
                          StyleBox["}",
                            FontFamily->"Times"]}], 
                        StyleBox[",",
                          FontFamily->"Times"], 
                        StyleBox["\[Ellipsis]",
                          FontFamily->"Times"]}], 
                      StyleBox["}",
                        FontFamily->"Times"]}]}]}]},
              {
                RowBox[{
                  StyleBox["\[IndentingNewLine]",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox["ParametricPlot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[\({x[t], y[t]}, {t, tmin, tmax}\),
                      FontWeight->"Bold"], 
                    StyleBox["]",
                      FontWeight->"Bold"]}]}], 
                RowBox[{
                  StyleBox["\[IndentingNewLine]",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox["Plot",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox[\(y[t]\),
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["vs",
                        FontFamily->"Times"], 
                      StyleBox[".",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox[\(x[t]\),
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox["  ",
                      FontFamily->"Times"], 
                    StyleBox["as",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["t",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["varies",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["from",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["tmin",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["to",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["tmax",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Times"]}]}]}
              },
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.12"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.6.6 3D Plots", "Subsubtitle",
  CellTags->"c:32"],

Cell[TextData[{
  "There are various ways of plotting functions of two variables.  One way is \
to make a surface plot. For example, to plot the surface ",
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ sin(x\ y)\)]],
  ", use the ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The basic form of this plot mirrors that of the ",
  StyleBox["Plot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function, as shown in Cell ",
  ButtonBox["9.81",
    ButtonData:>"Cell 9.81",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:48"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plt\  = \ Plot3D[Sin[x\ y], {x, 0, Pi}, {y, 0, Pi}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.81"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.2187 .17096 -5.81399 -9 ]
[.2187 .17096 .18601 0 ]
[.42503 .08982 -5.4158 -9 ]
[.42503 .08982 .5842 0 ]
[.64842 .00203 -5.01761 -9 ]
[.64842 .00203 .98239 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.80399 .15298 0 -6.10779 ]
[.80399 .15298 6 2.89221 ]
[.89336 .28984 0 -5.97836 ]
[.89336 .28984 6 3.02164 ]
[.97161 .40968 0 -5.86822 ]
[.97161 .40968 6 3.13178 ]
[.02424 .26434 -12 -2.74167 ]
[.02424 .26434 0 6.25833 ]
[.01578 .31735 -24 -2.78649 ]
[.01578 .31735 0 6.21351 ]
[.00702 .37222 -6 -2.83304 ]
[.00702 .37222 0 6.16696 ]
[-0.00204 .42906 -18 -2.88143 ]
[-0.00204 .42906 0 6.11857 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(1)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(2)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(3)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.79163 .1574 m
.78546 .15961 L
s
[(1)] .80399 .15298 -1 .35729 Mshowa
.88089 .29393 m
.87466 .29598 L
s
[(2)] .89336 .28984 -1 .32852 Mshowa
.95906 .4135 m
.95278 .41541 L
s
[(3)] .97161 .40968 -1 .30405 Mshowa
.125 Mabswid
.71056 .03337 m
.70688 .03479 L
s
.73173 .06576 m
.72804 .06715 L
s
.75228 .0972 m
.74859 .09856 L
s
.77224 .12773 m
.76854 .12908 L
s
.81049 .18623 m
.80677 .18754 L
s
.82882 .21427 m
.8251 .21556 L
s
.84665 .24155 m
.84292 .24282 L
s
.864 .26809 m
.86027 .26934 L
s
.89734 .3191 m
.8936 .32031 L
s
.91337 .34361 m
.90962 .34481 L
s
.92899 .3675 m
.92523 .36868 L
s
.94421 .39079 m
.94045 .39195 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03646 .25956 m
.04257 .25717 L
s
[(-1)] .02424 .26434 1 -0.39074 Mshowa
.02804 .31268 m
.03417 .31035 L
s
[(-0.5)] .01578 .31735 1 -0.38078 Mshowa
.01933 .36767 m
.02548 .36539 L
s
[(0)] .00702 .37222 1 -0.37044 Mshowa
.0103 .42461 m
.01648 .42239 L
s
[(0.5)] -0.00204 .42906 1 -0.35968 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.0348 .27004 m
.03847 .26861 L
s
.03313 .28059 m
.0368 .27917 L
s
.03144 .29122 m
.03512 .2898 L
s
.02975 .30191 m
.03342 .3005 L
s
.02632 .32353 m
.03 .32213 L
s
.02459 .33445 m
.02828 .33306 L
s
.02285 .34544 m
.02654 .34406 L
s
.02109 .35652 m
.02478 .35514 L
s
.01755 .3789 m
.02124 .37754 L
s
.01576 .3902 m
.01945 .38885 L
s
.01395 .40159 m
.01765 .40025 L
s
.01213 .41306 m
.01584 .41172 L
s
.00846 .43625 m
.01217 .43492 L
s
.0066 .44797 m
.01031 .44665 L
s
.00473 .45977 m
.00844 .45846 L
s
.00285 .47166 m
.00656 .47035 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.786 .299 0 r
.37903 .68168 .4017 .70148 .43787 .75798 .4152 .73425 Metetra
0 .262 .753 r
.4152 .73425 .43787 .75798 .47644 .78379 .45381 .76192 Metetra
.691 .752 .898 r
.45381 .76192 .47644 .78379 .51651 .75902 .49424 .74648 Metetra
.887 .825 .78 r
.49424 .74648 .51651 .75902 .55645 .69077 .53505 .68955 Metetra
.949 .87 .725 r
.53505 .68955 .55645 .69077 .59538 .60842 .57509 .61178 Metetra
.956 .916 .732 r
.57509 .61178 .59538 .60842 .63386 .54567 .61436 .54122 Metetra
.874 .934 .857 r
.61436 .54122 .63386 .54567 .67356 .5249 .65396 .50072 Metetra
.526 .672 .93 r
.65396 .50072 .67356 .5249 .71625 .55018 .69555 .50077 Metetra
.254 .358 .777 r
.69555 .50077 .71625 .55018 .76261 .6063 .74041 .53738 Metetra
.237 .289 .714 r
.74041 .53738 .76261 .6063 .81136 .66239 .78863 .5926 Metetra
.319 .345 .731 r
.78863 .5926 .81136 .66239 .85929 .68401 .83853 .63891 Metetra
.49 .532 .827 r
.83853 .63891 .85929 .68401 .90306 .65248 .88706 .64973 Metetra
.795 .992 .88 r
.88706 .64973 .90306 .65248 .94175 .57779 .93143 .61348 Metetra
.93143 .61348 .94175 .57779 .9779 .4918 .97109 .54085 Metetra
.747 .247 0 r
.35575 .66136 .37903 .68168 .4152 .73425 .39198 .70977 Metetra
0 .239 .736 r
.39198 .70977 .4152 .73425 .45381 .76192 .43062 .73841 Metetra
.609 .719 .923 r
.43062 .73841 .45381 .76192 .49424 .74648 .47129 .73121 Metetra
.852 .821 .817 r
.47129 .73121 .49424 .74648 .53505 .68955 .51281 .68608 Metetra
.936 .874 .751 r
.51281 .68608 .53505 .68955 .57509 .61178 .55395 .61615 Metetra
.958 .919 .727 r
.55395 .61615 .57509 .61178 .61436 .54122 .59424 .54315 Metetra
.925 .954 .786 r
.59424 .54315 .61436 .54122 .65396 .50072 .63425 .48807 Metetra
.758 .87 .93 r
.63425 .48807 .65396 .50072 .69555 .50077 .67525 .46458 Metetra
.436 .539 .863 r
.67525 .46458 .69555 .50077 .74041 .53738 .71866 .47625 Metetra
.304 .353 .748 r
.71866 .47625 .74041 .53738 .78863 .5926 .7654 .51594 Metetra
.307 .323 .713 r
.7654 .51594 .78863 .5926 .83853 .63891 .81519 .56681 Metetra
.37 .377 .736 r
.81519 .56681 .83853 .63891 .88706 .64973 .86633 .60612 Metetra
.509 .556 .839 r
.86633 .60612 .88706 .64973 .93143 .61348 .91607 .61328 Metetra
.711 .987 .855 r
.91607 .61328 .93143 .61348 .97109 .54085 .96194 .57955 Metetra
.693 .182 0 r
.33185 .64049 .35575 .66136 .39198 .70977 .36819 .68452 Metetra
0 .237 .735 r
.36819 .68452 .39198 .70977 .43062 .73841 .40686 .71324 Metetra
.518 .676 .936 r
.40686 .71324 .43062 .73841 .47129 .73121 .44769 .713 Metetra
.802 .809 .856 r
.44769 .713 .47129 .73121 .51281 .68608 .48974 .67951 Metetra
.913 .875 .786 r
.48974 .67951 .51281 .68608 .55395 .61615 .53187 .6199 Metetra
.952 .925 .741 r
.53187 .6199 .55395 .61615 .59424 .54315 .57333 .54958 Metetra
.939 .96 .745 r
.57333 .54958 .59424 .54315 .63425 .48807 .61417 .48607 Metetra
.875 .964 .852 r
.61417 .48607 .63425 .48807 .67525 .46458 .65519 .4436 Metetra
.664 .771 .93 r
.65519 .4436 .67525 .46458 .71866 .47625 .69761 .42999 Metetra
.435 .491 .818 r
.69761 .42999 .71866 .47625 .7654 .51594 .74264 .44562 Metetra
.358 .368 .735 r
.74264 .44562 .7654 .51594 .81519 .56681 .79092 .48326 Metetra
.359 .347 .71 r
.79092 .48326 .81519 .56681 .86633 .60612 .84213 .52899 Metetra
.401 .389 .731 r
.84213 .52899 .86633 .60612 .91607 .61328 .89475 .56491 Metetra
.496 .533 .825 r
.89475 .56491 .91607 .61328 .96194 .57955 .94638 .57452 Metetra
.621 .101 0 r
.3073 .61906 .33185 .64049 .36819 .68452 .3438 .6585 Metetra
0 .254 .749 r
.3438 .6585 .36819 .68452 .40686 .71324 .38252 .68642 Metetra
.43 .627 .936 r
.38252 .68642 .40686 .71324 .44769 .713 .42343 .69169 Metetra
.736 .784 .891 r
.42343 .69169 .44769 .713 .48974 .67951 .46587 .66906 Metetra
.875 .869 .829 r
.46587 .66906 .48974 .67951 .53187 .6199 .50883 .62128 Metetra
.936 .93 .773 r
.50883 .62128 .53187 .6199 .57333 .54958 .55146 .55806 Metetra
.936 .966 .735 r
.55146 .55806 .57333 .54958 .61417 .48607 .59342 .4926 Metetra
.902 .986 .767 r
.59342 .4926 .61417 .48607 .65519 .4436 .63505 .43766 Metetra
.831 .95 .897 r
.63505 .43766 .65519 .4436 .69761 .42999 .67718 .40266 Metetra
.631 .712 .905 r
.67718 .40266 .69761 .42999 .74264 .44562 .72091 .39231 Metetra
.467 .486 .795 r
.72091 .39231 .74264 .44562 .79092 .48326 .76724 .4061 Metetra
.408 .389 .727 r
.76724 .4061 .79092 .48326 .84213 .52899 .81675 .43835 Metetra
.401 .366 .705 r
.81675 .43835 .84213 .52899 .89475 .56491 .86922 .47867 Metetra
.421 .389 .718 r
.86922 .47867 .89475 .56491 .94638 .57452 .92349 .5136 Metetra
.524 .001 0 r
.28207 .59704 .3073 .61906 .3438 .6585 .3188 .63168 Metetra
0 .288 .777 r
.3188 .63168 .3438 .6585 .38252 .68642 .35761 .65796 Metetra
.359 .584 .928 r
.35761 .65796 .38252 .68642 .42343 .69169 .39857 .66717 Metetra
.656 .745 .916 r
.39857 .66717 .42343 .69169 .46587 .66906 .44124 .65408 Metetra
.818 .85 .873 r
.44124 .65408 .46587 .66906 .50883 .62128 .48483 .61857 Metetra
.905 .93 .821 r
.48483 .61857 .50883 .62128 .55146 .55806 .52851 .56576 Metetra
.922 .975 .758 r
.52851 .56576 .55146 .55806 .59342 .4926 .57175 .5044 Metetra
.886 .986 .717 r
.57175 .5044 .59342 .4926 .63505 .43766 .61445 .44448 Metetra
.856 .997 .775 r
.61445 .44448 .63505 .43766 .67718 .40266 .65703 .39496 Metetra
.809 .945 .913 r
.65703 .39496 .67718 .40266 .72091 .39231 .70025 .36232 Metetra
.645 .706 .891 r
.70025 .36232 .72091 .39231 .76724 .4061 .74506 .34985 Metetra
.512 .507 .788 r
.74506 .34985 .76724 .4061 .81675 .43835 .79234 .35739 Metetra
.455 .415 .725 r
.79234 .35739 .81675 .43835 .86922 .47867 .84268 .38133 Metetra
.438 .383 .699 r
.84268 .38133 .86922 .47867 .92349 .5136 .8961 .41482 Metetra
0 .117 .595 r
.25614 .5744 .28207 .59704 .3188 .63168 .29317 .60405 Metetra
0 .338 .814 r
.29317 .60405 .3188 .63168 .35761 .65796 .33212 .62788 Metetra
.315 .552 .919 r
.33212 .62788 .35761 .65796 .39857 .66717 .37311 .63944 Metetra
.573 .697 .925 r
.37311 .63944 .39857 .66717 .44124 .65408 .4159 .63408 Metetra
.74 .81 .907 r
.4159 .63408 .44124 .65408 .48483 .61857 .45992 .6102 Metetra
.851 .912 .875 r
.45992 .6102 .48483 .61857 .52851 .56576 .50447 .56963 Metetra
.894 .98 .811 r
.50447 .56963 .52851 .56576 .57175 .5044 .54894 .51724 Metetra
.857 .988 .719 r
.54894 .51724 .57175 .5044 .61445 .44448 .59299 .4597 Metetra
.795 .97 .667 r
.59299 .4597 .61445 .44448 .65703 .39496 .63664 .40413 Metetra
.789 .989 .742 r
.63664 .40413 .65703 .39496 .70025 .36232 .68027 .35683 Metetra
.805 .97 .907 r
.68027 .35683 .70025 .36232 .74506 .34985 .72451 .32253 Metetra
.69 .754 .9 r
.72451 .32253 .74506 .34985 .79234 .35739 .77017 .30396 Metetra
.567 .554 .799 r
.77017 .30396 .79234 .35739 .84268 .38133 .81803 .30169 Metetra
.504 .451 .73 r
.81803 .30169 .84268 .38133 .8961 .41482 .86871 .31414 Metetra
0 .247 .718 r
.22947 .55112 .25614 .5744 .29317 .60405 .26688 .57559 Metetra
.029 .399 .854 r
.26688 .57559 .29317 .60405 .33212 .62788 .30604 .59624 Metetra
.303 .538 .912 r
.30604 .59624 .33212 .62788 .37311 .63944 .34709 .60852 Metetra
.504 .649 .922 r
.34709 .60852 .37311 .63944 .4159 .63408 .38993 .60876 Metetra
.653 .753 .923 r
.38993 .60876 .4159 .63408 .45992 .6102 .43419 .59486 Metetra
.77 .864 .919 r
.43419 .59486 .45992 .6102 .50447 .56963 .47936 .56674 Metetra
.842 .964 .884 r
.47936 .56674 .50447 .56963 .54894 .51724 .52489 .52633 Metetra
.826 .998 .781 r
.52489 .52633 .54894 .51724 .59299 .4597 .57033 .47725 Metetra
.728 .947 .64 r
.57033 .47725 .59299 .4597 .63664 .40413 .61546 .4241 Metetra
.642 .893 .56 r
.61546 .4241 .63664 .40413 .68027 .35683 .66028 .37173 Metetra
.652 .92 .623 r
.66028 .37173 .68027 .35683 .72451 .32253 .70508 .32459 Metetra
.759 .996 .835 r
.70508 .32459 .72451 .32253 .77017 .30396 .75035 .28626 Metetra
.757 .871 .931 r
.75035 .28626 .77017 .30396 .81803 .30169 .7967 .2592 Metetra
.643 .648 .839 r
.7967 .2592 .81803 .30169 .86871 .31414 .84481 .24464 Metetra
0 .379 .825 r
.20204 .52717 .22947 .55112 .26688 .57559 .23991 .54629 Metetra
.134 .465 .891 r
.23991 .54629 .26688 .57559 .30604 .59624 .27937 .56307 Metetra
.32 .542 .91 r
.27937 .56307 .30604 .59624 .34709 .60852 .32054 .57452 Metetra
.462 .612 .912 r
.32054 .57452 .34709 .60852 .38993 .60876 .36341 .57804 Metetra
.576 .69 .919 r
.36341 .57804 .38993 .60876 .43419 .59486 .40778 .57171 Metetra
.675 .787 .933 r
.40778 .57171 .43419 .59486 .47936 .56674 .45332 .55459 Metetra
.759 .901 .94 r
.45332 .55459 .47936 .56674 .52489 .52633 .49963 .5269 Metetra
.786 .99 .888 r
.49963 .5269 .52489 .52633 .57033 .47725 .5463 .48996 Metetra
.697 .964 .724 r
.5463 .48996 .57033 .47725 .61546 .4241 .59298 .44601 Metetra
.538 .84 .521 r
.59298 .44601 .61546 .4241 .66028 .37173 .63948 .39791 Metetra
.63948 .39791 .66028 .37173 .70508 .32459 .68577 .34877 Metetra
.68577 .34877 .70508 .32459 .75035 .28626 .732 .30161 Metetra
.511 .843 .556 r
.732 .30161 .75035 .28626 .7967 .2592 .77845 .2591 Metetra
.719 .988 .851 r
.77845 .2591 .7967 .2592 .84481 .24464 .82559 .22337 Metetra
.108 .497 .903 r
.17381 .50253 .20204 .52717 .23991 .54629 .21224 .51614 Metetra
.245 .529 .918 r
.21224 .51614 .23991 .54629 .27937 .56307 .25208 .52843 Metetra
.361 .559 .91 r
.25208 .52843 .27937 .56307 .32054 .57452 .29346 .53763 Metetra
.452 .592 .901 r
.29346 .53763 .32054 .57452 .36341 .57804 .3364 .54208 Metetra
.527 .638 .902 r
.3364 .54208 .36341 .57804 .40778 .57171 .38082 .54038 Metetra
.596 .702 .918 r
.38082 .54038 .40778 .57171 .45332 .55459 .42655 .5315 Metetra
.662 .794 .945 r
.42655 .5315 .45332 .55459 .49963 .5269 .47334 .51494 Metetra
.715 .907 .963 r
.47334 .51494 .49963 .5269 .5463 .48996 .5209 .49075 Metetra
.698 .98 .898 r
.5209 .49075 .5463 .48996 .59298 .44601 .56893 .45953 Metetra
.546 .898 .677 r
.56893 .45953 .59298 .44601 .63948 .39791 .61717 .42239 Metetra
.61717 .42239 .63948 .39791 .68577 .34877 .66543 .38083 Metetra
.66543 .38083 .68577 .34877 .732 .30161 .71362 .33659 Metetra
.71362 .33659 .732 .30161 .77845 .2591 .76173 .2915 Metetra
.76173 .2915 .77845 .2591 .82559 .22337 .80991 .24736 Metetra
.269 .591 .948 r
.14474 .47715 .17381 .50253 .21224 .51614 .18383 .4851 Metetra
.352 .587 .932 r
.18383 .4851 .21224 .51614 .25208 .52843 .22418 .49238 Metetra
.418 .584 .909 r
.22418 .49238 .25208 .52843 .29346 .53763 .26588 .49807 Metetra
.47 .589 .89 r
.26588 .49807 .29346 .53763 .3364 .54208 .30898 .50124 Metetra
.513 .605 .882 r
.30898 .50124 .3364 .54208 .38082 .54038 .35347 .50108 Metetra
.552 .636 .888 r
.35347 .50108 .38082 .54038 .42655 .5315 .39927 .49683 Metetra
.592 .687 .908 r
.39927 .49683 .42655 .5315 .47334 .51494 .4463 .48795 Metetra
.631 .762 .942 r
.4463 .48795 .47334 .51494 .5209 .49075 .49438 .47406 Metetra
.661 .864 .976 r
.49438 .47406 .5209 .49075 .56893 .45953 .54334 .45502 Metetra
.635 .947 .949 r
.54334 .45502 .56893 .45953 .61717 .42239 .59298 .43094 Metetra
.474 .882 .743 r
.59298 .43094 .61717 .42239 .66543 .38083 .6431 .40215 Metetra
.6431 .40215 .66543 .38083 .71362 .33659 .69355 .36919 Metetra
.69355 .36919 .71362 .33659 .76173 .2915 .74417 .3328 Metetra
.036 0 0 r
.74417 .3328 .76173 .2915 .80991 .24736 .7949 .29382 Metetra
.404 .659 .963 r
.1148 .45101 .14474 .47715 .18383 .4851 .15466 .45317 Metetra
.449 .634 .934 r
.15466 .45317 .18383 .4851 .22418 .49238 .19564 .455 Metetra
.482 .612 .904 r
.19564 .455 .22418 .49238 .26588 .49807 .23779 .45611 Metetra
.507 .598 .879 r
.23779 .45611 .26588 .49807 .30898 .50124 .28118 .45609 Metetra
.527 .593 .863 r
.28118 .45609 .30898 .50124 .35347 .50108 .32582 .45455 Metetra
.546 .598 .857 r
.32582 .45455 .35347 .50108 .39927 .49683 .37171 .45112 Metetra
.564 .614 .861 r
.37171 .45112 .39927 .49683 .4463 .48795 .41882 .44545 Metetra
.583 .643 .876 r
.41882 .44545 .4463 .48795 .49438 .47406 .46713 .43725 Metetra
.603 .69 .904 r
.46713 .43725 .49438 .47406 .54334 .45502 .51655 .42627 Metetra
.621 .76 .945 r
.51655 .42627 .54334 .45502 .59298 .43094 .567 .41231 Metetra
.625 .85 .985 r
.567 .41231 .59298 .43094 .6431 .40215 .61839 .39528 Metetra
.565 .917 .961 r
.61839 .39528 .6431 .40215 .69355 .36919 .6706 .37514 Metetra
.373 .832 .748 r
.6706 .37514 .69355 .36919 .74417 .3328 .72353 .35194 Metetra
.72353 .35194 .74417 .3328 .7949 .29382 .77706 .32579 Metetra
.511 .705 .958 r
.08395 .42408 .1148 .45101 .15466 .45317 .12469 .42032 Metetra
.531 .669 .925 r
.12469 .42032 .15466 .45317 .19564 .455 .16642 .41636 Metetra
.544 .638 .894 r
.16642 .41636 .19564 .455 .23779 .45611 .20919 .41207 Metetra
.553 .613 .867 r
.20919 .41207 .23779 .45611 .28118 .45609 .25302 .40733 Metetra
.559 .594 .845 r
.25302 .40733 .28118 .45609 .32582 .45455 .29795 .40202 Metetra
.565 .583 .831 r
.29795 .40202 .32582 .45455 .37171 .45112 .344 .396 Metetra
.57 .578 .822 r
.344 .396 .37171 .45112 .41882 .44545 .3912 .38915 Metetra
.575 .578 .819 r
.3912 .38915 .41882 .44545 .46713 .43725 .43957 .38134 Metetra
.582 .586 .822 r
.43957 .38134 .46713 .43725 .51655 .42627 .4891 .37247 Metetra
.589 .602 .833 r
.4891 .37247 .51655 .42627 .567 .41231 .53979 .36241 Metetra
.598 .627 .851 r
.53979 .36241 .567 .41231 .61839 .39528 .59165 .35107 Metetra
.607 .664 .879 r
.59165 .35107 .61839 .39528 .6706 .37514 .64465 .33835 Metetra
.615 .717 .918 r
.64465 .33835 .6706 .37514 .72353 .35194 .69877 .32416 Metetra
.615 .789 .965 r
.69877 .32416 .72353 .35194 .77706 .32579 .75399 .30843 Metetra
.593 .734 .942 r
.05214 .39631 .08395 .42408 .12469 .42032 .0939 .38653 Metetra
.599 .695 .91 r
.0939 .38653 .12469 .42032 .16642 .41636 .13652 .37654 Metetra
.6 .66 .88 r
.13652 .37654 .16642 .41636 .20919 .41207 .18004 .3663 Metetra
.599 .63 .853 r
.18004 .3663 .20919 .41207 .25302 .40733 .22447 .35581 Metetra
.598 .604 .829 r
.22447 .35581 .25302 .40733 .29795 .40202 .26986 .34504 Metetra
.596 .584 .81 r
.26986 .34504 .29795 .40202 .344 .396 .31623 .33396 Metetra
.594 .567 .794 r
.31623 .33396 .344 .396 .3912 .38915 .3636 .32255 Metetra
.592 .554 .781 r
.3636 .32255 .3912 .38915 .43957 .38134 .41201 .31079 Metetra
.591 .544 .771 r
.41201 .31079 .43957 .38134 .4891 .37247 .46149 .29866 Metetra
.59 .537 .764 r
.46149 .29866 .4891 .37247 .53979 .36241 .51207 .28612 Metetra
.59 .533 .759 r
.51207 .28612 .53979 .36241 .59165 .35107 .56377 .27316 Metetra
.59 .531 .757 r
.56377 .27316 .59165 .35107 .64465 .33835 .61663 .25975 Metetra
.591 .533 .758 r
.61663 .25975 .64465 .33835 .69877 .32416 .67068 .24585 Metetra
.593 .537 .761 r
.67068 .24585 .69877 .32416 .75399 .30843 .72595 .23145 Metetra
.656 .751 .92 r
.01933 .36767 .05214 .39631 .0939 .38653 .06223 .35177 Metetra
.653 .712 .891 r
.06223 .35177 .0939 .38653 .13652 .37654 .10588 .3356 Metetra
.648 .677 .864 r
.10588 .3356 .13652 .37654 .18004 .3663 .1503 .31915 Metetra
.642 .646 .839 r
.1503 .31915 .18004 .3663 .22447 .35581 .19549 .30241 Metetra
.635 .618 .816 r
.19549 .30241 .22447 .35581 .26986 .34504 .24149 .28537 Metetra
.629 .594 .795 r
.24149 .28537 .26986 .34504 .31623 .33396 .28832 .26802 Metetra
.623 .573 .777 r
.28832 .26802 .31623 .33396 .3636 .32255 .336 .25036 Metetra
.618 .554 .761 r
.336 .25036 .3636 .32255 .41201 .31079 .38454 .23238 Metetra
.613 .538 .746 r
.38454 .23238 .41201 .31079 .46149 .29866 .43398 .21406 Metetra
.608 .523 .733 r
.43398 .21406 .46149 .29866 .51207 .28612 .48435 .19541 Metetra
.603 .51 .721 r
.48435 .19541 .51207 .28612 .56377 .27316 .53566 .1764 Metetra
.599 .499 .711 r
.53566 .1764 .56377 .27316 .61663 .25975 .58794 .15703 Metetra
.596 .488 .702 r
.58794 .15703 .61663 .25975 .67068 .24585 .64122 .13729 Metetra
.593 .479 .693 r
.64122 .13729 .67068 .24585 .72595 .23145 .69554 .11717 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(1)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(2)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(3)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00joooool01OnHV9So410@o`000?lb<S;oc<c<07Sooooo003[ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S80N?ooool00>oooooo00?o0000ooooooooool04_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^05oooooo003^ooooo`03ojVYZOl@413ooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1O
ooooo`00kOooool00ol@413o0000okZj^P0Dooooo`05oa0@4?ooooooooooooooool@4100Goooool0
0>kooooo00?o^[Zjob4Q8Oooool04oooool01Ol0003ooooooooooooooooo000005oooooo003[oooo
o`05oa0@4?nHV9SooooookZj^_l000005?ooool01Ol0003ooooooooooooooooo000005oooooo003[
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT05?ooool01Ol@413ooooooooooooooooo410@05oooooo
003oooooo`Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Oooooo`00oOooool2o`0000Gooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1Oooooo`00n_ooool3o`000003ooooool0003ooooo06Sooooo003h
ooooo`;o00001?ooool2o`0006Sooooo003eooooo`?o00001_ooool00ol0003oooooo`00001Woooo
o`00loooool2o`0000Wooooo00?o0000ooooool00000Ioooool00?3ooooo0ol000000ooooooo0000
ooooo`08ooooo`04o`000?ooooooooooo`0006Kooooo003]ooooo`?o00001Oooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool00000IOooool00>_ooooo0_l0000Aooooo`05o`00
0?ooooooooooooooool00000IOooool00>Sooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0H_ooool00>Kooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>?ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0HOooool00>7ooooo0_l00002ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00oooool2o`00067ooooo003Nooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05oooooo003Looooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05oooooo003Iooooo`?o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05kooooo003Fooooo`?o00009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo05gooooo003Dooooo`;o0000:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
05gooooo003Aooooo`?o00000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0G?ooool00<oooooo0_l0000^ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0Foooool00<cooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Foooool00<[ooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0F_ooool00:3ooooo1Ol0000Rooooo`?o0000=Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05[ooooo002Pooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`00
03Sooooo00?o0000ooooooooool02_ooool2o`0005[ooooo002Qooooo`03oiRHV?lQ8B7ok^k^01ko
oooo0ol00002ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1Hooooo`00X_ooool00onHV9So8B4Qonk^kP0Jooooo`?o0000?Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05Sooooo002Sooooo`03ogMgMomVIVKooooo01Oooooo0_l0
0010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Eoooool00:Cooooo00?o0000
ooooooooool04oooool3o`0004?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1F
ooooo`00X?ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0_l00016ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0E_ooool00:3ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00@
ooooo`?o0000B?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Gooooo002coooo
o`;o00000oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0E?ooool00;3ooooo0ol0001=ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0E?ooool00:kooooo0_l0001@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
Doooool00:_ooooo0ol0001Booooo`03o`000?oooooooooo013ooooo0_l0001Cooooo`00Z?ooool3
o`0005Gooooo00?o0000ooooooooool03oooool2o`0005Cooooo002Vooooo`;o000000?oooooo`00
0?ooool0EOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo057ooooo002Sooooo`?o
00001?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0D?ooool00:7ooooo0_l0001Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
D?ooool009kooooo0ol0001Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Cooo
ool009cooooo0_l0001Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C_ooool0
09Wooooo0ol0001Tooooo`;o00005Oooool00ol0003oooooooooo`1>ooooo`00Uoooool2o`0000?o
oooo00?o0000ooooooooool0G_ooool5o`0001Kooooo00?o0000ooooooooool0COooool009Cooooo
0ol0001Tooooo`;o00000onGN[42o`0001Oooooo00?o0000ooooooooool0C?ooool0097ooooo0ol0
001Tooooo`?o00001_nGN[42o`0001Kooooo0_l0001=ooooo`00Soooool2o`0006Cooooo0ol00009
oiMj/@;o00005_ooool2o`0004gooooo002<ooooo`?o0000I?ooool2o`0000coUgZa0_l0000Hoooo
o`03o`000?oooooooooo04[ooooo002:ooooo`;o00000_ooool00ol0003oooooooooo`1Oooooo`?o
00003_nGN[42o`0001Sooooo00?o0000ooooooooool0B_ooool008Oooooo0ol0001Tooooo`;o0000
4OnGN[400ol0003oUgZao`00000Hooooo`03o`000?oooooooooo00Sooooo1?l000000ol@413ooooo
ooooo`0jooooo`00QOooool2o`0006Cooooo0ol000000onHO;?o0000oiMj/@0@oiMj/@03o`000?nG
N[7o000001Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0looooo`00G?ooool4
o`000003oa0@4?oooooooooo01oooooo0ol0001Sooooo`?o00001?nHO;<00ol0003oUgZaoiMj/@0?
oiMj/@03o`000?nGN[7o000001Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0l
ooooo`00G_ooool00ol0003oooooooooo`0Oooooo`;o0000Hoooool3o`0000SoV7bc00?o0000oiMj
/OnGN[403_nGN[401?l0003oUgZaoiMj/Ol0000Iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0??ooool005kooooo00?o0000ooooooooool07?ooool3o`0006;ooooo0ol0000;oiQl
/`03o`000?nGN[7oUgZa00koUgZa00Co0000oiMj/OnGN[7o00006_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo03cooooo001Nooooo`03o`000?oooooooooo01[ooooo0_l00003oooo
o`03o`000?oooooooooo05cooooo0ol0000>oiQl/`03o`000?nGN[7oUgZa00koUgZa00Co0000oiMj
/OnGN[7o00006_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo001Noooo
o`03o`000?oooooooooo01Oooooo0ol0001Qooooo`?o00004OnHO;<00ol0003oUgZaoiMj/@0>oiMj
/@04o`000?nGN[7oUgZao`0001_ooooo0_l00007ooooo`03o`000?oooooooooo03cooooo001Noooo
o`03o`000?oooooooooo01Cooooo0ol0001Qooooo`?o000000?oVGnfo`000?nHO;<04_nHO;<00ol0
003oUgZaoiMj/@0=oiMj/@05o`000?nGN[7oUgZaoiMj/Ol000006Oooool00ol0003oooooo`000005
ooooo`03oeEEEOmVIVKo000003kooooo001Nooooo`03o`000?oooooooooo01;ooooo0_l0001Roooo
o`;o00001?nIOkH00ol0003oV7bcoiQl/`0AoiQl/`03o`000?nGN[7oUgZa00goUgZa00Go0000oiMj
/OnGN[7oUgZao`00000Kooooo`03o`000?oooooooooo04Cooooo001Looooo`03oeEEEOmVIVKo0000
017ooooo0ol0001Qooooo`?o00001onIOkH00ol0003oV7bcoiQl/`0@oiQl/`03o`000?nGN[7oUgZa
00goUgZa00Go0000oiMj/OnGN[7oUgZao`00000Looooo`03o`000?oooooooooo04?ooooo001^oooo
o`;o00000oooool00ol0003oooooooooo`1Kooooo`?o00002_nIOkH00ol0003oV7bcoiQl/`0@oiQl
/`03o`000?nGN[7oUgZa00goUgZa00Go0000oiMj/OnGN[7oUgZao`00000Looooo`03o`000?oooooo
oooo04?ooooo001[ooooo`?o0000HOooool2o`0000goVGnf00?o0000oiQl/onHO;<04OnHO;<00ol0
003oUgZaoiMj/@0<oiMj/@03o`000?nGN[7oUgZa00;oUgZa00?o0000ooooooooool06_ooool00ol0
003oooooooooo`12ooooo`00JOooool2o`00067ooooo0ol0000?oiUo]P03o`000?nHO;?oV7bc017o
V7bc00?o0000oiMj/OnGN[403OnGN[401Ol0003oUgZaoiMj/OnGN[7o000001gooooo00?o0000oooo
ooooool0@Oooool006Kooooo0ol0001Qooooo`;o00004onIOkH00ol0003oV7bcoiQl/`0@oiQl/`03
o`000?nGN[7oUgZa00goUgZa00Go0000oiMj/OnGN[7oUgZao`00000Mooooo`03o`000?oooooooooo
047ooooo001Tooooo`;o0000HOooool3o`000003oiZ2^?l0003oVGnf01;oVGnf00?o0000oiQl/onH
O;<04?nHO;<00ol0003oUgZaoiMj/@0=oiMj/@05o`000?nGN[7oUgZaoiMj/Ol000007_ooool00ol0
003oooooooooo`10ooooo`00HOooool3o`000003ooooool0003ooooo05gooooo0ol00004oiZ2^003
o`000?nIOkKoVGnf017oVGnf00?o0000oiQl/onHO;<04OnHO;<00ol0003oUgZaoiMj/@0<oiMj/@03
o`000?nGN[7oUgZa00;oUgZa00?o0000ooooooooool07?ooool00ol0003oooooooooo`0oooooo`00
G_ooool3o`0000Gooooo00?o0000ooooooooool0F?ooool3o`0000SoVX:h00?o0000oiUo]_nIOkH0
4?nIOkH00ol0003oV7bcoiQl/`0AoiQl/`03o`000?nGN[7oUgZa00coUgZa00?o0000oiMj/OnGN[40
0_nGN[400ol0003oooooooooo`0Looooo`;o0000@?ooool005cooooo0_l0001Pooooo`?o00002onJ
P[P00ol0003oVGnfoiUo]P0AoiUo]P03o`000?nHO;?oV7bc013oV7bc00?o0000oiMj/OnGN[403?nG
N[400ol0003oUgZaoiMj/@02oiMj/@03o`000?oooooooooo01gooooo00?o0000ooooooooool0?_oo
ool005Wooooo0ol0001Oooooo`?o00003_nJP[P00ol0003oVGnfoiUo]P0AoiUo]P03o`000?nHO;?o
V7bc013oV7bc00?o0000oiMj/OnGN[403?nGN[400ol0003oUgZaoiMj/@02oiMj/@03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0?Oooool005Oooooo0_l0001Pooooo`;o00004_nJP[P00ol0
003oVGnfoiUo]P0@oiUo]P03o`000?nHO;?oV7bc017oV7bc00?o0000oiMj/OnGN[402onGN[400ol0
003oUgZaoiMj/@03oiMj/@03o`000?oooooooooo01gooooo00?o0000ooooooooool0?Oooool005Co
oooo0ol000000ooooooo0000ooooo`1Looooo`?o000000?oVhFko`000?nJP[P04OnJP[P00ol0003o
VGnfoiUo]P0@oiUo]P03o`000?nHO;?oV7bc017oV7bc00?o0000oiMj/OnGN[402onGN[400ol0003o
UgZaoiMj/@03oiMj/@03o`000?oooooooooo01kooooo00?o0000ooooooooool0??ooool005;ooooo
0_l0001Oooooo`?o00001?nKQK/00ol0003oVX:hoiZ2^00@oiZ2^003o`000?nIOkKoVGnf017oVGnf
00?o0000oiQl/onHO;<04?nHO;<00ol0003oUgZaoiMj/@0;oiMj/@03o`000?nGN[7oUgZa00?oUgZa
00?o0000ooooooooool07oooool00ol0003oooooooooo`0kooooo`00Coooool3o`0005kooooo0ol0
0008oi^5^`03o`000?nJP[SoVX:h013oVX:h00?o0000oiUo]_nIOkH04?nIOkH00ol0003oV7bcoiQl
/`0@oiQl/`03o`000?nGN[7oUgZa00_oUgZa00?o0000oiMj/OnGN[401?nGN[400ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo03_ooooo001=ooooo`;o0000G_ooool3o`0000_oVhFk00?o0000
oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P0@oiUo]P03o`000?nHO;?oV7bc017oV7bc00?o0000
oiMj/OnGN[402_nGN[400ol0003oUgZaoiMj/@04oiMj/@03o`000?oooooooooo01oooooo00?o0000
ooooooooool0>_ooool004[ooooo0ol0001Mooooo`?o00003_nKQK/00ol0003oVX:hoiZ2^00@oiZ2
^003o`000?nIOkKoVGnf017oVGnf00?o0000oiQl/onHO;<04?nHO;<00ol0003oUgZaoiMj/@0:oiMj
/@03o`000?nGN[7oUgZa00CoUgZa00?o0000ooooooooool08?ooool00ol0003oooooooooo`0ioooo
o`00Aoooool3o`000003ooooool0003ooooo05_ooooo0_l0000Boi^5^`03o`000?nJP[SoVX:h013o
VX:h00?o0000oiUo]_nIOkH04?nIOkH00ol0003oV7bcoiQl/`0@oiQl/`03o`000?nGN[7oUgZa00[o
UgZa00?o0000oiMj/OnGN[401?nGN[400ol0003oooooooooo`0Pooooo`;o0000>_ooool004Gooooo
0_l0001Nooooo`?o000000?oW8Vno`000?nKQK/04OnKQK/00ol0003oVX:hoiZ2^00@oiZ2^003o`00
0?nIOkKoVGnf013oVGnf00?o0000oiQl/onHO;<04?nHO;<00ol0003oUgZaoiMj/@0:oiMj/@03o`00
0?nGN[7oUgZa00GoUgZa00?o0000ooooooooool07oooool2o`0003[ooooo000Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h08oooool3o`0005gooooo0ol00004oib9_P03o`000?nKQK_oVhFk013oVhFk
00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P0@oiUo]P03o`000?nHO;?oV7bc017oV7bc
00?o0000oiMj/OnGN[402OnGN[400ol0003oUgZaoiMj/@05oiMj/@03o`000?oooooooooo027ooooo
00?o0000ooooooooool0=oooool001[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000
G_ooool2o`0000SoW8Vn00?o0000oi^5^onKQK/04?nKQK/00ol0003oVX:hoiZ2^00@oiZ2^003o`00
0?nIOkKoVGnf013oVGnf00?o0000oiQl/onHO;<04?nHO;<00ol0003oUgZaoiMj/@09oiMj/@03o`00
0?nGN[7oUgZa00GoUgZa00?o0000ooooooooool07_ooool2o`000003ooooool0003ooooo03Sooooo
000Jooooo`05oa0@4?ooooooooooooooool@41007_ooool3o`0005gooooo0ol0000:oib9_P03o`00
0?nKQK_oVhFk013oVhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P0@oiUo]P03o`00
0?nHO;?oV7bc013oV7bc00?o0000oiMj/OnGN[402_nGN[400ol0003oUgZaoiMj/@04oiMj/@03o`00
0?oooooooooo01gooooo0ol00002ooooo`03o`000?oooooooooo03Kooooo000Jooooo`05o`000?oo
ooooooooooooool000007?ooool2o`000003ooooool0003ooooo05[ooooo0ol0000=oib9_P03o`00
0?nKQK_oVhFk013oVhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P0@oiUo]P03o`00
0?nHO;?oV7bc013oV7bc00?o0000oiMj/OnGN[402_nGN[400ol0003oUgZaoiMj/@05oiMj/@03o`00
0?oooooooooo01_ooooo0ol000001Onho=Wo0000oooooooooooo000003Oooooo000Jooooo`05o`00
0?ooooooooooooooool000006Oooool3o`0005gooooo0_l0000Aoib9_P03o`000?nKQK_oVhFk00oo
VhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P0@oiUo]P03o`000?nHO;?oV7bc017o
V7bc00?o0000oiMj/OnGN[402OnGN[400ol0003oUgZaoiMj/@03oiMj/@?o00006oooool4o`0000?o
^?cI00?o0000ooooool00000=oooool001[ooooo00Go410@oooooooooooooooooa0@400Gooooo`;o
0000GOooool3o`000003oij=`_l0003oW8Vn013oW8Vn00?o0000oi^5^onKQK/04?nKQK/00ol0003o
VX:hoiZ2^00@oiZ2^003o`000?nIOkKoVGnf013oVGnf00?o0000oiQl/onHO;<04?nHO;<00ol0003o
UgZaoiMj/@09oiMj/@03o`000?nGN[7o000000?o00000_nGRL800ol0003oooooooooo`0Hooooo`Go
00001?nho=T00ol0003oooooo`00000fooooo`006_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Co
oooo0ol0001Looooo`?o00001OnNSL800ol0003oW8Vnoib9_P0>oib9_P03o`000?nKQK_oVhFk013o
VhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P0@oiUo]P03o`000?nHO;?oV7bc013o
V7bc00?o0000oiMj/OnGN[401onGN[44o`0000OoUhW200?o0000ooooooooool05_ooool5o`0000Ko
^?cI00?o0000ooooool00000=Oooool001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000GOooool2o`0000SoWXg200?o0000oib9__nLRKh03onLRKh00ol0003oVhFkoi^5^`0?oi^5^`03
o`000?nJP[SoVX:h013oVX:h00?o0000oiUo]_nIOkH04?nIOkH00ol0003oV7bcoiQl/`0@oiQl/`03
o`000?nGN[7oUgZa00CoUgZa0ol00002oiN9`P03o`000?nGRL;oUhW200KoUhW200?o0000oooooooo
ool05?ooool7o`0000Oo^?cI0ol0000dooooo`00;_ooool2o`0000;ooooo00?o0000ooooooooool0
F?ooool3o`0000[oWXg200?o0000oib9__nLRKh03onLRKh00ol0003oVhFkoi^5^`0@oi^5^`03o`00
0?nJP[SoVX:h013oVX:h00?o0000oiUo]_nIOkH03onIOkH00ol0003oV7bcoiQl/`0AoiQl/`03o`00
0?nGN[7o000000?o00001OnGRL800ol0003oUhW2oiN9`P06oiN9`P03o`000?oooooooooo01?ooooo
1ol00009okSlf@;o0000=?ooool002_ooooo0ol0001Looooo`?o00003_nNSL800ol0003oW8Vnoib9
_P0>oib9_P03o`000?nKQK_oVhFk013oVhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo
]P0@oiUo]P03o`000?nHO;?oV7bc00koV7bc1?l00008oiN9`P;o00002OnGRL800ol0003ooooooooo
o`0Aooooo`Oo00002Onho=T4o`0003?ooooo000Yooooo`;o0000GOooool2o`00017oWXg200?o0000
oib9__nLRKh03onLRKh00ol0003oVhFkoi^5^`0?oi^5^`03o`000?nJP[SoVX:h013oVX:h00?o0000
oiUo]_nIOkH04?nIOkH00ol0003oV7bcoiQl/`0;oiQl/`?o00000_nGR<800ol0003oUhW2oiN9`P04
oiN9`P?o000000?oUhW2o`000?nGRL802?nGRL800ol0003oooooooooo`0?ooooo`Oo000000?o2@00
o`000?nho=T01?nho=T4o`0000;oY:GF0_l0000cooooo`009_ooool3o`0005cooooo0ol000000onO
T/Ko0000oij=`P0@oij=`P03o`000?nLRKkoW8Vn00ooW8Vn00?o0000oi^5^onKQK/04?nKQK/00ol0
003oVX:hoiZ2^00@oiZ2^003o`000?nIOkKoVGnf00ooVGnf00?o0000oiQl/onHO;<01onHO;<4o`00
00KoUhS200?o0000oiN9`_nGRL800ol00005oiN9`P03o`000?nGRL;oUhW200KoUhW200?o0000oooo
ooooool03_ooool7o`0000;o2@0000?o0000okSlfOl000000ol00007ojBUeP;o0000<_ooool002Go
oooo0_l0001Kooooo`?o00001OnOT/H00ol0003oWXg2oij=`P0?oij=`P03o`000?nLRKkoW8Vn00ko
W8Vn00?o0000oi^5^onKQK/04?nKQK/00ol0003oVX:hoiZ2^00@oiZ2^003o`000?nIOkKoVGnf00oo
VGnf00?o0000oiQl/onHO;<00onHO;<4o`0000[oUhS20ol00009oiN9`P03o`000?nGRL;oUhW200Ko
UhW200?o0000ooooooooool03?ooool7o`0000;o2@000ol0000;ojBUeP03o`000?oooooo0000037o
oooo000Uooooo`?o0000F?ooool2o`0000SoWi;600?o0000oij=`_nNSL803onNSL800ol0003oW8Vn
oib9_P0?oib9_P03o`000?nKQK_oVhFk00ooVhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnf
oiUo]P0@oiUo]P03o`000?nHO;?o000000;o00002onGR<84o`0000coUhW200?o0000oiN9`_nGRL80
1OnGRL800ol0003oooooooooo`0;ooooo`Oo00000ol900000ol0003oY:GFojBUeP0;ojBUeP03o`00
0?oooooo0000037ooooo000Tooooo`?o000000?oooooo`000?ooool0Doooool3o`0000[oWi;600?o
0000oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0?oib9_P03o`000?nKQK_oVhFk00ooVhFk00?o
0000oiZ2^?nJP[P04OnJP[P00ol0003oVGnfoiUo]P0=oiUo]PCo00002onGR<83o`0000CoUhS200?o
0000oiN9`_nGRL802OnGRL800ol0003oUhW2oiN9`P05oiN9`P03o`000?oooooooooo00[ooooo1ol0
0004o`T00003o`000?nTYMKoY:GF00coY:GF00?o0000ooooool00000<?ooool001[ooooo1?l00000
0ol@413oooooooooo`04ooooo`05o`000?ooooooooooooooool00000D?ooool3o`0000koWi;600?o
0000oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0>oib9_P03o`000?nKQK_oVhFk013oVhFk00?o
0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo]P09oiUo]PCo00000_nGQl400ol0003oUhS2oiN8
`P07oiN8`P?o00001onGR<800ol0003oUhW2oiN9`P0:oiN9`P03o`000?nGRL;oUhW200GoUhW200?o
0000ooooooooool02?ooool7o`0000Co2@0000?o0000ojBUe_nTYMH03OnTYMH01?l0003ooooooooo
ool0000_ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Boooool2o`00017oWi;600?o0000oij=`_nNSL803onNSL800ol0003oW8Vnoib9
_P0>oib9_P03o`000?nKQK_oVhFk013oVhFk00?o0000oiZ2^?nJP[P04?nJP[P00ol0003oVGnfoiUo
]P04oiUo]PGo00001onGQl400ol0003oUhS2oiN8`P03oiN8`P?o00002onGR<800ol0003oUhW2oiN9
`P0:oiN9`P03o`000?nGRL;oUhW200CoUhW200?o0000ooooooooool01oooool7o`0000Go2@0000?o
0000ojBUe_nTYMH03OnTYMH00ol0003oooooooooo`02o`0002kooooo000Aooooo`Ko00001Oooool0
0ol0003oooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`17ooooo`?o000000?oXIS;
o`000?nOT/H04?nOT/H00ol0003oWXg2oij=`P0?oij=`P03o`000?nLRKkoW8Vn00ooW8Vn00?o0000
oi^5^onKQK/03onKQK/00ol0003oVX:hoiZ2^00AoiZ2^003o`000?nIOkKo000000?o00003?nGQl40
0ol0003oUhS2oiN8`P03o`0000koUhS200?o0000oiN9`_nGRL802onGRL800ol0003oUhW2oiN9`P03
oiN9`P03o`000?oooooooooo00Kooooo1ol00006o`T00003o`000?nTYMKoY:GF00koY:GF00Co0000
ooooool0003o0000;_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04?ooooo0ol00005oj6Hb`03o`000?nOT/KoWi;600ooWi;600?o0000
oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0>oib9_P03o`000?nKQK_oVhFk013oVhFk00?o0000
oiZ2^?nJP[P03_nJP[P4o`00013oUhO10ol0000AoiN8`P03o`000?nGRL;oUhW200_oUhW200?o0000
oiN9`_nGRL801?nGRL800ol0003oooooooooo`04ooooo`Oo00001_l90002o`00013oY:GF00Co0000
oooooooooooo0000;_ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo043ooooo0_l00008oj6Hb`03o`000?nOT/KoWi;600ooWi;600?o0000
oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0>oib9_P03o`000?nKQK_oVhFk013oVhFk00?o0000
oiZ2^?nJP[P02OnJP[P5o`0000;oUhS200?o0000oiN7`OnGQl403OnGQl42o`000003oiN7`Ol0003o
UhS201;oUhS200?o0000oiN9`_nGRL802onGRL800ol0003oUhW2oiN9`P03oiN9`P03o`000?oooooo
oooo00?ooooo1ol00007o`T00003o`000?o1g^ko000000ooY:GF00Go0000ooooooooooooooooo`00
0009ooooo`Go00007oooool001cooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000
ooooooooool0??ooool3o`0000[oXIS;00?o0000oinBa_nOT/H03onOT/H00ol0003oWXg2oij=`P0?
oij=`P03o`000?nLRKkoW8Vn00ooW8Vn00?o0000oi^5^onKQK/03onKQK/00ol0003oVX:hoiZ2^005
oiZ2^0Co00002?nGR<800ol0003oUhO1oiN7`@09oiN7`@?o00000onGQl400ol0003oUhS2oiN8`P0A
oiN8`P03o`000?nGRL;oUhW200coUhW200?o0000oiN9`_nGRL800_nGRL800ol0003oooooooooo`02
ooooo`Oo00002?l900000ol0003o`Mk^o`00000@ojBUeP05o`000?ooooooooooooooool000002?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A401oooooo000Looooo`03o`000?oooooooooo00Cooooo0_l0
000:ooooo`03o`000?oooooooooo03Sooooo0ol0000>oj6Hb`03o`000?nOT/KoWi;600ooWi;600?o
0000oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0>oib9_P03o`000?nKQK_oVhFk013oVhFk00?o
0000oiZ2^?l000001?l0000<oiN8`P03o`000?nGQl7oUhO100KoUhO10ol00007oiN7`@03o`000?nG
R<;oUhS2013oUhS200?o0000oiN9`_nGRL803?nGRL800ol0003oUhW2oiN9`P03oiN9`P03o`000?oo
oooooooo00Oo00002?l900001Ol0003o`Mk^ol7Nk_o1g^ko000000ooY:GF00Go0000oooooooooooo
ooooo`000009ooooo`03oiRHV?lQ8B7ok^k^023ooooo000Jooooo`03oeEEEOmVIVKo000000Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`;o00004OnQV</00ol0003oWi;6
oinBaP0?oinBaP03o`000?nNSL;oWXg200ooWXg200?o0000oib9__nLRKh03_nLRKh00ol0003oVhFk
oi^5^`0>oi^5^`Co00004OnGR<800ol0003oUhO1oiN7`@03oiN7`@?o00002_nGQl400ol0003oUhS2
oiN8`P0AoiN8`P03o`000?nGRL;oUhW200coUhW200?o0000oiN9`_nGRL800_nGRL89o`0000Wo2@00
00Go0000ol7Nk_o1g^ko`Mk^o`00000?ojBUeP03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00onHV9So8B4Qonk^kP0Oooooo`008oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo037ooooo0ol000000onRW]3o0000oj6Hb`0Aoj6Hb`03o`000?nOT/KoWi;600ooWi;6
00?o0000oij=`_nNSL803_nNSL800ol0003oW8Vnoib9_P0?oib9_P03o`000?nKQK_oVhFk00[oVhFk
0ol00002oiN9``03o`000?nGR<;oUhS2017oUhS200?o0000oiN7`Ol000000_l0000=oiN7`@03o`00
0?nGR<;oUhS2017oUhS200?o0000oiN9`_nGRL803OnGRL801?l0003oUhW2oiN9`_nGRL88o`0000[o
2@0000Go0000ol7Nk_o1g^ko`Mk^o`00000@ojBUeP03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00omgMgOoIVIVooooo`0Nooooo`008oooool2o`0000gooooo00?o0000oooooooo
ool0;_ooool2o`0000GoXYk@00?o0000oj6HbonQV</03onQV</00ol0003oWi;6oinBaP0?oinBaP03
o`000?nNSL;oWXg200ooWXg200?o0000oib9__nLRKh03_nLRKh00ol0003oVhFkoi^5^`06oi^5^`Co
00001_nGRL<00ol0003oUhS2oiN8`P0?oiN8`P?o00004OnGQl400ol0003oUhS2oiN8`P0AoiN8`P03
o`000?nGRL;oUhW200goUhW200Co0000oiN9`_nGRL;oUhW21_l0000:o`T00003o`000?o1g^ko`Mk^
00?o`Mk^00?o0000ojBUe_nTYMH03OnTYMH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool002?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Zooooo`?o00001onRW]000ol0003oXIS;oj6Hb`0?oj6Hb`03o`000?nOT/KoWi;600oo
Wi;600?o0000oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0>oib9_P03o`000?nKQK_oVhFk00?o
VhFk0ol0000:oiN9``03o`000?nGR<;oUhS200coUhS20ol000000onGR<;o0000oiN7`@0AoiN7`@03
o`000?nGR<;oUhS2017oUhS200?o0000oiN9`_nGRL803OnGRL801?l0003oUhW2oiN9`_nGRL86o`00
00Wo2@000_l00005ol7NkP03o`000?nTYMKoY:GF00goY:GF00?o0000ooooooooool00oooool2o`00
00Cooooo00Go0000okZj^_ooooooV9RHoa0@400Oooooo`008oooool00ol0003oooooooooo`0>oooo
o`;o0000:?ooool2o`0000_oXYk@00?o0000oj6HbonQV</03onQV</00ol0003oWi;6oinBaP0?oinB
aP03o`000?nNSL;oWXg200koWXg200?o0000oib9__nLRKh03onLRKh00ol0003oVhFko`000002o`00
00goUhW300?o0000oiN8`_nGR<802OnGR<83o`0000GoUhS200?o0000oiN7`OnGQl403onGQl400ol0
003oUhS2oiN8`P0AoiN8`P03o`000?nGRL;oUhW200koUhW200?o0000oiN9`_nGRL801Ol00009o`T0
00?o00001_o1g^h00ol0003oY:GFojBUeP0=ojBUeP07o`000?ooooooooooooooool0003oooooo`00
0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`07oooool002?ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Rooooo`?o00003OnRW]000ol0003oXIS;oj6Hb`0?oj6Hb`03o`000?nO
T/KoWi;600ooWi;600?o0000oij=`_nNSL803onNSL800ol0003oW8Vnoib9_P0<oib9_PCo00004OnG
RL<00ol0003oUhS2oiN8`P05oiN8`P?o00002?nGR<800ol0003oUhO1oiN7`@0@oiN7`@03o`000?nG
R<;oUhS2017oUhS200?o0000oiN9`_nGRL803_nGRL800ol0003oUhW2oiN9`P04o`0000So2@000ol0
0007ol7NkP03o`000?nTYMKoY:GF00goY:GF00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Vooooo`008_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo0ol0000@
oj:Nd003o`000?nQV<_oXIS;013oXIS;00?o0000oinBa_nOT/H03_nOT/H00ol0003oWXg2oij=`P0?
oij=`P03o`000?nLRKkoW8Vn00SoW8Vn1?l00002oiN;a@03o`000?nGRL?oUhW3013oUhW300?o0000
oiN8`_nGR<800_nGR<83o`0000_oUhS200?o0000oiN7`OnGQl404?nGQl400ol0003oUhS2oiN8`P0A
oiN8`P03o`000?nGRL;oUhW200ooUhW200?o0000oiN9`_l000000_l00007o`T0013o00003?nTYMH0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo000Rooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06_ooool3o`0000;oY:GF00?o0000oj:Nd?nRW]003onRW]000ol0
003oXIS;oj6Hb`0?oj6Hb`03o`000?nOT/KoWi;600ooWi;600?o0000oij=`_nNSL803_nNSL800ol0
003oW8Vnoib9_P04oib9_PCo00001onGRlD00ol0003oUhW3oiN9``0@oiN9``04o`000?nGR<;o0000
o`0000ooUhS200?o0000oiN7`OnGQl404?nGQl400ol0003oUhS2oiN8`P0AoiN8`P03o`000?nGRL;o
UhW200koUhW200?o0000oiN9`_l000000_l00006o`T000Go00002OnASL`00ol0003oPG>joh5c^P04
o`0000WoY:GF00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`008_ooool3o`00
01Cooooo00?o0000ooooooooool05_ooool3o`0000KoY:GF00?o0000oj:Nd?nRW]003_nRW]000ol0
003oXIS;oj6Hb`0@oj6Hb`03o`000?nOT/KoWi;600koWi;600?o0000oij=`_nNSL803onNSL800ol0
003oW8Vno`000003o`0000_oUh_500?o0000oiN9`onGRL<03onGRL<3o`00017oUhS200?o0000oiN7
`OnGQl404?nGQl400ol0003oUhS2oiN8`P0AoiN8`P03o`000?nGRL;oUhW200ooUhW21?l00005o`T0
00Ko00002OnASL`00ol0003oPG>joh5c^P04oh5c^PGo00001?nTYMH00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Cooooo000Rooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool04_ooool3o`0000WoY:GF00?o0000oj:Nd?nRW]003onRW]000ol0003oXIS;oj6Hb`0?oj6Hb`03
o`000?nOT/KoWi;600koWi;600?o0000oij=`_nNSL803OnNSL84o`0000ooUh_500?o0000oiN9`onG
RL<03?nGRL<3o`000003oiN9`ol0003oUhS2017oUhS200?o0000oiN7`OnGQl404?nGQl400ol0003o
UhS2oiN8`P0AoiN8`P03o`000?nGRL;oUhW200coUhW20ol000001OnMbOOo0000oig9monMbOOo0000
00;o2@001ol0000;oi6=c003o`000?n1Lk[oPG>j00SoPG>j1Ol00007ooooo`03o`000?oooooooooo
02?ooooo000Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool3o`0000go
Y:GF00?o0000oj:Nd?nRW]003_nRW]000ol0003oXIS;oj6Hb`0?oj6Hb`03o`000?nOT/KoWi;600oo
Wi;600?o0000oij=`_nNSL802?nNSL84o`0000;oUhg700?o0000oiN;aOnGRlD03onGRlD00ol0003o
UhW3oiN9``08oiN9``?o00001OnGRL<00ol0003oUhS2oiN8`P0@oiN8`P03o`000?nGQl7oUhO1013o
UhO100?o0000oiN8`_nGR<804OnGR<800ol0003oUhW2oiN9`P07oiN9`PCo00001OnMbOL00ol0003o
WLWgoig9m`08o`0000coTHg<00?o0000oh5c^_n1LkX03?n1LkX2o`0000Oooooo00?o0000oooooooo
ool08_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:oooo
o`?o00004?nTYMH00ol0003oXYk@oj:Nd00?oj:Nd003o`000?nQV<_oXIS;00ooXIS;00?o0000oinB
a_nOT/H03_nOT/H00ol0003oWXg2oij=`P04oij=`PCo00001onGSLL00ol0003oUh_5oiN;a@0>oiN;
a@03o`000?nGRL?oUhW300GoUhW30ol00008oiN9``03o`000?nGR<;oUhS2013oUhS200?o0000oiN7
`OnGQl404?nGQl400ol0003oUhS2oiN8`P0AoiN8`P03o`000?nGRL;oUhW200?oUhW21?l00009oig9
m`04o`000?nMbOOoWLWgoig9m`Oo00003?nASL`00ol0003oPG>joh5c^P0=oh5c^P03o`000?oooooo
oooo00Gooooo0_l0000Sooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Jooooo`03o`000?oooooooooo00Kooooo0ol00000
0onU[Mgo0000ojBUeP0AojBUeP03o`000?nRW]3oXYk@00koXYk@00?o0000oj6HbonQV</03onQV</0
0ol0003oWi;6oinBaP0>oinBaP03o`000?nNSL;oWXg200Co00002onGSLL00ol0003oUh_5oiN;a@0?
oiN;a@04o`000?nGRL?oUhW3oiN9``?o00002onGRL<00ol0003oUhS2oiN8`P0@oiN8`P03o`000?nG
Ql7oUhO1017oUhO100?o0000oiN8`_nGR<804?nGR<800ol0003oUhW2oiN9`P03o`0000koWLWg00?o
0000oig9monMbOL00_nMbOL4o`0000koTHg<00?o0000oh5c^_n1LkX03?n1LkX00ol0003ooooooooo
o`05ooooo`;o00008oooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo0_l0
0005ojF]g@03o`000?nTYMKoY:GF00ooY:GF00?o0000oj:Nd?nRW]003onRW]000ol0003oXIS;oj6H
b`0?oj6Hb`03o`000?nOT/KoWi;600_oWi;61Ol0000?oiN=a`03o`000?nGRlGoUh_500ooUh_51?l0
000?oiN9``03o`000?nGR<;oUhS2013oUhS200?o0000oiN7`OnGQl404?nGQl400ol0003oUhS2oiN8
`P0?oiN8`PCo00004_nMbOL00ol0003oWLWgoig9m`02oig9m`?o00003_nASL`00ol0003oPG>joh5c
^P0=oh5c^P03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool000Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`02o`0000SoYJgM00?o0000ojBUe_nTYMH03onTYMH00ol0003oXYk@oj:N
d00>oj:Nd003o`000?nQV<_oXIS;00ooXIS;00?o0000oinBa_nOT/H01_nOT/H5o`0000?oV97;00?o
0000oiN=aonGSLL03onGSLL00ol0003oUh_5oiN;a@0<oiN;a@Co00004OnGRL<00ol0003oUhS2oiN8
`P0@oiN8`P03o`000?nGQl7oUhO1013oUhO100?o0000oiN8`_nGR<803?nGR<83o`0000;oWKO[00?o
0000oig9monMbOL04OnMbOL00ol0003oWLWgoig9m`02oig9m`?o00003_nASL`00ol0003oPG>joh5c
^P0=oh5c^P03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool000Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0Kooooo`?o00002_nU[Md00ol0003oY:GFojBUeP0?ojBUeP03o`000?nRW]3oXYk@00ooXYk@
00?o0000oj6HbonQV</03_nQV</01?l0003oWi;6oinBa_nOT/H5o`0000WoV97;00?o0000oiN=aonG
SLL03_nGSLL00ol0003oUh_5oiN;a@09oiN;a@?o00000onGRlD00ol0003oUhW3oiN9``0@oiN9``03
o`000?nGR<;oUhS200ooUhS200?o0000oiN7`OnGQl404OnGQl400ol0003oUhS2oiN8`P07oiN8`PCo
00001_nM]n/00ol0003oWLWgoig9m`0Aoig9m`04o`000?nMbOOo0000o`0000;o/<7V00?o0000oi6=
c?nASL`03OnASL`00ol0003oPG>joh5c^P0<oh5c^P03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool07oooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Kooooo0_l0000Jooooo`;o00003_nU[Md00ol0003oY:GFojBUeP0?ojBUeP03o`000?nRW]3oXYk@
00koXYk@00?o0000oj6HbonQV</03OnQV</5o`0000koV97;00?o0000oiN=aonGSLL03onGSLL00ol0
003oUh_5oiN;a@05oiN;a@?o00001_nGRlD00ol0003oUhW3oiN9``0@oiN9``03o`000?nGR<;oUhS2
013oUhS200?o0000oiN7`OnGQl404?nGQl400ol0003oUhS2oiN8`P03oiN8`PCo00002onM]n/00ol0
003oWLWgoig9m`0?oig9m`?o00001On``NH00ol0003oTHg<oi6=c00<oi6=c003o`000?n1Lk[oPG>j
00goPG>j00?o0000ooooooooool01oooool00ol0003oooooooooo`0Nooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool2o`0001Wooooo0_l0000@ojF]
g@03o`000?nTYMKoY:GF00ooY:GF00?o0000oj:Nd?nRW]003_nRW]000ol0003oXIS;oj6Hb`09oj6H
b`Co00000_nHULl00ol0003oV97;oiRAb`0>oiRAb`03o`000?nGSLOoUhg700ooUhg700?o0000oiN;
aOnGRlD00onGRlD2o`0000[oUh_500?o0000oiN9`onGRL<03onGRL<00ol0003oUhS2oiN8`P0@oiN8
`P03o`000?nGQl7oUhO1013oUhO100?o0000oiN8`_nGR<800ol0000@oifgj`03o`000?nMbOOoWLWg
00coWLWg0_l00003ok31iP03o`000?n``NKo/<7V00;o/<7V00?o0000oi6=c?nASL`03?nASL`00ol0
003oPG>joh5c^P0=oh5c^P03o`000?oooooooooo00Oooooo00?o0000ooooooooool07_ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool00ol0003oooooooooo`0Eoooo
o`?o000000?oYkKTo`000?nU[Md04?nU[Md00ol0003oY:GFojBUeP0?ojBUeP03o`000?nRW]3oXYk@
00koXYk@00?o0000oj6HbonQV</01?nQV</4o`0000OoV9G?00?o0000oiRAbonHTL/03_nHTL/00ol0
003oUhg7oiN=a`0>oiN=a`03o`000?nGRlGoUh_500?o00003?nGRlD00ol0003oUhW3oiN9``0@oiN9
``03o`000?nGR<;oUhS200ooUhS200?o0000oiN7`OnGQl403onGQl44o`0001CoWKO[00?o0000oig9
monMbOL02OnMbOL2o`0000Go/<7V00?o0000ok31i_n``NH00_n``NH00ol0003oTHg<oi6=c00=oi6=
c003o`000?n1Lk[oPG>j00coPG>j00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Moooo
o`008?ooool00ol0003oooooooooo`0Booooo`?o00001OnW]^@00ol0003oYJgMojF]g@0?ojF]g@03
o`000?nTYMKoY:GF00koY:GF00?o0000oj:Nd?nRW]003_nRW]000ol0003oXIS;oj6Hb`04o`0000_o
V9G?00?o0000oiRAbonHTL/03_nHTL/00ol0003oUhg7oiN=a`0>oiN=a`?o00004?nGRlD00ol0003o
UhW3oiN9``0?oiN9``03o`000?nGR<;oUhS2013oUhS200?o0000oiN7`OnGQl402OnGQl45o`0000;o
VjWQ00?o0000oifgjonM]n/05?nM]n/00ol0003oWLWgoig9m`06oig9m`;o00002?n``NH00ol0003o
/<7Vok31iP02ok31iP03o`000?nASLcoTHg<00coTHg<00?o0000oh5c^_n1LkX03?n1LkX00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01cooooo000Pooooo`;o00004?ooool3o`0000WoYkKT
00?o0000ojF]gOnU[Md03_nU[Md00ol0003oY:GFojBUeP0?ojBUeP03o`000?nRW]3oXYk@00coXYk@
1?l0000@oiREc`03o`000?nHTL_oV97;00koV97;00?o0000oiN=aonGSLL02_nGSLL3o`000003oiN=
aol0003oUh_5013oUh_500?o0000oiN9`onGRL<04?nGRL<00ol0003oUhS2oiN8`P0?oiN8`P03o`00
0?nGQl7oUhO100GoUhO11?l00008oi^Yh@03o`000?nM]n_oWKO[01CoWKO[00?o0000oig9monMbOL0
0_nMbOL3o`0000_o/<7V00Go0000ok31i_n``NKo/<7Vo`00000>oi6=c003o`000?n1Lk[oPG>j00go
PG>j00?o0000ooooooooool01oooool3o`0001gooooo000Pooooo`03o`000?oooooooooo00cooooo
0ol0000=ojNfi003o`000?nU[MgoYJgM00koYJgM00?o0000ojBUe_nTYMH03_nTYMH00ol0003oXYk@
oj:Nd008oj:Nd0Co00000_nIV]@00ol0003oV9G?oiREc`0?oiREc`03o`000?nHTL_oV97;00koV97;
00?o0000oiN=aonGSLL01onGSLL3o`0000GoUhg700?o0000oiN;aOnGRlD03_nGRlD00ol0003oUhW3
oiN9``0@oiN9``03o`000?nGR<;oUhS200ooUhS200?o0000oiN7`OnGQl401Ol0000=oi^Yh@03o`00
0?nM]n_oWKO[01CoWKO[00Co0000oig9mol0003o00000oo>n>P00ol0003o/<7Vok31iP09ok31iP05
o`000?n``NKo/<7Vok31i_l000003OnASL`00ol0003oPG>joh5c^P0=oh5c^P03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06oooool0023ooooo00?o0000ooooooooool02Oooool3o`00013o
YkKT00?o0000ojF]gOnU[Md03onU[Md00ol0003oY:GFojBUeP0>ojBUeP03o`000?nRW]3oXYk@00Co
XYk@0ol00007oiVJe003o`000?nHULooV9G?00koV9G?00?o0000oiRAbonHTL/03_nHTL/00ol0003o
Uhg7oiN=a`04oiN=a`?o00002?nGSLL00ol0003oUh_5oiN;a@0?oiN;a@03o`000?nGRL?oUhW300oo
UhW300?o0000oiN8`_nGR<803_nGR<84o`0001;oVjWQ00?o0000oifgjonM]n/05?nM]n/2o`0000Co
c_SX1ol00006ok31iP05o`000?n``NKo/<7Vok31i_l000003_nASL`00ol0003oPG>joh5c^P0<oh5c
^P03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool0023ooooo0_l00007ooooo`?o
000000?oYl3[o`000?nW]^@04OnW]^@00ol0003oYJgMojF]g@0>ojF]g@03o`000?nTYMKoY:GF00ko
Y:GF00?o0000oj:Nd?nRW]001?l0000:oiVJe003o`000?nHULooV9G?00ooV9G?00?o0000oiRAbonH
TL/03_nHTL/00ol0003oUhg7oiN=a`03o`0000_oUhg700?o0000oiN;aOnGRlD03onGRlD00ol0003o
UhW3oiN9``0@oiN9``03o`000?nGR<;oUhS200WoUhS21?l00002oiVPf@03o`000?nKZN7oVjWQ01;o
VjWQ00?o0000oifgjonM]n/04OnM]n/2o`0000;oc_SX1?l00002ojFdi003o`000?n3PLWoPh7900;o
Ph792?l00002ok31iP03o`000?nASLcoTHg<00coTHg<00?o0000oh5c^_n1LkX03?n1LkX00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo000Oooooo`03o`000?oooooooooo00Gooooo
0_l00005ojO0j`03o`000?nW]^CoYkKT013oYkKT00?o0000ojF]gOnU[Md03_nU[Md00ol0003oY:GF
ojBUeP0<ojBUePCo00003onIV]@00ol0003oV9G?oiREc`0>oiREc`03o`000?nHTL_oV97;00koV97;
0ol0000?oiN=a`03o`000?nGRlGoUh_500ooUh_500?o0000oiN9`onGRL<03onGRL<00ol0003oUhS2
oiN8`P04oiN8`PGo00001onIX=T00ol0003oVjWQoi^Yh@0Boi^Yh@03o`000?nM]n_oWKO[00goWKO[
0ol000001?o>n>So0000o`000?l00007ojFdi003o`000?n3PLWoPh7900WoPh791Ol0000<oi6=c003
o`000?n1Lk[oPG>j00goPG>j00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`00
7oooool00ol0003oooooooooo`03ooooo`;o00002?nW`>/00ol0003oYkKTojNfi00?ojNfi003o`00
0?nU[MgoYJgM00koYJgM00?o0000ojBUe_nTYMH01onTYMH5o`0000;oVJ7J00?o0000oiVJe?nIV]@0
3_nIV]@00ol0003oV9G?oiREc`0?oiREc`03o`000?nHTL_oV97;00[oV97;0ol000000onHTL_o0000
oiN=a`0?oiN=a`03o`000?nGRlGoUh_500ooUh_500?o0000oiN9`onGRL<03onGRL<00ol0003oUhS2
oiN8`P04o`0000goVJ3I00?o0000oi^YhOnKZN404OnKZN400ol0003oWKO[oifgj`0;oifgj`Ko0000
2_nU]>@00ol0003oPh79oh>1b@0:oh>1b@04o`000?n3PLWo0000ogAZ^@;o00002onASL`00ol0003o
PG>joh5c^P0<oh5c^P03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool001oooooo
00?o0000ooooooooool00ol0000;ojO0j`03o`000?nW]^CoYkKT00ooYkKT00?o0000ojF]gOnU[Md0
3_nU[Md01?l0003oY:GFojBUe_nTYMH5o`0000SoVJ7J00?o0000oiVJe?nIV]@03_nIV]@00ol0003o
V9G?oiREc`0>oiREc`03o`000?nHTL_oV97;00OoV97;0ol00004oiRAb`03o`000?nGSLOoUhg700ko
Uhg700?o0000oiN;aOnGRlD04?nGRlD00ol0003oUhW3oiN9``0<oiN9``Go00004OnIX=T00ol0003o
VjWQoi^Yh@0Boi^Yh@03o`000?nM]n_oWKO[00SoWKO[1?l0000?ojFdi003o`000?n3PLWoPh7900Wo
Ph7900?o0000oh>1bOl000000omdJ[T2o`0000WoTHg<00?o0000oh5c^_n1LkX03?n1LkX00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo000Oooooo`?o00003onW`>/00ol0003oYkKT
ojNfi00?ojNfi003o`000?nU[MgoYJgM00coYJgM1Ol0000=oiVQfP03o`000?nIV]CoVI[D00koVI[D
00?o0000oiREconHULl03onHULl00ol0003oV97;oiRAb`03oiRAb`?o00002?nHTL/00ol0003oUhg7
oiN=a`0>oiN=a`03o`000?nGRlGoUh_500ooUh_500?o0000oiN9`onGRL<01_nGRL<6o`0000?oUY[E
00?o0000oiVPfOnIX=T04OnIX=T00ol0003oVjWQoi^Yh@0Boi^Yh@03o`000?nM]n_oWKO[00GoWKO[
0_l000000omOe;oo0000o`00000@ojFdi003o`000?n3PLWoPh7900[oPh7900?o0000oh>1bOl00000
1?mdJ[T2o`0000OoTHg<00?o0000oh5c^_n1LkX03On1LkX00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Oooooo000Oooooo`;o00004OnW`>/00ol0003oYkKTojNfi00?ojNfi003o`000?nU
[MgoYJgM00SoYJgM0ol00002oiVXh@03o`000?nIXM[oVJ7J00koVJ7J00?o0000oiVJe?nIV]@03_nI
V]@00ol0003oV9G?oiREc`0>oiREc`04o`000?nHTL_oV97;oiRAb`;o00002onHTL/00ol0003oUhg7
oiN=a`0>oiN=a`03o`000?nGRlGoUh_500ooUh_500Co0000oiN9`onGRL?oUhW31Ol0000:oiJJe@03
o`000?nIX=WoVJ3I013oVJ3I00?o0000oi^YhOnKZN404_nKZN400ol0003oWKO[oifgj`02oifgj`Ko
00000_o?lNT00ol0003oYKCTojFdi00=ojFdi003o`000?n3PLWoPh7900_oPh790_l00006ogAZ^@?o
00001OnASL`00ol0003oPG>joh5c^P0<oh5c^P03o`000?oooooooooo00_ooooo0_l0000Hooooo`00
5?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooool000004OnW`>/00ol0003o
YkKTojNfi00>ojNfi003o`000?nU[MgoYJgM00CoYJgM1?l00006oiVXh@03o`000?nIXM[oVJ7J00ko
VJ7J00?o0000oiVJe?nIV]@03OnIV]@00ol0003oV9G?oiREc`0>oiREc`Co00003OnHTL/00ol0003o
Uhg7oiN=a`0?oiN=a`03o`000?nGRlGoUh_500coUh_51_l0000?oiJJe@03o`000?nIX=WoVJ3I017o
VJ3I00?o0000oi^YhOnKZN404_nKZN400ol0003oWKO[o`000005o`0000Goco7Y00?o0000ojFdi?nU
]>@03OnU]>@00ol0003oPh79oh>1b@0;oh>1b@03o`000?mdJ[WoM6Zi00OoM6Zi0_l00003oi6=c003
o`000?n1Lk[oPG>j00coPG>j00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`00
5?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00Go0000ooooooooooooooooo`00000AojO0
j`03o`000?nW]^CoYkKT00koYkKT00?o0000ojF]gOnU[Md00ol0000;oiVXh@03o`000?nIXM[oVJ7J
00goVJ7J00?o0000oiVJe?nIV]@03_nIV]@00ol0003oV9G?oiREc`0;oiREc`Co00004?nHTL/00ol0
003oUhg7oiN=a`0>oiN=a`03o`000?nGRlGoUh_500KoUh_51_l00003oiBFdP03o`000?nFV]GoUY[E
013oUY[E00?o0000oiVPfOnIX=T04OnIX=T00ol0003oVjWQoi^Yh@0Aoi^Yh@?o00000_n@j_H2o`00
00Koco7Y00?o0000ojFdi?nU]>@03OnU]>@00ol0003oPh79oh>1b@0;oh>1b@;o00002_mdJ[T2o`00
0003oi6=c?l0003oPG>j00goPG>j00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eoooo
o`005?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00003ooooo`03o`000?nW`>_oYl3[
00ooYl3[00?o0000ojNfi?nW]^@03?nW]^@4o`0000koVJSQ00?o0000oiVQf_nIXMX03_nIXMX00ol0
003oVI[DoiVJe00>oiVJe003o`000?nHULooV9G?00OoV9G?0ol00003oiREc`03o`000?nHTL_oV97;
00koV97;00?o0000oiN=aonGSLL03_nGSLL01?l0003oUh_5oiN;aOnGRlD5o`0000[oU9KB00?o0000
oiJJeOnFV]D03onFV]D00ol0003oVJ3IoiVPf@0AoiVPf@03o`000?nKZN7oVjWQ00koVjWQ0ol00004
oi3ZmP03o`000?o?lNWoco7Y00Ooco7Y00?o0000ojFdi?nU]>@03OnU]>@00ol0003oPh79oh>1b@0;
oh>1b@03o`000?mdJ[WoM6Zi00[oM6Zi0ol0000>oh5c^P03o`000?oooooooooo00cooooo00?o0000
ooooooooool05Oooool001Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo0_l0000@ojO0j`03o`000?nW]^CoYkKT00KoYkKT1Ol00002oiVaj003o`000?nIZ>7o
VJSQ00koVJSQ00?o0000oiVQf_nIXMX03OnIXMX00ol0003oVI[DoiVJe00>oiVJe003o`000?nHULoo
V9G?00CoV9G?0ol00007oiREc`03o`000?nHTL_oV97;00koV97;00?o0000oiN=aonGSLL02onGSLL6
o`0000ooU9KB00?o0000oiJJeOnFV]D04?nFV]D00ol0003oVJ3IoiVPf@0AoiVPf@03o`000?nKZN7o
VjWQ00_oVjWQ0_l00005oi3ZmP;o00002oo?lNT00ol0003oYKCTojFdi00<ojFdi003o`000?n3PLWo
Ph7900_oPh790_l0000=ogAZ^@;o00003On1LkX00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Cooooo000Dooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05
ooooo`03o`000?nW`>_oYl3[00koYl3[00?o0000ojNfi?nW]^@01Ol00008oiVaj003o`000?nIZ>7o
VJSQ00koVJSQ00?o0000oiVQf_nIXMX03OnIXMX00ol0003oVI[DoiVJe00>oiVJe003o`000?nHULoo
V9G?00?o00002_nHULl00ol0003oV97;oiRAb`0>oiRAb`03o`000?nGSLOoUhg700KoUhg71Ol00003
oi>Cd@03o`000?nDU];oU9KB013oU9KB00?o0000oiJJeOnFV]D03onFV]D00ol0003oVJ3IoiVPf@0A
oiVPf@03o`000?nKZN7oVjWQ00SoVjWQ0ol00005oi3ZmP?o00003Oo?lNT00ol0003oYKCTojFdi00<
ojFdi003o`000?n3PLWoPh7900_oPh7900?o0000ogAZ^OmdJ[T02omdJ[T00ol0003oL6:bo`00000<
oh5c^P03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool001Cooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?o0000ojO0jonW`>/03?nW`>/4
o`0000koVK7X00?o0000oiVXhOnIZ>403OnIZ>400ol0003oVJ7JoiVQfP0>oiVQfP03o`000?nIV]Co
VI[D00goVI[D0ol0000>oiREc`03o`000?nHTL_oV97;00goV97;00Co0000oiN=aonGSLOoUhg71Ol0
0009oi>Cd@03o`000?nDU];oU9KB00ooU9KB00?o0000oiJJeOnFV]D04?nFV]D00ol0003oVJ3IoiVP
f@0AoiVPf@03o`000?nKZN7oVjWQ00GoVjWQ0_l00007oi3ZmP;o00003oo?lNT00ol0003oYKCTojFd
i00<ojFdi003o`000?n3PLWoPh7900_oPh790_l0000<ogAZ^@03o`000?m`H[;oL6:b00;o00002_n1
LkX00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo000Dooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool3o`0000Sooooo00?o0000ojO0jonW`>/01_nW`>/5o`0000;oUk_a00?o
0000oiVaj?nI/NP03_nI/NP00ol0003oVJSQoiVXh@0=oiVXh@03o`000?nIXM[oVJ7J00goVJ7J00?o
0000oiVJe?nIV]@02_nIV]@3o`000003oiVJe?l0003oV9G?00koV9G?00?o0000oiRAbonHTL/02_nH
TL/7o`0000koTi?A00?o0000oiBFd_nDU]804?nDU]800ol0003oUY[EoiJJe@0@oiJJe@03o`000?nI
X=WoVJ3I017oVJ3I00?o0000oi^YhOnKZN400_nKZN42o`0000OoT>[f0ol0000Aoloaj@03o`000?nU
]>CoYKCT00coYKCT00?o0000oh>1bOn3PLT02_n3PLT00ol0003oM6Zio`00000<ogAZ^@04o`000?m`
H[;oL6:bog1R/P;o00002On1LkX00ol0003oooooooooo`0>ooooo`;o00004oooool001Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Wooooo00?o0000ojO0jonW`>/0
1Ol00008oiNkl@03o`000?nI/NSoVK7X00goVK7X00?o0000oiVXhOnIZ>403_nIZ>400ol0003oVJ7J
oiVQfP0=oiVQfP03o`000?nIV]CoVI[D00KoVI[D0ol00004oiVJe003o`000?nHULooV9G?00goV9G?
00?o0000oiRAbonHTL/00_nHTL/8o`0000CoTI?B00?o0000oi>CdOnCTm403onCTm400ol0003oU9KB
oiBFdP0?oiBFdP03o`000?nFV]GoUY[E013oUY[E00?o0000oiVPfOnIX=T04OnIX=T00ol0003oVjWQ
o`000002o`0000SoT>[f00?o0000olWm_Ol000004Oo?lNT5o`0000_oYKCT00?o0000oh>1bOn3PLT0
2_n3PLT01?l0003oM6ZiogAZ^Ol0000;ogAZ^@03o`000?m`H[;oL6:b00?oL6:b00?o0000oh5c^_n1
LkX01_n1LkX00ol0003oooooooooo`0>ooooo`;o00004oooool001gooooo00?o0000ooooooooool0
2_ooool2o`0000koUk_a00?o0000oiVaj?nI/NP03OnI/NP00ol0003oVJSQoiVXh@0=oiVXh@03o`00
0?nIXM[oVJ7J00goVJ7J00?o0000oiVJe?nIV]@00onIV]@3o`0000SoVI[D00?o0000oiREconHULl0
2OnHULl8o`0000goTI?B00?o0000oi>CdOnCTm403_nCTm400ol0003oU9KBoiBFdP0@oiBFdP03o`00
0?nFV]GoUY[E013oUY[E00?o0000oiVPfOnIX=T04?nIX=T4o`0000OoT>[f1_l0000;oloaj@Go0000
0_nQ]^L00ol0003oMgc;ogMlb`04o`0000OoYKCT00?o0000oh>1bOn3PLT02on3PLT00ol0003oM6Zi
o`00000;ogAZ^@03o`000?m`H[;oL6:b00CoL6:b0_l00006oh5c^P03o`000?oooooooooo00oooooo
00?o0000ooooooooool01oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo000Mooooo`03o`00
0?oooooooooo00_ooooo00?o0000oiNklOnG^o403OnG^o400ol0003oVK7XoiVaj00=oiVaj003o`00
0?nIZ>7oVJSQ00goVJSQ00?o0000oiVQf_nIXMX03OnIXMX00ol0003oVI[DoiVJe002o`0000_oVI[D
00?o0000oiREconHULl00_nHULl7o`0000CoT9GD00?o0000oi6Cd_nATm803_nATm800ol0003oTi?A
oi>Cd@0?oi>Cd@03o`000?nDU];oU9KB00ooU9KB00?o0000oiJJeOnFV]D04?nFV]D00ol0003oVJ3I
oiVPf@0=oiVPf@?o00001?nOfO`4o`0000;oT>[f0ol000001?o;n:[o0000om_oa_oKolH3o`0000?o
co7Y1Ol00008oj6fi`03o`000?mgO<_oMgc;00?oMgc;1?l00004ojFdi003o`000?n3PLWoPh7900[o
Ph7900Co0000ogAZ^OmdJ[Wo00002omdJ[T00ol0003oL6:bog1R/P05og1R/P;o00001On1LkX00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00Go410@okZj^_ooooooMgMgoc8b<P05
ooooo`007Oooool2o`0000gooooo00?o0000oiNklOnG^o403OnG^o400ol0003oVK7XoiVaj00=oiVa
j003o`000?nIZ>7oVJSQ00goVJSQ00?o0000oiVQf_nIXMX03?nIXMX3o`0000[oVI[D2?l0000<oi2E
e003o`000?nATm;oTI?B00koTI?B00?o0000oi>CdOnCTm403_nCTm400ol0003oU9KBoiBFdP0@oiBF
dP03o`000?nFV]GoUY[E013oUY[E00?o0000oiVPfOnIX=T02OnIX=T3o`0000_oWmWl0_l00003ol_h
ZP03o`000?oKolKofoo600Cofoo60ol0000=oj6fi`03o`000?mgO<_oMgc;00OoMgc;1Ol0000<oh>1
b@05o`000?mdJ[WoM6ZiogAZ^Ol000002_mdJ[T00ol0003oL6:bog1R/P07og1R/P03o`000?n1Lk[o
PG>j00;oPG>j00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo000Mooooo`03o`000?oooooooooo00gooooo00?o0000oiNklOnG^o403OnG^o400ol0
003oVK7XoiVaj00=oiVaj003o`000?nIZ>7oVJSQ00coVJSQ00?o0000oiVQf_nIXMX02OnIXMX3o`00
0003oiVQf_l0003oVI[D00?oVI[D1ol00004ohnHf003o`000?n@UMCoT9GD00goT9GD00?o0000oi6C
d_nATm803_nATm800ol0003oTi?Aoi>Cd@0?oi>Cd@03o`000?nDU];oU9KB00ooU9KB00?o0000oiJJ
eOnFV]D04?nFV]D00ol0003oVJ3IoiVPf@06oiVPf@?o00003?nOfO`2o`0000CoboRZ00?o0000om_o
a_oKolH01?oKolH00ol0003oe??Uo`00000>oj6fi`03o`000?mgO<_oMgc;00_oMgc;0ol0000;oh>1
b@05o`000?mdJ[WoM6ZiogAZ^Ol000002OmdJ[T00ol0003oL6:bog1R/P08og1R/P;o00000_n1LkX0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?oZJVYoa0@4?ooool01?ooool0
01gooooo00?o0000ooooooooool03_ooool00ol0003oUk_aoiNkl@0=oiNkl@03o`000?nI/NSoVK7X
00coVK7X00?o0000oiVXhOnIZ>403OnIZ>400ol0003oVJ7JoiVQfP05oiVQfPco00003?n?V=P00ol0
003oT9GDoi2Ee00=oi2Ee003o`000?nATm;oTI?B00koTI?B00?o0000oi>CdOnCTm403_nCTm400ol0
003oU9KBoiBFdP0@oiBFdP03o`000?nFV]GoUY[E013oUY[E00?o0000oiVPfOnIX=T00_nIX=T3o`00
00koWmWl0ol00003ol_hZP03o`000?oKolKofoo600Cofoo600Go0000omCciOoDlnGoe??Uo`00000>
oj6fi`03o`000?mgO<_oMgc;00_oMgc;00?o0000ofQS^_l000002_n3PLT01Ol0003oM6ZiogAZ^Omd
J[Wo000000WoM6Zi00?o0000og1R/_m`H[802_m`H[83o`0001?ooooo00?o0000ooooooooool01_oo
ool00ol@413o0000okZj^P05ooooo`007?ooool3o`00013ooooo00?o0000oiNklOnG^o403OnG^o40
0ol0003oVK7XoiVaj00<oiVaj003o`000?nIZ>7oVJSQ00[oVJSQ2ol00007ohfLg@03o`000?n?V=So
SiSH00goSiSH00?o0000oi2Ee?n@UM@03On@UM@00ol0003oTI?Boi6CdP0>oi6CdP03o`000?nCTm7o
Ti?A00ooTi?A00?o0000oiBFd_nDU]803onDU]800ol0003oUY[EoiJJe@0@oiJJe@03o`000?nIX=Wo
000000;o00003onOfO`4o`0000?oboRZ00?o0000om_oa_oKolH01?oKolH00ol0003oe??UomCci@03
omCci@03o`000?nQ]^OoXKKW00_oXKKW00?o0000ogMlbomgO</02omgO</00ol0003oJ6>jofQS^P02
o`0000SoPh7900?o0000ogAZ^OmdJ[T00_mdJ[T00ol0003oM6ZiogAZ^@07ogAZ^@03o`000?m`H[;o
L6:b00_oL6:b0_l0000Cooooo`03o`000?oooooooooo00Kooooo00?o^[Zjob4Q8Oooool01?ooool0
01cooooo00?o0000ooooooooool04Oooool00ol0003oUk_aoiNkl@0=oiNkl@03o`000?nI/NSoVK7X
00coVK7X00?o0000oiVXhOnIZ>400_nIZ>47o`0000?oRj?T1?l0000<ohfLg@03o`000?n?V=SoSiSH
00goSiSH00?o0000oi2Ee?n@UM@03On@UM@00ol0003oTI?Boi6CdP0>oi6CdP03o`000?nCTm7oTi?A
00koTi?A00?o0000oiBFd_nDU]804?nDU]800ol0003oUY[EoiJJe@0>oiJJe@Co00003onOfO`2o`00
0003ogWQ__l0003o000000?oboRZ00?o0000om_oa_oKolH01?oKolH00ol0003oe??UomCci@04omCc
i@03o`000?nQ]^OoXKKW00coXKKW00?o0000ogMlbomgO</02omgO</01Ol0003oJ6>jofQS^_mXHk[o
000000OoPh7900?o0000ogAZ^OmdJ[T00omdJ[T00ol0003oM6ZiogAZ^@06ogAZ^@03o`000?m`H[;o
L6:b00coL6:b00?o0000ooooooooool04Oooool2o`0000Cooooo00Go410@oiRHV?oooooo^[Zjo`00
0005ooooo`007?ooool00ol0003oooooooooo`0Booooo`03o`000?nG^o7oUk_a00goUk_a00?o0000
oiVaj?nI/NP01OnI/NP;o`0000SoRj?T1?l0000>ohfLg@03o`000?n?V=SoSiSH00goSiSH00?o0000
oi2Ee?n@UM@03On@UM@00ol0003oTI?Boi6CdP0>oi6CdP03o`000?nCTm7oTi?A00koTi?A00?o0000
oiBFd_nDU]804?nDU]800ol0003oUY[EoiJJe@0:oiJJe@Co00001?nN`_400ol0003oWmWloioIo00;
oioIo003o`000?mihKkoNN6n00;o00000oo;n:X00ol0003ofoo6om_oaP04om_oaP03o`000?oDlnGo
e??U00Koe??U00?o0000oj6fionQ]^L02onQ]^L00ol0003oMgc;ogMlb`0;ogMlb`03o`000?mXHk[o
J6>j00;oJ6>j0_l00006oh>1b@03o`000?mdJ[WoM6Zi00?oM6Zi00?o0000ogAZ^OmdJ[T01OmdJ[T0
0ol0003oL6:bog1R/P0<og1R/P03o`000?oooooooooo013ooooo00?o0000ooooool000001?ooool0
1OnYZJWo410@o`000?l@413oZJVY00Gooooo000Looooo`03o`000?oooooooooo01?ooooo00?o0000
oiNklOnG^o402_nG^o4:o`0000OoQj_/00?o0000oh^Si?n;Xn@01_n;Xn@3o`0000CoRj?T00?o0000
ohfLgOn=W=d03?n=W=d00ol0003oSiSHohnHf00=ohnHf003o`000?n@UMCoT9GD00goT9GD00?o0000
oi6Cd_nATm803_nATm800ol0003oTi?Aoi>Cd@0>oi>Cd@03o`000?nDU];oU9KB013oU9KB00?o0000
oiJJeOnFV]D01?nFV]D5o`0000WoW/;a00?o0000oioIo?nOfO`02?nOfO`2o`0000;oNN6n0_l00003
ol_hZP03o`000?oKolKofoo600?ofoo60_l0000:omCci@03o`000?nQ]^OoXKKW00[oXKKW00?o0000
ogMlbomgO</02omgO</00ol0003oJ6>jofQS^P04ofQS^P03o`000?n3PLWoPh7900?oPh7900?o0000
ogAZ^OmdJ[T00omdJ[T00ol0003oM6ZiogAZ^@05ogAZ^@03o`000?m`H[;oL6:b00coL6:b00?o0000
ooooooooool04oooool00ol0003oooooooooo`0;ooooo`007?ooool3o`0001Cooooo00?o0000oiNk
lOnG^o400_nG^o47o`0000?oP[Ce00?o0000ohN[k?n7Zn`03?n7Zn`00ol0003oRj?Toh^Si002oh^S
i0?o00001on;Xn@00ol0003oSIcMohfLg@0=ohfLg@03o`000?n?V=SoSiSH00coSiSH00?o0000oi2E
e?n@UM@03On@UM@00ol0003oTI?Boi6CdP0>oi6CdP03o`000?nCTm7oTi?A00koTi?A00?o0000oiBF
d_nDU]804?nDU]800ol0003oUY[EoiJJe@04o`0000ooW/;a0_l00006oioIo0;o00000_mihKh3o`00
00CoboRZ00?o0000om_oa_oKolH00_oKolH00ol0003oe??UomCci@0:omCci@03o`000?nQ]^OoXKKW
00_oXKKW00?o0000ogMlbomgO</02omgO</00ol0003oJ6>jofQS^P04ofQS^P03o`000?n3PLWoPh79
00;oPh7900?o0000ogAZ^OmdJ[T01?mdJ[T00ol0003oM6ZiogAZ^@05ogAZ^@03o`000?m`H[;oL6:b
00coL6:b00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003o
ooooooooo`0Eooooo`Co00002on2]?D00ol0003oQj_/ohN[k00<ohN[k0Co00002on;Xn@00ol0003o
SIcMohfLg@0<ohfLg@03o`000?n?V=SoSiSH00goSiSH00?o0000oi2Ee?n@UM@03On@UM@00ol0003o
TI?Boi6CdP0=oi6CdP03o`000?nCTm7oTi?A00ooTi?A00?o0000oiBFd_nDU]803_nDU]84o`0001Go
W/;a00?o0000oioIo?nOfO`00_nOfO`00ol0003oNN6no`000003o`000003ok[bXol0003oboRZ00;o
boRZ00?o0000om_oa_oKolH00_oKolH00ol0003oe??UomCci@0<omCci@03o`000?nQ]^OoXKKW00[o
XKKW00?o0000ogMlbomgO</02omgO</00ol0003oJ6>jofQS^P05ofQS^P;o00000on3PLT00ol0003o
M6ZiogAZ^@04ogAZ^@03o`000?mdJ[WoM6Zi00CoM6Zi00?o0000og1R/_m`H[803?m`H[800ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^
kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0H
ooooo`03o`000?n2]?GoP[Ce00_oP[Ce00?o0000ohN[k?n7Zn`02_n7Zn`3o`0000koRj?T00?o0000
ohfLgOn=W=d03?n=W=d00ol0003oSiSHohnHf00<ohnHf003o`000?n@UMCoT9GD00goT9GD00?o0000
oi6Cd_nATm803_nATm800ol0003oTi?Aoi>Cd@0>oi>Cd@03o`000?nDU];oU9KB00[oU9KB1?l00002
oiZ`i`03o`000?nN`_7oW/;a01GoW/;a00?o0000oioIo?l000001Ol000000onbm[Wo0000o`000003
ol_hZP03o`000?oKolKofoo600;ofoo600?o0000omCciOoDlnD03OoDlnD3o`0000[oXKKW00?o0000
ogMlbomgO</02omgO</00ol0003oJ6>jofQS^P07ofQS^P04o`000?n3PLWoPh79o`0000KoM6Zi00?o
0000ogAZ^OmdJ[T01?mdJ[T00ol0003oL6:bog1R/P0<og1R/P03o`000?oooooooooo01;ooooo0ol0
000;ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000oh:dmOn2]?D02on2]?D00ol0003oQj_/
ohN[k006ohN[k0?o00000_n7Zn`00ol0003oRj?Toh^Si00<oh^Si003o`000?n=W=goSIcM00coSIcM
00?o0000ohnHf?n?V=P03On?V=P00ol0003oT9GDoi2Ee00<oi2Ee003o`000?nATm;oTI?B00koTI?B
00?o0000oi>CdOnCTm403onCTm400ol0003oU9KBoiBFdP04oiBFdPGo00001onJ/>L00ol0003oW/;a
oik2l@0Doik2l@?o00000_nRl_82o`000003ok;f^Ol0003o000000?oboRZ00?o0000om_oa_oKolH0
0_oKolH00ol0003oe??UomCci@0;omCci@?o000000?oZLG^o`000?m_OM400ol00008oj6fi`03o`00
0?mgO<_oMgc;00_oMgc;00?o0000ofQS^_mXHkX01omXHkX3o`0000OoM6Zi00?o0000ogAZ^OmdJ[T0
1?mdJ[T00ol0003oL6:bog1R/P0<og1R/P03o`000?oooooooooo00kooooo0ol00002ooooo`03o`00
0?oooooooooo00Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00?o
0000ooooooooool00_ooool2o`0001_ooooo00?o0000oh:dmOn2]?D02on2]?D00ol0003oQj_/ohN[
k002ohN[k0?o00001_n7Zn`00ol0003oRj?Toh^Si00<oh^Si003o`000?n=W=goSIcM00coSIcM00?o
0000ohnHf?n?V=P03?n?V=P00ol0003oT9GDoi2Ee00=oi2Ee003o`000?nATm;oTI?B00koTI?B00?o
0000oi>CdOnCTm403_nCTm400ol0003oU9KBoiBFdP04o`0000goV[3W00?o0000oik2lOnN`_404OnN
`_42o`0000CoX_;b0_l000000onbm[Wo0000o`000003ol_hZP03o`000?oKolKofoo600;ofoo600?o
0000omCciOoDlnD02OoDlnD3o`0000GoZLG^00Co0000ofmmdOm_OM7oKggA0_l00006oj6fi`03o`00
0?mgO<_oMgc;00_oMgc;00?o0000ofQS^_mXHkX02OmXHkX2o`0000OoM6Zi00?o0000ogAZ^OmdJ[T0
0omdJ[T00ol0003oL6:bog1R/P0<og1R/P03o`000?oooooooooo00_ooooo0ol00005ooooo`03o`00
0?oooooooooo00Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Kooooo`;o00003?n2]?D4o`0000[oQj_/00?o
0000oh^Si?n;Xn@03?n;Xn@00ol0003oSIcMohfLg@0;ohfLg@03o`000?n?V=SoSiSH00goSiSH00?o
0000oi2Ee?n@UM@03?n@UM@00ol0003oTI?Boi6CdP0>oi6CdP03o`000?nCTm7oTi?A00coTi?A1Ol0
000BoiZ`i`03o`000?nN`_7oW/;a00koW/;a0_l00004oj;blP?o000000?o/_Jio`000?l000000oo;
n:X00ol0003ofoo6om_oaP05o`0000Ooe??U0ol00008ojW5kP03o`000?m_OM7oKggA00?oKggA0ol0
0004oj6fi`03o`000?mgO<_oMgc;00[oMgc;00?o0000ofQS^_mXHkX02_mXHkX2o`0000OoM6Zi00?o
0000ogAZ^OmdJ[T00_mdJ[T00ol0003oL6:bog1R/P0<og1R/P03o`000?oooooooooo00Oooooo1?l0
0008ooooo`03o`000?oooooooooo00Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01gooooo00?o
0000oh:dmOn2]?D01on2]?D4o`0000goQj_/00?o0000oh^Si?n;Xn@02on;Xn@00ol0003oSIcMohfL
g@0<ohfLg@03o`000?n?V=SoSiSH00coSiSH00?o0000oi2Ee?n@UM@03On@UM@00ol0003oTI?Boi6C
dP0>oi6CdP03o`000?nCTm7oTi?A00KoTi?A1Ol00003oiFTh003o`000?nJ/>OoV[3W01;oV[3W00?o
0000oik2lOnN`_402onN`_42o`0000GoX_;b00Co0000oh_U[Ol0003o/_Ji0_l00003ol_hZPCo0000
0_oRo;L00ol0003oi_c4onKla003o`000004omCciOl0003o0000o`0000coZLG^00?o0000ofmmdOm_
OM401Om_OM42o`0000;oXKKW00?o0000ogMlbomgO</02omgO</00ol0003oJ6>jofQS^P09ofQS^P03
o`000?mVGKCo000000KoM6Zi00?o0000ogAZ^OmdJ[T00_mdJ[T00ol0003oL6:bog1R/P0<og1R/P03
o`000?oooooooooo00Cooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo00000ooooooo410@
ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?n2]?GoP[Ce00?oP[Ce0ol00004oh:dm@03o`000?n7ZncoQj_/00_oQj_/
00?o0000oh^Si?n;Xn@02on;Xn@00ol0003oSIcMohfLg@0;ohfLg@03o`000?n?V=SoSiSH00goSiSH
00?o0000oi2Ee?n@UM@03?n@UM@00ol0003oTI?Boi6CdP0>oi6CdP04o`000?nCTm7oTi?Aoi>Cd@Go
00002OnEY>000ol0003oV[3WoiZ`i`0BoiZ`i`03o`000?nN`_7oW/;a00SoW/;a0_l00005oj;blP;o
000000OoRnF]o`000?nbm[Wo0000ok[bXol0003oboRZ00?o00001?oRo;L00ol0003oi_c4onKla004
onKla003o`000?nYaNkoZLG^00goZLG^00?o0000ofmmdOm_OM401om_OM43o`0000goMgc;00?o0000
ofQS^_mXHkX02OmXHkX01?l0003oIUfdofIM]?l00006ogAZ^@03o`000?mdJ[WoM6Zi00;oM6Zi00?o
0000og1R/_m`H[803?m`H[800ol0003oooooooooo`03o`00013ooooo00?o0000ooooooooool02?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`05ooooo`?o0000
8?ooool00ol0003oP[Ceo`000002o`0000SoP[Ce00?o0000ohN[k?n7Zn`02_n7Zn`00ol0003oRj?T
oh^Si00<oh^Si003o`000?n=W=goSIcM00_oSIcM00?o0000ohnHf?n?V=P03?n?V=P00ol0003oT9GD
oi2Ee00=oi2Ee003o`000?nATm;oTI?B00[oTI?B1ol0000?oiFTh003o`000?nJ/>OoV[3W01;oV[3W
00?o0000oik2lOnN`_401OnN`_42o`0000KoX_;b00co0000oh_U[Ol0003o0000ok;f^Ol0003o^_:S
o`000?o;n:[o0000om_l^?l00004on;l]`03o`000?oVo<Coi_c400Goi_c40_l0000>ojW5kP03o`00
0?m_OM7oKggA00[oKggA0_l0000;ogMlb`03o`000?mXHk[oJ6>j00[oJ6>j00?o0000ofIM]?mVGK@0
0_l00005ogAZ^@05o`000?mdJ[WoM6ZiogAZ^Ol000003_m`H[83o`0001?ooooo00?o0000oooooooo
ool02?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`0000Cooooo00?o0000oooo
ooooool07oooool3o`0000coP[Ce00?o0000ohN[k?n7Zn`02_n7Zn`00ol0003oRj?Toh^Si00;oh^S
i003o`000?n=W=goSIcM00coSIcM00?o0000ohnHf?n?V=P03?n?V=P00ol0003oT9GDoi2Ee00<oi2E
e003o`000?nATm;oTI?B00;oTI?B2?l00004oi2Mg003o`000?nEY>3oUJCP013oUJCP00?o0000oiZ`
ionJ/>L04_nJ/>L00ol0003oW/;aoik2l@02oik2l@;o00001onRl_84o`000003ok;f^Ol0003o^_:S
00?o000000?ofobho`000?oRo;L00ooRo;L00ol0003oi_c4onKla005onKla004o`000?oOm][ogoKJ
o`0000koZLG^00?o0000ofmmdOm_OM402Om_OM400ol0003oFejlo`00000:ogMlb`03o`000?mXHk[o
J6>j00[oJ6>j00?o0000ofIM]?mVGK@00_mVGK@00ol0003oM6ZiogAZ^@03ogAZ^@04o`000?mdJ[Wo
M6Zio`0000koL6:b00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`0Looooo`?o00000ooooolEo`0000GoQj_/00?o0000oh^Si?n;Xn@02on;Xn@0
0ol0003oSIcMohfLg@0;ohfLg@03o`000?n?V=SoSiSH00coSiSH00?o0000oi2Ee?n@UM@01_n@UM@;
o`0000goT9gL00?o0000oiFTh?nEY>003onEY>000ol0003oV[3WoiZ`i`0CoiZ`i`04o`000?nN`_7o
0000o`0000OoX_;b0ol000001Onbn^Go0000ok;f^Ol0003o^_:S00;o00000_oKo;P00ol0003oh_bg
on;l]`02on;l]`03o`000?oVo<Coi_c400Goi_c400?o0000omoff_oOm]X00_oOm]X00ol0003oZLG^
ojW5kP0;ojW5kP03o`000?m_OM7oKggA00[oKggA00Co0000oe]N_?l0003o00002OmgO</00ol0003o
J6>jofQS^P09ofQS^P03o`000?mVGKCoIUfd00?oIUfd00?o0000ogAZ^OmdJ[T00_mdJ[T01?l0003o
M6ZiogAZ^Ol0000>og1R/P03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool06Oooool3o`0000Sooooo00?o0000ofNXm_mWZ?H02?mWZ?H00ol0003o
LZ;_og:Rk`05og:RkcWo00001on;VM/00ol0003oT9gLoi2Mg00?oi2Mg003o`000?nEY>3oUJCP00oo
UJCP00?o0000oiZ`ionJ/>L04_nJ/>L6o`0000CoX_;b0_l00002ok;ji@03o`000?nbm[Wo/_Ji00;o
00000ooKo;P00ol0003oh_bgon;l]`03on;l]`03o`000?oVo<Coi_c400Coi_c400?o0000omoff_oO
m]X01?oOm]X00ol0003oZLG^ojW5kP0;ojW5kP03o`000?m_OM7oKggA00WoKggA00Go0000oe]N_?mK
G[coFejlo`000008ogMlb`03o`000?mXHk[oJ6>j00[oJ6>j00?o0000ofIM]?mVGK@00omVGK@00ol0
003oM6ZiogAZ^@02ogAZ^@04o`000?mdJ[WoM6Zio`0000koL6:b00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`006_ooool2o`0001Sooooo0_l0000<ooooo`03o`000?mWZ?KoIjSf
00SoIjSf00?o0000og:RkombX^l02_mbX^l00ol0003oNicWog^Li`0;og^Li`03o`000?n1VN7oPIWQ
00_oPIWQ00?o0000ohJGg?n6Um`03?n6Um`00ol0003oRiWKoh^If`0=oh^If`03o`000?n@WMcoT9gL
00koT9gL00?o0000oiFTh?nEY>004?nEY>000ol0003oV[3WoiZ`i`0>oiZ`i`?o00001_nYgOT4o`00
00?o/_[U00?o0000ok;f^Onbm[T00_l00004om_l^003o`000?oRo;Ooh_bg00;oh_bg00?o0000onKl
a?oVo<@01?oVo<@00ol0003ogoKJomoffP06omoffP03o`000?nYaNkoZLG^00[oZLG^00?o0000ofmm
dOm_OM402Om_OM400ol0003oFejloe]N_002oe]N_003o`000?mgO<_oMgc;00GoMgc;00?o0000ofQS
^_mXHkX02_mXHkX00ol0003oIUfdofIM]004ofIM]0;o00000omdJ[T00ol0003oM6Zio`00000>og1R
/P03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool05?ooool3o`0000oooooo00?o0000ofNXm_mWZ?H02?mWZ?H00ol0003oLZ;_og:Rk`0:og:Rk`03
o`000?mkW>OoNicW00_oNicW00?o0000oh6IhOn1VN402on1VN400ol0003oQYOLohJGg00<ohJGg003
o`000?n;VM_oRiWK00goRiWK00?o0000oi2Mg?n@WM`03_n@WM`00ol0003oUJCPoiFTh00@oiFTh003
o`000?nJ/>OoV[3W00[oV[3W0ol0000:ojWMn@03o`000?nbn^Go/_[U00;o/_[U00Ko0000ok;f^Onb
m[Wo0000om?oaol00003om_l^003o`000?oRo;Ooh_bg00;oh_bg00?o0000onKla?oVo<@01?oVo<@0
0ol0003ogoKJomoffP08omoffP03o`000?nYaNkoZLG^00[oZLG^00?o0000ofmmdOm_OM402Om_OM40
0ol0003oFejloe]N_002oe]N_0;o00001_mgO</00ol0003oJ6>jofQS^P09ofQS^P03o`000?mVGKCo
IUfd00KoIUfd00Co0000ogAZ^OmdJ[WoM6Zi0_l0000>og1R/P03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01oooool001Wooooo00?o0000ooooooooool04_ooool3o`0001?ooooo0_l00009
ofNXmP03o`000?mbX^ooLZ;_00[oLZ;_00?o0000og^LiomkW>L02omkW>L00ol0003oPIWQoh6Ih@0;
oh6Ih@03o`000?n6UmcoQYOL00coQYOL00?o0000oh^Ifon;VM/03?n;VM/00ol0003oT9gLoi2Mg00?
oi2Mg003o`000?nEY>3oUJCP00ooUJCP00?o0000oiZ`ionJ/>L01onJ/>L3o`0000_oZMgi0_l00004
ok;ji@06o`000?nbm[Wo/_Jio`000?oColOo00000ooKo;P00ol0003oh_bgon;l]`02on;l]`03o`00
0?oVo<Coi_c400Coi_c400?o0000omoff_oOm]X02OoOm]X4o`0000WoZLG^00?o0000ofmmdOm_OM40
2Om_OM400ol0003oFejloe]N_004oe]N_003o`000?mgO<_oMgc;00?oMgc;00?o0000ofQS^_mXHkX0
2OmXHkX00ol0003oIUfdofIM]007ofIM]006o`000?mdJ[WoM6Zio`000?mdJ[Wo00003_m`H[800ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo000Iooooo`03o`000?oooooooooo00oo
oooo0ol0000Hooooo`03o`000?mWZ?KoIjSf00OoIjSf00?o0000og:RkombX^l02_mbX^l00ol0003o
NicWog^Li`0:og^Li`03o`000?n1VN7oPIWQ00_oPIWQ00?o0000ohJGg?n6Um`03?n6Um`00ol0003o
RiWKoh^If`0=oh^If`03o`000?n@WMcoT9gL00koT9gL00?o0000oiFTh?nEY>004?nEY>000ol0003o
V[3WoiZ`i`03oiZ`i`?o00003OnYgOT00ol0003o/_[Uok;ji@03ok;ji@06o`000?nbm[Wo/_Jio`00
0?oColOo00000ooKo;P00ol0003oh_bgon;l]`03on;l]`03o`000?oVo<Coi_c400?oi_c400?o0000
omoff_oOm]X02?oOm]X2o`000004ol;Nk_l0003oKhWLofn9g0?o00001_nYaNh00ol0003oKggAofmm
d@09ofmmd@03o`000?mKG[coFejl00GoFejl0_l00003ogMlb`03o`000?mXHk[oJ6>j00[oJ6>j00?o
0000ofIM]?mVGK@01omVGK@2o`000003ogAZ^Ol0003o000000koL6:b00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`07ooooo`006Oooool2o`0000gooooo0ol0000Looooo`03o`000?mWZ?Ko
IjSf00OoIjSf00?o0000og:RkombX^l02OmbX^l00ol0003oNicWog^Li`0;og^Li`03o`000?n1VN7o
PIWQ00_oPIWQ00?o0000ohJGg?n6Um`03?n6Um`00ol0003oRiWKoh^If`0=oh^If`03o`000?n@WMco
T9gL00koT9gL00?o0000oiFTh?nEY>004?nEY>000ol0003oV[3Wo`000002o`0000koZMgi0_l00005
ok;ji@04o`000?nbm[Wo/_Jio`0000;odoo700Go0000om_l^?oKo;Sofobho`000004on;l]`03o`00
0?oVo<Coi_c400?oi_c400?o0000omoff_oOm]X02?oOm]X00ol0003o`]k^ol;NkP02ol;NkP03o`00
0?m_RMcoKhWL00;oKhWL1?l00003ojW5kP03o`000?m_OM7oKggA00WoKggA00?o0000oe]N_?mKG[`0
1_mKG[`01Ol0003oMgc;ogMlbomgO<_o000000_oJ6>j00?o0000ofIM]?mVGK@02OmVGK@00ol0003o
M6Zio`00000>og1R/P03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool001Wooooo
00?o0000ooooooooool02Oooool3o`00023ooooo00?o0000ofNXm_mWZ?H01omWZ?H00ol0003oLZ;_
og:Rk`09og:Rk`03o`000?mkW>OoNicW00_oNicW00?o0000oh6IhOn1VN402on1VN400ol0003oQYOL
ohJGg00;ohJGg003o`000?n;VM_oRiWK00goRiWK00?o0000oi2Mg?n@WM`03_n@WM`00ol0003oUJCP
oiFTh00?oiFTh0Co00003onYgOT00ol0003o/_[Uok;ji@04ok;ji@04o`000?nbm[Wo/_Jio`0000;o
doo700Go0000om_l^?oKo;Sofobho`000004on;l]`03o`000?oVo<Coi_c400?oi_c400?o0000omof
f_oOm]X01ooOm]X2o`0000Go`]k^00?o0000ofn9g?m_RM`01_m_RM`4o`0000_oKggA00?o0000oe]N
_?mKG[`01omKG[`01?l0003oMgc;ogMlbol0000;ofQS^P03o`000?mVGKCoIUfd00[oIUfd0ol0000=
og1R/P03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool001Wooooo00?o0000oooo
ooooool01_ooool3o`0002Cooooo0ol00007ofNXmP03o`000?mbX^ooLZ;_00WoLZ;_00?o0000og^L
iomkW>L02_mkW>L00ol0003oPIWQoh6Ih@0;oh6Ih@03o`000?n6UmcoQYOL00coQYOL00?o0000oh^I
fon;VM/03On;VM/00ol0003oT9gLoi2Mg00>oi2Mg003o`000?nEY>3oUJCP00_oUJCP0ol00004oj73
l@03o`000?nYgOWoZMgi00_oZMgi00?o0000ok;jiOnbn^D01?nbn^D01?l0003o/_Jio`000?l00002
om?oa`05o`000?oKo;Sofobhom_l^?l000001?oRo;L00ol0003oi_c4onKla003onKla003o`000?oO
m][ogoKJ00KogoKJ0_l00008ol;NkP03o`000?m_RMcoKhWL00SoKhWL0ol00009ofmmd@03o`000?mK
G[coFejl00SoFejl0ol0000<ofQS^P03o`000?mVGKCoIUfd00[oIUfd0_l0000>og1R/P03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool001Wooooo00?o0000ooooooooool00oooool3
o`0002Sooooo00?o0000odBGl_l000001?l00003ofNXmP03o`000?mbX^ooLZ;_00WoLZ;_00?o0000
og^LiomkW>L02_mkW>L00ol0003oPIWQoh6Ih@0;oh6Ih@03o`000?n6UmcoQYOL00coQYOL00?o0000
oh^Ifon;VM/03On;VM/00ol0003oT9gLoi2Mg00>oi2Mg003o`000?nEY>3oUJCP00OoUJCP0ol00008
oj73l@;o00002OnYgOT2o`0000Ko/_[U00Oo0000ok;f^Ol0003obOgSo`000?oColOo000000?ofobh
00?o0000on;l]ooRo;L00_oRo;L00ol0003oi_c4onKla003onKla003o`000?oOm][ogoKJ00GogoKJ
0_l0000;ol;NkP03o`000?m_RMcoKhWL00SoKhWL00?o0000odeJ_ol000002Om_OM400ol0003oFejl
oe]N_009oe]N_0;o00002omXHkX00ol0003oIUfdofIM]00;ofIM]0;o00003Om`H[800ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Oooooo000Hooooo`Oo0000;?ooool00ol0003oA9ObodBG
lP03odBGlPGo00002_mbX^l00ol0003oNicWog^Li`0:og^Li`03o`000?n1VN7oPIWQ00coPIWQ00?o
0000ohJGg?n6Um`02on6Um`00ol0003oRiWKoh^If`0=oh^If`03o`000?n@WMcoT9gL00koT9gL00?o
0000oiFTh?nEY>001?nEY>03o`0000goXL?a00?o0000ojWMnOnYgOT01OnYgOT00ol0003o/_[Uok;j
i@05ok;ji@?o000000GobOgSo`000?oColOodoo7o`000003om_l^003o`000?oRo;Ooh_bg00;oh_bg
00?o0000onKla?oVo<@00_oVo<@00ol0003ogoKJomoffP05omoffP03o`000?o2g^ko`]k^00_o`]k^
00?o0000ofn9g?m_RM`02Om_RM`00ol0003oCEZoo`000008ofmmd@03o`000?mKG[coFejl00[oFejl
0_l0000:ofQS^P03o`000?mVGKCoIUfd00_oIUfd00?o0000of]S]ol000003?m`H[800ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Kooooo000Hooooo`Co0000<?ooool00ol0003oA9ObodBG
lP06odBGlPGo00001ombX^l00ol0003oNicWog^Li`0:og^Li`03o`000?n1VN7oPIWQ00_oPIWQ00?o
0000ohJGg?n6Um`03?n6Um`00ol0003oRiWKoh^If`0=oh^If`03o`000?n@WMcoT9gL00koT9gL00?o
0000oiFTh?nEY>000ol0000Aoj73l@;o00000onYgOT2o`0000Oo/_[U0_l00002olWmh`04o`000?oC
olOodoo7o`0000?ofobh00?o0000on;l]ooRo;L00_oRo;L00ol0003oi_c4onKla006o`0000?ogoKJ
0_l0000?ol;NkP03o`000?m_RMcoKhWL00SoKhWL00Co0000odeJ_om=F[oo00001om_OM400ol0003o
Fejloe]N_00:oe]N_003o`000?mKF;Go000000[oJ6>j00?o0000ofIM]?mVGK@02_mVGK@00ol0003o
Jf>go`000002o`0000[oL6:b00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`00
3_ooool4o`000003oa0@4?oooooooooo00?ooooo0_l0000cooooo`03o`000?m4Uo;oA9Ob00KoA9Ob
00Co0000oeZFk_mJU^koFYK^1ol000000ombX^oo0000og^Li`0;og^Li`03o`000?n1VN7oPIWQ00_o
PIWQ00?o0000ohJGg?n6Um`02on6Um`00ol0003oRiWKoh^If`0>oh^If`03o`000?n@WMcoT9gL00co
T9gL1?l0000Foj73l@03o`000?nYgOWo000000So/_[U00Go0000olWmhoo9oN?obOgSo`000002om?o
a`05o`000?oKo;Sofobhom_l^?l000001?oRo;L4o`0000;okoNl00Co0000oo3e__o`mKkol?Fn1?l0
000@ol;NkP03o`000?m_RMcoKhWL00SoKhWL00Co0000odeJ_om=F[ooCEZo0_l00006ofmmd@03o`00
0?mKG[coFejl00WoFejl00Co0000oe]H]OmKF;Go00002OmXHkX00ol0003oIUfdofIM]00;ofIM]004
o`000?m[HkOo0000of]S]`;o00002Om`H[800ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo000@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<Oooool00ol0003o
A9ObodBGlP06odBGlP03o`000?mJU^koFYK^00OoFYK^1ol00007og^Li`03o`000?n1VN7oPIWQ00co
PIWQ00?o0000ohJGg?n6Um`02on6Um`00ol0003oRiWKoh^If`0=oh^If`03o`000?n@WMcoT9gL00Oo
T9gL1Ol00003oiN_j003o`000?nQ`o7oXL?a01CoXL?a2ol00003olWmh`05o`000?oColOodoo7om?o
aol000000_oKo;P01?l0003oh_bgon;l]ooRo;L3o`0000CokoNl00?o0000oo3e__o`mKh01?o`mKh0
1?l0003ok?C9o`000?l0000?ol;NkP03o`000?m_RMcoKhWL00SoKhWL00?o0000odeJ_om=F[l00_m=
F[l00ol0003oKggAofmmd@03ofmmd@03o`000?mKG[coFejl00[oFejl00Co0000oe]H]OmKF;Go0000
2?mXHkX00ol0003oIUfdofIM]00;ofIM]004o`000?m[HkOoJf>go`0000;oJf>g00?o0000og1R/_m`
H[801_m`H[800ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo000@ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool00ol0003oA9ObodBGlP06odBGlP03o`00
0?mJU^koFYK^00SoFYK^00?o0000of^Ej?m[UNP00_m[UNP7o`000003og^Liol0003oPIWQ00coPIWQ
00?o0000ohJGg?n6Um`03?n6Um`00ol0003oRiWKoh^If`0=oh^If`04o`000?n@WMcoT9gLoi2Mg0Go
00002OnG[nP00ol0003oXL?aoj73l@0Aoj73l@;o00002?ngj?H00ol0003obOgSolWmh`02olWmh`05
o`000?oColOodoo7om?oaol000000ooKo;P01_l0003oh_bgo`000?l0003ok?W2o`0000CokoNl00?o
0000oo3e__o`mKh01?o`mKh00ol0003ok?C9oncdb@02oncdb@03o`000?o2g^ko`]k^00go`]k^00?o
0000ofn9g?m_RM`01om_RM`00ol0003oCEZoodeJ_`03odeJ_`03o`000?m_OM7oKggA00;oKggA00?o
0000oe]N_?mKG[`02_mKG[`01Ol0003oFeReoe]H]OmKF;Go000000OoJ6>j00?o0000ofIM]?mVGK@0
2omVGK@01Ol0003oJf>gof]S]om[HkOo000000;oJf>g0_l00006og1R/P03o`000?oooooooooo017o
oooo00?o0000ooooooooool01_ooool0013ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?m4Uo;oA9Ob00KoA9Ob00?o0000oeZFk_mJU^h02?mJU^h00ol0003oJiGX
of^Ej008of^Ej0_o00001On1VN400ol0003oQYOLohJGg00;ohJGg003o`000?n;VM_oRiWK00KoRiWK
2ol0000?oiN_j003o`000?nQ`o7oXL?a00koXL?a0_l00009okOXmP03o`000?o9oN?obOgS00;obOgS
00Go0000om?oaooColOodoo7o`000003om_l^0?o00000_o/nL800ol0003okoNlonog_003onog_003
o`000?o`mKkol?Fn00?ol?Fn00?o0000oncdbOo/m<T01?o/m<T2o`0000go`]k^00?o0000ofn9g?m_
RM`02?m_RM`00ol0003oCEZoodeJ_`03odeJ_`03o`000?m_OM7oKggA00;oKggA00?o0000oe]N_?mK
G[`02OmKG[`00ol0003oFeReoe]H]@02oe]H]@03o`000?mXHk[oJ6>j00GoJ6>j00?o0000ofIM]?mV
GK@02omVGK@01?l0003oJf>gof]S]ol00004of]S]`;o00001Om`H[800ol0003oooooooooo`0?oooo
o`;o00002?ooool0013ooooo00?o0000ooooooooool02_ooool2o`0003;ooooo00?o0000odBGl_m4
Uo801_m4Uo800ol0003oFYK^oeZFkP08oeZFkP03o`000?m[UNSoJiGX00WoJiGX00?o0000ogRFhomh
U^<01_mhU^<Lo`0000SoSJ;S00?o0000oiN_j?nG[nP04?nG[nP00ol0003oXL?aoj73l@0;oj73l@;o
00002Ongj?H2o`0000CobOgS00?o0000om?oaooColL00_oColL00ol0003ofobhom_l^002o`0000?o
k?W200?o0000onog_?o_mk`00oo_mk`00ol0003ol?Fnoo3e_P03oo3e_P03o`000?o/m<Wok?C900Oo
k?C94?l00008ofn9g003o`000?m=F[ooCEZo00CoCEZo00Go0000ofmmdOm_OM7oKggAo`00000<oe]N
_003o`000?mKF;GoFeRe00;oFeRe00?o0000ofQS^_mXHkX01?mXHkX00ol0003oIUfdofIM]00;ofIM
]005o`000?m[HkOoJf>gof]S]ol000001Om[HkL00ol0003oL6:bog1R/P02og1R/P03o`000?oooooo
oooo00oooooo0_l00008ooooo`004?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
033ooooo0ol00006odBGlP03o`000?mJU^koFYK^00SoFYK^00?o0000of^Ej?m[UNP02Om[UNP00ol0
003oN9KSogRFh`0;ogRFh`03o`000?n3V^7oPi[Q00_oPi[Q00?o0000ohfRhon=X^<03_n=X^<00ol0
003oUjoXoiN_j00@oiN_j003o`000?nQ`o7oXL?a00SoXL?a0_l0000:okOXmP03o`000?o9oN?obOgS
00?obOgS00?o0000om?oaooColL00_oColL01?l0003ofobho`000?l00005onci`P03o`000?o_mkco
koNl00;okoNl00?o0000oo3e__o`mKh01?o`mKh00ol0003ok?C9oncdb@07oncdb@03o`000?n6[>ko
QZc^00_oQZc^00?o0000od5Ka_l000001om_RM`00ol0003oCEZoodeJ_`05odeJ_`;o000000?oKggA
o`000?mKG[`02omKG[`00ol0003oFeReoe]H]@03oe]H]@03o`000?mXHk[oJ6>j00?oJ6>j00?o0000
ofIM]?mVGK@02omVGK@00ol0003oJf>gof]S]`02of]S]`03o`000?m[HkOoJf>g00?oJf>g0_l00002
og1R/P03o`000?oooooooooo00oooooo0ol00007ooooo`004?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo037ooooo1?l00004odBGlP03o`000?mJU^koFYK^00OoFYK^00?o0000of^E
j?m[UNP02_m[UNP00ol0003oN9KSogRFh`0;ogRFh`03o`000?n3V^7oPi[Q00_oPi[Q00?o0000ohfR
hon=X^<03_n=X^<00ol0003oUjoXoiN_j00@oiN_j003o`000?nQ`o7oXL?a00GoXL?a0_l0000;okOX
mP03o`000?o9oN?obOgS00CobOgS00Wo0000om?oaooColOodoo7o`000?oKo;So0000onCjcol00000
1?o/nL800ol0003okoNlonog_003onog_003o`000?o`mKkol?Fn00?ol?Fn00?o0000oncdbOo/m<T0
1oo/m<T00ol0003ognoKo`00000=ohJ/kP03o`000?m1FlKo000000OoKhWL00?o0000odeJ_om=F[l0
1_m=F[l00ol0003oKggAo`00000;oe]N_003o`000?mKF;GoFeRe00CoFeRe00?o0000ofQS^_mXHkX0
0omXHkX00ol0003oIUfdofIM]00:ofIM]003o`000?m[HkOoJf>g00?oJf>g00?o0000of]S]om[HkL0
1?m[HkL3o`00013ooooo0_l000000ooooooo0000ooooo`06ooooo`003_ooool00omEEEGoIVIVo`00
000@ooooo`03o`000?oooooooooo037ooooo00?o0000oa]oiolKOnL00ol00002odBGlP03o`000?mJ
U^koFYK^00OoFYK^00?o0000of^Ej?m[UNP02Om[UNP00ol0003oN9KSogRFh`0<ogRFh`03o`000?n3
V^7oPi[Q00_oPi[Q00?o0000ohfRhon=X^<03_n=X^<00ol0003oUjoXoiN_j00@oiN_j003o`000?nQ
`o7oXL?a00;oXL?a0_l0000;okOXmP;o00001_o9oN<01?l0003odoo7om?oaooColL3o`000003onCj
col0003ok?W200?ok?W200?o0000onog_?o_mk`00oo_mk`00ol0003ol?Fnoo3e_P03oo3e_P03o`00
0?o/m<Wok?C900Ook?C900Go0000omo_fooOkm_ognoKo`00000<ohJ/kP04o`000?m1FlKo@E_6o`00
00KoKhWL00?o0000odeJ_om=F[l01om=F[l2o`0000_oFejl00?o0000oe]H]OmKF;D01OmKF;D00ol0
003oJ6>jofQS^P02ofQS^P03o`000?mVGKCoIUfd00_oIUfd00?o0000of]S]om[HkL00_m[HkL00ol0
003oJf>gof]S]`06of]S]`;o00003oooool2o`000003ooooool0003ooooo00Kooooo000Rooooo`03
o`000?oooooooooo037ooooo00?o0000oa]oiolKOnL00_lKOnL4o`0000WoFYK^00?o0000of^Ej?m[
UNP02Om[UNP00ol0003oN9KSogRFh`0;ogRFh`03o`000?n3V^7oPi[Q00coPi[Q00?o0000ohfRhon=
X^<03_n=X^<00ol0003oUjoXoiN_j00@oiN_j004o`000?nQ`o7o0000o`0000co]nSf00?o0000olWm
hoo9oN<01Oo9oN<00ol0003odoo7om?oa`02om?oa`04o`000?oTn/ooi?[?o`0000Gok?W200?o0000
onog_?o_mk`00_o_mk`00ol0003ol?Fnoo3e_P04oo3e_P03o`000?o/m<Wok?C900Kok?C900?o0000
omo_fooOkm/00ooOkm/00ol0003oQZc^ohJ/kP09ohJ/kP04o`000?m1FlKo@E_6od5KaP;o00001Om_
RM`00ol0003oCEZoodeJ_`07odeJ_`03o`000?mKG[coFejl00[oFejl00?o0000oe]H]OmKF;D01OmK
F;D01Ol0003oJ6>jofQS^_mXHk[o000000goIUfd00?o0000of]S]om[HkL00om[HkL00ol0003oJf>g
of]S]`06of]S]`03o`000?oooooooooo00cooooo0ol000000ooooooo0000ooooo`06ooooo`008ooo
ool2o`0003;ooooo0_l00005oa]oi`Co00001omJU^h00ol0003oJiGXof^Ej009of^Ej003o`000?mh
U^?oN9KS00_oN9KS00?o0000oh>JhOn3V^402on3V^400ol0003oSJ;SohfRh`0?ohfRh`03o`000?nG
[nSoUjoX00ooUjoX0ol0000<okOXmP03o`000?o9oN?obOgS00GobOgS00?o0000om?oaooColL00_oC
olL01Ol0003oi?[?onCjcooTn/oo000000Cok?W200?o0000onog_?o_mk`00oo_mk`00ol0003ol?Fn
oo3e_P03oo3e_P03o`000?o/m<Wok?C900Kok?C900?o0000omo_fooOkm/01?oOkm/00ol0003oQZc^
ohJ/kP0:ohJ/kP03o`000?m1FlKo@E_600;o@E_600?o0000ofn9g?m_RM`00_m_RM`00ol0003oCEZo
odeJ_`08odeJ_`03o`000?mKG[coFejl00WoFejl00?o0000oe]H]OmKF;D01_mKF;D01?l0003oJ6>j
ofQS^_l0000=ofIM]003o`000?m[HkOoJf>g00CoJf>g00?o0000of]S]om[HkL01Om[HkL00ol0003o
ooooooooo`0<ooooo`?o000000?oooooo`000?ooool01_ooool002Gooooo00?o0000ooooooooool0
<Oooool00ol0003o6goWoa]oi`03oa]oi`03o`000?lnQn_o?XO[00?o00001?mJU^h00ol0003oJiGX
of^Ej00:of^Ej003o`000?mhU^?oN9KS00_oN9KS00?o0000oh>JhOn3V^402on3V^400ol0003oSJ;S
ohfRh`0>ohfRh`03o`000?nG[nSoUjoX00coUjoX0ol00003ojW;l@;o00002?ngj?H2o`0000OobOgS
00Co0000om?oaooColOodoo70_l00003onCjc`03o`000?o/nL;ok?W200?ok?W200?o0000onog_?o_
mk`00_o_mk`00ol0003ol?Fnoo3e_P03oo3e_P03o`000?o/m<Wok?C900Kok?C900?o0000omo_fooO
km/01_oOkm/00ol0003oQZc^ohJ/kP09ohJ/kP03o`000?m1FlKo@E_600?o@E_600Go0000ofn9g?m_
RMcoKhWLo`00000:odeJ_`;o00002_mKG[`00ol0003oFeReoe]H]@07oe]H]@04o`000?mXHk[oJ6>j
o`0000coIUfd00?o0000of]S]om[HkL01Om[HkL00ol0003oJf>gof]S]`05of]S]`03o`000?oooooo
oooo00[ooooo1?l000000ooooooo0000ooooo`06ooooo`009_ooool00ol0003oooooooooo`0aoooo
o`03o`000?lKOnOo6goW00?o6goW00?o0000ocj7jolnQn/00_lnQn/3o`0000;oFYK^00?o0000of^E
j?m[UNP02Om[UNP00ol0003oN9KSogRFh`0;ogRFh`03o`000?n3V^7oPi[Q00coPi[Q00?o0000ohfR
hon=X^<03_n=X^<00ol0003oUjoXoiN_j008oiN_j0?o00002?nYbo43o`0000Co]nSf00?o0000olWm
hoo9oN<01_o9oN<00ol0003odoo7o`000002o`000005omOfh_l0003oi?[?onCjcol000001Oo/nL80
0ol0003okoNlonog_002onog_003o`000?o`mKkol?Fn00?ol?Fn00?o0000oncdbOo/m<T01_o/m<T0
0ol0003ognoKomo_f`08omo_f`03o`000?n6[>koQZc^00WoQZc^00?o0000od5Ka_m1FlH00om1FlH0
1Ol0003oKhWLofn9g?m_RMco000000WoCEZo00?o0000odiB]_l000002_mKG[`00ol0003oFeReoe]H
]@07oe]H]@03o`000?mXHk[o000000goIUfd00?o0000of]S]om[HkL01?m[HkL00ol0003oJf>gof]S
]`05of]S]`03o`000?oooooooooo00[ooooo1?l000000ooooooo0000ooooo`06ooooo`009oooool0
0ol0003oooooooooo`0aooooo`03o`000?lKOnOo6goW00?o6goW00?o0000ocj7jolnQn/01?lnQn/4
o`0000_oJiGX00?o0000ogRFhomhU^<02omhU^<00ol0003oPi[Qoh>Jh@0<oh>Jh@03o`000?n=X^?o
SJ;S00koSJ;S00?o0000oiN_j?nG[nP01?nG[nP3o`0000koZL_a0_l000000ongj?Ko0000olWmh`07
olWmh`?o00000ooGm^801Ol0003oi?[?onCjcooTn/oo000000Cok?W200?o0000onog_?o_mk`00oo_
mk`00ol0003ol?Fnoo3e_P03oo3e_P03o`000?o/m<Wok?C900Gok?C900?o0000omo_fooOkm/02OoO
km/3o`0000WoQZc^00?o0000od5Ka_m1FlH01?m1FlH2o`000003ofn9g?l0003oCEZo00WoCEZo00?o
0000odiB]_l000002OmKG[`00ol0003oFeReoe]H]@08oe]H]@;o00003OmVGK@00ol0003oJf>gof]S
]`05of]S]`03o`000?m[HkOoJf>g00CoJf>g00?o0000ooooooooool02_ooool4o`0000;ooooo00?o
0000ooooooooool01?ooool002Sooooo0_l0000booooo`;o00001?lKOnL00ol0003o?XO[ocj7j`06
ocj7j`Co00002Om[UNP00ol0003oN9KSogRFh`0:ogRFh`03o`000?n3V^7oPi[Q00goPi[Q00?o0000
ohfRhon=X^<03_n=X^<00ol0003oUjoXoiN_j003o`0001;oZL_a2ol00005omOfhP05o`000?oTn/oo
i?[?onCjcol000001Oo/nL800ol0003okoNlonog_002onog_003o`000?o`mKkol?Fn00?ol?Fn00?o
0000oncdbOo/m<T01Oo/m<T00ol0003ognoKomo_f`08omo_f`;o00000oooool2o`0000SoQZc^00?o
0000od5Ka_m1FlH01Om1FlH00ol0003oKhWLo`000009odeJ_`04o`000?m>D[KoCU:fo`0000SoFejl
00?o0000oe]H]OmKF;D02OmKF;D2o`0000coIUfd00?o0000of]S]om[HkL01_m[HkL00ol0003oJf>g
of]S]`04of]S]`03o`000?oooooooooo00Sooooo1Ol00002ooooo`03o`000?oooooooooo00Cooooo
000Zooooo`03o`000?oooooooooo037ooooo0_l00003oa]oi`03o`000?lnQn_o?XO[00Ko?XO[00?o
0000oeb?j?mLSnP01Ol00004of^Ej003o`000?mhU^?oN9KS00_oN9KS00?o0000oh>JhOn3V^403?n3
V^400ol0003oSJ;SohfRh`0=ohfRh`Co00004onYbo42o`0000So`^K`00?o0000omOfh_oGm^801?oG
m^801Ol0003oi?[?onCjcooTn/oo000000Gok?W200?o0000onog_?o_mk`00_o_mk`00ol0003ol?Fn
oo3e_P03oo3e_P03o`000?o/m<Wok?C900Gok?C900?o0000omo_fooOkm/01ooOkm/2o`0000Oooooo
00?o0000ohJ/k_n6[>h01On6[>h00ol0003o@E_6od5KaP06od5KaP;o00002Om=F[l01Ol0003oCU:f
odiB]_m>D[Ko000000OoFejl00?o0000oe]H]OmKF;D02_mKF;D2o`0000coIUfd00?o0000of]S]om[
HkL01Om[HkL00ol0003oJf>gof]S]`04of]S]`03o`000?oooooooooo00Sooooo1Ol00002ooooo`03
o`000?oooooooooo00Cooooo000[ooooo`03o`000?oooooooooo037ooooo0ol00002oa]oi`03o`00
0?lnQn_o?XO[00Ko?XO[00?o0000oeb?j?mLSnP01?mLSnP6o`0000goN9KS00?o0000oh>JhOn3V^40
3?n3V^400ol0003oSJ;SohfRh`07ohfRh`Go00001?nH/n/00ol0003oZL_aojW;l@0?ojW;l@03o`00
0?o2i_3o`^K`00Oo`^K`00?o0000omOfh_oGm^801?oGm^800ol0003oi?[?onCjc`02onCjc`03o`00
0?o/nL;ok?W200;ok?W200?o0000onog_?o_mk`00oo_mk`00ol0003ol?Fnoo3e_P03oo3e_P03o`00
0?o/m<Wok?C900Cok?C900?o0000omo_fooOkm/01_oOkm/2o`0000[ooooo0_l00005ohJ/kP03o`00
0?m1FlKo@E_600Oo@E_600?o0000odeJ_om=F[l02?m=F[l01Ol0003oCU:fodiB]_m>D[Ko000000Oo
Fejl00?o0000oe]H]OmKF;D02OmKF;D00ol0003oIV>ko`00000;ofIM]003o`000?m[HkOoJf>g00Ko
Jf>g00?o0000of]S]om[HkL00om[HkL00ol0003oooooooooo`07ooooo`Go00000oooool00ol0003o
ooooooooo`04ooooo`00;?ooool00ol0003oooooooooo`0aooooo`06o`000?l0HM?o0000o`000?lK
OnOo00002?lnQn/00ol0003oG8oXoeb?j008oeb?j0Ko00002?mhU^<00ol0003oPi[Qoh>Jh@0=oh>J
h@04o`000?n=X^?oSJ;SohfRh`Go00002_nH/n/00ol0003oZL_aojW;l@0<ojW;l@;o00002Oo2i_00
0ol0003oeoKRomOfhP04omOfhP03o`000?oTn/ooi?[?00;oi?[?00?o0000onci`_o/nL800oo/nL80
0ol0003okoNlonog_002onog_003o`000?o`mKkol?Fn00?ol?Fn00?o0000oncdbOo/m<T01?o/m<T0
0ol0003ognoKomo_f`06omo_f`03o`000?oooooooooo00cooooo0_l00004ohJ/kP03o`000?m1FlKo
@E_600Oo@E_600?o0000odeJ_om=F[l01om=F[l00ol0003oCU:fodiB]P02odiB]P03o`000?mKG[co
Fejl00CoFejl00?o0000oe]H]OmKF;D02OmKF;D00ol0003oIV>kofIS^`02o`0000WoIUfd00?o0000
of]S]om[HkL01om[HkL00ol0003oJf>gof]S]`03of]S]`03o`000?oooooooooo00Kooooo1Ol00003
ooooo`03o`000?oooooooooo00Cooooo000]ooooo`;o0000<_ooool00ol0003o067Co`1Qd`03o`00
00So?XO[00?o0000oeb?j?mLSnP02?mLSnP00ol0003oLiOVog>GiP02og>GiPOo00000_mhU^<00ol0
003oPi[Qoh>Jh@06oh>Jh@[o00004?nH/n/00ol0003oZL_aojW;l@09ojW;l@;o00002Oo2i_02o`00
00KoeoKR00?o0000onCjcooTn/l00_oTn/l00ol0003ok?W2onci`P03onci`P03o`000?o_mkcokoNl
00;okoNl00?o0000oo3e__o`mKh00oo`mKh00ol0003ok?C9oncdb@04oncdb@03o`000?oOkm_ognoK
00GognoK0_l0000Aooooo`05o`000?n6[>koQZc^ohJ/k_l000002Om1FlH00ol0003oCEZoodeJ_`07
odeJ_`03o`000?m>D[KoCU:f00?oCU:f00?o0000oe]N_?mKG[`00omKG[`00ol0003oFeReoe]H]@0:
oe]H]@05o`000?mVHk_oIV>kofIS^ol000002?mVGK@00ol0003oJf>gof]S]`08of]S]`03o`000?m[
HkOoJf>g00;oJf>g00?o0000ooooooooool01_ooool5o`0000?ooooo00?o0000ooooooooool01?oo
ool002oooooo00?o0000ooooooooool0<?ooool01?l0003o067Co`1Qdol0HM<2o`0000So?XO[00?o
0000oeb?j?mLSnP02?mLSnP00ol0003oLiOVog>GiP08og>GiP_o00001on6XnH00ol0003oV;?[oiRc
j`0AoiRcj`03o`000?nYbo7oZL_a00OoZL_a00?o0000ol;Vl?o2i_002?o2i_000ol0003oeoKRomOf
hP05omOfhP03o`000?oTn/ooi?[?00?oi?[?00?o0000onci`_o/nL800_o/nL800ol0003okoNlonog
_003onog_003o`000?o`mKkol?Fn00go00000ooOkm/2o`0001Cooooo0_l00002ohJ/kP03o`000?m1
FlKo@E_600Ko@E_60_l00009odeJ_`03o`000?m>D[KoCU:f00?oCU:f00?o0000oe]N_?mKG[`00omK
G[`00ol0003oFeReoe]H]@09oe]H]@03o`000?mVHk_oIV>k00;oIV>k00?o0000ofIM]?mVGK@01_mV
GK@00ol0003oJf>gof]S]`07of]S]`03o`000?m[HkOoJf>g00?oJf>g00?o0000ooooooooool01?oo
ool6o`0000Cooooo00?o0000ooooooooool00oooool0033ooooo00?o0000ooooooooool0<?ooool0
0ol0003o067Co`1Qd`02o`1Qd`;o00001olnQn/00ol0003oG8oXoeb?j008oeb?j003o`000?mcUnKo
LiOV00[oLiOV00?o0000ohJSi_n6XnH03On6XnH00ol0003oV;?[oiRcj`0AoiRcj`03o`000?nYbo7o
ZL_a00CoZL_a0_l0000:ol;Vl003o`000?oGm^;oeoKR00GoeoKR00?o0000onCjcooTn/l00ooTn/l0
0ol0003ok?W2onci`P03onci`P03o`000?o_mkcokoNl00;okoNl1?l00002oo?/_@03o`000?oejk[o
mN^j00ComN^j00Co0000ooCZ^oodj[_om>Zk0ol0000Hooooo`?o00002Om1FlH2o`0000SoCEZo00?o
0000odiB]_m>D[H01?m>D[H00ol0003oFejloe]N_002oe]N_003o`000?mKF;GoFeRe00WoFeRe00?o
0000ofIS^omVHk/00omVHk/2o`0000KoIUfd00?o0000of]S]om[HkL02?m[HkL00ol0003oJf>gof]S
]`02of]S]`03o`000?oooooooooo00Cooooo1_l00004ooooo`03o`000?oooooooooo00?ooooo000a
ooooo`03o`000?oooooooooo033ooooo00Ko0000o`1Qdol0HM?o067Co`000?lRMn@3o`0000Co?XO[
00?o0000oeb?j?mLSnP02?mLSnP00ol0003oLiOVog>GiP0;og>GiP03o`000?n6XnKoQZ?V00goQZ?V
00?o0000oiRcjonH/n/04OnH/n/01?l0003oZL_aojW;lOnYbo42o`0000_o`^K`00?o0000omOfh_oG
m^801_oGm^800ol0003oi?[?onCjc`02onCjc`03o`000?o/nL;ok?W200?ok?W200Co0000onog_?o_
mkcokoNl0ol00004oo?/_@03o`000?oejk[omN^j00ComN^j00?o0000ooCZ^oodj[/01?odj[/00ol0
003oooooooooo`0Hooooo`03o`000?m1FlKo@E_600Oo@E_600?o0000oca9]_l000001om=F[l00ol0
003oCU:fodiB]P05odiB]P05o`000?mKG[coFejloe]N_?l000003?mKF;D00ol0003oIV>kofIS^`04
ofIS^`03o`000?mVGKCoIUfd00?oIUfd00?o0000of]S]om[HkL02Om[HkL01Ol0003oJf>gof]S]om[
HkOo000000Gooooo1ol00004ooooo`03o`000?oooooooooo00?ooooo000booooo`03o`000?oooooo
oooo033ooooo0_l00002o`1Qd`04o`000?lRMnCo8WOTob9gi0;o00000olnQn/00ol0003oG8oXoeb?
j008oeb?j003o`000?mcUnKoLiOV00_oLiOV00?o0000ohJSi_n6XnH03On6XnH00ol0003oV;?[oiRc
j`0AoiRcj`03o`000?nYbo7o000000co`^K`00?o0000omOfh_oGm^801_oGm^800ol0003oi?[?onCj
c`03onCjc`03o`000?o/nL;ok?W200?ok?W21?l000000oo_k/Go0000oo?/_@04oo?/_@03o`000?oe
jk[omN^j00?omN^j00?o0000ooCZ^oodj[/01?odj[/00ol0003oooooooooo`0Jooooo`03o`000?m1
FlKo@E_600Ko@E_600Co0000oca9]_llBKKo00001om=F[l00ol0003oCU:fodiB]P05odiB]P04o`00
0?mKG[coFejlo`0000coFeRe00?o0000ofIS^omVHk/01OmVHk/2o`0000?oIUfd00?o0000of]S]om[
HkL02_m[HkL01Ol0003oJf>gof]S]om[HkOo000000Cooooo1_l00005ooooo`03o`000?oooooooooo
00?ooooo000cooooo`;o0000<_ooool01?l0003o067Co`1Qdol00004ob9gi0;o00000_lnQn/00ol0
003oG8oXoeb?j008oeb?j003o`000?mcUnKoLiOV00_oLiOV00?o0000ohJSi_n6XnH03On6XnH00ol0
003oV;?[oiRcj`0@oiRcj`?o00002_o2i_02o`0000SoeoKR00?o0000onCjcooTn/l00ooTn/l00ol0
003ok?W2onci`P03onci`P;o00000oo_k/D00ol0003olnbmoo?/_@03oo?/_@03o`000?oejk[omN^j
00ComN^j00?o0000ooCZ^oodj[/00oodj[/00ol0003oooooooooo`0Kooooo`03o`000?m1FlKo@E_6
00Oo@E_600Co0000oca9]_llBKKo00001_m=F[l00ol0003oCU:fodiB]P06odiB]P04o`000?mKG[co
Fejlo`0000_oFeRe00?o0000ofIS^omVHk/01omVHk/01Ol0003oIUfdofIM]?mVGKCo000000_oJf>g
00Go0000of]S]om[HkOoJf>go`000004ooooo`Ko00001Oooool00ol0003oooooooooo`03ooooo`00
=Oooool00ol0003oooooooooo`0`ooooo`;o000000?o067Co`000?lRMn@01?lRMn@4o`0000[oG8oX
00?o0000og>Gi_mcUnH02_mcUnH00ol0003oQZ?VohJSiP0>ohJSiP03o`000?nH/n_oV;?[00coV;?[
0ol00003ojc9kP;o00001oo2i_000ol0003oeoKRomOfhP07omOfhP03o`000?oTn/ooi?[?00?oi?[?
00?o0000onci`_o/nL800_o/nL82o`0000Goknk500?o0000oo?/_Oock;d00_ock;d00ol0003omN^j
ooG[^P04ooG[^P03o`000?odj[_om>Zk00Com>Zk00?o0000ooooooooool07?ooool00ol0003o@E_6
od5KaP06od5KaP04o`000?llBKKo?4Vfo`0000KoCEZo00?o0000odiB]_m>D[H01om>D[H00ol0003o
Fejlo`00000<oe]H]@03o`000?mVHk_oIV>k00OoIV>k00Co0000ofIM]?mVGKCo00003?m[HkL01Ol0
003oJf>gof]S]om[HkOo000000;ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo000foooo
o`03o`000?oooooooooo033ooooo0_l000000ol0HM?o0000ob9gi006ob9gi0;o00002OmLSnP00ol0
003oLiOVog>GiP0;og>GiP03o`000?n6XnKoQZ?V00goQZ?V00?o0000oiRcjonH/n/02_nH/n/2o`00
00So[<W^0_l00004ol;Vl003o`000?oGm^;oeoKR00OoeoKR00?o0000onCjcooTn/l01?oTn/l00ol0
003ok?W2o`000002o`000003onO^d_l0003oknk500?oknk500?o0000oo?/_Oock;d00oock;d00ol0
003omN^jooG[^P04ooG[^P03o`000?odj[_om>Zk00?om>Zk00?o0000ooooooooool07_ooool00ol0
003o@E_6od5KaP05od5KaP05o`000?llBKKo?4Vfoca9]_l000001Om=F[l00ol0003oCU:fodiB]P08
odiB]P;o00003?mKF;D00ol0003oIV>kofIS^`08ofIS^`?o00003Om[HkL01?l0003oJf>gof]S]ol0
0002ooooo`Go000000?o]_cJo`000?ooool01?ooool00ol0003oooooooooo`03ooooo`00=oooool0
0ol0003oooooooooo`0`ooooo`Co00002?lRMn@3o`0000OoG8oX00?o0000og>Gi_mcUnH02omcUnH0
0ol0003oQZ?VohJSiP0=ohJSiP03o`000?nH/n_oV;?[00KoV;?[0ol0000<ojc9kP;o000000?o`^K`
o`000?oGm^802?oGm^800ol0003oi?[?onCjc`04onCjc`?o00000ooWk]800ol0003oknk5ono^a@02
ono^a@03o`000?ock;golnbm00?olnbm00?o0000ooG[^_oejkX01?oejkX00ol0003om>ZkooCZ^`04
ooCZ^`03o`000?oooooooooo01oooooo00?o0000od5Ka_m1FlH01Om1FlH01Ol0003o?4Vfoca9]_ll
BKKo000000GoCEZo00?o0000odiB]_m>D[H02?m>D[H2o`0000_oFeRe00?o0000ofIS^omVHk/02_mV
Hk/2o`0000goJf>g00Co0000of]S]ol0003ooooo1Ol000000onfo=[o0000ooooo`06ooooo`03o`00
0?oooooooooo00;ooooo000hooooo`;o0000<Oooool01?l0003o03ngo`000?l00007ob9gi003o`00
0?mAR^SoDH[X00?o00001OmLSnP00ol0003oLiOVog>GiP0;og>GiP03o`000?n6XnKoQZ?V00goQZ?V
00?o0000oiRcjonH/n/00onH/n/2o`00013o[<W^1ol00004omOfhP03o`000?oTn/ooi?[?00Go0000
1OoWk]800ol0003oknk5ono^a@03ono^a@03o`000?ock;golnbm00?olnbm00?o0000ooG[^_oejkX0
0ooejkX00ol0003om>ZkooCZ^`04ooCZ^`03o`000?oooooooooo027ooooo00?o0000od5Ka_m1FlH0
1?m1FlH00ol0003o?4Vfoca9]P02oca9]P03o`000?m=F[ooCEZo00;oCEZo00?o0000odiB]_m>D[H0
2Om>D[H2o`0000_oFeRe00?o0000ofIS^omVHk/02_mVHk/4o`0000[oJf>g00?o0000of]S]om[HkL0
1_l000000onfo=[o0000ooooo`06ooooo`03o`000?oooooooooo00;ooooo000jooooo`03o`000?oo
oooooooo02oooooo00Co0000o`0o]ol0003o00001olRMn@00ol0003oDH[Xoe6:j002oe6:j0?o0000
0_mLSnP00ol0003oLiOVog>GiP0;og>GiP03o`000?n6XnKoQZ?V00koQZ?V00?o0000oiRcjol00000
0_l0000Aojc9kP03o`000?o5gN_oaMg[00GoaMg[1ol00004omWYg`03o`000?oWk];oinkB00;oinkB
00?o0000ono^aOo_k/D00oo_k/D00ol0003olnbmoo?/_@03oo?/_@03o`000?oejk[omN^j00ComN^j
00?o0000ooCZ^oodj[/00oodj[/00ol0003oooooooooo`0Sooooo`03o`000?m1FlKo@E_600?o@E_6
00?o0000oca9]_llBKH00ollBKH01Ol0003oCEZoodeJ_om=F[oo000000_oCU:f00?o0000oeiP_?l0
00002_mKF;D00ol0003oIV>kofIS^`0:ofIS^`04o`000?mnR=?oOXSCogj8d`Ko00001Om[HkL00ol0
003oJf>go`000004o`0000;o]_cJ00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`00>oooool00ol0003oooooooooo`0_ooooo`04o`000?l0?kOo03ngo`0000Oo8WOT00?o0000oe6:
j?mAR^P01?mAR^P4o`0000goLiOV00?o0000ohJSi_n6XnH02_n6XnH5o`0001;o[<W^0_l00009olGM
j`03o`000?oIjMoofNWO00KofNWO00?o0000onO^d_oWk]800ooWk]800ol0003oknk5ono^a@03ono^
a@03o`000?ock;golnbm00?olnbm00?o0000ooG[^_oejkX00ooejkX00ol0003om>ZkooCZ^`04ooCZ
^`03o`000?oooooooooo02?ooooo00?o0000od5Ka_m1FlH01?m1FlH00ol0003o?4Vfoca9]P03oca9
]P05o`000?m=F[ooCEZoodeJ_ol000002om>D[H00ol0003oGV2lo`000009oe]H]@03o`000?mVHk_o
IV>k00_oIV>k00?o0000ogj8domnR=<01_mnR=<<o`0000;o]_cJ00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`00??ooool00ol0003oooooooooo`0_ooooo`;o000000?o03ngo`00
0?l000001_lRMn@00ol0003oDH[Xoe6:j006oe6:j0[o00001OmcUnH00ol0003oQZ?VohJSiP02ohJS
iPOo00001OnC/>/00ol0003o[<W^ojc9kP0>ojc9kP03o`000?o5gN_oaMg[00SoaMg[00?o0000omWY
gooIjMl01_oIjMl00ol0003oinkBonO^dP03onO^dP03o`000?o_k/Goknk500?oknk500?o0000oo?/
_Oock;d00oock;d00ol0003omN^jooG[^P04ooG[^P03o`000?odj[_om>Zk00?om>Zk00?o0000oooo
ooooool09Oooool00ol0003o@E_6od5KaP03od5KaP03o`000?llBKKo?4Vf00Co?4Vf00Co0000odeJ
_om=F[oo00002om>D[H00ol0003oGV2loeiP_002o`0000SoFeRe00?o0000ofIS^omVHk/02_mVHk/0
0ol0003oOXSCogj8d`0<ogj8d`Ko000000?o]_cJo`000?ooool01oooool00ol0003oooooooooo`02
ooooo`00?Oooool2o`00037ooooo0_l000000ol7I][o0000o`000005ob9gi003o`000?mAR^SoDH[X
00KoDH[X00?o0000ogJLjOmfW>T01_mfW>T:o`0000goTk3[00?o0000ojc9k_n/bNh02on/bNh2o`00
00[oaMg[00?o0000omWYgooIjMl01_oIjMl00ol0003oinkBonO^dP03onO^dP03o`000?o_k/Goknk5
00?oknk500?o0000oo?/_Oock;d01?ock;d00ol0003omN^jooG[^P03ooG[^P03o`000?odj[_om>Zk
00?om>Zk00?o0000ooooooooool09oooool00ol0003o@E_6od5KaP02od5KaP03o`000?llBKKo?4Vf
00Co?4Vf00Co0000odeJ_om=F[oo00002om>D[H00ol0003oGV2loeiP_002oeiP_003o`000?mKF;Go
FeRe00GoFeRe00?o0000ofIS^omVHk/02omVHk/00ol0003oOXSCogj8d`0<ogj8d`03o`000?mnR=?o
OXSC00;oOXSC0_l00008ooooo`03o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooooooo
02oooooo0_l00002o`MVfP;o00001?lRMn@00ol0003oDH[Xoe6:j006oe6:j003o`000?mfW>WoMYcY
00_oMYcY00?o0000oi>`jonC/>/03onC/>/00ol0003o[<W^ojc9kP09ojc9kP03o`000?o5gN_oaMg[
00WoaMg[00?o0000omWYgooIjMl01_oIjMl00ol0003oinkBonO^dP04onO^dP03o`000?o_k/Goknk5
00?oknk500?o0000oo?/_Oock;d00oock;d00ol0003omN^jooG[^P03ooG[^P03o`000?odj[_om>Zk
00Com>Zk00?o0000ooooooooool0:?ooool01Ol0003o@E_6od5Ka_m1FlKo000000Oo?4Vf00Co0000
odeJ_om=F[oo00002om>D[H00ol0003oGV2loeiP_002oeiP_003o`000?mKF;GoFeRe00CoFeRe00?o
0000ofIS^omVHk/02omVHk/00ol0003oOXSCogj8d`0=ogj8d`04o`000?mnR=?oOXSCo`0000[ooooo
00?o0000ooooooooool00_ooool0043ooooo00?o0000ooooooooool0;oooool2o`0000?o1fKJ0_l0
0002ob9gi003o`000?mAR^SoDH[X00OoDH[X00?o0000ogJLjOmfW>T02omfW>T00ol0003oTk3[oi>`
j`0?oi>`j`03o`000?n/bNko[<W^00Ko[<W^0_l0000;olGMj`03o`000?oIjMoofNWO00KofNWO00?o
0000onO^d_oWk]801?oWk]800ol0003oknk5ono^a@03ono^a@03o`000?ock;golnbm00?olnbm00?o
0000ooG[^_oejkX01?oejkX00ol0003om>ZkooCZ^`03ooCZ^`03o`000?oooooooooo02[ooooo00Go
0000od5Ka_m1FlKo@E_6o`000007oca9]P03o`000?m=F[oo000000_oCU:f00?o0000oeiP_?mNH;`0
0omNH;`2o`0000GoFeRe00?o0000ofIS^omVHk/02_mVHk/00ol0003oOXSCogj8d`0>ogj8d`;o0000
3?ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0_ooooo`;o00001?l7
I]X2o`000003ob9gi?l0003oDH[X00SoDH[X00?o0000ogJLjOmfW>T02omfW>T00ol0003oTk3[oi>`
j`0?oi>`j`03o`000?n/bNko[<W^00Co[<W^00?o0000olGMjoo5gN/02_o5gN/00ol0003ofNWOomWY
g`07omWYg`03o`000?oWk];oinkB00?oinkB00?o0000ono^aOo_k/D01?o_k/D00ol0003olnbmoo?/
_@03oo?/_@03o`000?oejk[omN^j00?omN^j00?o0000ooCZ^oodj[/01?odj[/00ol0003ooooooooo
o`0[ooooo`04o`000?m1FlKo@E_6o`0000So?4Vf0_l0000;odiB]P03o`000?mNH;coGV2l00GoGV2l
00?o0000oe]H]OmKF;D00_mKF;D00ol0003oIV>kofIS^`0;ofIS^`03o`000?mnR=?oOXSC00coOXSC
0_l0000=ooooo`03o`000?oooooooooo007ooooo0012ooooo`03o`000?oooooooooo02oooooo0_l0
0005o`MVfP?o00002OmAR^P00ol0003oMYcYogJLj@0;ogJLj@03o`000?nC/>_oTk3[00ooTk3[00Co
0000ojc9k_n/bNko[<W^0_l0000<olGMj`03o`000?oIjMoofNWO00OofNWO00?o0000onO^d_oWk]80
0ooWk]800ol0003oknk5ono^a@04ono^a@03o`000?ock;golnbm00?olnbm00?o0000ooG[^_oejkX0
1?oejkX00ol0003om>ZkooCZ^`03ooCZ^`03o`000?oooooooooo02cooooo00Co0000od5Ka_m1FlKo
00002OllBKH2o`0000_oCU:f00?o0000oeiP_?mNH;`01OmNH;`01Ol0003oFeReoe]H]OmKF;Go0000
00goIV>k00?o0000ogj8domnR=<02omnR=<2o`000003ooooool0003ooooo00_ooooo00?o0000oooo
ooooool00Oooool004?ooooo0_l0000aooooo`03o`000?l7I][o1fKJ00Co1fKJ0_l00009oe6:j003
o`000?mfW>WoMYcY00_oMYcY00?o0000oi>`jonC/>/03onC/>/00ol0003o[<W^o`00000=olGMj`03
o`000?oIjMoofNWO00OofNWO00?o0000onO^d_oWk]801?oWk]800ol0003oknk5ono^a@04ono^a@03
o`000?ock;golnbm00?olnbm00?o0000ooG[^_oejkX00ooejkX00ol0003om>ZkooCZ^`03ooCZ^`03
o`000?oooooooooo02kooooo00Co0000od5Ka_m1FlKo00002OllBKH2o`0000[oCU:f00?o0000oeiP
_?mNH;`01_mNH;`01Ol0003oFeReoe]H]OmKF;Go000000goIV>k00?o0000ogj8domnR=<02OmnR=<2
o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00AOooool00ol0
003oooooooooo`0_ooooo`03o`000?l7I][o1fKJ00Go1fKJ0ol00006oe6:j003o`000?mfW>WoMYcY
00coMYcY00?o0000oi>`jonC/>/03OnC/>/4o`0000coaMg[00?o0000omWYgooIjMl01ooIjMl00ol0
003oinkBonO^dP04onO^dP03o`000?o_k/Goknk500Coknk500?o0000oo?/_Oock;d00oock;d00ol0
003omN^jooG[^P03ooG[^P03o`000?odj[_om>Zk00Com>Zk00?o0000ooooooooool0;oooool00ol0
003o@E_6o`000009oca9]P03o`000?mAF;_o000000WoCU:f00?o0000oeiP_?mNH;`01omNH;`2o`00
0003oe]H]Ol0003oIV>k00coIV>k00?o0000ogj8domnR=<01omnR=<2o`000003okKlf_l0003ooooo
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00A_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?l7I][o1fKJ00Co1fKJ00?o0000odf9jOm=RNT00ol00004oe6:j003
o`000?mfW>WoMYcY00coMYcY00?o0000oi>`jonC/>/02OnC/>/3o`0000CoYl3/0_l00009olGMj`03
o`000?oIjMoofNWO00OofNWO00?o0000onO^d_oWk]801?oWk]800ol0003oknk5ono^a@04ono^a@03
o`000?ock;golnbm00Colnbm00?o0000ooG[^_oejkX00ooejkX00ol0003om>ZkooCZ^`03ooCZ^`03
o`000?oooooooooo037ooooo0_l00009oca9]P04o`000?mAF;_oDERko`0000WoCU:f00?o0000oeiP
_?mNH;`02?mNH;`2o`0000koIV>k00?o0000ogj8domnR=<01OmnR=<01?l0003o]_cJokKlf_l00005
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004Oooooo00?o0000oooo
ooooool0;oooool00ol0003o1fKJo`MVfP04o`MVfP03o`000?m=RNWoCHWY00;oCHWY0ol00002oe6:
j003o`000?mfW>WoMYcY00coMYcY00?o0000oi>`jonC/>/01?nC/>/4o`0000WoYl3/0_l00006olGM
j`03o`000?oIjMoofNWO00OofNWO00?o0000onO^d_oWk]801OoWk]800ol0003oknk5ono^a@04ono^
a@03o`000?ock;golnbm00?olnbm00?o0000ooG[^_oejkX00ooejkX00ol0003om>ZkooCZ^`04ooCZ
^`03o`000?oooooooooo03;ooooo0_l00009oca9]P04o`000?mAF;_oDERko`0000SoCU:f00?o0000
oeiP_?mNH;`02OmNH;`2o`0000goIV>k00?o0000ogj8domnR=<01?mnR=<01?l0003o]_cJokKlf_l0
0007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00Oooool004Sooooo0_l0000`
ooooo`;o00001Ol7I]X00ol0003oCHWYodf9j@04odf9j@Co00003_mfW>T00ol0003oTk3[oi>`j`03
o`0000ooYl3/00?o0000olGMjoo5gN/00_o5gN/00ol0003ofNWOomWYg`08omWYg`03o`000?oWk];o
inkB00CoinkB00?o0000ono^aOo_k/D01?o_k/D00ol0003olnbmoo?/_@04oo?/_@03o`000?oejk[o
mN^j00?omN^j00?o0000ooCZ^oodj[/00oodj[/00ol0003oooooooooo`0dooooo`03o`000?llBKKo
?4Vf00Oo?4Vf00Go0000oe5H^omAF;_oDERko`000007odiB]P03o`000?mNH;coGV2l00[oGV2l1?l0
000:ofIS^`03o`000?mnR=?oOXSC00;oOXSC0_l00003okKlfP03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0;_ooool2
o`0000Go1fKJ00?o0000odf9jOm=RNT01_m=RNTBo`0001?oYl3/0_l000000oo5gN_o0000omWYg`09
omWYg`03o`000?oWk];oinkB00CoinkB00?o0000ono^aOo_k/D01Oo_k/D00ol0003olnbmoo?/_@03
oo?/_@03o`000?oejk[omN^j00?omN^j00?o0000ooCZ^oodj[/01?l0000gooooo`03o`000?llBKKo
?4Vf00Oo?4Vf00?o0000oe5H^omAF;/00_mAF;/00ol0003oCU:fodiB]P05odiB]P03o`000?mNH;co
GV2l00WoGV2l00Co0000oh:>e_n2S]KoPXkF1Ol00006ofIS^`04o`000?mnR=?oOXSCo`0000Co]_cJ
00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Booo
ool00ol0003oooooooooo`0^ooooo`?o00000ol7I]X00ol0003oCHWYodf9j@07odf9j@03o`000?n1
Y^coPJK/00coPJK/00?o0000ojO0k?nW`>`04onW`>`3o`0000WofNWO00?o0000onO^d_oWk]801?oW
k]800ol0003oknk5ono^a@05ono^a@03o`000?ock;golnbm00?olnbm00Co0000ooG[^_oejk[omN^j
1_l00003oo;N^@03o`000?oooooooooo03Kooooo00?o0000oca9]_llBKH01ollBKH00ol0003oDERk
oe5H^`02oe5H^`03o`000?m>D[KoCU:f00CoCU:f00?o0000oeiP_?mNH;`02_mNH;`00ol0003oPXkF
oh:>eP05oh:>ePGo000000CoIV>ko`000?mnR=?o00001Onfo=X00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001<ooooo`03o`000?oooooooooo02kooooo
00Co0000o`1Fd?l0003o00000_l7I]X00ol0003oCHWYodf9j@07odf9j@03o`000?n1Y^coPJK/00co
PJK/00?o0000ojO0k?nW`>`04?nW`>`2o`0000?o_LoX0ol00005omWYg`03o`000?oWk];oinkB00Go
inkB00?o0000ono^aOo_k/D01?o_k/D00ol0003olnbmoo?/_@04oo?/_@Co00000_o_gl000ol0003o
l]jioo;N^@03oo;N^@03o`000?oooooooooo03Sooooo00?o0000oca9]_llBKH01_llBKH00ol0003o
DERkoe5H^`03oe5H^`;o00001?m>D[H00ol0003oGV2loeiP_00:oeiP_003o`000?n2S]KoPXkF00[o
PXkF2Ol0000<ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001=ooooo`;o0000
;oooool01?l0003o05K@o`1Fd?l00002o`MVfP03o`000?m=RNWoCHWY00OoCHWY00?o0000oh6Vk?n1
Y^`03?n1Y^`00ol0003oYl3/ojO0k00=ojO0k0;o00002?nmcnP3o`000003omWYgol0003oinkB00Ko
inkB00?o0000ono^aOo_k/D01Oo_k/D00ol0003olnbmoo?/_@05o`0000Cokmo000?o0000oo;N^Oob
g[T01?obg[T00ol0003oooooooooo`0iooooo`03o`000?llBKKo?4Vf00Go?4Vf00?o0000oe5H^omA
F;/01OmAF;/00ol0003oCU:fodiB]P02odiB]P03o`000?mNH;coGV2l00[oGV2l00?o0000oh:>e_n2
S]H03on2S]H00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7o
oooo001?ooooo`03o`000?oooooooooo02gooooo00?o0000o`1Fd?l0E]000ol0000:odf9j@03o`00
0?n1Y^coPJK/00coPJK/00?o0000ojO0k?nW`>`02_nW`>`2o`0000co_LoX5Ol00003onWOb@03o`00
0?o_gl3okmo000?okmo000?o0000oo;N^Oobg[T00oobg[T00ol0003oooooooooo`0kooooo`03o`00
0?llBKKo?4Vf00Go?4Vf00?o0000oe5H^omAF;/01OmAF;/01Ol0003oCU:fodiB]_m>D[Ko000000co
GV2l00?o0000oh:>e_n2S]H03_n2S]H00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`7ooooo001@ooooo`03o`000?oooooooooo02cooooo0_l00003o`1Fd0;o0000
2_m=RNT00ol0003oPJK/oh6Vk00<oh6Vk003o`000?nW`>coYl3/00SoYl3/00?o0000okg?j?nmcnP0
2onmcnP00ol0003odMWOom7Ig`07om7Ig`03o`000?oOg]CogmkD00GogmkD00?o0000onWObOoYglT0
0ooYglT00ol0003okmo0onoO`003onoO`003o`000?obg[Wol]ji00Col]ji00?o0000ooooooooool0
??ooool00ol0003o?4Vfoca9]P04oca9]P03o`000?mAF;_oDERk00KoDERk00Co0000odiB]_m>D[Ko
00003OmNH;`00ol0003oPXkFoh:>eP0<oh:>eP03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00oooool1o`00007ooooo0Oooool0057ooooo00?o0000ooooooooool0;?ooool2o`0000Co05K@
00?o0000odf9jOm=RNT02?m=RNT00ol0003oPJK/oh6Vk00<oh6Vk003o`000?nW`>coYl3/00GoYl3/
0_l0000=okg?j003o`000?oAfMoodMWO00OodMWO00?o0000omoNe?oOg]@01OoOg]@00ol0003ojMo9
onWOb@04onWOb@03o`000?o_gl3okmo000?okmo000?o0000oo;N^Oobg[T00oobg[T00ol0003ooooo
ooooo`0mooooo`03o`000?llBKKo?4Vf00Co?4Vf00?o0000oe5H^omAF;/01omAF;/01?l0003oCU:f
odiB]_l0000<oeiP_003o`000?n2S]KoPXkF00[oPXkF0_l0000Dooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`00D_ooool00ol0003oooooooooo`0/ooooo`;o00001?l0E]03o`0000SoCHWY
00?o0000oh6Vk?n1Y^`03?n1Y^`00ol0003oYl3/ojO0k002ojO0k0;o00003_nmcnP00ol0003odMWO
om7Ig`07om7Ig`03o`000?oOg]CogmkD00GogmkD00?o0000onWObOoYglT01?oYglT00ol0003okmo0
onoO`003onoO`003o`000?obg[Wol]ji00Col]ji00?o0000ooooooooool0?_ooool00ol0003o?4Vf
oca9]P04oca9]P03o`000?mAF;_oDERk00OoDERk00?o0000odiB]_l000003OmNH;`00ol0003oPXkF
oh:>eP08oh:>eP;o00005_ooool00ol0003oooooooooo`02ooooo`7o00000Oooool005?ooooo0_l0
000]ooooo`?o00000_l0E]000ol0003oD8g[oe2=j`05o`0000CoCHWY00?o0000oh6Vk?n1Y^`03?n1
Y^`01?l0003oYl3/o`000?l0000>okg?j0;o00002OoAfMl00ol0003ogmkDomoNe006omoNe003o`00
0?oYglWojMo900?ojMo900?o0000onoO`?o_gl001?o_gl000ol0003ol]jioo;N^@04oo;N^@03o`00
0?oooooooooo03oooooo00?o0000oca9]_llBKH00ollBKH00ol0003oDERkoe5H^`08oe5H^`;o0000
3OmNH;`00ol0003oPXkFoh:>eP07oh:>eP03o`000?o;oN7o000001Kooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo001Eooooo`03o`000?oooooooooo02_ooooo00?o0000o`19a_l000000_l0
E]000ol0003oD8g[oe2=j`04oe2=j`Ko00001on1Y^`9o`0000ko_LoX00?o0000om7IgooAfMl02?oA
fMl00ol0003ogmkDomoNe006omoNe003o`000?oYglWojMo900CojMo900?o0000onoO`?o_gl000oo_
gl000ol0003ol]jioo;N^@04oo;N^@03o`000?oooooooooo047ooooo00?o0000oca9]_llBKH00_ll
BKH00ol0003oDERkoe5H^`09oe5H^`;o00003?mNH;`00ol0003oPXkFoh:>eP06oh:>eP03o`000?o;
oN7o000001Sooooo00Go0000ooooooooooooooooo`000001ooooo`00E_ooool00ol0003ooooooooo
o`0[ooooo`06o`000?l0BLKo0000o`000?l0E]3o00002_m@SN/8o`0000WoT[;/00?o0000okg?j?nm
cnP02_nmcnP00ol0003odMWOom7Ig`08om7Ig`03o`000?oOg]CogmkD00KogmkD00?o0000onWObOoY
glT01?oYglT00ol0003okmo0onoO`004onoO`003o`000?obg[Wol]ji00Col]ji00?o0000oooooooo
ool0@_ooool01Ol0003o?4Vfoca9]_llBKKo000000coDERk0ol0000;oeiP_003o`000?n2S]KoPXkF
00?oPXkF0_l00002ol_mh@03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00000Oooool0
05Oooooo00?o0000ooooooooool0:oooool01_l0003o04W6o`19a_l0003o05K@o`0000[oD8g[00?o
0000oi:bk?nB/^`03_nB/^`2o`0000So_LoX0_l0000:om7Ig`03o`000?oOg]CogmkD00KogmkD00?o
0000onWObOoYglT01OoYglT00ol0003okmo0onoO`003onoO`003o`000?obg[Wol]ji00Col]ji00?o
0000ooooooooool0A?ooool01Ol0003o?4Vfoca9]_llBKKo000000_oDERk00?o0000ogf8dommR=<0
1?l00007oeiP_003o`000?n2S]KoPXkF00;oPXkF00Go0000ol_mhOo;oN7obogQo`00000Kooooo`03
o`000?oooooo0000007ooooo001Hooooo`;o0000;?ooool00ol0003o04W6o`19aP03o`0000[oD8g[
00?o0000oi:bk?nB/^`03onB/^`00ol0003o_LoXokg?j004okg?j003o`000?oAfMoodMWO00WodMWO
00?o0000omoNe?oOg]@01ooOg]@00ol0003ojMo9onWOb@04onWOb@03o`000?o_gl3okmo000Cokmo0
00?o0000oo;N^Oobg[T01?obg[T00ol0003oooooooooo`15ooooo`04o`000?llBKKo?4Vfo`0000co
DERk00?o0000ogf8dommR=<00ommR=<4o`0000CoGV2l00Co0000oh:>e_n2S]Ko00001?o;oN400ol0
003oooooooooo`0Iooooo`03o`000?oooooo0000007ooooo001Jooooo`03o`000?oooooooooo02[o
oooo00Co0000o`19a_l0BLKo04W60_l0000:oe2=j`03o`000?nB/^coT[;/00ooT[;/0_l00003okg?
j003o`000?oAfMoodMWO00[odMWO00?o0000omoNe?oOg]@01_oOg]@00ol0003ojMo9onWOb@05onWO
b@03o`000?o_gl3okmo000?okmo000?o0000oo;N^Oobg[T01?obg[T00ol0003oooooooooo`16oooo
o`04o`000?llBKKo?4Vfo`0000coDERk00?o0000ogf8dommR=<01ommR=<5o`000003oh:>e_l0003o
bogQ00?obogQ00?o0000ooooooooool06oooool1o`00007ooooo0Ol0000005_ooooo00?o0000oooo
ooooool0:_ooool01?l0003o04W6o`19a_l0BLH2o`0000[oD8g[00?o0000oi:bk?nB/^`04?nB/^`0
0ol0003o_LoXo`00000<om7Ig`03o`000?oOg]CogmkD00KogmkD00?o0000onWObOoYglT01OoYglT0
0ol0003okmo0onoO`004onoO`003o`000?obg[Wol]ji00Col]ji00?o0000ooooooooool0Aoooool0
1?l0003o?4Vfoca9]_l0000;oe5H^`03o`000?mmR=?oOHSC00_oOHSC1Ol00002ol_mh@03o`000?oo
oooooooo01cooooo0_l0000005cooooo00?o0000ooooooooool0:_ooool01?l0003o04W6o`19a_l0
BLH2o`0000[oD8g[00?o0000oi:bk?nB/^`03onB/^`3o`0000_odMWO00?o0000omoNe?oOg]@01ooO
g]@00ol0003ojMo9onWOb@04onWOb@03o`000?o_gl3okmo000Cokmo000?o0000oo;N^Oobg[T01?ob
g[T00ol0003oooooooooo`19ooooo`03o`000?llBKKo000000coDERk00?o0000ogf8dommR=<03omm
R=<2o`0001kooooo0ol0000005gooooo0_l0000[ooooo`03o`000?l0BLKo04W600;o04W600?o0000
oe2=jom@SN/01om@SN/00ol0003oT[;/oi:bk00<oi:bk0?o00000onW_^X00ol0003odMWOom7Ig`07
om7Ig`03o`000?oOg]CogmkD00OogmkD00?o0000onWObOoYglT01OoYglT00ol0003okmo0onoO`004
onoO`003o`000?obg[Wol]ji00Col]ji00?o0000ooooooooool0B_ooool2o`0000coDERk00?o0000
ogf8dommR=<03_mmR=<00ol0003oooooooooo`0Jooooo`Co00000oooool005oooooo00?o0000oooo
ooooool0:Oooool2o`0000?o04W60ol00007oe2=j`03o`000?nB/^coT[;/00SoT[;/0ol00007ojNn
jP;o00001_oAfMl00ol0003ogmkDomoNe007omoNe003o`000?oYglWojMo900GojMo900?o0000onoO
`?o_gl001?o_gl000ol0003ol]jioo;N^@04oo;N^@03o`000?oooooooooo04cooooo0_l0000<oe5H
^`03o`000?mmR=?oOHSC00_oOHSC0_l0000Iooooo`Co00001oooool0063ooooo00?o0000oooooooo
ool0:?ooool00ol0003o046oo`000002o`19aP03o`000?mKUNgoFiG]00Go00000om@SN/00ol0003o
T[;/oi:bk004oi:bk0?o00003?nW_^X2o`0000?odMWO00?o0000omoNe?oOg]@02?oOg]@00ol0003o
jMo9onWOb@05onWOb@03o`000?o_gl3okmo000Cokmo000?o0000oo;N^Oobg[T01?obg[T00ol0003o
ooooooooo`1=ooooo`;o00002omAF;/00ol0003oOHSCogf8d`0:ogf8d`03o`000?oooooooooo01Ko
oooo0ol0000;ooooo`00HOooool00ol0003oooooooooo`0Xooooo`06o`000?l0@Koo0000o`000?l0
BLKo00001_mKUNd5o`0000;oT[;/0ol0000AojNnjP03o`000?oAfMoo000000[ogmkD00?o0000onWO
bOoYglT01OoYglT00ol0003okmo0onoO`004onoO`003o`000?obg[Wol]ji00Col]ji00?o0000oooo
ooooool0D?ooool2o`0000WoDERk00?o0000ogf8dommR=<02?mmR=<2o`0001Gooooo1?l0000>oooo
o`00H_ooool2o`0002Wooooo00Ko0000o`11_ol0@Koo0000o`19a_l00009oe^Ek@?o00005?nW_^X3
o`0000WogmkD00?o0000onWObOoYglT01_oYglT00ol0003okmo0onoO`004onoO`003o`000?obg[Wo
l]ji00Col]ji00?o0000ooooooooool0D_ooool3o`0000OoDERk00?o0000ogf8dommR=<01_mmR=<0
0ol0003oooooooooo`0Aooooo`Co00004_ooool006Cooooo00?o0000ooooooooool09oooool00ol0
003o046oo`11_`03o`0000_oFiG]00?o0000ojNnj_nW_^X03onW_^X2o`0000?o_<ST0_l00006omoN
e003o`000?oYglWojMo900KojMo900?o0000onoO`?o_gl001?o_gl000ol0003ol]jioo;N^@04oo;N
^@03o`000?oooooooooo05Kooooo0_l00005oe5H^`03o`000?mmR=?oOHSC00CoOHSC0_l0000@oooo
o`Co00005_ooool006Gooooo00?o0000ooooooooool09oooool01?l0003o046oo`11_ol0@Kl2o`00
00_oFiG]00?o0000ojNnj_nW_^X03OnW_^X00ol0003o_<STokc8i005okc8i0;o00001?oOg]@00ol0
003ojMo9onWOb@06onWOb@03o`000?o_gl3okmo000Cokmo000?o0000oo;N^Oobg[T01?obg[T00ol0
003oooooooooo`1Hooooo`;o00001?mAF;/00ol0003oOHSCogf8d`02ogf8d`03o`000?oooooooooo
00cooooo1?l0000Jooooo`00I_ooool00ol0003oooooooooo`0Wooooo`04o`000?l0@Koo046oo`11
_`;o00002omKUNd00ol0003oYkkZojNnjP0:ojNnjP;o00002_nlb>@2o`000003omoNe?l0003ojMo9
00OojMo900?o0000onoO`?o_gl001?o_gl000ol0003ol]jioo;N^@05oo;N^@03o`000?oooooooooo
05[ooooo0ol000001?mAF;_o0000ogf8dommR=<2o`0000cooooo0ol0000Nooooo`00Ioooool00ol0
003oooooooooo`0Wooooo`04o`000?l0@Koo046oo`11_`;o00002omKUNd00ol0003oYkkZojNnjP07
ojNnjP;o00003Onlb>@4o`0000KojMo900?o0000onoO`?o_gl001Oo_gl000ol0003ol]jioo;N^@04
oo;N^@03o`000?oooooooooo05kooooo0_l000000ommR=?o0000ooooo`09ooooo`Co00008Oooool0
06Sooooo0_l0000Xooooo`03o`000?l0@Koo046o00;o046o00?o0000oe^EkOmKUNd02OmKUNd00ol0
003oYkkZojNnjP04ojNnjP;o00003_nlb>@00ol0003ocLoKolg?f`02olg?f`Co00000_oYglT00ol0
003okmo0onoO`004onoO`003o`000?obg[Wol]ji00Gol]ji00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`05ooooo`Co00009Oooool006[ooooo00?o0000ooooooooool09_ooool2o`0000?o
046o1Ol00007oe^Ek@03o`000?nW_^[oYkkZ00;oYkkZ00?o0000okc8i?nlb>@03Onlb>@00ol0003o
cLoKolg?f`07olg?f`Ko00000oo_gl000ol0003ol]jioo;N^@04oo;N^@03o`000?oooooooooo06Go
oooo1?l0000Yooooo`00Joooool00ol0003oooooooooo`0Vooooo`;o00000_l0@Kl00ol0003oKZ3_
ofjPk`02ofjPk`Oo000000?oFiG]o`000?nW_^X00_l0000?okc8i003o`000?o=cm_ocLoK00WocLoK
00?o0000om[BdOoJd]400_oJd]47o`0000?ol]ji00?o0000ooooooooool0HOooool4o`0002gooooo
001/ooooo`03o`000?oooooooooo02Kooooo0ol000000ol0@Koo0000ofjPk`09ofjPk`Co00003_nl
b>@2o`0000_ocLoK00?o0000om[BdOoJd]401OoJd]400ol0003ohm?7on?Ca`02on?Ca`?o0000HOoo
ool3o`00037ooooo001]ooooo`;o00009oooool01Ol0003o03blo`000?l0@Koo000000goKZ3_00?o
0000okc8i?nlb>@02_nlb>@00ol0003ocLoKolg?f`0:olg?f`03o`000?oJd]7of];A00Gof];A00?o
0000on?CaooSdlL01OoSdlL00ol0003oooooooooo`1Kooooo`Co0000=?ooool006oooooo00?o0000
ooooooooool09Oooool00ol0003o03blo`000002o`0000goKZ3_00?o0000okc8i?nlb>@02?nlb>@0
0ol0003ocLoKolg?f`0:olg?f`03o`000?oJd]7of];A00Gof];A00?o0000on?CaooSdlL01OoSdlL0
0ol0003oooooooooo`1Hooooo`Co0000>?ooool0073ooooo00?o0000ooooooooool09Oooool00ol0
003o03blo`0l_002o`0000goKZ3_00?o0000okc8i?nlb>@01Onlb>@2o`0000cocLoK00?o0000om[B
dOoJd]401OoJd]400ol0003ohm?7on?Ca`06on?Ca`03o`000?oooooooooo05Cooooo1?l0000loooo
o`00LOooool00ol0003oooooooooo`0Uooooo`03o`000?l0?;co03bl00;o00003Om^X>l00ol0003o
_<STokc8i003okc8i003o`000?o=cm_ocLoK00_ocLoK00?o0000om[BdOoJd]401_oJd]400ol0003o
hm?7on?Ca`05on?Ca`03o`000?oooooooooo057ooooo1?l00010ooooo`00L_ooool2o`0002Kooooo
00?o0000o`0l_?l0?;`00_l0000=ofjPk`05o`000?nlb>Co_<STokc8i?l000003Oo=cm/00ol0003o
f];Aom[Bd@06om[Bd@03o`000?oSdlOohm?700Gohm?700?o0000ooooooooool0C_ooool4o`0004Co
oooo001dooooo`03o`000?oooooooooo02Cooooo0_l00002o`0l_003o`000?m^X>ooKZ3_00_oKZ3_
00?o0000okc8i?l000003Oo=cm/00ol0003of];Aom[Bd@06om[Bd@03o`000?oSdlOohm?700Kohm?7
00?o0000ooooooooool0Boooool3o`0004Sooooo001eooooo`03o`000?oooooooooo02Cooooo0_l0
0002o`0l_13o00003?o=cm/00ol0003of];Aom[Bd@06om[Bd@03o`000?oSdlOohm?700Kohm?700?o
0000ooooooooool0B?ooool4o`0004_ooooo001fooooo`03o`000?oooooooooo02Cooooo0_l00000
0ol0?;co0000ohB]k`0>ohB]k`03o`000?o=cm_ocLoK00SocLoK00?o0000om[BdOoJd]401ooJd]40
0ol0003ohm?7on?Ca`06on?Ca`03o`000?oooooooooo04Cooooo1?l0001?ooooo`00Moooool00ol0
003oooooooooo`0Tooooo`Co00003on4[Nl00ol0003ocLoKolg?f`06olg?f`03o`000?oJd]7of];A
00Oof];A00?o0000on?CaooSdlL01_oSdlL00ol0003oooooooooo`11ooooo`Co0000Doooool007So
oooo0_l0000Tooooo`;o000000?o03flo`000?l000003on4[Nl2o`0000GocLoK00?o0000om[BdOoJ
d]401ooJd]400ol0003ohm?7on?Ca`06on?Ca`03o`000?oooooooooo03kooooo1?l0001Gooooo`00
N_ooool00ol0003oooooooooo`0Qooooo`04o`000?oooooo0000o`0m_0;o00004?n4[Nl01Ol0003o
cLoKolg?foo=cm_o000000[of];A00?o0000on?CaooSdlL01_oSdlL00ol0003oooooooooo`0koooo
o`?o0000Foooool007_ooooo00?o0000ooooooooool08?ooool01Ol0003oooooooooool0003o03fl
00;o00004?n4[Nl00ol0003ocLoKo`00000:om[Bd@03o`000?oSdlOohm?700Kohm?700?o0000oooo
ooooool0>?ooool4o`0005kooooo001looooo`03o`000?oooooooooo01oooooo00Ko0000oooooooo
ooooooooo`000?l0?K`2o`0000koQ:g_1?l00009om[Bd@03o`000?oSdlOohm?700Oohm?700?o0000
ooooooooool0=?ooool4o`0006;ooooo001mooooo`;o00007oooool00ol0003oooooooooo`02oooo
o`;o000000?o03flo`000?n4[Nl01on4[Nl5o`0000CoVkS/00?o0000om[BdOoJd]401OoJd]400ol0
003ohm?7on?Ca`07on?Ca`03o`000?oooooooooo037ooooo1?l0001Vooooo`00Ooooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00?ooooo0_l000001?l0?Kco0000ohB]kon4[Nl5o`00
00[oVkS/0_l00005om[Bd@03o`000?oSdlOohm?700Kohm?700?o0000ooooooooool0;_ooool4o`00
06[ooooo0020ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool5o`00017o
VkS/00Go0000om[BdOoJd]7of];Ao`000009on?Ca`03o`000?oooooooooo02_ooooo0ol0001^oooo
o`00POooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00Go0000o`13`?l0
003o03flo`00000Aoi^hk003o`000?oJd]7o000000Wohm?700?o0000ooooooooool0:?ooool4o`00
077ooooo0022ooooo`;o00006_ooool00ol0003oooooooooo`06ooooo`03o`000?l0@l3o000000;o
00004?nK^>`3o`0000Wohm?700?o0000ooooooooool09?ooool4o`0007Gooooo0024ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o04?0o`13`002o`0000coVkS/
0ol00003ok30i@;o00001_oSdlL00ol0003oooooooooo`0Qooooo`Co0000NOooool008Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?l0@l3o04?000;o00002?nK
^>`3o`0000So/<3U0_l00003on?Ca`03o`000?oooooooooo01kooooo1?l0001mooooo`00Q_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000o`13`?l0@l000_l00005
oi^hk0;o00003On``>D2o`000003on?Caol0003ooooo01cooooo0ol00021ooooo`00Qoooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo0_l00002o`13`003o`000?nK^>co0000
00;o00004?n``>D2o`0001[ooooo1?l00024ooooo`00R?ooool2o`0001Cooooo00?o0000oooooooo
ool03?ooool01?l0003o04?0o`13`?l0000Bok30i@03o`000?oooooooooo01Kooooo1?l00028oooo
o`00R_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000o`13`?l0
00004?n``>D2o`0001Gooooo1?l0002<ooooo`00Roooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00kooooo0ol0000>ok30i@03o`000?oooooooooo017ooooo1?l0002@ooooo`00S?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo0_l0000;ok30i@;o00004?oo
ool4o`0009Cooooo002=ooooo`;o00003oooool00ol0003oooooooooo`0Aooooo`;o00002?n``>D2
o`0000oooooo0ol0002Hooooo`00Soooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01;ooooo0_l00006ok30i@03o`000?oooooooooo00_ooooo1?l0002Kooooo`00T?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00Co0000ok30iOn``>Go/<3U0_l0000:oooo
o`Co0000Woooool0097ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03
o`000?n``>Go000000Sooooo1?l0002Sooooo`00T_ooool2o`0000Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`03ooooo`Co0000Yoooool009Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Jooooo`?o0000Zoooool009Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`Co0000[_ooool009Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`Co0000/_ooool009Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0>ooooo`Co0000]_ooool009Sooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
1?l0002jooooo`00V_ooool01?l0003oooooooooool00009ooooo`?o0000__ooool009_ooooo00?o
0000ooooool000001Oooool4o`000<7ooooo002Looooo`;o000000?oooooo`000?l000000_l00035
ooooo`00WOooool2o`000<Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {0, 0, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["You can change the viewpoint of this plot by using a",
    FontWeight->"Plain"],
  " ",
  StyleBox["Show ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["command, coupled with a ",
    FontWeight->"Plain"],
  StyleBox["ViewPoint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" option.",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox[" See, for example, Cell ",
    FontWeight->"Plain"],
  StyleBox[ButtonBox["9.82",
    ButtonData:>"Cell 9.82",
    ButtonStyle->"Hyperlink"],
    FontWeight->"Plain"],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold",
  CellTags->"i:53"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plt, ViewPoint -> {0.000, \ 0.000, \ 3.000}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.82"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[0 -0.0125 -3 -9 ]
[0 -0.0125 3 0 ]
[.31831 -0.0125 -3 -9 ]
[.31831 -0.0125 3 0 ]
[.63662 -0.0125 -3 -9 ]
[.63662 -0.0125 3 0 ]
[.95493 -0.0125 -3 -9 ]
[.95493 -0.0125 3 0 ]
[-0.0125 0 -6 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .31831 -6 -4.5 ]
[-0.0125 .31831 0 4.5 ]
[-0.0125 .63662 -6 -4.5 ]
[-0.0125 .63662 0 4.5 ]
[-0.0125 .95493 -6 -4.5 ]
[-0.0125 .95493 0 4.5 ]
[.95111 .93861 0 -4.5 ]
[.95111 .93861 12 4.5 ]
[.96465 .95215 0 -4.5 ]
[.96465 .95215 24 4.5 ]
[.97906 .96656 0 -4.5 ]
[.97906 .96656 6 4.5 ]
[.99441 .98191 0 -4.5 ]
[.99441 .98191 18 4.5 ]
[1.01081 .99831 0 -4.5 ]
[1.01081 .99831 6 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .00625 L
s
[(0)] 0 -0.0125 0 1 Mshowa
.31831 0 m
.31831 .00625 L
s
[(1)] .31831 -0.0125 0 1 Mshowa
.63662 0 m
.63662 .00625 L
s
[(2)] .63662 -0.0125 0 1 Mshowa
.95493 0 m
.95493 .00625 L
s
[(3)] .95493 -0.0125 0 1 Mshowa
.125 Mabswid
.06366 0 m
.06366 .00375 L
s
.12732 0 m
.12732 .00375 L
s
.19099 0 m
.19099 .00375 L
s
.25465 0 m
.25465 .00375 L
s
.38197 0 m
.38197 .00375 L
s
.44563 0 m
.44563 .00375 L
s
.5093 0 m
.5093 .00375 L
s
.57296 0 m
.57296 .00375 L
s
.70028 0 m
.70028 .00375 L
s
.76394 0 m
.76394 .00375 L
s
.82761 0 m
.82761 .00375 L
s
.89127 0 m
.89127 .00375 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
.00625 0 L
s
[(0)] -0.0125 0 1 0 Mshowa
0 .31831 m
.00625 .31831 L
s
[(1)] -0.0125 .31831 1 0 Mshowa
0 .63662 m
.00625 .63662 L
s
[(2)] -0.0125 .63662 1 0 Mshowa
0 .95493 m
.00625 .95493 L
s
[(3)] -0.0125 .95493 1 0 Mshowa
.125 Mabswid
0 .06366 m
.00375 .06366 L
s
0 .12732 m
.00375 .12732 L
s
0 .19099 m
.00375 .19099 L
s
0 .25465 m
.00375 .25465 L
s
0 .38197 m
.00375 .38197 L
s
0 .44563 m
.00375 .44563 L
s
0 .5093 m
.00375 .5093 L
s
0 .57296 m
.00375 .57296 L
s
0 .70028 m
.00375 .70028 L
s
0 .76394 m
.00375 .76394 L
s
0 .82761 m
.00375 .82761 L
s
0 .89127 m
.00375 .89127 L
s
.25 Mabswid
.9375 .9375 m
1 1 L
s
.93861 .93861 m
.93236 .93861 L
s
[(-1)] .95111 .93861 -1 0 Mshowa
.95215 .95215 m
.9459 .95215 L
s
[(-0.5)] .96465 .95215 -1 0 Mshowa
.96656 .96656 m
.96031 .96656 L
s
[(0)] .97906 .96656 -1 0 Mshowa
.98191 .98191 m
.97566 .98191 L
s
[(0.5)] .99441 .98191 -1 0 Mshowa
.99831 .99831 m
.99206 .99831 L
s
[(1)] 1.01081 .99831 -1 0 Mshowa
.125 Mabswid
.94125 .94125 m
.9375 .94125 L
s
.94393 .94393 m
.94018 .94393 L
s
.94664 .94664 m
.94289 .94664 L
s
.94938 .94938 m
.94563 .94938 L
s
.95496 .95496 m
.95121 .95496 L
s
.95781 .95781 m
.95406 .95781 L
s
.96069 .96069 m
.95694 .96069 L
s
.9636 .9636 m
.95985 .9636 L
s
.96955 .96955 m
.9658 .96955 L
s
.97258 .97258 m
.96883 .97258 L
s
.97565 .97565 m
.9719 .97565 L
s
.97876 .97876 m
.97501 .97876 L
s
.9851 .9851 m
.98135 .9851 L
s
.98834 .98834 m
.98459 .98834 L
s
.99161 .99161 m
.98786 .99161 L
s
.99494 .99494 m
.99119 .99494 L
s
.25 Mabswid
.0625 .0625 m
0 0 L
s
0 0 m
0 1 L
s
0 1 m
.0625 .9375 L
s
.0625 .9375 m
.0625 .0625 L
s
.9375 .0625 m
.9375 .9375 L
s
.9375 .9375 m
1 1 L
s
1 1 m
1 0 L
s
1 0 m
.9375 .0625 L
s
.0625 .0625 m
0 0 L
s
0 0 m
1 0 L
s
1 0 m
.9375 .0625 L
s
.9375 .0625 m
.0625 .0625 L
s
.0625 .9375 m
.9375 .9375 L
s
.9375 .9375 m
1 1 L
s
1 1 m
0 1 L
s
0 1 m
.0625 .9375 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.03344 .03344 .03344 .10009 .09881 .09881 .10009 .03344 Metetra
.706 .55 .674 r
.10009 .03344 .09881 .09881 .1646 .09752 .16675 .03344 Metetra
.704 .521 .638 r
.16675 .03344 .1646 .09752 .23082 .09622 .2334 .03344 Metetra
.7 .489 .599 r
.2334 .03344 .23082 .09622 .29747 .09493 .30005 .03344 Metetra
.694 .456 .558 r
.30005 .03344 .29747 .09493 .36455 .09364 .3667 .03344 Metetra
.686 .42 .515 r
.3667 .03344 .36455 .09364 .43206 .09237 .43335 .03344 Metetra
.676 .383 .469 r
.43335 .03344 .43206 .09237 .5 .0911 .5 .03344 Metetra
.567 .118 .144 r
.89991 .03344 .91604 .08396 .98665 .08287 .96656 .03344 Metetra
.585 .153 .188 r
.83325 .03344 .84577 .08507 .91604 .08396 .89991 .03344 Metetra
.603 .19 .233 r
.7666 .03344 .77585 .08623 .84577 .08507 .83325 .03344 Metetra
.62 .229 .28 r
.69995 .03344 .7063 .08741 .77585 .08623 .7666 .03344 Metetra
.636 .267 .327 r
.6333 .03344 .63713 .08862 .7063 .08741 .69995 .03344 Metetra
.651 .306 .375 r
.56665 .03344 .56836 .08985 .63713 .08862 .6333 .03344 Metetra
.664 .345 .423 r
.5 .03344 .5 .0911 .56836 .08985 .56665 .03344 Metetra
.674 .55 .706 r
.03344 .10009 .03344 .16675 .09752 .1646 .09881 .09881 Metetra
.673 .522 .673 r
.09881 .09881 .09752 .1646 .16244 .16244 .1646 .09752 Metetra
.67 .493 .637 r
.1646 .09752 .16244 .16244 .22824 .16031 .23082 .09622 Metetra
.666 .462 .6 r
.23082 .09622 .22824 .16031 .29492 .15821 .29747 .09493 Metetra
.66 .432 .563 r
.29747 .09493 .29492 .15821 .36247 .15617 .36455 .09364 Metetra
.654 .403 .527 r
.36455 .09364 .36247 .15617 .43085 .15423 .43206 .09237 Metetra
.648 .375 .493 r
.43206 .09237 .43085 .15423 .5 .15239 .5 .0911 Metetra
.633 .312 .41 r
.91604 .08396 .92613 .14489 .99787 .14438 .98665 .08287 Metetra
.629 .304 .401 r
.84577 .08507 .85437 .14563 .92613 .14489 .91604 .08396 Metetra
.628 .302 .399 r
.77585 .08623 .78272 .1466 .85437 .14563 .84577 .08507 Metetra
.629 .306 .405 r
.7063 .08741 .71133 .14778 .78272 .1466 .77585 .08623 Metetra
.631 .316 .418 r
.63713 .08862 .64034 .14915 .71133 .14778 .7063 .08741 Metetra
.636 .331 .438 r
.56836 .08985 .56986 .15069 .64034 .14915 .63713 .08862 Metetra
.641 .351 .463 r
.5 .0911 .5 .15239 .56986 .15069 .56836 .08985 Metetra
.638 .521 .704 r
.03344 .16675 .03344 .2334 .09622 .23082 .09752 .1646 Metetra
.637 .493 .67 r
.09752 .1646 .09622 .23082 .16031 .22824 .16244 .16244 Metetra
.635 .465 .635 r
.16244 .16244 .16031 .22824 .22575 .22575 .22824 .16031 Metetra
.633 .439 .602 r
.22824 .16031 .22575 .22575 .29254 .22338 .29492 .15821 Metetra
.632 .417 .573 r
.29492 .15821 .29254 .22338 .36061 .22122 .36247 .15617 Metetra
.632 .401 .551 r
.36247 .15617 .36061 .22122 .42983 .21932 .43085 .15423 Metetra
.633 .394 .537 r
.43085 .15423 .42983 .21932 .5 .21773 .5 .15239 Metetra
.693 .588 .734 r
.92613 .14489 .92491 .21672 .99346 .21803 .99787 .14438 Metetra
.686 .54 .682 r
.85437 .14563 .85523 .21582 .92491 .21672 .92613 .14489 Metetra
.676 .495 .634 r
.78272 .1466 .78467 .21533 .85523 .21582 .85437 .14563 Metetra
.664 .457 .593 r
.71133 .14778 .71353 .21529 .78467 .21533 .78272 .1466 Metetra
.654 .426 .562 r
.64034 .14915 .64216 .21568 .71353 .21529 .71133 .14778 Metetra
.644 .405 .542 r
.56986 .15069 .57087 .21651 .64216 .21568 .64034 .14915 Metetra
.638 .395 .534 r
.5 .15239 .5 .21773 .57087 .21651 .56986 .15069 Metetra
.599 .489 .7 r
.03344 .2334 .03344 .30005 .09493 .29747 .09622 .23082 Metetra
.6 .462 .666 r
.09622 .23082 .09493 .29747 .15821 .29492 .16031 .22824 Metetra
.602 .439 .633 r
.16031 .22824 .15821 .29492 .22338 .29254 .22575 .22575 Metetra
.606 .422 .606 r
.22575 .22575 .22338 .29254 .29042 .29042 .29254 .22338 Metetra
.614 .415 .589 r
.29254 .22338 .29042 .29042 .35911 .28867 .36061 .22122 Metetra
.625 .421 .585 r
.36061 .22122 .35911 .28867 .42913 .28738 .42983 .21932 Metetra
.64 .44 .596 r
.42983 .21932 .42913 .28738 .5 .28663 .5 .21773 Metetra
.702 .773 .907 r
.92491 .21672 .91305 .29347 .97615 .29594 .99346 .21803 Metetra
.71 .732 .868 r
.85523 .21582 .84795 .29123 .91305 .29347 .92491 .21672 Metetra
.712 .683 .82 r
.78467 .21533 .78091 .28932 .84795 .29123 .85523 .21582 Metetra
.706 .627 .766 r
.71353 .21529 .71216 .28784 .78091 .28932 .78467 .21533 Metetra
.693 .57 .712 r
.64216 .21568 .64209 .28686 .71216 .28784 .71353 .21529 Metetra
.676 .517 .662 r
.57087 .21651 .57118 .28645 .64209 .28686 .64216 .21568 Metetra
.658 .472 .622 r
.5 .21773 .5 .28663 .57118 .28645 .57087 .21651 Metetra
.558 .456 .694 r
.03344 .30005 .03344 .3667 .09364 .36455 .09493 .29747 Metetra
.563 .432 .66 r
.09493 .29747 .09364 .36455 .15617 .36247 .15821 .29492 Metetra
.573 .417 .632 r
.15821 .29492 .15617 .36247 .22122 .36061 .22338 .29254 Metetra
.589 .415 .614 r
.22338 .29254 .22122 .36061 .28867 .35911 .29042 .29042 Metetra
.612 .43 .612 r
.29042 .29042 .28867 .35911 .35809 .35809 .35911 .28867 Metetra
.639 .463 .628 r
.35911 .28867 .35809 .35809 .42882 .35764 .42913 .28738 Metetra
.67 .512 .662 r
.42913 .28738 .42882 .35764 .5 .3578 .5 .28663 Metetra
.711 .857 .951 r
.91305 .29347 .89659 .3678 .9557 .3698 .97615 .29594 Metetra
.723 .838 .935 r
.84795 .29123 .83582 .36567 .89659 .3678 .91305 .29347 Metetra
.735 .808 .91 r
.78091 .28932 .77293 .36354 .83582 .36567 .84795 .29123 Metetra
.74 .764 .872 r
.71216 .28784 .70768 .36155 .77293 .36354 .78091 .28932 Metetra
.737 .708 .823 r
.64209 .28686 .64016 .35984 .70768 .36155 .71216 .28784 Metetra
.723 .642 .767 r
.57118 .28645 .57072 .35856 .64016 .35984 .64209 .28686 Metetra
.699 .574 .711 r
.5 .28663 .5 .3578 .57072 .35856 .57118 .28645 Metetra
.515 .42 .686 r
.03344 .3667 .03344 .43335 .09237 .43206 .09364 .36455 Metetra
.527 .403 .654 r
.09364 .36455 .09237 .43206 .15423 .43085 .15617 .36247 Metetra
.551 .401 .632 r
.15617 .36247 .15423 .43085 .21932 .42983 .22122 .36061 Metetra
.585 .421 .625 r
.22122 .36061 .21932 .42983 .28738 .42913 .28867 .35911 Metetra
.628 .463 .639 r
.28867 .35911 .28738 .42913 .35764 .42882 .35809 .35809 Metetra
.674 .525 .674 r
.35809 .35809 .35764 .42882 .42895 .42895 .42882 .35764 Metetra
.718 .601 .725 r
.42882 .35764 .42895 .42895 .5 .42951 .5 .3578 Metetra
.751 .874 .936 r
.89659 .3678 .88265 .43622 .94163 .43691 .9557 .3698 Metetra
.752 .879 .937 r
.83582 .36567 .82366 .43527 .88265 .43622 .89659 .3678 Metetra
.759 .871 .929 r
.77293 .36354 .76357 .43411 .82366 .43527 .83582 .36567 Metetra
.769 .849 .911 r
.70768 .36155 .70149 .43284 .76357 .43411 .77293 .36354 Metetra
.775 .811 .881 r
.64016 .35984 .63688 .43156 .70149 .43284 .70768 .36155 Metetra
.771 .754 .838 r
.57072 .35856 .56959 .43041 .63688 .43156 .64016 .35984 Metetra
.752 .681 .783 r
.5 .3578 .5 .42951 .56959 .43041 .57072 .35856 Metetra
.469 .383 .676 r
.03344 .43335 .03344 .5 .0911 .5 .09237 .43206 Metetra
.493 .375 .648 r
.09237 .43206 .0911 .5 .15239 .5 .15423 .43085 Metetra
.537 .394 .633 r
.15423 .43085 .15239 .5 .21773 .5 .21932 .42983 Metetra
.596 .44 .64 r
.21932 .42983 .21773 .5 .28663 .5 .28738 .42913 Metetra
.662 .512 .67 r
.28738 .42913 .28663 .5 .3578 .5 .35764 .42882 Metetra
.725 .601 .718 r
.35764 .42882 .3578 .5 .42951 .5 .42895 .42895 Metetra
.774 .694 .774 r
.42895 .42895 .42951 .5 .5 .5 .5 .42951 Metetra
.785 .782 .85 r
.88265 .43622 .87614 .5 .93926 .5 .94163 .43691 Metetra
.789 .847 .894 r
.82366 .43527 .81545 .5 .87614 .5 .88265 .43622 Metetra
.791 .877 .91 r
.76357 .43411 .75567 .5 .81545 .5 .82366 .43527 Metetra
.797 .883 .908 r
.70149 .43284 .6953 .5 .75567 .5 .76357 .43411 Metetra
.806 .869 .894 r
.63688 .43156 .63304 .5 .6953 .5 .70149 .43284 Metetra
.811 .834 .868 r
.56959 .43041 .56802 .5 .63304 .5 .63688 .43156 Metetra
.803 .775 .827 r
.5 .42951 .5 .5 .56802 .5 .56959 .43041 Metetra
.144 .118 .567 r
.03344 .89991 .03344 .96656 .08287 .98665 .08396 .91604 Metetra
.41 .312 .633 r
.08396 .91604 .08287 .98665 .14438 .99787 .14489 .92613 Metetra
.734 .588 .693 r
.14489 .92613 .14438 .99787 .21803 .99346 .21672 .92491 Metetra
.907 .773 .702 r
.21672 .92491 .21803 .99346 .29594 .97615 .29347 .91305 Metetra
.951 .857 .711 r
.29347 .91305 .29594 .97615 .3698 .9557 .3678 .89659 Metetra
.936 .874 .751 r
.3678 .89659 .3698 .9557 .43691 .94163 .43622 .88265 Metetra
.85 .782 .785 r
.43622 .88265 .43691 .94163 .5 .93926 .5 .87614 Metetra
.832 .998 .832 r
.92117 .92117 .90657 .97433 .95411 .95411 .97433 .90657 Metetra
.833 .789 .81 r
.85593 .92712 .85168 .99235 .90657 .97433 .92117 .92117 Metetra
.571 .373 .574 r
.78081 .92122 .78465 .99814 .85168 .99235 .85593 .92712 Metetra
.393 .161 .439 r
.70332 .90664 .7092 .98813 .78465 .99814 .78081 .92122 Metetra
.342 .122 .428 r
.63014 .89041 .63383 .96839 .7092 .98813 .70332 .90664 Metetra
.416 .233 .523 r
.56317 .879 .5642 .94938 .63383 .96839 .63014 .89041 Metetra
.629 .506 .694 r
.5 .87614 .5 .93926 .5642 .94938 .56317 .879 Metetra
.188 .153 .585 r
.03344 .83325 .03344 .89991 .08396 .91604 .08507 .84577 Metetra
.401 .304 .629 r
.08507 .84577 .08396 .91604 .14489 .92613 .14563 .85437 Metetra
.682 .54 .686 r
.14563 .85437 .14489 .92613 .21672 .92491 .21582 .85523 Metetra
.868 .732 .71 r
.21582 .85523 .21672 .92491 .29347 .91305 .29123 .84795 Metetra
.935 .838 .723 r
.29123 .84795 .29347 .91305 .3678 .89659 .36567 .83582 Metetra
.937 .879 .752 r
.36567 .83582 .3678 .89659 .43622 .88265 .43527 .82366 Metetra
.894 .847 .789 r
.43527 .82366 .43622 .88265 .5 .87614 .5 .81545 Metetra
.81 .789 .833 r
.92712 .85593 .92117 .92117 .97433 .90657 .99235 .85168 Metetra
.589 .397 .589 r
.85171 .85171 .85593 .92712 .92117 .92117 .92712 .85593 Metetra
.425 .181 .439 r
.77279 .84098 .78081 .92122 .85593 .92712 .85171 .85171 Metetra
.367 .124 .408 r
.69696 .82827 .70332 .90664 .78081 .92122 .77279 .84098 Metetra
.406 .192 .473 r
.62724 .8181 .63014 .89041 .70332 .90664 .69696 .82827 Metetra
.556 .397 .621 r
.56269 .81343 .56317 .879 .63014 .89041 .62724 .8181 Metetra
.766 .679 .766 r
.5 .81545 .5 .87614 .56317 .879 .56269 .81343 Metetra
.233 .19 .603 r
.03344 .7666 .03344 .83325 .08507 .84577 .08623 .77585 Metetra
.399 .302 .628 r
.08623 .77585 .08507 .84577 .14563 .85437 .1466 .78272 Metetra
.634 .495 .676 r
.1466 .78272 .14563 .85437 .21582 .85523 .21533 .78467 Metetra
.82 .683 .712 r
.21533 .78467 .21582 .85523 .29123 .84795 .28932 .78091 Metetra
.91 .808 .735 r
.28932 .78091 .29123 .84795 .36567 .83582 .36354 .77293 Metetra
.929 .871 .759 r
.36354 .77293 .36567 .83582 .43527 .82366 .43411 .76357 Metetra
.91 .877 .791 r
.43411 .76357 .43527 .82366 .5 .81545 .5 .75567 Metetra
.574 .373 .571 r
.92122 .78081 .92712 .85593 .99235 .85168 .99814 .78465 Metetra
.439 .181 .425 r
.84098 .77279 .85171 .85171 .92712 .85593 .92122 .78081 Metetra
.389 .126 .389 r
.76343 .76343 .77279 .84098 .85171 .85171 .84098 .77279 Metetra
.417 .176 .439 r
.69168 .75557 .69696 .82827 .77279 .84098 .76343 .76343 Metetra
.531 .341 .568 r
.6256 .75119 .62724 .8181 .69696 .82827 .69168 .75557 Metetra
.708 .594 .726 r
.56281 .75123 .56269 .81343 .62724 .8181 .6256 .75119 Metetra
.848 .799 .803 r
.5 .75567 .5 .81545 .56269 .81343 .56281 .75123 Metetra
.28 .229 .62 r
.03344 .69995 .03344 .7666 .08623 .77585 .08741 .7063 Metetra
.405 .306 .629 r
.08741 .7063 .08623 .77585 .1466 .78272 .14778 .71133 Metetra
.593 .457 .664 r
.14778 .71133 .1466 .78272 .21533 .78467 .21529 .71353 Metetra
.766 .627 .706 r
.21529 .71353 .21533 .78467 .28932 .78091 .28784 .71216 Metetra
.872 .764 .74 r
.28784 .71216 .28932 .78091 .36354 .77293 .36155 .70768 Metetra
.911 .849 .769 r
.36155 .70768 .36354 .77293 .43411 .76357 .43284 .70149 Metetra
.908 .883 .797 r
.43284 .70149 .43411 .76357 .5 .75567 .5 .6953 Metetra
.439 .161 .393 r
.90664 .70332 .92122 .78081 .99814 .78465 .98813 .7092 Metetra
.408 .124 .367 r
.82827 .69696 .84098 .77279 .92122 .78081 .90664 .70332 Metetra
.439 .176 .417 r
.75557 .69168 .76343 .76343 .84098 .77279 .82827 .69696 Metetra
.538 .324 .538 r
.68856 .68856 .69168 .75557 .76343 .76343 .75557 .69168 Metetra
.686 .55 .694 r
.62544 .68816 .6256 .75119 .69168 .75557 .68856 .68856 Metetra
.814 .757 .8 r
.56351 .69054 .56281 .75123 .6256 .75119 .62544 .68816 Metetra
.88 .862 .818 r
.5 .6953 .5 .75567 .56281 .75123 .56351 .69054 Metetra
.327 .267 .636 r
.03344 .6333 .03344 .69995 .08741 .7063 .08862 .63713 Metetra
.418 .316 .631 r
.08862 .63713 .08741 .7063 .14778 .71133 .14915 .64034 Metetra
.562 .426 .654 r
.14915 .64034 .14778 .71133 .21529 .71353 .21568 .64216 Metetra
.712 .57 .693 r
.21568 .64216 .21529 .71353 .28784 .71216 .28686 .64209 Metetra
.823 .708 .737 r
.28686 .64209 .28784 .71216 .36155 .70768 .35984 .64016 Metetra
.881 .811 .775 r
.35984 .64016 .36155 .70768 .43284 .70149 .43156 .63688 Metetra
.894 .869 .806 r
.43156 .63688 .43284 .70149 .5 .6953 .5 .63304 Metetra
.428 .122 .342 r
.89041 .63014 .90664 .70332 .98813 .7092 .96839 .63383 Metetra
.473 .192 .406 r
.8181 .62724 .82827 .69696 .90664 .70332 .89041 .63014 Metetra
.568 .341 .531 r
.75119 .6256 .75557 .69168 .82827 .69696 .8181 .62724 Metetra
.694 .55 .686 r
.68816 .62544 .68856 .68856 .75557 .69168 .75119 .6256 Metetra
.799 .741 .799 r
.62679 .62679 .62544 .68816 .68856 .68856 .68816 .62544 Metetra
.855 .85 .837 r
.56473 .62946 .56351 .69054 .62544 .68816 .62679 .62679 Metetra
.883 .885 .829 r
.5 .63304 .5 .6953 .56351 .69054 .56473 .62946 Metetra
.375 .306 .651 r
.03344 .56665 .03344 .6333 .08862 .63713 .08985 .56836 Metetra
.438 .331 .636 r
.08985 .56836 .08862 .63713 .14915 .64034 .15069 .56986 Metetra
.542 .405 .644 r
.15069 .56986 .14915 .64034 .21568 .64216 .21651 .57087 Metetra
.662 .517 .676 r
.21651 .57087 .21568 .64216 .28686 .64209 .28645 .57118 Metetra
.767 .642 .723 r
.28645 .57118 .28686 .64209 .35984 .64016 .35856 .57072 Metetra
.838 .754 .771 r
.35856 .57072 .35984 .64016 .43156 .63688 .43041 .56959 Metetra
.868 .834 .811 r
.43041 .56959 .43156 .63688 .5 .63304 .5 .56802 Metetra
.523 .233 .416 r
.879 .56317 .89041 .63014 .96839 .63383 .94938 .5642 Metetra
.621 .397 .556 r
.81343 .56269 .8181 .62724 .89041 .63014 .879 .56317 Metetra
.726 .594 .708 r
.75123 .56281 .75119 .6256 .8181 .62724 .81343 .56269 Metetra
.8 .757 .814 r
.69054 .56351 .68816 .62544 .75119 .6256 .75123 .56281 Metetra
.837 .85 .855 r
.62946 .56473 .62679 .62679 .68816 .62544 .69054 .56351 Metetra
.857 .884 .857 r
.56631 .56631 .56473 .62946 .62679 .62679 .62946 .56473 Metetra
.869 .877 .84 r
.5 .56802 .5 .63304 .56473 .62946 .56631 .56631 Metetra
.423 .345 .664 r
.03344 .5 .03344 .56665 .08985 .56836 .0911 .5 Metetra
.463 .351 .641 r
.0911 .5 .08985 .56836 .15069 .56986 .15239 .5 Metetra
.534 .395 .638 r
.15239 .5 .15069 .56986 .21651 .57087 .21773 .5 Metetra
.622 .472 .658 r
.21773 .5 .21651 .57087 .28645 .57118 .28663 .5 Metetra
.711 .574 .699 r
.28663 .5 .28645 .57118 .35856 .57072 .3578 .5 Metetra
.783 .681 .752 r
.3578 .5 .35856 .57072 .43041 .56959 .42951 .5 Metetra
.827 .775 .803 r
.42951 .5 .43041 .56959 .5 .56802 .5 .5 Metetra
.694 .506 .629 r
.87614 .5 .879 .56317 .94938 .5642 .93926 .5 Metetra
.766 .679 .766 r
.81545 .5 .81343 .56269 .879 .56317 .87614 .5 Metetra
.803 .799 .848 r
.75567 .5 .75123 .56281 .81343 .56269 .81545 .5 Metetra
.818 .862 .88 r
.6953 .5 .69054 .56351 .75123 .56281 .75567 .5 Metetra
.829 .885 .883 r
.63304 .5 .62946 .56473 .69054 .56351 .6953 .5 Metetra
.84 .877 .869 r
.56802 .5 .56631 .56631 .62946 .56473 .63304 .5 Metetra
.843 .841 .843 r
.5 .5 .5 .56802 .56631 .56631 .56802 .5 Metetra
0 g
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
.00625 0 L
s
[(0)] -0.0125 0 1 0 Mshowa
0 .31831 m
.00625 .31831 L
s
[(1)] -0.0125 .31831 1 0 Mshowa
0 .63662 m
.00625 .63662 L
s
[(2)] -0.0125 .63662 1 0 Mshowa
0 .95493 m
.00625 .95493 L
s
[(3)] -0.0125 .95493 1 0 Mshowa
.125 Mabswid
0 .06366 m
.00375 .06366 L
s
0 .12732 m
.00375 .12732 L
s
0 .19099 m
.00375 .19099 L
s
0 .25465 m
.00375 .25465 L
s
0 .38197 m
.00375 .38197 L
s
0 .44563 m
.00375 .44563 L
s
0 .5093 m
.00375 .5093 L
s
0 .57296 m
.00375 .57296 L
s
0 .70028 m
.00375 .70028 L
s
0 .76394 m
.00375 .76394 L
s
0 .82761 m
.00375 .82761 L
s
0 .89127 m
.00375 .89127 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`002?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^06Cooooo1?l000000ol@413oooooooooo`1Pooooo`Go0000Hoooool01OnHV9So410@
o`000?lb<S;oc<c<02?ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0I_ooool00ol0003o
ooooooooo`1Rooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Hoooool01Ol@413o^[ZjoooooomgMgOo
<S8b02?ooooo0008ooooo`05oa0@4?ooooooooooooooool@4100I_ooool00ol0003oooooooooo`1S
ooooo`03oiRHV?lQ8B7ok^k^06Sooooo00?o0000ooooooooool08Oooool000Sooooo00Go0000oooo
ooooooooooooo`00001Vooooo`03o`000?oooooooooo06Cooooo00?oV9RHob4Q8Oo^k^h0I_ooool0
0onYZJWo410@ooooo`0Rooooo`002?ooool01Ol0003ooooooooooooooooo000006Kooooo00?o0000
ooooooooool0IOooool00omgMgOoIVIVooooo`1Tooooo`03oa0@4?l0003o^[Zj02?ooooo0008oooo
o`05oa0@4?ooooooooooooooool@4100I_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
oooo06Cooooo00?o^[Zjob4Q8Oooool08_ooool000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1V
ooooo`03o`000?oooooooooo06;ooooo00Go0000okZj^_ooooooV9RHoa0@401Sooooo`05oa0@4?nH
V9SooooookZj^_l000008oooool000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Tooooo`03oeEE
EOmVIVKo000006Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01Sooooo`05ojVYZOl@413o0000oa0@
4?nYZJT08oooool00?ooooooJOooool00?ooooooJOooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
oooooomTooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`3oooooofCooooo00001Ol@413ooooooooo
oooooooo410@0?ooooooI?ooool00005o`000?ooooooooooooooool000001_ooooooo`0004Wo0000
5Oooool00005o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00000Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooo000001Gooooo00001Ol@413ooooooooooooooooo410@00Kooooo00Co0000oooooooooooo
0000I?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooool0000Eooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`05o`000?ooooooooooooooool00000ooooooloooooo`05o`000?ooooooooooooooool000005Ooo
ool00005onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo000;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooooliooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooocOooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo=Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolcooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4oooool000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooc7ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0?oooooo;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01?ooooo000;ooooo`03o`000?oooooooooo00Soooooool0000co`0000[ooooo00?o0000oooo
ooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o]9>dokBC]00CokBC]003
o`000?ndS:co]8b/01?o]8b/00?o0000okB5XondQJ<04_ndQJ<00ol0003o/gfIok=mV@0Cok=mV@03
o`000?naM8ko/GB>01?o/GB>00?o0000ojm[Pon_Jh<04on_Jh<00ol0003o[F9hojeRN00BojeRN003
o`000?nYF6coZEQ/01?oZEQ/00?o0000ojI>GonVCUl04onVCUl00ol0003oXTACoj94D`0Coj94D`03
o`000?nN>TOoWSY701?oWSY700?o0000oiX`>onJ<3/04_nJ<3/00ol0003oUBL`oiDW<00CoiDW<003
o`000?nA7RCoTAhT01?oTAhT00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`00
2oooool00ol0003oooooooooo`08ooooo`03o`000?ndTkCo]9>d01?o]9>d00?o0000okB<[?ndS:`0
4ondS:`00ol0003o]8FSokB5X`0BokB5X`03o`000?ncOIWo/gfI01?o/gfI00?o0000ok5dS_naM8h0
4onaM8h00ol0003o[f^3ojm[P`0Cojm[P`03o`000?n]HWSo[F9h01;o[F9h00?o0000ojUHK?nYF6`0
4onYF6`00ol0003oYTiOojI>G`0CojI>G`03o`000?nRA5?oXTAC01?oXTAC00?o0000oihjAonN>TL0
4onN>TL00ol0003oVS0koiX`>`0BoiX`>`03o`000?nE9c3oUBL`01?oUBL`00?o0000oi4N9?nA7R@0
5?nA7R@00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000okBC]?ndTk@04ondTk@00ol0003o]8b/okB<[00CokB<[003o`000?nd
QJ?o]8FS01;o]8FS00?o0000ok=mVOncOIT04oncOIT00ol0003o/GB>ok5dSP0Cok5dSP03o`000?n_
Jh?o[f^301?o[f^300?o0000ojeRN?n]HWP04_n]HWP00ol0003oZEQ/ojUHK00CojUHK003o`000?nV
CUooYTiO01?oYTiO00?o0000oj94DonRA5<04onRA5<00ol0003oWSY7oihjA`0CoihjA`03o`000?nJ
<3_oVS0k01?oVS0k00?o0000oiDW<?nE9c004onE9c000ol0003oTAhToi4N900Coi4N9003o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o]9>dokBC]00CokBC]003o`000?ndS:co]8b/01?o]8b/00?o0000okB5XondQJ<04_ndQJ<0
0ol0003o/gfIok=mV@0Cok=mV@03o`000?naM8ko/GB>01?o/GB>00?o0000ojm[Pon_Jh<04on_Jh<0
0ol0003o[F9hojeRN00BojeRN003o`000?nYF6coZEQ/01?oZEQ/00?o0000ojI>GonVCUl04onVCUl0
0ol0003oXTACoj94D`0Coj94D`03o`000?nN>TOoWSY701CoWSY700?o0000oiX`>onJ<3/04_nJ<3/0
0ol0003oUBL`oiDW<00CoiDW<003o`000?nA7RCoTAhT01?oTAhT00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?ndTkCo]9>d
01?o]9>d00?o0000okB<[?ndS:`04ondS:`00ol0003o]8FSokB5X`0BokB5X`03o`000?ncOIWo/gfI
01?o/gfI00?o0000ok5dS_naM8h04onaM8h00ol0003o[f^3ojm[P`0Cojm[P`03o`000?n]HWSo[F9h
01;o[F9h00?o0000ojUHK?nYF6`04onYF6`00ol0003oYTiOojI>G`0CojI>G`03o`000?nRA5?oXTAC
01CoXTAC00?o0000oihjAonN>TL04onN>TL00ol0003oVS0koiX`>`0BoiX`>`03o`000?nE9c3oUBL`
01?oUBL`00?o0000oi4N9?nA7R@05?nA7R@00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000okBC]?ndTk@04ondTk@00ol0003o
]8b/okB<[00CokB<[003o`000?ndQJ?o]8FS01;o]8FS00?o0000ok=mVOncOIT04oncOIT00ol0003o
/GB>ok5dSP0Cok5dSP03o`000?n_Jh?o[f^301?o[f^300?o0000ojeRN?n]HWP04_n]HWP00ol0003o
ZEQ/ojUHK00CojUHK003o`000?nVCUooYTiO01?oYTiO00?o0000oj94DonRA5<05?nRA5<00ol0003o
WSY7oihjA`0CoihjA`03o`000?nJ<3_oVS0k01;oVS0k00?o0000oiDW<?nE9c005?nE9c000ol0003o
TAhToi4N900Coi4N9003o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool000_ooooo
00?o0000ooooooooool02?ooool00ol0003o]9>dokBC]00CokBC]003o`000?ndS:co]8b/01?o]8b/
00?o0000okB5XondQJ<04_ndQJ<00ol0003o/gfIok=mV@0Cok=mV@03o`000?naM8ko/GB>01?o/GB>
00?o0000ojm[Pon_Jh<04on_Jh<00ol0003o[F9hojeRN00BojeRN003o`000?nYF6coZEQ/01?oZEQ/
00?o0000ojI>GonVCUl04onVCUl00ol0003oXTACoj94D`0Doj94D`03o`000?nN>TOoWSY701?oWSY7
00?o0000oiX`>onJ<3/04onJ<3/00ol0003oUBL`oiDW<00CoiDW<003o`000?nA7RCoTAhT01?oTAhT
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?ndTkCo]9>d01?o]9>d00?o0000okB<[?ndS:`04ondS:`00ol0003o]8FSokB5
X`0BokB5X`03o`000?ncOIWo/gfI01?o/gfI00?o0000ok5dS_naM8h04onaM8h00ol0003o[f^3ojm[
P`0Cojm[P`03o`000?n]HWSo[F9h01;o[F9h00?o0000ojUHK?nYF6`04onYF6`00ol0003oYTiOojI>
G`0CojI>G`03o`000?nRA5?oXTAC01CoXTAC00?o0000oihjAonN>TL04onN>TL00ol0003oVS0koiX`
>`0CoiX`>`03o`000?nE9c3oUBL`01?oUBL`00?o0000oi4N9?nA7R@05?nA7R@00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
okBC]?ndTk@04ondTk@00ol0003o]8b/okB<[00CokB<[003o`000?ndQJ?o]8FS01;o]8FS00?o0000
ok=mVOncOIT04oncOIT00ol0003o/GB>ok5dSP0Cok5dSP03o`000?n_Jh?o[f^301?o[f^300?o0000
ojeRN?n]HWP04_n]HWP00ol0003oZEQ/ojUHK00CojUHK003o`000?nVCUooYTiO01?oYTiO00?o0000
oj94DonRA5<05?nRA5<00ol0003oWSY7oihjA`0DoihjA`03o`000?nJ<3_oVS0k01;oVS0k00?o0000
oiDW<?nE9c005?nE9c000ol0003oTAhToi4N900Coi4N9003o`000?oooooooooo00Gooooo00?o0000
ooooooooool04oooool000_ooooo0_l00009ooooo`03o`000?ndTkCo]9>d01?o]9>d00?o0000okB<
[?ndS:`04ondS:`00ol0003o]8FSokB5X`0BokB5X`03o`000?ncOIWo/gfI01?o/gfI00?o0000ok5d
S_naM8h04_naM8h00ol0003o[f^3ojm[P`0Cojm[P`03o`000?n]HWSo[F9h01?o[F9h00?o0000ojUH
K?nYF6`05?nYF6`00ol0003oYTiOojI>G`0CojI>G`03o`000?nRA5?oXTAC01?oXTAC00?o0000oihj
AonN>TL05?nN>TL00ol0003oVS0koiX`>`0BoiX`>`03o`000?nE9c3oUBL`01CoUBL`00?o0000oi4N
9?nA7R@05?nA7R@00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03
o`000?oooooooooo00Sooooo00?o0000okBC]?ndTk@04_ndTk@00ol0003o]8b/okB<[00CokB<[003
o`000?ndQJ?o]8FS01?o]8FS00?o0000ok=mVOncOIT04_ncOIT00ol0003o/GB>ok5dSP0Cok5dSP03
o`000?n_Jh?o[f^301?o[f^300?o0000ojeRN?n]HWP04on]HWP00ol0003oZEQ/ojUHK00DojUHK003
o`000?nVCUooYTiO01?oYTiO00?o0000oj94DonRA5<04onRA5<00ol0003oWSY7oihjA`0DoihjA`03
o`000?nJ<3_oVS0k01;oVS0k00?o0000oiDW<?nE9c005?nE9c000ol0003oTAhToi4N900Doi4N9003
o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool0
2?ooool00ol0003o]9>dokBC]00BokBC]003o`000?ndS:co]8b/01?o]8b/00?o0000okB5XondQJ<0
4ondQJ<00ol0003o/gfIok=mV@0Bok=mV@03o`000?naM8ko/GB>01?o/GB>00?o0000ojm[Pon_Jh<0
4on_Jh<00ol0003o[F9hojeRN00CojeRN003o`000?nYF6coZEQ/01CoZEQ/00?o0000ojI>GonVCUl0
4onVCUl00ol0003oXTACoj94D`0Coj94D`03o`000?nN>TOoWSY701CoWSY700?o0000oiX`>onJ<3/0
4onJ<3/00ol0003oUBL`oiDW<00DoiDW<003o`000?nA7RCoTAhT01?oTAhT00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?nd
TkCo]9>d01;o]9>d00?o0000okB<[?ndS:`04ondS:`00ol0003o]8FSokB5X`0CokB5X`03o`000?nc
OIWo/gfI01;o/gfI00?o0000ok5dS_naM8h04onaM8h00ol0003o[f^3ojm[P`0Cojm[P`03o`000?n]
HWSo[F9h01?o[F9h00?o0000ojUHK?nYF6`05?nYF6`00ol0003oYTiOojI>G`0CojI>G`03o`000?nR
A5?oXTAC01?oXTAC00?o0000oihjAonN>TL05?nN>TL00ol0003oVS0koiX`>`0CoiX`>`03o`000?nE
9c3oUBL`01CoUBL`00?o0000oi4N9?nA7R@05?nA7R@00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000okBC]?ndTk@04_ndTk@0
0ol0003o]8b/okB<[00CokB<[003o`000?ndQJ?o]8FS01?o]8FS00?o0000ok=mVOncOIT04_ncOIT0
0ol0003o/GB>ok5dSP0Cok5dSP03o`000?n_Jh?o[f^301?o[f^300?o0000ojeRN?n]HWP04on]HWP0
0ol0003oZEQ/ojUHK00DojUHK003o`000?nVCUooYTiO01?oYTiO00?o0000oj94DonRA5<05?nRA5<0
0ol0003oWSY7oihjA`0CoihjA`03o`000?nJ<3_oVS0k01?oVS0k00?o0000oiDW<?nE9c005?nE9c00
0ol0003oTAhToi4N900Doi4N9003o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
00_ooooo00?o0000ooooooooool02?ooool00ol0003o]9>dokBC]00BokBC]003o`000?ndS:co]8b/
01?o]8b/00?o0000okB5XondQJ<04ondQJ<00ol0003o/gfIok=mV@0Bok=mV@03o`000?naM8ko/GB>
01?o/GB>00?o0000ojm[Pon_Jh<04on_Jh<00ol0003o[F9hojeRN00CojeRN003o`000?nYF6coZEQ/
01CoZEQ/00?o0000ojI>GonVCUl04onVCUl00ol0003oXTACoj94D`0Doj94D`03o`000?nN>TOoWSY7
01CoWSY700?o0000oiX`>onJ<3/04_nJ<3/00ol0003oUBL`oiDW<00EoiDW<003o`000?nA7RCoTAhT
01?oTAhT00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003o
ooooooooo`08ooooo`03o`000?ndTkCo]9>d01;o]9>d00?o0000okB<[?ndS:`04ondS:`00ol0003o
]8FSokB5X`0CokB5X`03o`000?ncOIWo/gfI01;o/gfI00?o0000ok5dS_naM8h04onaM8h00ol0003o
[f^3ojm[P`0Cojm[P`03o`000?n]HWSo[F9h01?o[F9h00?o0000ojUHK?nYF6`05?nYF6`00ol0003o
YTiOojI>G`0CojI>G`03o`000?nRA5?oXTAC01CoXTAC00?o0000oihjAonN>TL05?nN>TL00ol0003o
VS0koiX`>`0CoiX`>`03o`000?nE9c3oUBL`00WoUBL`8ol00004ooooo`03o`000?oooooooooo01?o
oooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000okBC]?ndTk@04_ndTk@00ol0003o]8b/
okB<[00CokB<[003o`000?ndQJ?o]8FS01?o]8FS00?o0000ok=mVOncOIT04_ncOIT00ol0003o/GB>
ok5dSP0Cok5dSP03o`000?n_Jh?o[f^301?o[f^300?o0000ojeRN?n]HWP04on]HWP00ol0003oZEQ/
ojUHK00DojUHK003o`000?nVCUooYTiO01?oYTiO00?o0000oj94DonRA5<02OnRA5=4o`0000_oXDeV
00?o0000oj9?J?nRCfP05?nRCfP00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
000;ooooo`03o`000?oooooooooo00Sooooo00?o0000okBC]?ndTk@04_ndTk@00ol0003o]8b/okB<
[00CokB<[003o`000?ndQJ?o]8FS01?o]8FS00?o0000ok=mVOncOIT04_ncOIT00ol0003o/GB>ok5d
SP0Cok5dSP03o`000?n_Jh?o[f^301?o[f^300?o0000ojeRN?n]HWP04on]HWP00ol0003oZEQ/ojUH
K009ojUHK2go00002onQD6/00ol0003oXDiWoj5>I`0Doj5>I`03o`000?nPCFKoX4eV01?oX4eV00?o
0000oj5=I_nQCFH05?nQCFH00ol0003oXTmXoj9?J00Doj9?J003o`000?oooooooooo00;ooooo00?o
0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o]9>dokBC]00B
okBC]003o`000?ndS:co]8b/01?o]8b/00?o0000okB5XondQJ<04ondQJ<00ol0003o/gfIok=mV@0B
ok=mV@03o`000?naM8ko/GB>00So/GB>@ol0000;ojAIMP03o`000?nRE73oXUA`01?oXUA`00?o0000
oj5@JonQD6/05?nQD6/00ol0003oXDiWoj5>I`0Doj5>I`03o`000?nPCFKoX4eV01?oX4eV00?o0000
oj5=I_nQCFH05OnQCFH00ol0003oXTmXoj9?J00Doj9?J005o`000?ooooooooooooooool000005Ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003o]9>dokBC]00BokBC]003o`000?ndS:co
]8b/01?o]8b/00?o0000okB5XondQJ<02?ndQJ<[o`0000_oZ6j@00?o0000ojMWQ_nWIhH04onWIhH0
0ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKoY5Uf01CoY5Uf00?o0000oj9DL?nRE7004onRE700
0ol0003oXE1[oj5@J`0Doj5@J`03o`000?nQCVOoXDiW01CoXDiW00?o0000oj1=I_nPCFH04onPCFH0
0ol0003oXDeVoj5=IP0Eoj5=IP03o`000?nRCfSoXTmX01CoXTmX00Go0000ooooooooooooooooo`00
000Eooooo`002oooool00ol0003oooooooooo`08ooooocKo00002on[OZ<00ol0003oZWJIojYfV@0B
ojYfV@03o`000?nXKY3oZ6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH00ol0003oYEmnojEOOP0C
ojEOOP03o`000?nTFGKoY5Uf01CoY5Uf00?o0000oj9DL?nRE7004onRE7000ol0003oXE1[oj5@J`0D
oj5@J`03o`000?nQCVOoXDiW01CoXDiW00?o0000oj1=I_nPCFH05?nPCFH00ol0003oXDeVoj5=IP0D
oj5=IP03o`000?nRCfSoXTmX01CoXTmX00Go0000ooooooooooooooooo`00000Eooooo`002oooool0
0ol0003oooooooooo`08ooooo`03o`000?n/S;Co[8bd01;o[8bd00?o0000ojb5[?n/QJ`04on/QJ`0
0ol0003oZgjSoj]nX`0Coj]nX`03o`000?nZMYWoZWJI01;oZWJI00?o0000ojQ^T?nXKY004onXKY00
0ol0003oYfN6ojMWQP0CojMWQP03o`000?nUGgkoYEmn01?oYEmn00?o0000ojAIM_nTFGH05?nTFGH0
0ol0003oXUA`oj9DL00Coj9DL003o`000?nQD6_oXE1[01CoXE1[00?o0000oj5>IonQCVL05?nQCVL0
0ol0003oX4eVoj1=IP0Doj1=IP03o`000?nQCFKoXDeV01CoXDeV00?o0000oj9?J?nRCfP05?nRCfP0
1Ol0003ooooooooooooooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ojb<]?n/S;@04_n/S;@00ol0003o[8F/ojb5[00Cojb5[003o`000?n[OZ?oZgjS01?oZgjS00?o0000
ojYfVOnZMYT04_nZMYT00ol0003oZ6j@ojQ^T00CojQ^T003o`000?nWIhKoYfN601?oYfN600?o0000
ojEOO_nUGgh04onUGgh00ol0003oY5UfojAIMP0DojAIMP03o`000?nRE73oXUA`01?oXUA`00?o0000
oj5@JonQD6/05OnQD6/00ol0003oXDiWoj5>I`0Doj5>I`03o`000?nPCFKoX4eV01?oX4eV00?o0000
oj5=I_nQCFH05?nQCFH00ol0003oXTmXoj9?J00Doj9?J005o`000?ooooooooooooooool000005Ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco
[8F/01?o[8F/00?o0000oj]nXon[OZ<04on[OZ<00ol0003oZWJIojYfV@0BojYfV@03o`000?nXKY3o
Z6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH00ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKo
Y5Uf01CoY5Uf00?o0000oj9DL?nRE7004onRE7000ol0003oXE1[oj5@J`0Eoj5@J`03o`000?nQCVOo
XDiW01CoXDiW00?o0000oj1=I_nPCFH04onPCFH00ol0003oXDeVoj5=IP0Eoj5=IP03o`000?nRCfSo
XTmX01CoXTmX00Co0000oooooooooooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco[8F/01?o[8F/00?o0000oj]nXon[OZ<04on[OZ<0
0ol0003oZWJIojYfV@0BojYfV@03o`000?nXKY3oZ6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH0
0ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKoY5Uf01CoY5Uf00?o0000oj9DL?nRE7004onRE700
0ol0003oXE1[oj5@J`0Eoj5@J`03o`000?nQCVOoXDiW01CoXDiW00?o0000oj1=I_nPCFH04onPCFH0
0ol0003oXDeVoj5=IP0Eoj5=IP03o`000?nRCfSoXTmX01CoXTmX00Co0000oooooooooooo00005Ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco
[8F/01?o[8F/00?o0000oj]nXon[OZ<04on[OZ<00ol0003oZWJIojYfV@0BojYfV@03o`000?nXKY3o
Z6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH00ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKo
Y5Uf01CoY5Uf00?o0000oj9DL?nRE7004onRE7000ol0003oXE1[oj5@J`0Eoj5@J`03o`000?nQCVOo
XDiW01CoXDiW00?o0000oj1=I_nPCFH04onPCFH00ol0003oXDeVoj5=IP0Eoj5=IP03o`000?nRCfSo
XTmX01CoXTmX00Co0000oooooooooooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco[8F/01?o[8F/00?o0000oj]nXon[OZ<04on[OZ<0
0ol0003oZWJIojYfV@0BojYfV@03o`000?nXKY3oZ6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH0
0ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKoY5Uf01CoY5Uf00?o0000oj9DL?nRE7004onRE700
0ol0003oXE1[oj5@J`0Eoj5@J`03o`000?nQCVOoXDiW01CoXDiW00?o0000oj1=I_nPCFH05?nPCFH0
0ol0003oXDeVoj5=IP0Doj5=IP03o`000?nRCfSoXTmX01CoXTmX00Co0000oooooooooooo00005Ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco
[8F/01?o[8F/00?o0000oj]nXon[OZ<04on[OZ<00ol0003oZWJIojYfV@0BojYfV@03o`000?nXKY3o
Z6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH00ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKo
Y5Uf01CoY5Uf00?o0000oj9DL?nRE7005?nRE7000ol0003oXE1[oj5@J`0Doj5@J`03o`000?nQCVOo
XDiW01CoXDiW00?o0000oj1=I_nPCFH05?nPCFH00ol0003oXDeVoj5=IP0Doj5=IP03o`000?nRCfSo
XTmX01CoXTmX00Co0000oooooooooooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco[8F/01?o[8F/00?o0000oj]nXon[OZ<04on[OZ<0
0ol0003oZWJIojYfV@0BojYfV@03o`000?nXKY3oZ6j@01?oZ6j@00?o0000ojMWQ_nWIhH04onWIhH0
0ol0003oYEmnojEOOP0CojEOOP03o`000?nTFGKoY5Uf01CoY5Uf00?o0000oj9DL?nRE7005?nRE700
0ol0003oXE1[oj5@J`0Doj5@J`03o`000?nQCVOoXDiW01CoXDiW00?o0000oj1=I_nPCFH05?nPCFH0
0ol0003oXDeVoj5=IP0Eoj5=IP03o`000?nRCfSoXTmX01CoXTmX00?o0000ooooool000005Oooool0
00_ooooo0_l00009ooooo`03o`000?n/S;Co[8bd01;o[8bd00?o0000ojb5[?n/QJ`04on/QJ`00ol0
003oZgjSoj]nX`0Coj]nX`03o`000?nZMYWoZWJI01;oZWJI00?o0000ojQ^T?nXKY004onXKY000ol0
003oYfN6ojMWQP0CojMWQP03o`000?nUGgkoYEmn01?oYEmn00?o0000ojAIM_nTFGH05?nTFGH00ol0
003oXUA`oj9DL00Doj9DL003o`000?nQD6_oXE1[01CoXE1[00?o0000oj5>IonQCVL05?nQCVL00ol0
003oX4eVoj1=IP0Doj1=IP03o`000?nQCFKoXDeV01GoXDeV00?o0000oj9?J?nRCfP05?nRCfP00ol0
003oooooo`00000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n/S;Co[8bd01;o
[8bd00?o0000ojb5[?n/QJ`04on/QJ`00ol0003oZgjSoj]nX`0Boj]nX`03o`000?nZMYWoZWJI01;o
ZWJI00?o0000ojQ^T?nXKY005?nXKY000ol0003oYfN6ojMWQP0CojMWQP03o`000?nUGgkoYEmn01?o
YEmn00?o0000ojAIM_nTFGH05?nTFGH00ol0003oXUA`oj9DL00Doj9DL003o`000?nQD6_oXE1[01Co
XE1[00?o0000oj5>IonQCVL05?nQCVL00ol0003oX4eVoj1=IP0Doj1=IP03o`000?nQCFKoXDeV01Go
XDeV00?o0000oj9?J?nRCfP05?nRCfP00ol0003oooooo`00000Eooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?n/S;Co[8bd01;o[8bd00?o0000ojb5[?n/QJ`04_n/QJ`00ol0003oZgjS
oj]nX`0Coj]nX`03o`000?nZMYWoZWJI01;oZWJI00?o0000ojQ^T?nXKY005?nXKY000ol0003oYfN6
ojMWQP0CojMWQP03o`000?nUGgkoYEmn01?oYEmn00?o0000ojAIM_nTFGH05?nTFGH00ol0003oXUA`
oj9DL00Doj9DL003o`000?nQD6_oXE1[01CoXE1[00?o0000oj5>IonQCVL05?nQCVL00ol0003oX4eV
oj1=IP0Doj1=IP03o`000?nQCFKoXDeV01GoXDeV00?o0000oj9?J?nRCfP05?nRCfP00ol0003ooooo
o`00000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n/S;Co[8bd01;o[8bd00?o
0000ojb5[?n/QJ`04_n/QJ`00ol0003oZgjSoj]nX`0Coj]nX`03o`000?nZMYWoZWJI01;oZWJI00?o
0000ojQ^T?nXKY005?nXKY000ol0003oYfN6ojMWQP0CojMWQP03o`000?nUGgkoYEmn01?oYEmn00?o
0000ojAIM_nTFGH05?nTFGH00ol0003oXUA`oj9DL00Doj9DL003o`000?nQD6_oXE1[01GoXE1[00?o
0000oj5>IonQCVL05?nQCVL00ol0003oX4eVoj1=IP0Coj1=IP03o`000?nQCFKoXDeV01GoXDeV00?o
0000oj9?J?nRCfP05?nRCfP00ol0003oooooo`00000Eooooo`002oooool00ol0003oooooooooo`08
ooooo`03o`000?n/S;Co[8bd01;o[8bd00?o0000ojb5[?n/QJ`04_n/QJ`00ol0003oZgjSoj]nX`0C
oj]nX`03o`000?nZMYWoZWJI01;oZWJI00?o0000ojQ^T?nXKY005?nXKY000ol0003oYfN6ojMWQP0C
ojMWQP03o`000?nUGgkoYEmn01?oYEmn00?o0000ojAIM_nTFGH05?nTFGH00ol0003oXUA`oj9DL00D
oj9DL003o`000?nQD6_oXE1[01GoXE1[00?o0000oj5>IonQCVL05?nQCVL00ol0003oX4eVoj1=IP0D
oj1=IP03o`000?nQCFKoXDeV01GoXDeV00?o0000oj9?J?nRCfP05?nRCfP2o`0001Gooooo000;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ojb<]?n/S;@04_n/S;@00ol0003o[8F/ojb5[00Bojb5
[003o`000?n[OZ?oZgjS01?oZgjS00?o0000ojYfVOnZMYT04_nZMYT00ol0003oZ6j@ojQ^T00DojQ^
T003o`000?nWIhKoYfN601?oYfN600?o0000ojEOO_nUGgh04onUGgh00ol0003oY5UfojAIMP0DojAI
MP03o`000?nRE73oXUA`01CoXUA`00?o0000oj5@JonQD6/05OnQD6/00ol0003oXDiWoj5>I`0Doj5>
I`03o`000?nPCFKoX4eV01CoX4eV00?o0000oj5=I_nQCFH05OnQCFH00ol0003oXTmXoj9?J00Doj9?
J0;o00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o[8bdojb<]00Bojb<]003
o`000?n/QJco[8F/01;o[8F/00?o0000oj]nXon[OZ<04on[OZ<00ol0003oZWJIojYfV@0BojYfV@03
o`000?nXKY3oZ6j@01CoZ6j@00?o0000ojMWQ_nWIhH04onWIhH00ol0003oYEmnojEOOP0CojEOOP03
o`000?nTFGKoY5Uf01CoY5Uf00?o0000oj9DL?nRE7005?nRE7000ol0003oXE1[oj5@J`0Eoj5@J`03
o`000?nQCVOoXDiW01CoXDiW00?o0000oj1=I_nPCFH02OnPCFHlo`0001Gooooo000;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ojb<]?n/S;@04_n/S;@00ol0003o[8F/ojb5[00Bojb5[003o`00
0?n[OZ?oZgjS01?oZgjS00?o0000ojYfVOnZMYT04_nZMYT00ol0003oZ6j@ojQ^T00DojQ^T003o`00
0?nWIhKoYfN601?oYfN600?o0000ojEOO_nUGgh04onUGgh00ol0003oY5UfojAIMP0DojAIMP03o`00
0?nRE73oXUA`00WoXUA`A_l0000;ojenXP03o`000?n_RZko[hZ^01Go[hZ^00?o0000ok6F^onaU[/0
5?naU[/2o`0001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ojb<]?n/S;@04_n/
S;@00ol0003o[8F/ojb5[00Bojb5[003o`000?n[OZ?oZgjS01?oZgjS00?o0000ojYfVOnZMYT04_nZ
MYT00ol0003oZ6j@ojQ^T00DojQ^T003o`000?nWIhKoYfN601?oYfN600?o0000ojEOO_nUGgh04onU
Ggh00ol0003oY5UfojAIMP09ojAIMQOo00002onTIhX00ol0003oYff?ojM]S`0EojM]S`03o`000?nY
M9OoZGBG01CoZGBG00?o0000ojenX_n]OZ805?n]OZ800ol0003o[hZ^ojn:[P0Eojn:[P03o`000?na
U[_o/IJk01Co/IJk0_l0000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n/S;Co
[8bd01;o[8bd00?o0000ojb5[?n/QJ`04_n/QJ`00ol0003oZgjSoj]nX`0Coj]nX`03o`000?nZMYWo
ZWJI01;oZWJI00?o0000ojQ^T?nXKY005?nXKY000ol0003oYfN6ojMWQP08ojMWQRgo00002onSIHP0
0ol0003oY6N:ojAWRP0DojAWRP03o`000?nWKHooYff?01GoYff?00?o0000ojUdUonYM9L05?nYM9L0
0ol0003o[GjRojenXP0DojenXP03o`000?n_RZko[hZ^01Go[hZ^00?o0000ok6F^onaU[/05?naU[/2
o`0001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ojb<]?n/S;@04_n/S;@00ol0
003o[8F/ojb5[00Bojb5[003o`000?n[OZ?oZgjS01?oZgjS00?o0000ojYfVOnZMYT02?nZMYT/o`00
00_oXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Doj=UR003o`000?nTIh[oY6N:
01CoY6N:00?o0000ojM]SonWKHl05OnWKHl00ol0003oZGBGojUdU`0DojUdU`03o`000?n]OZ;o[GjR
01Co[GjR00?o0000ojn:[_n_RZh05On_RZh00ol0003o/IJkok6F^`0Dok6F^`;o00005Oooool000_o
oooo00?o0000ooooooooool02?ooool00ol0003o[8bdojb<]00Bojb<]003o`000?n/QJco[8F/01;o
[8F/00?o0000oj]nXon[OZ<02?n[OZ<Fo`0000[oXW2J00?o0000oj5ZT_nQJY805?nQJY800ol0003o
XFJ=oj5VS@0Coj5VS@03o`000?nRI8WoXVB901?oXVB900?o0000oj=UR?nSIHP05?nSIHP00ol0003o
Y6N:ojAWRP0DojAWRP03o`000?nWKHooYff?01GoYff?00?o0000ojUdUonYM9L05?nYM9L00ol0003o
[GjRojenXP0DojenXP03o`000?n_RZko[hZ^01Go[hZ^00?o0000ok6F^onaU[/05?naU[/2o`0001Go
oooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ojb<]?n/S;@04_n/S;@00ol0003o[8F/
ojb5[008ojb5[1Go00002onRMj800ol0003oXW2Joj9`VP0Boj9`VP03o`000?nQJY;oXFZB01CoXFZB
00?o0000oj5VSOnQIXd04onQIXd00ol0003oXVB9oj9TR@0Coj9TR@03o`000?nSIHSoXfF801CoXfF8
00?o0000ojAWR_nTIhX05?nTIhX00ol0003oYff?ojM]S`0EojM]S`03o`000?nYM9OoZGBG01CoZGBG
00?o0000ojenX_n]OZ805?n]OZ800ol0003o[hZ^ojn:[P0Eojn:[P03o`000?naU[_o/IJk01Co/IJk
0_l0000Eooooo`002oooool00ol0003oooooooooo`08ooooob3o00002_nSOZ/00ol0003oXWNRoj9g
XP0Coj9gXP03o`000?nRL9[oXW2J01;oXW2J00?o0000oj5ZT_nQJY805?nQJY800ol0003oXFJ=oj5V
S@0Coj5VS@03o`000?nRI8WoXVB901?oXVB900?o0000oj=UR?nSIHP05?nSIHP00ol0003oY6N:ojAW
RP0DojAWRP03o`000?nWKHooYff?01GoYff?00?o0000ojUdUonYM9L05?nYM9L00ol0003o[GjRojen
XP0DojenXP03o`000?n_RZko[hZ^01Go[hZ^00?o0000ok6F^onaU[/05?naU[/2o`0001Gooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0B
oj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04_nRL9X00ol0003oXFZBoj5ZTP0D
oj5ZTP03o`000?nQIXgoXFJ=01?oXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00D
oj=UR003o`000?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05OnWKHl00ol0003oZGBGojUdU`0D
ojUdU`03o`000?n]OZ;o[GjR01Co[GjR00?o0000ojn:[_n_RZh05On_RZh00ol0003o/IJkok6F^`0D
ok6F^`;o00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oXhFdoj>5]00Boj>5
]003o`000?nSOZ_oXgj[01;oXgj[00?o0000oj9gX_nRMj804onRMj800ol0003oXW2Joj9`VP0Boj9`
VP03o`000?nQJY;oXFZB01CoXFZB00?o0000oj5VSOnQIXd04onQIXd00ol0003oXVB9oj9TR@0Coj9T
R@03o`000?nSIHSoXfF801CoXfF800?o0000ojAWR_nTIhX05?nTIhX00ol0003oYff?ojM]S`0EojM]
S`03o`000?nYM9OoZGBG01CoZGBG00?o0000ojenX_n]OZ805?n]OZ800ol0003o[hZ^ojn:[P0Eojn:
[P03o`000?naU[_o/IJk01Co/IJk0_l0000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03
o`000?nSQKCoXhFd01;oXhFd00?o0000oj=nZonSOZ/04_nSOZ/00ol0003oXWNRoj9gXP0Coj9gXP03
o`000?nRL9[oXW2J01;oXW2J00?o0000oj5ZT_nQJY805?nQJY800ol0003oXFJ=oj5VS@0Coj5VS@03
o`000?nRI8WoXVB901?oXVB900?o0000oj=UR?nSIHP05?nSIHP00ol0003oY6N:ojAWRP0DojAWRP03
o`000?nWKHooYff?01GoYff?00?o0000ojUdUonYM9L05?nYM9L00ol0003o[GjRojenXP0DojenXP03
o`000?n_RZko[hZ^01Go[hZ^00?o0000ok6F^onaU[/05?naU[/2o`0001Gooooo000;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0Boj=nZ`03o`00
0?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04_nRL9X00ol0003oXFZBoj5ZTP0Doj5ZTP03o`00
0?nQIXgoXFJ=01?oXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Doj=UR003o`00
0?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05OnWKHl00ol0003oZGBGojUdU`0DojUdU`03o`00
0?n]OZ;o[GjR01Co[GjR00?o0000ojn:[_n_RZh05On_RZh00ol0003o/IJkok6F^`0Dok6F^`;o0000
5Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oXhFdoj>5]00Boj>5]003o`000?nS
OZ_oXgj[01;oXgj[00?o0000oj9gX_nRMj804onRMj800ol0003oXW2Joj9`VP0Boj9`VP03o`000?nQ
JY;oXFZB01CoXFZB00?o0000oj5VSOnQIXd04onQIXd00ol0003oXVB9oj9TR@0Coj9TR@03o`000?nS
IHSoXfF801CoXfF800?o0000ojAWR_nTIhX05?nTIhX00ol0003oYff?ojM]S`0EojM]S`03o`000?nY
M9OoZGBG01CoZGBG00?o0000ojenX_n]OZ805On]OZ800ol0003o[hZ^ojn:[P0Dojn:[P03o`000?na
U[_o/IJk01Co/IJk0_l0000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?nSQKCo
XhFd01;oXhFd00?o0000oj=nZonSOZ/04_nSOZ/00ol0003oXWNRoj9gXP0Coj9gXP03o`000?nRL9[o
XW2J01;oXW2J00?o0000oj5ZT_nQJY805?nQJY800ol0003oXFJ=oj5VS@0Coj5VS@03o`000?nRI8Wo
XVB901?oXVB900?o0000oj=UR?nSIHP05?nSIHP00ol0003oY6N:ojAWRP0EojAWRP03o`000?nWKHoo
Yff?01CoYff?00?o0000ojUdUonYM9L05?nYM9L00ol0003o[GjRojenXP0EojenXP03o`000?n_RZko
[hZ^01?o[hZ^00?o0000ok6F^onaU[/05?naU[/00ol0003oooooo`00000Eooooo`002oooool00ol0
003oooooooooo`08ooooo`03o`000?nSQKCoXhFd01;oXhFd00?o0000oj=nZonSOZ/04_nSOZ/00ol0
003oXWNRoj9gXP0Coj9gXP03o`000?nRL9[oXW2J01;oXW2J00?o0000oj5ZT_nQJY805?nQJY800ol0
003oXFJ=oj5VS@0Coj5VS@03o`000?nRI8WoXVB901?oXVB900?o0000oj=UR?nSIHP05OnSIHP00ol0
003oY6N:ojAWRP0DojAWRP03o`000?nWKHooYff?01CoYff?00?o0000ojUdUonYM9L05?nYM9L00ol0
003o[GjRojenXP0EojenXP03o`000?n_RZko[hZ^01?o[hZ^00?o0000ok6F^onaU[/05?naU[/00ol0
003oooooo`00000Eooooo`002oooool2o`0000Wooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003o
Xgj[oj=nZ`0Boj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04_nRL9X00ol0003o
XFZBoj5ZTP0Coj5ZTP03o`000?nQIXgoXFJ=01CoXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003o
XfF8oj=UR00Eoj=UR003o`000?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05?nWKHl00ol0003o
ZGBGojUdU`0DojUdU`03o`000?n]OZ;o[GjR01Go[GjR00?o0000ojn:[_n_RZh04on_RZh00ol0003o
/IJkok6F^`0Dok6F^`03o`000?oooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo
00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0Boj=nZ`03o`000?nRMj;oXWNR01?oXWNR
00?o0000oj9`V_nRL9X04_nRL9X00ol0003oXFZBoj5ZTP0Coj5ZTP03o`000?nQIXgoXFJ=01CoXFJ=
00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Eoj=UR003o`000?nTIh[oY6N:01CoY6N:
00?o0000ojM]SonWKHl05?nWKHl00ol0003oZGBGojUdU`0DojUdU`03o`000?n]OZ;o[GjR01Go[GjR
00?o0000ojn:[_n_RZh04on_RZh00ol0003o/IJkok6F^`0Dok6F^`03o`000?oooooo000001Gooooo
000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=n
Z`0Aoj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04onRL9X00ol0003oXFZBoj5Z
TP0Coj5ZTP03o`000?nQIXgoXFJ=01CoXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=U
R00Eoj=UR003o`000?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05?nWKHl00ol0003oZGBGojUd
U`0DojUdU`03o`000?n]OZ;o[GjR01Go[GjR00?o0000ojn:[_n_RZh04on_RZh00ol0003o/IJkok6F
^`0Dok6F^`03o`000?oooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0Aoj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000
oj9`V_nRL9X04onRL9X00ol0003oXFZBoj5ZTP0Coj5ZTP03o`000?nQIXgoXFJ=01CoXFJ=00?o0000
oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Eoj=UR003o`000?nTIh[oY6N:01CoY6N:00?o0000
ojM]SonWKHl05?nWKHl00ol0003oZGBGojUdU`0DojUdU`03o`000?n]OZ;o[GjR01Go[GjR00?o0000
ojn:[_n_RZh04on_RZh00ol0003o/IJkok6F^`0Dok6F^`03o`000?oooooo000001Gooooo000;oooo
o`03o`000?oooooooooo00Sooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0Aoj=n
Z`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04onRL9X00ol0003oXFZBoj5ZTP0Coj5Z
TP03o`000?nQIXgoXFJ=01CoXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Eoj=U
R003o`000?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05?nWKHl00ol0003oZGBGojUdU`0DojUd
U`03o`000?n]OZ;o[GjR01Go[GjR00?o0000ojn:[_n_RZh04on_RZh00ol0003o/IJkok6F^`0Dok6F
^`03o`000?oooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oj>5]?nS
QK@04_nSQK@00ol0003oXgj[oj=nZ`0Aoj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nR
L9X04onRL9X00ol0003oXFZBoj5ZTP0Coj5ZTP03o`000?nQIXgoXFJ=01CoXFJ=00?o0000oj9TROnR
I8T04onRI8T00ol0003oXfF8oj=UR00Eoj=UR003o`000?nTIh[oY6N:01CoY6N:00?o0000ojM]SonW
KHl05?nWKHl00ol0003oZGBGojUdU`0DojUdU`03o`000?n]OZ;o[GjR01Go[GjR00?o0000ojn:[_n_
RZh04on_RZh00ol0003o/IJkok6F^`0Dok6F^`03o`000?oooooo000001Gooooo000;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0Aoj=nZ`03o`00
0?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04onRL9X00ol0003oXFZBoj5ZTP0Coj5ZTP03o`00
0?nQIXgoXFJ=01CoXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Eoj=UR003o`00
0?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05?nWKHl00ol0003oZGBGojUdU`0DojUdU`03o`00
0?n]OZ;o[GjR01Go[GjR00?o0000ojn:[_n_RZh04on_RZh00ol0003o/IJkok6F^`0Dok6F^`03o`00
0?oooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oj>5]?nSQK@04_nS
QK@00ol0003oXgj[oj=nZ`0Aoj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nRL9X04onR
L9X00ol0003oXFZBoj5ZTP0Coj5ZTP03o`000?nQIXgoXFJ=01CoXFJ=00?o0000oj9TROnRI8T04onR
I8T00ol0003oXfF8oj=UR00Eoj=UR003o`000?nTIh[oY6N:01CoY6N:00?o0000ojM]SonWKHl05?nW
KHl00ol0003oZGBGojUdU`0DojUdU`03o`000?n]OZ;o[GjR01Go[GjR00?o0000ojn:[_n_RZh04on_
RZh00ol0003o/IJkok6F^`0Dok6F^`03o`000?oooooo000001Gooooo000;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000oj>5]?nSQK@04_nSQK@00ol0003oXgj[oj=nZ`0Aoj=nZ`03o`000?nRMj;o
XWNR01?oXWNR00?o0000oj9`V_nRL9X04onRL9X00ol0003oXFZBoj5ZTP0Coj5ZTP03o`000?nQIXgo
XFJ=01CoXFJ=00?o0000oj9TROnRI8T04onRI8T00ol0003oXfF8oj=UR00Eoj=UR003o`000?nTIh[o
Y6N:00WoY6N:GOl0000:ojn:[P03o`000?naU[_o/IJk01Co/IJk00?o0000ooooool000005Oooool0
00_ooooo00?o0000ooooooooool02?ooool00ol0003oXhFdoj>5]00Boj>5]003o`000?nSOZ_oXgj[
017oXgj[00?o0000oj9gX_nRMj804onRMj800ol0003oXW2Joj9`VP0Coj9`VP03o`000?nQJY;oXFZB
01?oXFZB00?o0000oj5VSOnQIXd02OnQIXe5o`0000_o[HBY00?o0000ok6A]_naTKH05?naTKH00ol0
003o]:34okBPa00DokBPa003o`000?nf[]7o]ZkA01Go]ZkA00?o0000okFkg_ne^mh02One^mhRo`00
0003ooooool0003ooooo01Cooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oj>5]?nS
QK@04_nSQK@00ol0003oXgj[oj=nZ`0Aoj=nZ`03o`000?nRMj;oXWNR01?oXWNR00?o0000oj9`V_nR
L9X04onRL9X00ol0003oXFZBoj5ZTP08oj5ZTQOo00002onOJiD00ol0003oXg2Hoj=`V00Coj=`V003
o`000?nXN9ooZ7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03
o`000?ndX<Co]:3401Co]:3400?o0000okJ^dOnf[]405Onf[]400ol0003o]K_NokFkgP0CokFkgP03
o`000?ncaNSo/lGX01Co/lGX00?o0000ooooool000005Oooool000_ooooo00?o0000ooooooooool0
2?ooool00ol0003oXhFdoj>5]00Boj>5]003o`000?nSOZ_oXgj[017oXgj[00?o0000oj9gX_nRMj80
4onRMj800ol0003oXW2Joj9`VP08oj9`VQKo00002onMJYH00ol0003oWf^Eoim[U@0Doim[U@03o`00
0?nSL9SoXg2H01?oXg2H00?o0000ojQhWonXN9l05OnXN9l00ol0003o[HBYojf4Z@0Dojf4Z@03o`00
0?naTKKo/I6f01Co/I6f00?o0000okBPa?ndX<@05?ndX<@00ol0003o]ZkAokJ^d@0EokJ^d@03o`00
0?ne^mko]K_N01?o]K_N00?o0000ok?5j?ncaNP05?ncaNP00ol0003oooooo`00000Eooooo`002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?nSQKCoXhFd01;oXhFd00?o0000oj=nZonSOZ/01onS
OZ/[o`0000_oVfbK00?o0000oieZU_nMJYH04onMJYH00ol0003oWf^Eoim[U@0Doim[U@03o`000?nS
L9SoXg2H01?oXg2H00?o0000ojQhWonXN9l05OnXN9l00ol0003o[HBYojf4Z@0Dojf4Z@03o`000?na
TKKo/I6f01Co/I6f00?o0000okBPa?ndX<@05?ndX<@00ol0003o]ZkAokJ^d@0EokJ^d@03o`000?ne
^mko]K_N01?o]K_N00?o0000ok?5j?ncaNP04oncaNP01?l0003oooooooooool0000Eooooo`002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?nSQKCoXhFd00SoXhFd5?l0000:oiUfZP03o`000?nJ
L:;oVW2R01?oVW2R00?o0000oi]/VonKK9/04onKK9/00ol0003oWFZFoieZUP0CoieZUP03o`000?nO
JiGoWf^E01CoWf^E00?o0000oj=`V?nSL9P04onSL9P00ol0003oZ7ROojQhW`0EojQhW`03o`000?n]
Q:Wo[HBY01Co[HBY00?o0000ok6A]_naTKH05?naTKH00ol0003o]:34okBPa00DokBPa003o`000?nf
[]7o]ZkA01Co]ZkA00?o0000okFkg_ne^mh04one^mh00ol0003o/lGXok?5j00Dok?5j004o`000?oo
ooooooooo`0001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo2ol0000:oiUm/`03o`000?nI
MZ[oVGJZ017oVGJZ00?o0000oiY`X_nJL:804onJL:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nM
JYKoWFZF01?oWFZF00?o0000oim[UOnOJiD05?nOJiD00ol0003oXg2Hoj=`V00Coj=`V003o`000?nX
N9ooZ7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?nd
X<Co]:3401Co]:3400?o0000okJ^dOnf[]405?nf[]400ol0003o]K_NokFkgP0CokFkgP03o`000?nc
aNSo/lGX01Co/lGX00Co0000oooooooooooo00005Oooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oVGfcoiUm/`0BoiUm/`03o`000?nIMZ[oVGJZ017oVGJZ00?o0000oiY`X_nJL:804onJ
L:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nMJYKoWFZF01?oWFZF00?o0000oim[UOnOJiD05?nO
JiD00ol0003oXg2Hoj=`V00Coj=`V003o`000?nXN9ooZ7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]
Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?ndX<Co]:3401Co]:3400?o0000okJ^dOnf[]405?nf
[]400ol0003o]K_NokFkgP0CokFkgP03o`000?ncaNSo/lGX01Co/lGX00Co0000oooooooooooo0000
5Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oVGfcoiUm/`0BoiUm/`03o`000?nI
MZ[oVGJZ017oVGJZ00?o0000oiY`X_nJL:804onJL:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nM
JYKoWFZF01?oWFZF00?o0000oim[UOnOJiD05?nOJiD00ol0003oXg2Hoj=`V00Coj=`V003o`000?nX
N9ooZ7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?nd
X<Co]:3401Co]:3400?o0000okJ^dOnf[]405?nf[]400ol0003o]K_NokFkgP0CokFkgP03o`000?nc
aNSo/lGX01?o/lGX00Go0000ooooooooooooooooo`00000Eooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?nIOK?oVGfc01;oVGfc00?o0000oiUfZ_nIMZX04OnIMZX00ol0003oVW2RoiY`
XP0CoiY`XP03o`000?nKK9_oVfbK01?oVfbK00?o0000oieZU_nMJYH04onMJYH00ol0003oWf^Eoim[
U@0Doim[U@03o`000?nSL9SoXg2H01?oXg2H00?o0000ojQhWonXN9l05OnXN9l00ol0003o[HBYojf4
Z@0Dojf4Z@03o`000?naTKKo/I6f01Co/I6f00?o0000okBPa?ndX<@05?ndX<@00ol0003o]ZkAokJ^
d@0DokJ^d@03o`000?ne^mko]K_N01?o]K_N00?o0000ok?5j?ncaNP04oncaNP01Ol0003ooooooooo
oooooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oiUm/onIOK<04_nI
OK<00ol0003oVGJZoiUfZP0AoiUfZP03o`000?nJL:;oVW2R01?oVW2R00?o0000oi]/VonKK9/04onK
K9/00ol0003oWFZFoieZUP0CoieZUP03o`000?nOJiGoWf^E01CoWf^E00?o0000oj=`V?nSL9P04onS
L9P00ol0003oZ7ROojQhW`0EojQhW`03o`000?n]Q:Wo[HBY01Co[HBY00?o0000ok6A]_naTKH05?na
TKH00ol0003o]:34okBPa00DokBPa003o`000?nf[]7o]ZkA01Co]ZkA00?o0000okFkg_ne^mh04one
^mh00ol0003o/lGXok?5j00Cok?5j005o`000?ooooooooooooooool000005Oooool000_ooooo00?o
0000ooooooooool02?ooool00ol0003oVGfcoiUm/`0BoiUm/`03o`000?nIMZ[oVGJZ017oVGJZ00?o
0000oiY`X_nJL:804onJL:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nMJYKoWFZF01?oWFZF00?o
0000oim[UOnOJiD05?nOJiD00ol0003oXg2Hoj=`V00Coj=`V003o`000?nXN9ooZ7RO01GoZ7RO00?o
0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?ndX<Co]:3401Co]:3400?o
0000okJ^dOnf[]405?nf[]400ol0003o]K_NokFkgP0BokFkgP03o`000?ncaNSo/lGX01Co/lGX00Go
0000ooooooooooooooooo`00000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?nI
OK?oVGfc01;oVGfc00?o0000oiUfZ_nIMZX04OnIMZX00ol0003oVW2RoiY`XP0CoiY`XP03o`000?nK
K9_oVfbK01?oVfbK00?o0000oieZU_nMJYH04onMJYH00ol0003oWf^Eoim[U@0Doim[U@03o`000?nS
L9SoXg2H01?oXg2H00?o0000ojQhWonXN9l05OnXN9l00ol0003o[HBYojf4Z@0Dojf4Z@03o`000?na
TKKo/I6f01Co/I6f00?o0000okBPa?ndX<@05?ndX<@00ol0003o]ZkAokJ^d@0DokJ^d@03o`000?ne
^mko]K_N01;o]K_N00?o0000ok?5j?ncaNP04oncaNP00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01?ooooo000;ooooo`;o00002Oooool00ol0003oVGfcoiUm/`0BoiUm/`03o`000?nIMZ[o
VGJZ017oVGJZ00?o0000oiY`X_nJL:804onJL:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nMJYKo
WFZF01?oWFZF00?o0000oim[UOnOJiD04onOJiD00ol0003oXg2Hoj=`V00Doj=`V003o`000?nXN9oo
Z7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?ndX<Co
]:3401?o]:3400?o0000okJ^dOnf[]405?nf[]400ol0003o]K_NokFkgP0CokFkgP03o`000?ncaNSo
/lGX01?o/lGX00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0
003oooooooooo`08ooooo`03o`000?nIOK?oVGfc01;oVGfc00?o0000oiUfZ_nIMZX04OnIMZX00ol0
003oVW2RoiY`XP0CoiY`XP03o`000?nKK9_oVfbK01?oVfbK00?o0000oieZU_nMJYH04_nMJYH00ol0
003oWf^Eoim[U@0Doim[U@03o`000?nSL9SoXg2H01CoXg2H00?o0000ojQhWonXN9l05OnXN9l00ol0
003o[HBYojf4Z@0Dojf4Z@03o`000?naTKKo/I6f01Co/I6f00?o0000okBPa?ndX<@04ondX<@00ol0
003o]ZkAokJ^d@0DokJ^d@03o`000?ne^mko]K_N01?o]K_N00?o0000ok?5j?ncaNP04oncaNP00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00So
oooo00?o0000oiUm/onIOK<04_nIOK<00ol0003oVGJZoiUfZP0AoiUfZP03o`000?nJL:;oVW2R01;o
VW2R00?o0000oi]/VonKK9/04onKK9/00ol0003oWFZFoieZUP0CoieZUP03o`000?nOJiGoWf^E01Co
Wf^E00?o0000oj=`V?nSL9P05?nSL9P00ol0003oZ7ROojQhW`0EojQhW`03o`000?n]Q:Wo[HBY01Co
[HBY00?o0000ok6A]_naTKH05?naTKH00ol0003o]:34okBPa00CokBPa003o`000?nf[]7o]ZkA01Co
]ZkA00?o0000okFkg_ne^mh04one^mh00ol0003o/lGXok?5j00Cok?5j003o`000?oooooooooo00;o
oooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oVGfc
oiUm/`0BoiUm/`03o`000?nIMZ[oVGJZ017oVGJZ00?o0000oiY`X_nJL:804_nJL:800ol0003oVfbK
oi]/V`0Coi]/V`03o`000?nMJYKoWFZF01?oWFZF00?o0000oim[UOnOJiD05?nOJiD00ol0003oXg2H
oj=`V00Doj=`V003o`000?nXN9ooZ7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6f
ok6A]P0Dok6A]P03o`000?ndX<Co]:3401?o]:3400?o0000okJ^dOnf[]405?nf[]400ol0003o]K_N
okFkgP0CokFkgP03o`000?ncaNSo/lGX01?o/lGX00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?nIOK?oVGfc017oVGfc00?o
0000oiUfZ_nIMZX04_nIMZX00ol0003oVW2RoiY`XP0BoiY`XP03o`000?nKK9_oVfbK01?oVfbK00?o
0000oieZU_nMJYH04onMJYH00ol0003oWf^Eoim[U@0Doim[U@03o`000?nSL9SoXg2H01CoXg2H00?o
0000ojQhWonXN9l05OnXN9l00ol0003o[HBYojf4Z@0Dojf4Z@03o`000?naTKKo/I6f01Co/I6f00?o
0000okBPa?ndX<@04ondX<@00ol0003o]ZkAokJ^d@0DokJ^d@03o`000?ne^mko]K_N01?o]K_N00?o
0000ok?5j?ncaNP04_ncaNP00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000oiUm/onIOK<04OnIOK<00ol0003oVGJZoiUfZP0B
oiUfZP03o`000?nJL:;oVW2R01;oVW2R00?o0000oi]/VonKK9/04onKK9/00ol0003oWFZFoieZUP0C
oieZUP03o`000?nOJiGoWf^E01CoWf^E00?o0000oj=`V?nSL9P05?nSL9P00ol0003oZ7ROojQhW`0E
ojQhW`03o`000?n]Q:Wo[HBY01Co[HBY00?o0000ok6A]_naTKH05?naTKH00ol0003o]:34okBPa00C
okBPa003o`000?nf[]7o]ZkA01Co]ZkA00?o0000okFkg_ne^mh04_ne^mh00ol0003o/lGXok?5j00C
ok?5j003o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000oooo
ooooool02?ooool00ol0003oVGfcoiUm/`0AoiUm/`03o`000?nIMZ[oVGJZ01;oVGJZ00?o0000oiY`
X_nJL:804_nJL:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nMJYKoWFZF01?oWFZF00?o0000oim[
UOnOJiD05?nOJiD00ol0003oXg2Hoj=`V00Doj=`V003o`000?nXN9ooZ7RO01GoZ7RO00?o0000ojf4
ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?ndX<Co]:3401?o]:3400?o0000okJ^
dOnf[]405?nf[]400ol0003o]K_NokFkgP0BokFkgP03o`000?ncaNSo/lGX01?o/lGX00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03
o`000?nIOK?oVGfc017oVGfc00?o0000oiUfZ_nIMZX04_nIMZX00ol0003oVW2RoiY`XP0BoiY`XP03
o`000?nKK9_oVfbK01?oVfbK00?o0000oieZU_nMJYH04onMJYH00ol0003oWf^Eoim[U@0Doim[U@03
o`000?nSL9SoXg2H01CoXg2H00?o0000ojQhWonXN9l05OnXN9l00ol0003o[HBYojf4Z@0Dojf4Z@03
o`000?naTKKo/I6f01Co/I6f00?o0000okBPa?ndX<@04ondX<@00ol0003o]ZkAokJ^d@0DokJ^d@03
o`000?ne^mko]K_N01;o]K_N00?o0000ok?5j?ncaNP04oncaNP00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oiUm/onIOK<0
4OnIOK<00ol0003oVGJZoiUfZP0BoiUfZP03o`000?nJL:;oVW2R01;oVW2R00?o0000oi]/VonKK9/0
4onKK9/00ol0003oWFZFoieZUP0CoieZUP03o`000?nOJiGoWf^E01CoWf^E00?o0000oj=`V?nSL9P0
5?nSL9P00ol0003oZ7ROojQhW`0EojQhW`03o`000?n]Q:Wo[HBY01Co[HBY00?o0000ok6A]_naTKH0
5?naTKH00ol0003o]:34okBPa00CokBPa003o`000?nf[]7o]ZkA01Co]ZkA00?o0000okFkg_ne^mh0
4_ne^mh00ol0003o/lGXok?5j00Bok?5j003o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oVGfcoiUm/`0AoiUm/`03o`000?nI
MZ[oVGJZ01;oVGJZ00?o0000oiY`X_nJL:804_nJL:800ol0003oVfbKoi]/V`0Coi]/V`03o`000?nM
JYKoWFZF01?oWFZF00?o0000oim[UOnOJiD05?nOJiD00ol0003oXg2Hoj=`V00Doj=`V003o`000?nX
N9ooZ7RO01GoZ7RO00?o0000ojf4ZOn]Q:T05?n]Q:T00ol0003o/I6fok6A]P0Dok6A]P03o`000?nd
X<Co]:3401?o]:3400?o0000okJ^dOnf[]404onf[]400ol0003o]K_NokFkgP0CokFkgP03o`000?nc
aNSo/lGX01;o/lGX00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`002oooool0
0ol0003oooooooooo`08ooooo`03o`000?nIOK?oVGfc017oVGfc00?o0000oiUfZ_nIMZX04_nIMZX0
0ol0003oVW2RoiY`XP0BoiY`XP03o`000?nKK9_oVfbK01?oVfbK00?o0000oieZU_nMJYH04onMJYH0
0ol0003oWf^Eoim[U@0Doim[U@03o`000?nSL9SoXg2H00WoXg2HAol0000:ok6A]P03o`000?ndX<Co
]:3401?o]:3400?o0000okJ^dOnf[]404onf[]400ol0003o]K_NokFkgP0CokFkgP03o`000?ncaNSo
/lGX01;o/lGX00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0
003oooooooooo`08ooooo`03o`000?nIOK?oVGfc017oVGfc00?o0000oiUfZ_nIMZX04_nIMZX00ol0
003oVW2RoiY`XP0BoiY`XP03o`000?nKK9_oVfbK01?oVfbK00?o0000oieZU_nMJYH02?nMJYH^o`00
00_oZh>Y00?o0000ok:B]_nbT[H05OnbT[H00ol0003o^JC4okVTa00DokVTa003o`000?nl]M;o_;GB
00[o_;GB;?l0000:okJ^d@03o`000?ne^mko]K_N01;o]K_N00?o0000ok?5j?ncaNP04oncaNP00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00So
oooo00?o0000oiUm/onIOK<04OnIOK<00ol0003oVGJZoiUfZP0BoiUfZP03o`000?nJL:;oVW2R00So
VW2R:ol0000;oia^W003o`000?nSMZ3oXgJP01CoXgJP00?o0000oj^3ZOn[PjT05?n[PjT00ol0003o
/Y:fok:B]P0Eok:B]P03o`000?niY<Co^JC401Co^JC400?o0000okbed_nl]M805?nl]M800ol0003o
_L?Ookg3g`0Cokg3g`03o`000?nlc^So_<kX00Wo_<kX5_l00009okFkgP03o`000?ncaNSo/lGX01;o
/lGX00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?nIOK?oVGfc017oVGfc00?o0000oiUfZ_nIMZX02?nIMZXEo`0000[oTVZQ
00?o0000oiIZWOnFJYd04onFJYd00ol0003oW6jLoia^W00Coia^W003o`000?nSMZ3oXgJP01CoXgJP
00?o0000oj^3ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03o`000?niY<Co^JC401Co^JC4
00?o0000okbed_nl]M805?nl]M800ol0003o_L?Ookg3g`0Cokg3g`03o`000?nlc^So_<kX01?o_<kX
00?o0000okWFkonie^l02Onie^lOo`0000Oooooo00?o0000ooooooooool04oooool000_ooooo00?o
0000ooooooooool02?ooool00ol0003oVGfcoiUm/`07oiUm/aGo00002_n@KZP00ol0003oTVZQoi9Z
X@0Boi9ZX@03o`000?nFJYgoUVZM01?oUVZM00?o0000oia^W?nLKY`04onLKY`00ol0003oXgJPoj=f
X00Doj=fX003o`000?n[PjWoZh>Y01CoZh>Y00?o0000ok:B]_nbT[H05OnbT[H00ol0003o^JC4okVT
a00DokVTa003o`000?nl]M;o_;GB01Co_;GB00?o0000okg3gonm`ml04onm`ml00ol0003o_<kXokc>
j00Cokc>j003o`000?nie^oo^MK_01;o^MK_00?o0000okKKlonffo<04_nffo<00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo2_l0000:
ohid/@03o`000?n@KZSoT6jX01;oT6jX00?o0000oi9ZXOnBJZ404_nBJZ400ol0003oUVZMoiIZW@0C
oiIZW@03o`000?nLKYcoW6jL01?oW6jL00?o0000oj=fX?nSMZ005?nSMZ000ol0003oZh>Yoj^3Z@0D
oj^3Z@03o`000?nbT[Ko/Y:f01Go/Y:f00?o0000okVTa?niY<@05?niY<@00ol0003o_;GBokbedP0D
okbedP03o`000?nm`moo_L?O01?o_L?O00?o0000okc>j?nlc^P04onlc^P00ol0003o^MK_okWFk`0B
okWFk`03o`000?nffo?o]]_c01;o]]_c00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n>M;7oSWBa017oSWBa00?o0000oi1^
Z?n@KZP04_n@KZP00ol0003oTVZQoi9ZX@0Boi9ZX@03o`000?nFJYgoUVZM01?oUVZM00?o0000oia^
W?nLKY`04onLKY`00ol0003oXgJPoj=fX00Doj=fX003o`000?n[PjWoZh>Y01CoZh>Y00?o0000ok:B
]_nbT[H05OnbT[H00ol0003o^JC4okVTa00DokVTa003o`000?nl]M;o_;GB01Co_;GB00?o0000okg3
gonm`ml04onm`ml00ol0003o_<kXokc>j00Bokc>j003o`000?nie^oo^MK_01;o^MK_00?o0000okKK
lonffo<04_nffo<00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ohid/On>M;404On>M;400ol0003oT6jXoi1^Z00Boi1^Z003
o`000?nBJZ7oTVZQ01;oTVZQ00?o0000oiIZWOnFJYd04onFJYd00ol0003oW6jLoia^W00Coia^W003
o`000?nSMZ3oXgJP01CoXgJP00?o0000oj^3ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03
o`000?niY<Co^JC401Co^JC400?o0000okbed_nl]M805?nl]M800ol0003o_L?Ookg3g`0Cokg3g`03
o`000?nlc^So_<kX01;o_<kX00?o0000okWFkonie^l04_nie^l00ol0003o]]_cokKKl`0BokKKl`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00003ooooool0003o000000;o0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?n>M;7oSWBa017oSWBa
00?o0000oi1^Z?n@KZP04_n@KZP00ol0003oTVZQoi9ZX@0Boi9ZX@03o`000?nFJYgoUVZM01?oUVZM
00?o0000oia^W?nLKY`04onLKY`00ol0003oXgJPoj=fX00Doj=fX003o`000?n[PjWoZh>Y01CoZh>Y
00?o0000ok:B]_nbT[H05OnbT[H00ol0003o^JC4okVTa00DokVTa003o`000?nl]M;o_;GB01?o_;GB
00?o0000okg3gonm`ml04onm`ml00ol0003o_<kXokc>j00Cokc>j003o`000?nie^oo^MK_01;o^MK_
00?o0000okKKlonffo<04_nffo<00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo
0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oSWBaohid
/@0Aohid/@03o`000?n@KZSoT6jX01;oT6jX00?o0000oi9ZXOnBJZ404_nBJZ400ol0003oUVZMoiIZ
W@0CoiIZW@03o`000?nLKYcoW6jL01?oW6jL00?o0000oj=fX?nSMZ005?nSMZ000ol0003oZh>Yoj^3
Z@0Doj^3Z@03o`000?nbT[Ko/Y:f01Go/Y:f00?o0000okVTa?niY<@05?niY<@00ol0003o_;GBokbe
dP0CokbedP03o`000?nm`moo_L?O01?o_L?O00?o0000okc>j?nlc^P04onlc^P00ol0003o^MK_okWF
k`0BokWFk`03o`000?nffo?o]]_c017o]]_c00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ohid/On>M;404On>M;400ol0003oT6jXoi1^Z00Boi1^Z003o`000?nBJZ7oTVZQ01;oTVZQ00?o0000
oiIZWOnFJYd04onFJYd00ol0003oW6jLoia^W00Coia^W003o`000?nSMZ3oXgJP01CoXgJP00?o0000
oj^3ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03o`000?niY<Co^JC401Co^JC400?o0000
okbed_nl]M804onl]M800ol0003o_L?Ookg3g`0Cokg3g`03o`000?nlc^So_<kX01?o_<kX00?o0000
okWFkonie^l04_nie^l00ol0003o]]_cokKKl`0AokKKl`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04oooool000?ooooo00?o0000ooooooooool01Oooool3o`0000Sooooo00?o0000ohid
/On>M;404On>M;400ol0003oT6jXoi1^Z00Boi1^Z003o`000?nBJZ7oTVZQ01;oTVZQ00?o0000oiIZ
WOnFJYd04onFJYd00ol0003oW6jLoia^W00Coia^W003o`000?nSMZ3oXgJP01CoXgJP00?o0000oj^3
ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03o`000?niY<Co^JC401Co^JC400?o0000okbe
d_nl]M804onl]M800ol0003o_L?Ookg3g`0Cokg3g`03o`000?nlc^So_<kX01?o_<kX00?o0000okWF
konie^l04Onie^l00ol0003o]]_cokKKl`0BokKKl`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03
o`000?n>M;7oSWBa017oSWBa00?o0000oi1^Z?n@KZP04_n@KZP00ol0003oTVZQoi9ZX@0Boi9ZX@03
o`000?nFJYgoUVZM01?oUVZM00?o0000oia^W?nLKY`04onLKY`00ol0003oXgJPoj=fX00Doj=fX003
o`000?n[PjWoZh>Y01CoZh>Y00?o0000ok:B]_nbT[H05OnbT[H00ol0003o^JC4okVTa00DokVTa003
o`000?nl]M;o_;GB01?o_;GB00?o0000okg3gonm`ml04onm`ml00ol0003o_<kXokc>j00Bokc>j003
o`000?nie^oo^MK_01;o^MK_00?o0000okKKlonffo<04_nffo<00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01?ooooo0003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oSWBaohid/@0Aohid/@03o`000?n@KZSoT6jX01;oT6jX00?o0000oi9ZXOnBJZ40
4_nBJZ400ol0003oUVZMoiIZW@0CoiIZW@03o`000?nLKYcoW6jL01?oW6jL00?o0000oj=fX?nSMZ00
5?nSMZ000ol0003oZh>Yoj^3Z@0Doj^3Z@03o`000?nbT[Ko/Y:f01Go/Y:f00?o0000okVTa?niY<@0
4oniY<@00ol0003o_;GBokbedP0DokbedP03o`000?nm`moo_L?O01?o_L?O00?o0000okc>j?nlc^P0
4_nlc^P00ol0003o^MK_okWFk`0BokWFk`03o`000?nffo?o]]_c017o]]_c00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Cooooo`000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ohid/On>M;404On>M;400ol0003oT6jXoi1^Z00Boi1^Z003o`000?nB
JZ7oTVZQ017oTVZQ00?o0000oiIZWOnFJYd04onFJYd00ol0003oW6jLoia^W00Doia^W003o`000?nS
MZ3oXgJP01CoXgJP00?o0000oj^3ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03o`000?ni
Y<Co^JC401?o^JC400?o0000okbed_nl]M805?nl]M800ol0003o_L?Ookg3g`0Cokg3g`03o`000?nl
c^So_<kX01;o_<kX00?o0000okWFkonie^l04_nie^l00ol0003o]]_cokKKl`0AokKKl`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04oooool00004oooooomEEEGoIVIVo`0000Oooooo00?o
0000ooooooooool02?ooool00ol0003oSWBaohid/@0Aohid/@03o`000?n@KZSoT6jX017oT6jX00?o
0000oi9ZXOnBJZ404_nBJZ400ol0003oUVZMoiIZW@0CoiIZW@03o`000?nLKYcoW6jL01CoW6jL00?o
0000oj=fX?nSMZ005?nSMZ000ol0003oZh>Yoj^3Z@0Doj^3Z@03o`000?nbT[Ko/Y:f01Go/Y:f00?o
0000okVTa?niY<@04oniY<@00ol0003o_;GBokbedP0DokbedP03o`000?nm`moo_L?O01?o_L?O00?o
0000okc>j?nlc^P04_nlc^P00ol0003o^MK_okWFk`0BokWFk`03o`000?nffo?o]]_c017o]]_c00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08
ooooo`03o`000?n>M;7oSWBa017oSWBa00?o0000oi1^Z?n@KZP04On@KZP00ol0003oTVZQoi9ZX@0B
oi9ZX@03o`000?nFJYgoUVZM01?oUVZM00?o0000oia^W?nLKY`05?nLKY`00ol0003oXgJPoj=fX00D
oj=fX003o`000?n[PjWoZh>Y01CoZh>Y00?o0000ok:B]_nbT[H05OnbT[H00ol0003o^JC4okVTa00C
okVTa003o`000?nl]M;o_;GB01Co_;GB00?o0000okg3gonm`ml04onm`ml00ol0003o_<kXokc>j00B
okc>j003o`000?nie^oo^MK_017o^MK_00?o0000okKKlonffo<04Onffo<00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ohid
/On>M;404On>M;400ol0003oT6jXoi1^Z00Aoi1^Z003o`000?nBJZ7oTVZQ01;oTVZQ00?o0000oiIZ
WOnFJYd04onFJYd00ol0003oW6jLoia^W00Doia^W003o`000?nSMZ3oXgJP01CoXgJP00?o0000oj^3
ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03o`000?niY<Co^JC401?o^JC400?o0000okbe
d_nl]M805?nl]M800ol0003o_L?Ookg3g`0Cokg3g`03o`000?nlc^So_<kX01;o_<kX00?o0000okWF
konie^l04Onie^l00ol0003o]]_cokKKl`0AokKKl`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oSWBaohid/@0Aohid/@03
o`000?n@KZSoT6jX017oT6jX00?o0000oi9ZXOnBJZ404_nBJZ400ol0003oUVZMoiIZW@0CoiIZW@03
o`000?nLKYcoW6jL01CoW6jL00?o0000oj=fX?nSMZ005?nSMZ000ol0003oZh>Yoj^3Z@0Doj^3Z@03
o`000?nbT[Ko/Y:f01Go/Y:f00?o0000okVTa?niY<@04oniY<@00ol0003o_;GBokbedP0DokbedP03
o`000?nm`moo_L?O01?o_L?O00?o0000okc>j?nlc^P04Onlc^P00ol0003o^MK_okWFk`0BokWFk`03
o`000?nffo?o]]_c017o]]_c00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`00
2oooool00ol0003oooooooooo`08ooooo`03o`000?n>M;7oSWBa017oSWBa00?o0000oi1^Z?n@KZP0
4On@KZP00ol0003oTVZQoi9ZX@0Boi9ZX@03o`000?nFJYgoUVZM01?oUVZM00?o0000oia^W?nLKY`0
5?nLKY`00ol0003oXgJPoj=fX00Doj=fX003o`000?n[PjWoZh>Y01CoZh>Y00?o0000ok:B]_nbT[H0
5OnbT[H00ol0003o^JC4okVTa00CokVTa003o`000?nl]M;o_;GB01Co_;GB00?o0000okg3gonm`ml0
4onm`ml00ol0003o_<kXokc>j00Aokc>j003o`000?nie^oo^MK_01;o^MK_00?o0000okKKlonffo<0
4Onffo<00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ohid/On>M;404On>M;400ol0003oT6jXoi1^Z00Aoi1^Z003o`000?nB
JZ7oTVZQ01;oTVZQ00?o0000oiIZWOnFJYd04onFJYd00ol0003oW6jLoia^W00Doia^W003o`000?nS
MZ3oXgJP01CoXgJP00?o0000oj^3ZOn[PjT05?n[PjT00ol0003o/Y:fok:B]P0Eok:B]P03o`000?ni
Y<Co^JC401?o^JC400?o0000okbed_nl]M804onl]M800ol0003o_L?Ookg3g`0Dokg3g`03o`000?nl
c^So_<kX017o_<kX00?o0000okWFkonie^l04_nie^l00ol0003o]]_cokKKl`0@okKKl`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003oSWBaohid/@0Aohid/@03o`000?n@KZSoT6jX017oT6jX00?o0000oi9ZXOnBJZ404_nBJZ40
0ol0003oUVZMoiIZW@0CoiIZW@03o`000?nLKYcoW6jL01CoW6jL00?o0000oj=fX?nSMZ005?nSMZ00
0ol0003oZh>Yoj^3Z@0Doj^3Z@03o`000?nbT[Ko/Y:f01Go/Y:f00?o0000okVTa?niY<@04oniY<@0
0ol0003o_;GBokbedP0CokbedP03o`000?nm`moo_L?O01?o_L?O00?o0000okc>j?nlc^P04_nlc^P0
0ol0003o^MK_okWFk`0AokWFk`03o`000?nffo?o]]_c017o]]_c00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n>M;7oSWBa
017oSWBa00?o0000oi1^Z?n@KZP04On@KZP00ol0003oTVZQoi9ZX@0Boi9ZX@03o`000?nFJYgoUVZM
01?oUVZM00?o0000oia^W?nLKY`05?nLKY`00ol0003oXgJPoj=fX00Doj=fX003o`000?n[PjWoZh>Y
01CoZh>Y00?o0000ok:B]_nbT[H05OnbT[H00ol0003o^JC4okVTa00CokVTa003o`000?nl]M;o_;GB
01?o_;GB00?o0000okg3gonm`ml04onm`ml00ol0003o_<kXokc>j00Bokc>j003o`000?nie^oo^MK_
017o^MK_00?o0000okKKlonffo<04Onffo<00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ohid/On>M;404On>M;400ol0003o
T6jXoi1^Z00Aoi1^Z003o`000?nBJZ7oTVZQ01;oTVZQ00?o0000oiIZWOnFJYd04onFJYd00ol0003o
W6jLoia^W00Doia^W003o`000?nSMZ3oXgJP01CoXgJP00?o0000oj^3ZOn[PjT05?n[PjT00ol0003o
/Y:fok:B]P0Eok:B]P03o`000?niY<Co^JC401?o^JC400?o0000okbed_nl]M804onl]M800ol0003o
_L?Ookg3g`0Cokg3g`03o`000?nlc^So_<kX01;o_<kX00?o0000okWFkonie^l04Onie^l00ol0003o
]]_cokKKl`0AokKKl`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool000_ooooo
00?o0000ooooooooool02?ooool00ol0003oSWBaohid/@0Aohid/@03o`000?n@KZSoT6jX017oT6jX
00?o0000oi9ZXOnBJZ404_nBJZ400ol0003oUVZMoiIZW@08oiIZWH[o00002_nl]M800ol0003o_L?O
okg3g`0Cokg3g`03o`000?nlc^So_<kX017o_<kX00?o0000okWFkonie^l04_nie^l00ol0003o]]_c
okKKl`0@okKKl`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool000_ooooo00?o
0000ooooooooool02?ooool00ol0003oSWBaohid/@0Aohid/@03o`000?n@KZSoT6jX00OoT6jX:_l0
000;oiE[W`03o`000?nPMZ?oX7JS01CoX7JS00?o0000ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI
^@0DokNI^@03o`000?o0[/So`:k801Go`:k800?o0000olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?
h@09olK?hAKo00002_nm`ml00ol0003o_<kXokc>j00Aokc>j003o`000?nie^oo^MK_01;o^MK_00?o
0000okKKlonffo<04?nffo<00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ohid/On>M;401on>M;4Do`0000[oQVNW00?o0000
oheVXOn=IZ404_n=IZ400ol0003oUF^OoiE[W`0CoiE[W`03o`000?nPMZ?oX7JS01CoX7JS00?o0000
ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI^@0DokNI^@03o`000?o0[/So`:k801Go`:k800?o0000
olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?h@0ColK?h@03o`000?o4fNWoa=WY00Woa=WY:Ol00009
okWFk`03o`000?nffo?o]]_c017o]]_c00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`002oooool00ol0003oooooooooo`08ooooo`[o00002_n3Jjl00ol0003oQVNWohIWY`0AohIW
Y`03o`000?n=IZ7oSFJQ01;oSFJQ00?o0000oiE[WonEJil04onEJil00ol0003oX7JSoj1fX`0Doj1f
X`03o`000?n/QZco[8J/01Co[8J/00?o0000okNI^OngVKT05?ngVKT00ol0003o`:k8ol2^b00Eol2^
b003o`000?o5`MKoaL7F01?oaL7F00?o0000olK?hOo6cn404oo6cn400ol0003oa=WYolCIj@0ColCI
j@03o`000?o2g^go`]k]017o`]k]00?o0000ol3Qkoo0hNl02?o0hNlDo`0000So]]_c00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03
o`000?n3JjooPf^_017oPf^_00?o0000ohIWYon6IjL04On6IjL00ol0003oSFJQoheVX@0BoheVX@03
o`000?nEJiooUF^O01?oUF^O00?o0000oj1fXonPMZ<05?nPMZ<00ol0003o[8J/ojb6[00Dojb6[003
o`000?ngVKWo]iVi01Co]iVi00?o0000ol2^b?o0[/P05Oo0[/P00ol0003oaL7FolG1eP0ColG1eP03
o`000?o6cn7oa/oQ01?oa/oQ00?o0000olCIjOo4fNT04oo4fNT00ol0003o`]k]ol;Nk@0Aol;Nk@03
o`000?o0hNoo`>7_017o`>7_00?o0000ol3Okoo0gnl02?o0gnl9o`0000kooooo00?o0000oooooooo
ool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oPf^_oh=[[`0Aoh=[[`03o`00
0?n6IjOoQVNW017oQVNW00?o0000oheVXOn=IZ404_n=IZ400ol0003oUF^OoiE[W`0CoiE[W`03o`00
0?nPMZ?oX7JS01CoX7JS00?o0000ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI^@0DokNI^@03o`00
0?o0[/So`:k801Go`:k800?o0000olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?h@0ColK?h@03o`00
0?o4fNWoa=WY01?oa=WY00?o0000ol;NkOo2g^d04Oo2g^d00ol0003o`>7_ol3Qk`0Aol3Qk`03o`00
0?o0gnoo`=o_013o`=o_00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?n3JjooPf^_017oPf^_00?o0000ohIWYon6IjL04On6
IjL00ol0003oSFJQoheVX@0BoheVX@03o`000?nEJiooUF^O01?oUF^O00?o0000oj1fXonPMZ<05?nP
MZ<00ol0003o[8J/ojb6[00Dojb6[003o`000?ngVKWo]iVi01Co]iVi00?o0000ol2^b?o0[/P05Oo0
[/P00ol0003oaL7FolG1eP0ColG1eP03o`000?o6cn7oa/oQ01?oa/oQ00?o0000olCIjOo4fNT04oo4
fNT00ol0003o`]k]ol;Nk@0@ol;Nk@03o`000?o0hNoo`>7_017o`>7_00?o0000ol3Okoo0gnl04Oo0
gnl00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000oh=[[on3Jjl04On3Jjl00ol0003oQVNWohIWY`0AohIWY`03o`000?n=IZ7o
SFJQ01;oSFJQ00?o0000oiE[WonEJil04onEJil00ol0003oX7JSoj1fX`0Doj1fX`03o`000?n/QZco
[8J/01Co[8J/00?o0000okNI^OngVKT05?ngVKT00ol0003o`:k8ol2^b00Eol2^b003o`000?o5`MKo
aL7F01?oaL7F00?o0000olK?hOo6cn404oo6cn400ol0003oa=WYolCIj@0BolCIj@03o`000?o2g^go
`]k]017o`]k]00?o0000ol3Qkoo0hNl04Oo0hNl00ol0003o`=o_ol3Ok`0Aol3Ok`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04oooool000_ooooo0_l00009ooooo`03o`000?n3JjooPf^_
017oPf^_00?o0000ohIWYon6IjL04On6IjL00ol0003oSFJQoheVX@0BoheVX@03o`000?nEJiooUF^O
01?oUF^O00?o0000oj1fXonPMZ<05?nPMZ<00ol0003o[8J/ojb6[00Dojb6[003o`000?ngVKWo]iVi
01Co]iVi00?o0000ol2^b?o0[/P05Oo0[/P00ol0003oaL7FolG1eP0ColG1eP03o`000?o6cn7oa/oQ
01;oa/oQ00?o0000olCIjOo4fNT04oo4fNT00ol0003o`]k]ol;Nk@0Aol;Nk@03o`000?o0hNoo`>7_
017o`>7_00?o0000ol3Okoo0gnl04?o0gnl00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oh=[[on3Jjl04On3Jjl00ol0003o
QVNWohIWY`0AohIWY`03o`000?n=IZ7oSFJQ01;oSFJQ00?o0000oiE[WonEJil04onEJil00ol0003o
X7JSoj1fX`0Doj1fX`03o`000?n/QZco[8J/01Co[8J/00?o0000okNI^OngVKT05?ngVKT00ol0003o
`:k8ol2^b00Eol2^b003o`000?o5`MKoaL7F01?oaL7F00?o0000olK?hOo6cn404_o6cn400ol0003o
a=WYolCIj@0ColCIj@03o`000?o2g^go`]k]017o`]k]00?o0000ol3Qkoo0hNl04Oo0hNl00ol0003o
`=o_ol3Ok`0@ol3Ok`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool000_ooooo
00?o0000ooooooooool02?ooool00ol0003oPf^_oh=[[`0Aoh=[[`03o`000?n6IjOoQVNW017oQVNW
00?o0000oheVXOn=IZ404_n=IZ400ol0003oUF^OoiE[W`0CoiE[W`03o`000?nPMZ?oX7JS01CoX7JS
00?o0000ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI^@0DokNI^@03o`000?o0[/So`:k801Go`:k8
00?o0000olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?h@0BolK?h@03o`000?o4fNWoa=WY01?oa=WY
00?o0000ol;NkOo2g^d04Oo2g^d00ol0003o`>7_ol3Qk`0Aol3Qk`03o`000?o0gnoo`=o_013o`=o_
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?n3JjooPf^_017oPf^_00?o0000ohIWYon6IjL04On6IjL00ol0003oSFJQoheV
X@0BoheVX@03o`000?nEJiooUF^O01?oUF^O00?o0000oj1fXonPMZ<05?nPMZ<00ol0003o[8J/ojb6
[00Dojb6[003o`000?ngVKWo]iVi01Co]iVi00?o0000ol2^b?o0[/P05Oo0[/P00ol0003oaL7FolG1
eP0ColG1eP03o`000?o6cn7oa/oQ01;oa/oQ00?o0000olCIjOo4fNT04oo4fNT00ol0003o`]k]ol;N
k@0Aol;Nk@03o`000?o0hNoo`>7_013o`>7_00?o0000ol3Okoo0gnl04Oo0gnl00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
oh=[[on3Jjl04On3Jjl00ol0003oQVNWohIWY`0AohIWY`03o`000?n=IZ7oSFJQ01;oSFJQ00?o0000
oiE[WonEJil04onEJil00ol0003oX7JSoj1fX`0Doj1fX`03o`000?n/QZco[8J/01Co[8J/00?o0000
okNI^OngVKT05?ngVKT00ol0003o`:k8ol2^b00Dol2^b003o`000?o5`MKoaL7F01CoaL7F00?o0000
olK?hOo6cn404_o6cn400ol0003oa=WYolCIj@0ColCIj@03o`000?o2g^go`]k]013o`]k]00?o0000
ol3Qkoo0hNl04Oo0hNl00ol0003o`=o_ol3Ok`0Aol3Ok`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oPf^_oh=[[`0Aoh=[
[`03o`000?n6IjOoQVNW013oQVNW00?o0000oheVXOn=IZ404on=IZ400ol0003oUF^OoiE[W`0CoiE[
W`03o`000?nPMZ?oX7JS01CoX7JS00?o0000ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI^@0DokNI
^@03o`000?o0[/So`:k801Co`:k800?o0000olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?h@0ColK?
h@03o`000?o4fNWoa=WY01?oa=WY00?o0000ol;NkOo2g^d04?o2g^d00ol0003o`>7_ol3Qk`0Aol3Q
k`03o`000?o0gnoo`=o_013o`=o_00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Coooo
o`002oooool00ol0003oooooooooo`08ooooo`03o`000?n3JjooPf^_013oPf^_00?o0000ohIWYon6
IjL04On6IjL00ol0003oSFJQoheVX@0CoheVX@03o`000?nEJiooUF^O01?oUF^O00?o0000oj1fXonP
MZ<05?nPMZ<00ol0003o[8J/ojb6[00Dojb6[003o`000?ngVKWo]iVi01Co]iVi00?o0000ol2^b?o0
[/P05?o0[/P00ol0003oaL7FolG1eP0ColG1eP03o`000?o6cn7oa/oQ01?oa/oQ00?o0000olCIjOo4
fNT04_o4fNT00ol0003o`]k]ol;Nk@0Aol;Nk@03o`000?o0hNoo`>7_017o`>7_00?o0000ol3Okoo0
gnl04?o0gnl00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000oh=[[on3Jjl04?n3Jjl00ol0003oQVNWohIWY`0AohIWY`03o`00
0?n=IZ7oSFJQ01?oSFJQ00?o0000oiE[WonEJil04onEJil00ol0003oX7JSoj1fX`0Doj1fX`03o`00
0?n/QZco[8J/01Co[8J/00?o0000okNI^OngVKT05?ngVKT00ol0003o`:k8ol2^b00Dol2^b003o`00
0?o5`MKoaL7F01?oaL7F00?o0000olK?hOo6cn404oo6cn400ol0003oa=WYolCIj@0BolCIj@03o`00
0?o2g^go`]k]017o`]k]00?o0000ol3Qkoo0hNl04?o0hNl00ol0003o`=o_ol3Ok`0Aol3Ok`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oPf^_oh=[[`0@oh=[[`03o`000?n6IjOoQVNW017oQVNW00?o0000oheVXOn=IZ404on=
IZ400ol0003oUF^OoiE[W`0CoiE[W`03o`000?nPMZ?oX7JS01CoX7JS00?o0000ojb6[?n/QZ`05?n/
QZ`00ol0003o]iViokNI^@0DokNI^@03o`000?o0[/So`:k801Co`:k800?o0000olG1e_o5`MH04oo5
`MH00ol0003oa/oQolK?h@0ColK?h@03o`000?o4fNWoa=WY01;oa=WY00?o0000ol;NkOo2g^d04Oo2
g^d00ol0003o`>7_ol3Qk`0@ol3Qk`03o`000?o0gnoo`=o_017o`=o_00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n3Jjoo
Pf^_013oPf^_00?o0000ohIWYon6IjL04On6IjL00ol0003oSFJQoheVX@0CoheVX@03o`000?nEJioo
UF^O01?oUF^O00?o0000oj1fXonPMZ<05?nPMZ<00ol0003o[8J/ojb6[00Dojb6[003o`000?ngVKWo
]iVi01Co]iVi00?o0000ol2^b?o0[/P05?o0[/P00ol0003oaL7FolG1eP0ColG1eP03o`000?o6cn7o
a/oQ01?oa/oQ00?o0000olCIjOo4fNT04_o4fNT00ol0003o`]k]ol;Nk@0@ol;Nk@03o`000?o0hNoo
`>7_017o`>7_00?o0000ol3Okoo0gnl04Oo0gnl00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oh=[[on3Jjl04?n3Jjl00ol0
003oQVNWohIWY`0AohIWY`03o`000?n=IZ7oSFJQ01?oSFJQ00?o0000oiE[WonEJil04onEJil00ol0
003oX7JSoj1fX`0Doj1fX`03o`000?n/QZco[8J/01Co[8J/00?o0000okNI^OngVKT05?ngVKT00ol0
003o`:k8ol2^b00Dol2^b003o`000?o5`MKoaL7F01?oaL7F00?o0000olK?hOo6cn404oo6cn400ol0
003oa=WYolCIj@0BolCIj@03o`000?o2g^go`]k]013o`]k]00?o0000ol3Qkoo0hNl04Oo0hNl00ol0
003o`=o_ol3Ok`0Aol3Ok`03o`000?oooooooooo00kooooo00?o0000ooooooooool04oooool000_o
oooo00?o0000ooooooooool02?ooool00ol0003oPf^_oh=[[`0@oh=[[`03o`000?n6IjOoQVNW017o
QVNW00?o0000oheVXOn=IZ404on=IZ400ol0003oUF^OoiE[W`0CoiE[W`03o`000?nPMZ?oX7JS01Co
X7JS00?o0000ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI^@0DokNI^@03o`000?o0[/So`:k801Co
`:k800?o0000olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?h@0BolK?h@03o`000?o4fNWoa=WY01?o
a=WY00?o0000ol;NkOo2g^d04?o2g^d00ol0003o`>7_ol3Qk`0@ol3Qk`03o`000?o0gnoo`=o_017o
`=o_00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?n3JjooPf^_013oPf^_00?o0000ohIWYon6IjL04On6IjL00ol0003oSFJQ
oheVX@0CoheVX@03o`000?nEJiooUF^O01?oUF^O00?o0000oj1fXonPMZ<05?nPMZ<00ol0003o[8J/
ojb6[00Dojb6[003o`000?ngVKWo]iVi01Co]iVi00?o0000ol2^b?o0[/P05?o0[/P00ol0003oaL7F
olG1eP0ColG1eP03o`000?o6cn7oa/oQ01;oa/oQ00?o0000olCIjOo4fNT04oo4fNT00ol0003o`]k]
ol;Nk@0@ol;Nk@03o`000?o0hNoo`>7_013o`>7_00?o0000ol3Okoo0gnl04Oo0gnl00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o
0000oh=[[on3Jjl04?n3Jjl00ol0003oQVNWohIWY`0AohIWY`03o`000?n=IZ7oSFJQ01?oSFJQ00?o
0000oiE[WonEJil04onEJil00ol0003oX7JSoj1fX`0Doj1fX`03o`000?n/QZco[8J/01Co[8J/00?o
0000okNI^OngVKT05?ngVKT00ol0003o`:k8ol2^b00Dol2^b003o`000?o5`MKoaL7F01?oaL7F00?o
0000olK?hOo6cn404_o6cn400ol0003oa=WYolCIj@0ColCIj@03o`000?o2g^go`]k]013o`]k]00?o
0000ol3Qkoo0hNl04?o0hNl00ol0003o`=o_ol3Ok`0Aol3Ok`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oPf^_oh=[[`0@
oh=[[`03o`000?n6IjOoQVNW017oQVNW00?o0000oheVXOn=IZ404on=IZ400ol0003oUF^OoiE[W`0C
oiE[W`03o`000?nPMZ?oX7JS01CoX7JS00?o0000ojb6[?n/QZ`05?n/QZ`00ol0003o]iViokNI^@0D
okNI^@03o`000?o0[/So`:k801Co`:k800?o0000olG1e_o5`MH04oo5`MH00ol0003oa/oQolK?h@0B
olK?h@03o`000?o4fNWoa=WY01;oa=WY00?o0000ol;NkOo2g^d04Oo2g^d00ol0003o`>7_ol3Qk`0@
ol3Qk`03o`000?o0gnoo`=o_017o`=o_00?o0000ooooooooool03oooool00ol0003oooooooooo`0C
ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?n3JjooPf^_013oPf^_00?o0000ohIW
Yon6IjL04On6IjL00ol0003oSFJQoheVX@08oheVXHWo00002_o5`MH00ol0003oa/oQolK?h@0BolK?
h@03o`000?o4fNWoa=WY01;oa=WY00?o0000ol;NkOo2g^d04?o2g^d00ol0003o`>7_ol3Qk`0Aol3Q
k`03o`000?o0gnoo`=o_017o`=o_00?o0000ooooooooool03oooool00ol0003oooooooooo`0Coooo
o`002oooool00ol0003oooooooooo`08oooooc;o00002on9I:800ol0003oV72SoiQ`X`0CoiQ`X`03
o`000?nYPj_oZH>[01CoZH>[00?o0000okVI]oniVKL05?niVKL00ol0003oa[76olJaaP0DolJaaP03
o`000?o=a]?ocLKC01CocLKC00?o0000oloEg_o?eMh02Oo?eMh[o`0000Woa=WY00?o0000ol;NkOo2
g^d04?o2g^d00ol0003o`>7_ol3Qk`0@ol3Qk`03o`000?o0gnoo`=o_017o`=o_00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`00
0?mhHZgoN6:]013oN6:]00?o0000ogiOYOmnGjD04OmnGjD00ol0003oRFBRohUTXP0CohUTXP03o`00
0?nHL:?oV72S01?oV72S00?o0000ojV3ZonYPj/05?nYPj/00ol0003o^IVgokVI]`0DokVI]`03o`00
0?o6/LKoa[7601Coa[7600?o0000olg6doo=a]<05?o=a]<00ol0003ocmGNoloEgP0ColoEgP03o`00
0?o>g^Coc]kT01;oc]kT00?o0000olcRj?o<h^P02Oo<h^Pjo`0000Wo`=o_00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mh
HZgoN6:]013oN6:]00?o0000ogiOYOmnGjD04OmnGjD00ol0003oRFBRohUTXP0CohUTXP03o`000?nH
L:?oV72S01?oV72S00?o0000ojV3ZonYPj/05?nYPj/00ol0003o^IVgokVI]`0DokVI]`03o`000?o6
/LKoa[7601Coa[7600?o0000olg6doo=a]<05?o=a]<00ol0003ocmGNoloEgP0ColoEgP03o`000?o>
g^Coc]kT01;oc]kT00?o0000olcRj?o<h^P04_o<h^P00ol0003ob^3Xol[Pj00@ol[Pj003o`000?o9
f>CobMST013obMST00?o0000olS8fOo8b=T02?o8b=T:o`0001;ooooo00?o0000ooooooooool04ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003oN6:]ogQR[@0@ogQR[@03o`000?mnGjGo
OUnU017oOUnU00?o0000ohUTX_n9I:804on9I:800ol0003oV72SoiQ`X`0CoiQ`X`03o`000?nYPj_o
ZH>[01CoZH>[00?o0000okVI]oniVKL05?niVKL00ol0003oa[76olJaaP0DolJaaP03o`000?o=a]?o
cLKC01CocLKC00?o0000oloEg_o?eMh04oo?eMh00ol0003oc]kTolkNi00BolkNi003o`000?o<h^So
c>;X01;oc>;X00?o0000ol[Pj?o:h>P04?o:h>P00ol0003obMSTolWHi00@olWHi003o`000?o8b=Wo
b<SI017ob<SI00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`002oooool2o`00
00Wooooo00?o0000ogQR[OmhHZd04?mhHZd00ol0003oOUnUogiOY@0AogiOY@03o`000?n9I:;oRFBR
01?oRFBR00?o0000oiQ`XonHL:<04onHL:<00ol0003oZH>[ojV3Z`0DojV3Z`03o`000?niVKOo^IVg
01Co^IVg00?o0000olJaa_o6/LH05?o6/LH00ol0003ocLKColg6d`0Dolg6d`03o`000?o?eMkocmGN
01?ocmGN00?o0000olkNi?o>g^@04_o>g^@00ol0003oc>;XolcRj00BolcRj003o`000?o:h>Sob^3X
013ob^3X00?o0000olWHi?o9f>@04?o9f>@00ol0003ob<SIolS8f@0AolS8f@03o`000?oooooooooo
013ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
N6:]ogQR[@0@ogQR[@03o`000?mnGjGoOUnU017oOUnU00?o0000ohUTX_n9I:804on9I:800ol0003o
V72SoiQ`X`0CoiQ`X`03o`000?nYPj_oZH>[01CoZH>[00?o0000okVI]oniVKL05?niVKL00ol0003o
a[76olJaaP0DolJaaP03o`000?o=a]?ocLKC01CocLKC00?o0000oloEg_o?eMh04oo?eMh00ol0003o
c]kTolkNi00BolkNi003o`000?o<h^Soc>;X017oc>;X00?o0000ol[Pj?o:h>P04Oo:h>P00ol0003o
bMSTolWHi00@olWHi003o`000?o8b=Wob<SI017ob<SI00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mhHZgoN6:]013oN6:]
00?o0000ogiOYOmnGjD04OmnGjD00ol0003oRFBRohUTXP0CohUTXP03o`000?nHL:?oV72S01?oV72S
00?o0000ojV3ZonYPj/05?nYPj/00ol0003o^IVgokVI]`0DokVI]`03o`000?o6/LKoa[7601Coa[76
00?o0000olg6doo=a]<05?o=a]<00ol0003ocmGNoloEgP0ColoEgP03o`000?o>g^Coc]kT017oc]kT
00?o0000olcRj?o<h^P04_o<h^P00ol0003ob^3Xol[Pj00Aol[Pj003o`000?o9f>CobMST013obMST
00?o0000olS8fOo8b=T04Oo8b=T00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo
000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ogQR[OmhHZd04?mhHZd00ol0003oOUnUogiO
Y@0AogiOY@03o`000?n9I:;oRFBR01?oRFBR00?o0000oiQ`XonHL:<04onHL:<00ol0003oZH>[ojV3
Z`0DojV3Z`03o`000?niVKOo^IVg01Co^IVg00?o0000olJaa_o6/LH05?o6/LH00ol0003ocLKColg6
d`0Dolg6d`03o`000?o?eMkocmGN01?ocmGN00?o0000olkNi?o>g^@04Oo>g^@00ol0003oc>;XolcR
j00BolcRj003o`000?o:h>Sob^3X013ob^3X00?o0000olWHi?o9f>@04?o9f>@00ol0003ob<SIolS8
f@0BolS8f@03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000
ooooooooool02?ooool00ol0003oN6:]ogQR[@0@ogQR[@03o`000?mnGjGoOUnU017oOUnU00?o0000
ohUTX_n9I:804on9I:800ol0003oV72SoiQ`X`0CoiQ`X`03o`000?nYPj_oZH>[01CoZH>[00?o0000
okVI]oniVKL05?niVKL00ol0003oa[76olJaaP0DolJaaP03o`000?o=a]?ocLKC01CocLKC00?o0000
oloEg_o?eMh04oo?eMh00ol0003oc]kTolkNi00AolkNi003o`000?o<h^Soc>;X01;oc>;X00?o0000
ol[Pj?o:h>P04?o:h>P00ol0003obMSTolWHi00@olWHi003o`000?o8b=Wob<SI01;ob<SI00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08oooo
o`03o`000?mhHZgoN6:]013oN6:]00?o0000ogiOYOmnGjD04OmnGjD00ol0003oRFBRohUTXP0CohUT
XP03o`000?nHL:?oV72S01?oV72S00?o0000ojV3ZonYPj/05?nYPj/00ol0003o^IVgokVI]`0DokVI
]`03o`000?o6/LKoa[7601Coa[7600?o0000olg6doo=a]<05?o=a]<00ol0003ocmGNoloEgP0ColoE
gP03o`000?o>g^Coc]kT017oc]kT00?o0000olcRj?o<h^P04_o<h^P00ol0003ob^3Xol[Pj00@ol[P
j003o`000?o9f>CobMST013obMST00?o0000olS8fOo8b=T04_o8b=T00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ogQR[Omh
HZd04?mhHZd00ol0003oOUnUogiOY@0AogiOY@03o`000?n9I:;oRFBR01?oRFBR00?o0000oiQ`XonH
L:<04onHL:<00ol0003oZH>[ojV3Z`0DojV3Z`03o`000?niVKOo^IVg01Co^IVg00?o0000olJaa_o6
/LH05?o6/LH00ol0003ocLKColg6d`0Dolg6d`03o`000?o?eMkocmGN01?ocmGN00?o0000olkNi?o>
g^@04Oo>g^@00ol0003oc>;XolcRj00BolcRj003o`000?o:h>Sob^3X013ob^3X00?o0000olWHi?o9
f>@04?o9f>@00ol0003ob<SIolS8f@0BolS8f@03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oN6:]ogQR[@0@ogQR[@03o`00
0?mnGjGoOUnU017oOUnU00?o0000ohUTX_n9I:804_n9I:800ol0003oV72SoiQ`X`0DoiQ`X`03o`00
0?nYPj_oZH>[01CoZH>[00?o0000okVI]oniVKL05?niVKL00ol0003oa[76olJaaP0DolJaaP03o`00
0?o=a]?ocLKC01CocLKC00?o0000oloEg_o?eMh04oo?eMh00ol0003oc]kTolkNi00AolkNi003o`00
0?o<h^Soc>;X01;oc>;X00?o0000ol[Pj?o:h>P04?o:h>P00ol0003obMSTolWHi00@olWHi003o`00
0?o8b=Wob<SI01;ob<SI00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?mhHZgoN6:]013oN6:]00?o0000ogiOYOmnGjD04Omn
GjD00ol0003oRFBRohUTXP0BohUTXP03o`000?nHL:?oV72S01CoV72S00?o0000ojV3ZonYPj/05?nY
Pj/00ol0003o^IVgokVI]`0DokVI]`03o`000?o6/LKoa[7601Coa[7600?o0000olg6doo=a]<05?o=
a]<00ol0003ocmGNoloEgP0BoloEgP03o`000?o>g^Coc]kT01;oc]kT00?o0000olcRj?o<h^P04Oo<
h^P00ol0003ob^3Xol[Pj00Aol[Pj003o`000?o9f>CobMST013obMST00?o0000olS8fOo8b=T04_o8
b=T00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ogQR[OmhHZd04?mhHZd00ol0003oOUnUogiOY@0AogiOY@03o`000?n9I:;o
RFBR01;oRFBR00?o0000oiQ`XonHL:<05?nHL:<00ol0003oZH>[ojV3Z`0DojV3Z`03o`000?niVKOo
^IVg01Co^IVg00?o0000olJaa_o6/LH05?o6/LH00ol0003ocLKColg6d`0Dolg6d`03o`000?o?eMko
cmGN01;ocmGN00?o0000olkNi?o>g^@04_o>g^@00ol0003oc>;XolcRj00AolcRj003o`000?o:h>So
b^3X017ob^3X00?o0000olWHi?o9f>@04?o9f>@00ol0003ob<SIolS8f@0AolS8f@03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003oN6:]ogQR[@0@ogQR[@03o`000?mnGjGoOUnU017oOUnU00?o0000ohUTX_n9I:804_n9I:800ol0
003oV72SoiQ`X`0DoiQ`X`03o`000?nYPj_oZH>[01CoZH>[00?o0000okVI]oniVKL05?niVKL00ol0
003oa[76olJaaP0DolJaaP03o`000?o=a]?ocLKC01CocLKC00?o0000oloEg_o?eMh04_o?eMh00ol0
003oc]kTolkNi00BolkNi003o`000?o<h^Soc>;X017oc>;X00?o0000ol[Pj?o:h>P04Oo:h>P00ol0
003obMSTolWHi00@olWHi003o`000?o8b=Wob<SI017ob<SI00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mhHZgoN6:]013o
N6:]00?o0000ogiOYOmnGjD04OmnGjD00ol0003oRFBRohUTXP0BohUTXP03o`000?nHL:?oV72S01Co
V72S00?o0000ojV3ZonYPj/05?nYPj/00ol0003o^IVgokVI]`0DokVI]`03o`000?o6/LKoa[7601Co
a[7600?o0000olg6doo=a]<05?o=a]<00ol0003ocmGNoloEgP0BoloEgP03o`000?o>g^Coc]kT01;o
c]kT00?o0000olcRj?o<h^P04Oo<h^P00ol0003ob^3Xol[Pj00Aol[Pj003o`000?o9f>CobMST013o
bMST00?o0000olS8fOo8b=T04Oo8b=T00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?o
oooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ogQR[OmhHZd04?mhHZd00ol0003oOUnU
ogiOY@0AogiOY@03o`000?n9I:;oRFBR01;oRFBR00?o0000oiQ`XonHL:<05?nHL:<00ol0003oZH>[
ojV3Z`0DojV3Z`03o`000?niVKOo^IVg01Co^IVg00?o0000olJaa_o6/LH05?o6/LH00ol0003ocLKC
olg6d`0Dolg6d`03o`000?o?eMkocmGN01;ocmGN00?o0000olkNi?o>g^@04_o>g^@00ol0003oc>;X
olcRj00AolcRj003o`000?o:h>Sob^3X017ob^3X00?o0000olWHi?o9f>@04?o9f>@00ol0003ob<SI
olS8f@0AolS8f@03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool000_ooooo00?o
0000ooooooooool02?ooool00ol0003oN6:]ogQR[@0@ogQR[@03o`000?mnGjGoOUnU017oOUnU00?o
0000ohUTX_n9I:804_n9I:800ol0003oV72SoiQ`X`0DoiQ`X`03o`000?nYPj_oZH>[01CoZH>[00?o
0000okVI]oniVKL05?niVKL00ol0003oa[76olJaaP0DolJaaP03o`000?o=a]?ocLKC01CocLKC00?o
0000oloEg_o?eMh04_o?eMh00ol0003oc]kTolkNi00AolkNi003o`000?o<h^Soc>;X01;oc>;X00?o
0000ol[Pj?o:h>P04Oo:h>P00ol0003obMSTolWHi00@olWHi003o`000?o8b=Wob<SI017ob<SI00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08
ooooo`03o`000?mhHZgoN6:]013oN6:]00?o0000ogiOYOmnGjD04OmnGjD00ol0003oRFBRohUTXP0B
ohUTXP03o`000?nHL:?oV72S01CoV72S00?o0000ojV3ZonYPj/05?nYPj/00ol0003o^IVgokVI]`0D
okVI]`03o`000?o6/LKoa[7601Coa[7600?o0000olg6doo=a]<05?o=a]<00ol0003ocmGNoloEgP0B
oloEgP03o`000?o>g^Coc]kT017oc]kT00?o0000olcRj?o<h^P04_o<h^P00ol0003ob^3Xol[Pj00@
ol[Pj003o`000?o9f>CobMST013obMST00?o0000olS8fOo8b=T04_o8b=T00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ogQR
[OmhHZd04?mhHZd00ol0003oOUnUogiOY@0AogiOY@03o`000?n9I:;oRFBR01;oRFBR00?o0000oiQ`
XonHL:<05?nHL:<00ol0003oZH>[ojV3Z`0DojV3Z`03o`000?niVKOo^IVg01Co^IVg00?o0000olJa
a_o6/LH05?o6/LH00ol0003ocLKColg6d`0Dolg6d`03o`000?o?eMkocmGN01;ocmGN00?o0000olkN
i?o>g^@04Oo>g^@00ol0003oc>;XolcRj00AolcRj003o`000?o:h>Sob^3X017ob^3X00?o0000olWH
i?o9f>@04?o9f>@00ol0003ob<SIolS8f@0BolS8f@03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oN6:]ogQR[@0@ogQR[@03
o`000?mnGjGoOUnU017oOUnU00?o0000ohUTX_n9I:804_n9I:800ol0003oV72SoiQ`X`0DoiQ`X`03
o`000?nYPj_oZH>[01CoZH>[00?o0000okVI]oniVKL05?niVKL00ol0003oa[76olJaaP0DolJaaP03
o`000?o=a]?ocLKC01CocLKC00?o0000oloEg_o?eMh04_o?eMh00ol0003oc]kTolkNi00AolkNi003
o`000?o<h^Soc>;X017oc>;X00?o0000ol[Pj?o:h>P04Oo:h>P00ol0003obMSTolWHi00@olWHi003
o`000?o8b=Wob<SI01;ob<SI00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`00
2oooool00ol0003oooooooooo`08ooooo`03o`000?mhHZgoN6:]013oN6:]00?o0000ogiOYOmnGjD0
4OmnGjD00ol0003oRFBRohUTXP0BohUTXP03o`000?nHL:?oV72S01CoV72S00?o0000ojV3ZonYPj/0
5?nYPj/00ol0003o^IVgokVI]`0DokVI]`03o`000?o6/LKoa[7601Coa[7600?o0000olg6doo=a]<0
5?o=a]<00ol0003ocmGNoloEgP0BoloEgP03o`000?o>g^Coc]kT017oc]kT00?o0000olcRj?o<h^P0
4Oo<h^P00ol0003ob^3Xol[Pj00Aol[Pj003o`000?o9f>CobMST013obMST00?o0000olS8fOo8b=T0
4_o8b=T00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oo
oooooooo00Soooooool0000Zo`0001?ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000
ooooooooool02?ooool00ol0003oK5RYofaHZ@0@ofaHZ@03o`000?mfFJCoMUVT017oMUVT00?o0000
ohQUXon8IJ<04_n8IJ<00ol0003oWgRXoimhZ00DoimhZ003o`000?nfT[;o]Y:b01Co]Y:b00?o0000
olR^`?o8[/005?o8[/000ol0003odlK=om?6c@0Dom?6c@03o`000?oGemOoemOG01CoemOG00?o0000
omOPg_oGh=h04_oGh=h00ol0003oe>;RomCRhP0AomCRhP03o`000?oAg>7odMcQ017odMcQ00?o0000
olg<fOo=c=T04Oo=c=T00ol0003oa:g4olB]a00@olB]a003o`000?naPJ7o/H6Q01;o/H6Q00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08oooo
o`03o`000?m/F:WoK5RY013oK5RY00?o0000ogIIY?mfFJ@04OmfFJ@00ol0003oR6FSohQUX`0BohQU
X`03o`000?nON:SoWgRX01CoWgRX00?o0000okJB/_nfT[805?nfT[800ol0003ob:k0olR^`00DolR^
`003o`000?oCa/godlK=01CodlK=00?o0000omOGeooGemL05?oGemL00ol0003oen3NomOPgP0BomOP
gP03o`000?oDh^;oe>;R017oe>;R00?o0000om7LhOoAg>404OoAg>400ol0003ocLcIolg<f@0Aolg<
f@03o`000?o4[LCoa:g4013oa:g400?o0000ok61XOnaPJ404_naPJ400ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01?ooooo000;ooooo`;o00002Oooool00ol0003oK5RYofaHZ@0@ofaHZ@03
o`000?mfFJCoMUVT017oMUVT00?o0000ohQUXon8IJ<04_n8IJ<00ol0003oWgRXoimhZ00DoimhZ003
o`000?nfT[;o]Y:b01Co]Y:b00?o0000olR^`?o8[/005?o8[/000ol0003odlK=om?6c@0Dom?6c@03
o`000?oGemOoemOG01CoemOG00?o0000omOPg_oGh=h04_oGh=h00ol0003oe>;RomCRhP0AomCRhP03
o`000?oAg>7odMcQ017odMcQ00?o0000olg<fOo=c=T04Oo=c=T00ol0003oa:g4olB]a00@olB]a003
o`000?naPJ7o/H6Q01;o/H6Q00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`00
2oooool00ol0003oooooooooo`08ooooo`03o`000?m/F:WoK5RY013oK5RY00?o0000ogIIY?mfFJ@0
4OmfFJ@00ol0003oR6FSohQUX`0BohQUX`03o`000?nON:SoWgRX01CoWgRX00?o0000okJB/_nfT[80
5?nfT[800ol0003ob:k0olR^`00DolR^`003o`000?oCa/godlK=01CodlK=00?o0000omOGeooGemL0
5?oGemL00ol0003oen3NomOPgP0BomOPgP03o`000?oDh^;oe>;R017oe>;R00?o0000om7LhOoAg>40
4OoAg>400ol0003ocLcIolg<f@0Aolg<f@03o`000?o4[LCoa:g4013oa:g400?o0000ok61XOnaPJ40
4onaPJ400ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ofaHZOm/F:T04?m/F:T00ol0003oMUVTogIIY00AogIIY003o`000?n8
IJ?oR6FS01;oR6FS00?o0000oimhZ?nON:P05?nON:P00ol0003o]Y:bokJB/P0DokJB/P03o`000?o8
[/3ob:k001Cob:k000?o0000om?6cOoCa/d05?oCa/d00ol0003oemOGomOGe`0DomOGe`03o`000?oG
h=koen3N01;oen3N00?o0000omCRh_oDh^804OoDh^800ol0003odMcQom7Lh@0Aom7Lh@03o`000?o=
c=WocLcI017ocLcI00?o0000olB]a?o4[L@04?o4[L@00ol0003o/H6Qok61X@0Cok61X@03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003oK5RYofaHZ@0@ofaHZ@03o`000?mfFJCoMUVT017oMUVT00?o0000ohQUXon8IJ<04_n8IJ<0
0ol0003oWgRXoimhZ00DoimhZ003o`000?nfT[;o]Y:b01Co]Y:b00?o0000olR^`?o8[/005?o8[/00
0ol0003odlK=om?6c@0Dom?6c@03o`000?oGemOoemOG01CoemOG00?o0000omOPg_oGh=h04_oGh=h0
0ol0003oe>;RomCRhP0AomCRhP03o`000?oAg>7odMcQ017odMcQ00?o0000olg<fOo=c=T04Oo=c=T0
0ol0003oa:g4olB]a00@olB]a003o`000?naPJ7o/H6Q01?o/H6Q00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?m/F:WoK5RY
013oK5RY00?o0000ogIIY?mfFJ@04OmfFJ@00ol0003oR6FSohQUX`0BohQUX`03o`000?nON:SoWgRX
01CoWgRX00?o0000okJB/_nfT[805?nfT[800ol0003ob:k0olR^`00DolR^`003o`000?oCa/godlK=
01CodlK=00?o0000omOGeooGemL05?oGemL00ol0003oen3NomOPgP0BomOPgP03o`000?oDh^;oe>;R
017oe>;R00?o0000om7LhOoAg>404OoAg>400ol0003ocLcIolg<f@0Aolg<f@03o`000?o4[LCoa:g4
013oa:g400?o0000ok61XOnaPJ404onaPJ400ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ofaHZOm/F:T04?m/F:T00ol0003o
MUVTogIIY00AogIIY003o`000?n8IJ?oR6FS01;oR6FS00?o0000oimhZ?nON:P05?nON:P00ol0003o
]Y:bokJB/P0DokJB/P03o`000?o8[/3ob:k001Cob:k000?o0000om?6cOoCa/d05?oCa/d00ol0003o
emOGomOGe`0DomOGe`03o`000?oGh=koen3N01;oen3N00?o0000omCRh_oDh^804OoDh^800ol0003o
dMcQom7Lh@0Aom7Lh@03o`000?o=c=WocLcI017ocLcI00?o0000olB]a?o4[L@04?o4[L@00ol0003o
/H6Qok61X@0Cok61X@03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool000_ooooo
00?o0000ooooooooool02?ooool00ol0003oK5RYofaHZ@0@ofaHZ@03o`000?mfFJCoMUVT017oMUVT
00?o0000ohQUXon8IJ<04_n8IJ<00ol0003oWgRXoimhZ00DoimhZ003o`000?nfT[;o]Y:b01Co]Y:b
00?o0000olR^`?o8[/005?o8[/000ol0003odlK=om?6c@0Dom?6c@03o`000?oGemOoemOG01CoemOG
00?o0000omOPg_oGh=h04_oGh=h00ol0003oe>;RomCRhP0AomCRhP03o`000?oAg>7odMcQ017odMcQ
00?o0000olg<fOo=c=T04Oo=c=T00ol0003oa:g4olB]a00@olB]a003o`000?naPJ7o/H6Q01?o/H6Q
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?m/F:WoK5RY013oK5RY00?o0000ogIIY?mfFJ@04OmfFJ@00ol0003oR6FSohQU
X`0BohQUX`03o`000?nON:SoWgRX01CoWgRX00?o0000okJB/_nfT[805?nfT[800ol0003ob:k0olR^
`00DolR^`003o`000?oCa/godlK=01CodlK=00?o0000omOGeooGemL05?oGemL00ol0003oen3NomOP
gP0BomOPgP03o`000?oDh^;oe>;R017oe>;R00?o0000om7LhOoAg>404OoAg>400ol0003ocLcIolg<
f@0Aolg<f@03o`000?o4[LCoa:g4013oa:g400?o0000ok61XOnaPJ404onaPJ400ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ofaHZOm/F:T04?m/F:T00ol0003oMUVTogIIY00AogIIY003o`000?n8IJ?oR6FS01;oR6FS00?o0000
oimhZ?nON:P05?nON:P00ol0003o]Y:bokJB/P0DokJB/P03o`000?o8[/3ob:k001Cob:k000?o0000
om?6cOoCa/d05?oCa/d00ol0003oemOGomOGe`0DomOGe`03o`000?oGh=koen3N017oen3N00?o0000
omCRh_oDh^804OoDh^800ol0003odMcQom7Lh@0Aom7Lh@03o`000?o=c=WocLcI017ocLcI00?o0000
olB]a?o4[L@04_o4[L@00ol0003o/H6Qok61X@0Cok61X@03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oK5RYofaHZ@0?ofaH
Z@03o`000?mfFJCoMUVT017oMUVT00?o0000ohQUXon8IJ<04on8IJ<00ol0003oWgRXoimhZ00Doimh
Z003o`000?nfT[;o]Y:b01Co]Y:b00?o0000olR^`?o8[/005Oo8[/000ol0003odlK=om?6c@0Com?6
c@03o`000?oGemOoemOG01?oemOG00?o0000omOPg_oGh=h04_oGh=h00ol0003oe>;RomCRhP0AomCR
hP03o`000?oAg>7odMcQ017odMcQ00?o0000olg<fOo=c=T04Oo=c=T00ol0003oa:g4olB]a00BolB]
a003o`000?naPJ7o/H6Q01?o/H6Q00?o0000ooooooooool03oooool00ol0003oooooooooo`0Coooo
o`002oooool00ol0003oooooooooo`08ooooo`03o`000?m/F:WoK5RY00ooK5RY00?o0000ogIIY?mf
FJ@04OmfFJ@00ol0003oR6FSohQUX`0CohQUX`03o`000?nON:SoWgRX01CoWgRX00?o0000okJB/_nf
T[805?nfT[800ol0003ob:k0olR^`00EolR^`003o`000?oCa/godlK=01?odlK=00?o0000omOGeooG
emL04ooGemL00ol0003oen3NomOPgP0BomOPgP03o`000?oDh^;oe>;R017oe>;R00?o0000om7LhOoA
g>404OoAg>400ol0003ocLcIolg<f@0Aolg<f@03o`000?o4[LCoa:g401;oa:g400?o0000ok61XOna
PJ404onaPJ400ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ofaHZOm/F:T03om/F:T00ol0003oMUVTogIIY00AogIIY003o`00
0?n8IJ?oR6FS01?oR6FS00?o0000oimhZ?nON:P05?nON:P00ol0003o]Y:bokJB/P0DokJB/P03o`00
0?o8[/3ob:k001Gob:k000?o0000om?6cOoCa/d04ooCa/d00ol0003oemOGomOGe`0ComOGe`03o`00
0?oGh=koen3N01;oen3N00?o0000omCRh_oDh^804OoDh^800ol0003odMcQom7Lh@0Aom7Lh@03o`00
0?o=c=WocLcI017ocLcI00?o0000olB]a?o4[L@04_o4[L@00ol0003o/H6Qok61X@0Cok61X@03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oK5RYofaHZ@0?ofaHZ@03o`000?mfFJCoMUVT017oMUVT00?o0000ohQUXon8IJ<04on8
IJ<00ol0003oWgRXoimhZ00DoimhZ003o`000?nfT[;o]Y:b01Co]Y:b00?o0000olR^`?o8[/005Oo8
[/000ol0003odlK=om?6c@0Com?6c@03o`000?oGemOoemOG01?oemOG00?o0000omOPg_oGh=h04_oG
h=h00ol0003oe>;RomCRhP0AomCRhP03o`000?oAg>7odMcQ017odMcQ00?o0000olg<fOo=c=T04Oo=
c=T00ol0003oa:g4olB]a00BolB]a003o`000?naPJ7o/H6Q01?o/H6Q00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?m/F:Wo
K5RY00ooK5RY00?o0000ogIIY?mfFJ@04OmfFJ@00ol0003oR6FSohQUX`0CohQUX`03o`000?nON:So
WgRX01CoWgRX00?o0000okJB/_nfT[805?nfT[800ol0003ob:k0olR^`00EolR^`003o`000?oCa/go
dlK=01?odlK=00?o0000omOGeooGemL04ooGemL00ol0003oen3NomOPgP0BomOPgP03o`000?oDh^;o
e>;R017oe>;R00?o0000om7LhOoAg>404OoAg>400ol0003ocLcIolg<f@0Aolg<f@03o`000?o4[LCo
a:g401;oa:g400?o0000ok61XOnaPJ404onaPJ400ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ofaHZOm/F:T03om/F:T00ol0
003oMUVTogIIY00AogIIY003o`000?n8IJ?oR6FS01?oR6FS00?o0000oimhZ?nON:P05?nON:P00ol0
003o]Y:bokJB/P0DokJB/P03o`000?o8[/3ob:k001Gob:k000?o0000om?6cOoCa/d04ooCa/d00ol0
003oemOGomOGe`0ComOGe`03o`000?oGh=koen3N01;oen3N00?o0000omCRh_oDh^804OoDh^800ol0
003odMcQom7Lh@0Aom7Lh@03o`000?o=c=WocLcI017ocLcI00?o0000olB]a?o4[L@04_o4[L@00ol0
003o/H6Qok61X@0Cok61X@03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool000_o
oooo00?o0000ooooooooool02?ooool00ol0003oK5RYofaHZ@0?ofaHZ@03o`000?mfFJCoMUVT017o
MUVT00?o0000ohQUXon8IJ<04on8IJ<00ol0003oWgRXoimhZ00DoimhZ003o`000?nfT[;o]Y:b01Co
]Y:b00?o0000olR^`?o8[/005Oo8[/000ol0003odlK=om?6c@0Com?6c@03o`000?oGemOoemOG01?o
emOG00?o0000omOPg_oGh=h04_oGh=h00ol0003oe>;RomCRhP0AomCRhP03o`000?oAg>7odMcQ017o
dMcQ00?o0000olg<fOo=c=T04Oo=c=T00ol0003oa:g4olB]a00BolB]a003o`000?naPJ7o/H6Q01Co
/H6Q00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?m/F:WoK5RY00ooK5RY00?o0000ogIIY?mfFJ@04OmfFJ@00ol0003oR6FS
ohQUX`0CohQUX`03o`000?nON:SoWgRX01CoWgRX00?o0000okJB/_nfT[805?nfT[800ol0003ob:k0
olR^`00EolR^`003o`000?oCa/godlK=01?odlK=00?o0000omOGeooGemL04ooGemL00ol0003oen3N
omOPgP0BomOPgP03o`000?oDh^;oe>;R017oe>;R00?o0000om7LhOoAg>404OoAg>400ol0003ocLcI
olg<f@0Aolg<f@03o`000?o4[LCoa:g401;oa:g400?o0000ok61XOnaPJ405?naPJ400ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ofaHZOm/F:T03om/F:T00ol0003oMUVTogIIY00AogIIY003o`000?n8IJ?oR6FS01?oR6FS00?o
0000oimhZ?nON:P05?nON:P00ol0003o]Y:bokJB/P0DokJB/P03o`000?o8[/3ob:k001Gob:k000?o
0000om?6cOoCa/d04ooCa/d00ol0003oemOGomOGe`0ComOGe`03o`000?oGh=koen3N01;oen3N00?o
0000omCRh_oDh^804OoDh^800ol0003odMcQom7Lh@0Aom7Lh@03o`000?o=c=WocLcI017ocLcI00?o
0000olB]a?o4[L@04_o4[L@00ol0003o/H6Qok61X@0Dok61X@03o`000?oooooooooo00kooooo00?o
0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oK5RYofaHZ@0?
ofaHZ@03o`000?mfFJCoMUVT017oMUVT00?o0000ohQUXon8IJ<04on8IJ<00ol0003oWgRXoimhZ00D
oimhZ003o`000?nfT[;o]Y:b01Co]Y:b00?o0000olR^`?o8[/005Oo8[/000ol0003odlK=om?6c@0C
om?6c@03o`000?oGemOoemOG01?oemOG00?o0000omOPg_oGh=h02?oGh=ico`00013ooooo00?o0000
ooooooooool04oooool000_ooooo00?o0000ooooooooool02?oooolMo`0000WoMUVT00?o0000ohQU
Xon8IJ<04on8IJ<00ol0003oWgRXoimhZ00DoimhZ003o`000?nfT[;o]Y:b01Co]Y:b00?o0000olR^
`?o8[/005Oo8[/000ol0003odlK=om?6c@08om?6cBco00002_oKh]/00ol0003oe]WJomKIfP0AomKI
fP03o`000?o<`M3oc<7@017oc<7@00?o0000okVH]OniV;D04OniV;D00ol0003oWVF>oiiUSP0BoiiU
SP03o`000?n5>f[oQC]Z01CoQC]Z00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Coooo
o`002oooool00ol0003oooooooooo`08ooooo`03o`000?mOCZKoGdjV00ooGdjV00?o0000og1DX_m`
E:802?m`E:9`o`0000_og]G?00?o0000omkPeooNh=L04ooNh=L00ol0003ofn;Kom_Rf`0Bom_Rf`03
o`000?oFfM[oe]WJ017oe]WJ00?o0000olc1d?o<`M004Oo<`M000ol0003o^IReokVH]@0AokVH]@03
o`000?nNIHkoWVF>01;oWVF>00?o0000ohDkJ_n5>fX05?n5>fX00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01?ooooo000;ooooo`;o00002Oooool00ol0003oGdjVoem>YP0?oem>YP03o`00
0?m`E:;oL5BR017oL5BR00?o0000ohYWY?n:Ij@04on:Ij@00ol0003oZHB]ojV4[@0DojV4[@03o`00
0?o4Y;Woa:Bi01Coa:Bi00?o0000omK1aOoF`LD05OoF`LD00ol0003og]G?omkEc`0ComkEc`03o`00
0?oNh=Oog^3G01?og^3G00?o0000om_RfooKh]/04_oKh]/00ol0003oe]WJomKIfP0AomKIfP03o`00
0?o<`M3oc<7@017oc<7@00?o0000okVH]OniV;D04OniV;D00ol0003oWVF>oiiUSP0BoiiUSP03o`00
0?n5>f[oQC]Z01GoQC]Z00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?mOCZKoGdjV00ooGdjV00?o0000og1DX_m`E:804Om`
E:800ol0003oRVNTohYWY00CohYWY003o`000?nYQ:goZHB]01CoZHB]00?o0000olBT^Oo4Y;T05?o4
Y;T00ol0003oe/75omK1a@0EomK1a@03o`000?oNeLoog]G?01?og]G?00?o0000omkPeooNh=L04ooN
h=L00ol0003ofn;Kom_Rf`0Bom_Rf`03o`000?oFfM[oe]WJ017oe]WJ00?o0000olc1d?o<`M004Oo<
`M000ol0003o^IReokVH]@0AokVH]@03o`000?nNIHkoWVF>01?oWVF>00?o0000ohDkJ_n5>fX05?n5
>fX00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000oem>Y_mOCZH03omOCZH00ol0003oL5BRog1DXP0Aog1DXP03o`000?n:IjCo
RVNT01?oRVNT00?o0000ojV4[OnYQ:d05?nYQ:d00ol0003oa:BiolBT^@0DolBT^@03o`000?oF`LGo
e/7501Goe/7500?o0000omkEcooNeLl04ooNeLl00ol0003og^3GomkPe`0ComkPe`03o`000?oKh]_o
fn;K01;ofn;K00?o0000omKIf_oFfMX04OoFfMX00ol0003oc<7@olc1d00Aolc1d003o`000?niV;Go
^IRe017o^IRe00?o0000oiiUS_nNIHh04onNIHh00ol0003oQC]ZohDkJP0DohDkJP03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003oGdjVoem>YP0?oem>YP03o`000?m`E:;oL5BR017oL5BR00?o0000ohYWY?n:Ij@04on:Ij@00ol0
003oZHB]ojV4[@0DojV4[@03o`000?o4Y;Woa:Bi01Coa:Bi00?o0000omK1aOoF`LD05OoF`LD00ol0
003og]G?omkEc`0ComkEc`03o`000?oNh=Oog^3G01?og^3G00?o0000om_RfooKh]/04_oKh]/00ol0
003oe]WJomKIfP0AomKIfP03o`000?o<`M3oc<7@017oc<7@00?o0000okVH]OniV;D04OniV;D00ol0
003oWVF>oiiUSP0CoiiUSP03o`000?n5>f[oQC]Z01CoQC]Z00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mOCZKoGdjV00oo
GdjV00?o0000og1DX_m`E:804Om`E:800ol0003oRVNTohYWY00CohYWY003o`000?nYQ:goZHB]01Co
ZHB]00?o0000olBT^Oo4Y;T05?o4Y;T00ol0003oe/75omK1a@0EomK1a@03o`000?oNeLoog]G?01?o
g]G?00?o0000omkPeooNh=L04ooNh=L00ol0003ofn;Kom_Rf`0Bom_Rf`03o`000?oFfM[oe]WJ017o
e]WJ00?o0000olc1d?o<`M004Oo<`M000ol0003o^IReokVH]@0AokVH]@03o`000?nNIHkoWVF>01?o
WVF>00?o0000ohDkJ_n5>fX05On5>fX00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?o
oooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oem>Y_mOCZH03omOCZH00ol0003oL5BR
og1DXP0Aog1DXP03o`000?n:IjCoRVNT01?oRVNT00?o0000ojV4[OnYQ:d05?nYQ:d00ol0003oa:Bi
olBT^@0DolBT^@03o`000?oF`LGoe/7501Goe/7500?o0000omkEcooNeLl04ooNeLl00ol0003og^3G
omkPe`0ComkPe`03o`000?oKh]_ofn;K01;ofn;K00?o0000omKIf_oFfMX04OoFfMX00ol0003oc<7@
olc1d00Aolc1d003o`000?niV;Go^IRe017o^IRe00?o0000oiiUS_nNIHh04onNIHh00ol0003oQC]Z
ohDkJP0EohDkJP03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool000_ooooo00?o
0000ooooooooool02?ooool00ol0003oGdjVoem>YP0?oem>YP03o`000?m`E:;oL5BR017oL5BR00?o
0000ohYWY?n:Ij@04on:Ij@00ol0003oZHB]ojV4[@0DojV4[@03o`000?o4Y;Woa:Bi01Coa:Bi00?o
0000omK1aOoF`LD05OoF`LD00ol0003og]G?omkEc`0ComkEc`03o`000?oNh=Oog^3G01?og^3G00?o
0000om_RfooKh]/04_oKh]/00ol0003oe]WJomKIfP0AomKIfP03o`000?o<`M3oc<7@017oc<7@00?o
0000okVH]OniV;D04OniV;D00ol0003oWVF>oiiUSP0DoiiUSP03o`000?n5>f[oQC]Z01CoQC]Z00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08
ooooo`03o`000?mOCZKoGdjV00ooGdjV00?o0000og1DX_m`E:804Om`E:800ol0003oRVNTohYWY00C
ohYWY003o`000?nYQ:goZHB]01CoZHB]00?o0000olBT^Oo4Y;T05?o4Y;T00ol0003oe/75omK1a@0E
omK1a@03o`000?oNeLoog]G?01?og]G?00?o0000omkPeooNh=L04ooNh=L00ol0003ofn;Kom_Rf`0B
om_Rf`03o`000?oFfM[oe]WJ017oe]WJ00?o0000olc1d?o<`M004Oo<`M000ol0003o^IReokVH]@0A
okVH]@03o`000?nNIHkoWVF>01CoWVF>00?o0000ohDkJ_n5>fX05?n5>fX00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oem>
Y_mOCZH03omOCZH00ol0003oL5BRog1DXP0Aog1DXP03o`000?n:IjCoRVNT01?oRVNT00?o0000ojV4
[OnYQ:d05?nYQ:d00ol0003oa:BiolBT^@0DolBT^@03o`000?oF`LGoe/7501Goe/7500?o0000omkE
cooNeLl04ooNeLl00ol0003og^3GomkPe`0ComkPe`03o`000?oKh]_ofn;K017ofn;K00?o0000omKI
f_oFfMX04OoFfMX00ol0003oc<7@olc1d00Bolc1d003o`000?niV;Go^IRe01;o^IRe00?o0000oiiU
S_nNIHh04onNIHh00ol0003oQC]ZohDkJP0EohDkJP03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oGdjVoem>YP0?oem>YP03
o`000?m`E:;oL5BR017oL5BR00?o0000ohYWY?n:Ij@04on:Ij@00ol0003oZHB]ojV4[@0DojV4[@03
o`000?o4Y;Woa:Bi01Coa:Bi00?o0000omK1aOoF`LD05OoF`LD00ol0003og]G?omkEc`0ComkEc`03
o`000?oNh=Oog^3G01?og^3G00?o0000om_RfooKh]/04OoKh]/00ol0003oe]WJomKIfP0AomKIfP03
o`000?o<`M3oc<7@01;oc<7@00?o0000okVH]OniV;D04_niV;D00ol0003oWVF>oiiUSP0CoiiUSP03
o`000?n5>f[oQC]Z01GoQC]Z00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`00
2oooool00ol0003oooooooooo`08ooooo`03o`000?mOCZKoGdjV00ooGdjV00?o0000og1DX_m`E:80
4Om`E:800ol0003oRVNTohYWY00CohYWY003o`000?nYQ:goZHB]01CoZHB]00?o0000olBT^Oo4Y;T0
5?o4Y;T00ol0003oe/75omK1a@0EomK1a@03o`000?oNeLoog]G?01?og]G?00?o0000omkPeooNh=L0
4ooNh=L00ol0003ofn;Kom_Rf`0Aom_Rf`03o`000?oFfM[oe]WJ017oe]WJ00?o0000olc1d?o<`M00
4_o<`M000ol0003o^IReokVH]@0BokVH]@03o`000?nNIHkoWVF>01?oWVF>00?o0000ohDkJ_n5>fX0
5On5>fX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000oem>Y_mOCZH03omOCZH00ol0003oL5BRog1DXP0Aog1DXP03o`000?n:
IjCoRVNT01?oRVNT00?o0000ojV4[OnYQ:d05?nYQ:d00ol0003oa:BiolBT^@0EolBT^@03o`000?oF
`LGoe/7501Coe/7500?o0000omkEcooNeLl04ooNeLl00ol0003og^3GomkPe`0ComkPe`03o`000?oK
h]_ofn;K017ofn;K00?o0000omKIf_oFfMX04OoFfMX00ol0003oc<7@olc1d00Bolc1d003o`000?ni
V;Go^IRe01;o^IRe00?o0000oiiUS_nNIHh04onNIHh00ol0003oQC]ZohDkJP0FohDkJP03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003oGdjVoem>YP0?oem>YP03o`000?m`E:;oL5BR017oL5BR00?o0000ohYWY?n:Ij@04on:Ij@0
0ol0003oZHB]ojV4[@0DojV4[@03o`000?o4Y;Woa:Bi01Goa:Bi00?o0000omK1aOoF`LD05?oF`LD0
0ol0003og]G?omkEc`0ComkEc`03o`000?oNh=Oog^3G01?og^3G00?o0000om_RfooKh]/04OoKh]/0
0ol0003oe]WJomKIfP0AomKIfP03o`000?o<`M3oc<7@01;oc<7@00?o0000okVH]OniV;D04_niV;D0
0ol0003oWVF>oiiUSP0DoiiUSP03o`000?n5>f[oQC]Z01GoQC]Z00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mOCZKoGdjV
00ooGdjV00?o0000og1DX_m`E:804Om`E:800ol0003oRVNTohYWY00CohYWY003o`000?nYQ:goZHB]
01CoZHB]00?o0000olBT^Oo4Y;T05Oo4Y;T00ol0003oe/75omK1a@0DomK1a@03o`000?oNeLoog]G?
01?og]G?00?o0000omkPeooNh=L04ooNh=L00ol0003ofn;Kom_Rf`0Aom_Rf`03o`000?oFfM[oe]WJ
017oe]WJ00?o0000olc1d?o<`M004_o<`M000ol0003o^IReokVH]@0BokVH]@03o`000?nNIHkoWVF>
01CoWVF>00?o0000ohDkJ_n5>fX05On5>fX00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oem>Y_mOCZH03omOCZH00ol0003o
L5BRog1DXP0Aog1DXP03o`000?n:IjCoRVNT01?oRVNT00?o0000ojV4[OnYQ:d05?nYQ:d00ol0003o
a:BiolBT^@0EolBT^@03o`000?oF`LGoe/7501Coe/7500?o0000omkEcooNeLl04ooNeLl00ol0003o
g^3GomkPe`0ComkPe`03o`000?oKh]_ofn;K017ofn;K00?o0000omKIf_oFfMX04OoFfMX00ol0003o
c<7@olc1d00Bolc1d003o`000?niV;Go^IRe01;o^IRe00?o0000oiiUS_nNIHh05?nNIHh00ol0003o
QC]ZohDkJP0EohDkJP03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool000_ooooo
00?o0000ooooooooool02?ooool00ol0003oGdjVoem>YP0?oem>YP03o`000?m`E:;oL5BR017oL5BR
00?o0000ohYWY?n:Ij@04on:Ij@00ol0003oZHB]ojV4[@0DojV4[@03o`000?o4Y;Woa:Bi01Goa:Bi
00?o0000omK1aOoF`LD05?oF`LD00ol0003og]G?omkEc`0ComkEc`03o`000?oNh=Oog^3G01?og^3G
00?o0000om_RfooKh]/04OoKh]/00ol0003oe]WJomKIfP0AomKIfP03o`000?o<`M3oc<7@01;oc<7@
00?o0000okVH]OniV;D04_niV;D00ol0003oWVF>oiiUSP0DoiiUSP03o`000?n5>f[oQC]Z01KoQC]Z
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?mOCZKoGdjV00ooGdjV00?o0000og1DX_m`E:804Om`E:800ol0003oRVNTohYW
Y00CohYWY003o`000?nYQ:goZHB]01CoZHB]00?o0000olBT^Oo4Y;T05Oo4Y;T00ol0003oe/75omK1
a@0DomK1a@03o`000?oNeLoog]G?01?og]G?00?o0000omkPeooNh=L04ooNh=L00ol0003ofn;Kom_R
f`0Aom_Rf`03o`000?oFfM[oe]WJ017oe]WJ00?o0000olc1d?o<`M004_o<`M000ol0003o^IReokVH
]@0BokVH]@03o`000?nNIHkoWVF>01CoWVF>00?o0000ohDkJ_n5>fX05_n5>fX00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
oem>Y_mOCZH03omOCZH00ol0003oL5BRog1DXP0Aog1DXP03o`000?n:IjCoRVNT01?oRVNT00?o0000
ojV4[OnYQ:d05?nYQ:d00ol0003oa:BiolBT^@0EolBT^@03o`000?oF`LGoe/7501Coe/7500?o0000
omkEcooNeLl04ooNeLl00ol0003og^3GomkPe`0ComkPe`03o`000?oKh]_ofn;K017ofn;K00?o0000
omKIf_oFfMX01ooFfMX[o`0000Wo^IRe00?o0000oiiUS_nNIHh05OnNIHh00ol0003oQC]ZohDkJP0E
ohDkJP03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool000Go00001_ooool00ol0
003oooooooooo`08ooooo`03o`000?mOCZKoGdjV00ooGdjV00?o0000og1DX_m`E:804Om`E:800ol0
003oRVNTohYWY00CohYWY003o`000?nYQ:goZHB]01CoZHB]00?o0000olBT^Oo4Y;T05Oo4Y;T00ol0
003oe/75omK1a@0DomK1a@03o`000?oNeLoog]G?01?og]G?00?o0000omkPeooNh=L03_oNh=LSo`00
00[oc;g<00?o0000ok6<[onaS:l04_naS:l00ol0003oTEN7oi5GQ`09oi5GQaKo00002onNIHh00ol0
003oQC]ZohDkJP0EohDkJP03o`000?oooooooooo00Wooooo00?o0000ooooooooool04oooool00005
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`08ooooo`03o`000?mOCZKoGdjV
00ooGdjV00?o0000og1DX_m`E:804Om`E:800ol0003oRVNTohYWY00CohYWY003o`000?nYQ:goZHB]
01CoZHB]00?o0000olBT^Oo4Y;T05Oo4Y;T00ol0003oe/75omK1a@0DomK1a@03o`000?oNeLoog]G?
01?og]G?00?o0000omkPeooNh=L00ooNh=L;o`0000Goh^;D00?o0000om[Ie_oJfMH04OoJfMH00ol0
003oc;g<olbmc00Aolbmc003o`000?naS:oo/Hb_01;o/Hb_00?o0000oi5GQonAEhL04_nAEhL00ol0
003oNC5WogTaI`0:ogTaIaWo00002on5>fX00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01?ooooo00001?ooooooV9RHob4Q8Oo^k^h7ooooo`03o`000?oooooooooo00Sooooo2_l00008oem>
YP03o`000?m`E:;oL5BR017oL5BR00?o0000ohYWY?n:Ij@04on:Ij@00ol0003oZHB]ojV4[@0DojV4
[@03o`000?o4Y;Woa:Bi01Goa:Bi00?o0000omK1aOoF`LD05?oF`LD00ol0003og]G?omkEc`08omkE
ca7o00004?oRh]@00ol0003of]WFom[IeP0Aom[IeP03o`000?o<_Lcoc;g<017oc;g<00?o0000ok6<
[onaS:l04_naS:l00ol0003oTEN7oi5GQ`0Boi5GQ`03o`000?mi<FOoNC5W01GoNC5W00?o0000ofdO
Eom]7eL02om]7eL<o`0000[ooooo00?o0000ooooooooool04oooool000;ooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`0000Sooooo00?o0000oe=4X_mCA:801omCA:8Co`0000WoL5BR00?o0000ohYWY?n:
Ij@04on:Ij@00ol0003oZHB]ojV4[@0DojV4[@03o`000?o4Y;Woa:Bi01Goa:Bi00?o0000omK1aOoF
`LD02OoF`LDFo`0000_oi=k>00?o0000on;Re?oRh]@04ooRh]@00ol0003of]WFom[IeP0Aom[IeP03
o`000?o<_Lcoc;g<017oc;g<00?o0000ok6<[onaS:l04_naS:l00ol0003oTEN7oi5GQ`0Boi5GQ`03
o`000?mi<FOoNC5W01GoNC5W00?o0000ofdOEom]7eL05_m]7eL00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01?ooooo0003ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oDdBRoe=4XP0?oe=4XP03o`000?m[D:7oJe2Q00SoJe2Q5Ol0000:ohYWY003o`00
0?nYQ:goZHB]01CoZHB]00?o0000olBT^Oo4Y;T02Oo4Y;THo`0000_ohLo600?o0000onCNc_oTg/h0
4ooTg/h00ol0003oh^;Don;Re00Con;Re003o`000?oJfMKof]WF017of]WF00?o0000olbmc?o<_L`0
4Oo<_L`00ol0003o/Hb_ok6<[`0Bok6<[`03o`000?nAEhOoTEN701?oTEN700?o0000ogTaIomi<FL0
5Omi<FL00ol0003oKAmGofdOE`0EofdOE`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4oooool000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?mC
A:;oDdBR00ooDdBR00?o0000of]@XOm[D:404Om[D:400ol0003oSffWohm]Y`09ohm]Ybgo00003?oB
]K`00ol0003ohLo6on7?aP0Don7?aP03o`000?oTg/koi=k>01?oi=k>00?o0000on;Re?oRh]@04ooR
h]@00ol0003of]WFom[IeP0Aom[IeP03o`000?o<_Lcoc;g<017oc;g<00?o0000ok6<[onaS:l04_na
S:l00ol0003oTEN7oi5GQ`0Coi5GQ`03o`000?mi<FOoNC5W01GoNC5W00?o0000ofdOEom]7eL05_m]
7eL00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00001Ol0003o^[ZjoooooonH
V9So410@00Kooooo00?o0000ooooooooool02?ooool00ol0003oDdBRoe=4XP0?oe=4XP03o`000?m[
D:7oJe2Q017oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0003o]Y6aokJA/@0DokJA/@03o`000?oB
]Kcod[Fl01God[Fl00?o0000on7?a_oQclH05?oQclH00ol0003oi=k>onCNcP0ConCNcP03o`000?oR
h]Coh^;D01?oh^;D00?o0000om[Ie_oJfMH04OoJfMH00ol0003oc;g<olbmc00Aolbmc003o`000?na
S:oo/Hb_01;o/Hb_00?o0000oi5GQonAEhL04onAEhL00ol0003oNC5WogTaI`0EogTaI`03o`000?m]
7eOoKAmG01KoKAmG00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`0000GoV9RH
oa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00Sooooo00?o0000oe=4X_mCA:803omC
A:800ol0003oJe2Qof]@X@0Aof]@X@03o`000?n?KJOoSffW01?oSffW00?o0000okJA/OnfTK405?nf
TK400ol0003od[Flom:e_00Eom:e_003o`000?oQclKohLo601CohLo600?o0000onCNc_oTg/h04ooT
g/h00ol0003oh^;Don;Re00Con;Re003o`000?oJfMKof]WF017of]WF00?o0000olbmc?o<_L`04Oo<
_L`00ol0003o/Hb_ok6<[`0Bok6<[`03o`000?nAEhOoTEN701?oTEN700?o0000ogTaIomi<FL05Omi
<FL00ol0003oKAmGofdOE`0FofdOE`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003oDdBRoe=4XP0?oe=4XP03o`000?m[D:7o
Je2Q017oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0003o]Y6aokJA/@0DokJA/@03o`000?oB]Kco
d[Fl01God[Fl00?o0000on7?a_oQclH05?oQclH00ol0003oi=k>onCNcP0ConCNcP03o`000?oRh]Co
h^;D01?oh^;D00?o0000om[Ie_oJfMH04OoJfMH00ol0003oc;g<olbmc00Aolbmc003o`000?naS:oo
/Hb_01;o/Hb_00?o0000oi5GQonAEhL04onAEhL00ol0003oNC5WogTaI`0EogTaI`03o`000?m]7eOo
KAmG01OoKAmG00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0
003oooooooooo`08ooooo`03o`000?mCA:;oDdBR00ooDdBR00?o0000of]@XOm[D:404Om[D:400ol0
003oSffWohm]Y`0Cohm]Y`03o`000?nfTK7o]Y6a01Co]Y6a00?o0000om:e_?oB]K`05OoB]K`00ol0
003ohLo6on7?aP0Don7?aP03o`000?oTg/koi=k>01?oi=k>00?o0000on;Re?oRh]@04ooRh]@00ol0
003of]WFom[IeP0Aom[IeP03o`000?o<_Lcoc;g<017oc;g<00?o0000ok6<[onaS:l04_naS:l00ol0
003oTEN7oi5GQ`0Doi5GQ`03o`000?mi<FOoNC5W01GoNC5W00?o0000ofdOEom]7eL05_m]7eL00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00So
oooo00?o0000oe=4X_mCA:803omCA:800ol0003oJe2Qof]@X@0Aof]@X@03o`000?n?KJOoSffW01?o
SffW00?o0000okJA/OnfTK405?nfTK400ol0003od[Flom:e_00Eom:e_003o`000?oQclKohLo601Co
hLo600?o0000onCNc_oTg/h04ooTg/h00ol0003oh^;Don;Re00Con;Re003o`000?oJfMKof]WF017o
f]WF00?o0000olbmc?o<_L`04Oo<_L`00ol0003o/Hb_ok6<[`0Bok6<[`03o`000?nAEhOoTEN701Co
TEN700?o0000ogTaIomi<FL05Omi<FL00ol0003oKAmGofdOE`0FofdOE`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oDdBR
oe=4XP0?oe=4XP03o`000?m[D:7oJe2Q017oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0003o]Y6a
okJA/@0DokJA/@03o`000?oB]Kcod[Fl01God[Fl00?o0000on7?a_oQclH05?oQclH00ol0003oi=k>
onCNcP0ConCNcP03o`000?oRh]Coh^;D01;oh^;D00?o0000om[Ie_oJfMH04OoJfMH00ol0003oc;g<
olbmc00Bolbmc003o`000?naS:oo/Hb_01?o/Hb_00?o0000oi5GQonAEhL04onAEhL00ol0003oNC5W
ogTaI`0EogTaI`03o`000?m]7eOoKAmG01KoKAmG00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mCA:;oDdBR00ooDdBR00?o
0000of]@XOm[D:404Om[D:400ol0003oSffWohm]Y`0Cohm]Y`03o`000?nfTK7o]Y6a01Co]Y6a00?o
0000om:e_?oB]K`05OoB]K`00ol0003ohLo6on7?aP0Don7?aP03o`000?oTg/koi=k>01?oi=k>00?o
0000on;Re?oRh]@04_oRh]@00ol0003of]WFom[IeP0Aom[IeP03o`000?o<_Lcoc;g<01;oc;g<00?o
0000ok6<[onaS:l04onaS:l00ol0003oTEN7oi5GQ`0Coi5GQ`03o`000?mi<FOoNC5W01GoNC5W00?o
0000ofdOEom]7eL05om]7eL00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000oe=4X_mCA:803omCA:800ol0003oJe2Qof]@X@0A
of]@X@03o`000?n?KJOoSffW01?oSffW00?o0000okJA/OnfTK405?nfTK400ol0003od[Flom:e_00E
om:e_003o`000?oQclKohLo601CohLo600?o0000onCNc_oTg/h04ooTg/h00ol0003oh^;Don;Re00B
on;Re003o`000?oJfMKof]WF017of]WF00?o0000olbmc?o<_L`04_o<_L`00ol0003o/Hb_ok6<[`0C
ok6<[`03o`000?nAEhOoTEN701?oTEN700?o0000ogTaIomi<FL05Omi<FL00ol0003oKAmGofdOE`0G
ofdOE`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool000_ooooo00?o0000oooo
ooooool02?ooool00ol0003oDdBRoe=4XP0?oe=4XP03o`000?m[D:7oJe2Q017oJe2Q00?o0000ohm]
Yon?KJL04on?KJL00ol0003o]Y6aokJA/@0DokJA/@03o`000?oB]Kcod[Fl01God[Fl00?o0000on7?
a_oQclH05OoQclH00ol0003oi=k>onCNcP0BonCNcP03o`000?oRh]Coh^;D01;oh^;D00?o0000om[I
e_oJfMH04OoJfMH00ol0003oc;g<olbmc00Bolbmc003o`000?naS:oo/Hb_01?o/Hb_00?o0000oi5G
QonAEhL04onAEhL00ol0003oNC5WogTaI`0FogTaI`03o`000?m]7eOoKAmG01KoKAmG00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03
o`000?mCA:;oDdBR00ooDdBR00?o0000of]@XOm[D:404Om[D:400ol0003oSffWohm]Y`0Cohm]Y`03
o`000?nfTK7o]Y6a01Co]Y6a00?o0000om:e_?oB]K`05OoB]K`00ol0003ohLo6on7?aP0Eon7?aP03
o`000?oTg/koi=k>01;oi=k>00?o0000on;Re?oRh]@04_oRh]@00ol0003of]WFom[IeP0Aom[IeP03
o`000?o<_Lcoc;g<01;oc;g<00?o0000ok6<[onaS:l04onaS:l00ol0003oTEN7oi5GQ`0Doi5GQ`03
o`000?mi<FOoNC5W01GoNC5W00?o0000ofdOEom]7eL05om]7eL00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oe=4X_mCA:80
3omCA:800ol0003oJe2Qof]@X@0@of]@X@03o`000?n?KJOoSffW01CoSffW00?o0000okJA/OnfTK40
5?nfTK400ol0003od[Flom:e_00Eom:e_003o`000?oQclKohLo601GohLo600?o0000onCNc_oTg/h0
4_oTg/h00ol0003oh^;Don;Re00Bon;Re003o`000?oJfMKof]WF017of]WF00?o0000olbmc?o<_L`0
4_o<_L`00ol0003o/Hb_ok6<[`0Cok6<[`03o`000?nAEhOoTEN701CoTEN700?o0000ogTaIomi<FL0
5Omi<FL00ol0003oKAmGofdOE`0GofdOE`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oDdBRoe=4XP0?oe=4XP03o`000?m[
D:7oJe2Q013oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0003o]Y6aokJA/@0EokJA/@03o`000?oB
]Kcod[Fl01God[Fl00?o0000on7?a_oQclH05OoQclH00ol0003oi=k>onCNcP0BonCNcP03o`000?oR
h]Coh^;D01;oh^;D00?o0000om[Ie_oJfMH04OoJfMH00ol0003oc;g<olbmc00Bolbmc003o`000?na
S:oo/Hb_01?o/Hb_00?o0000oi5GQonAEhL05?nAEhL00ol0003oNC5WogTaI`0EogTaI`03o`000?m]
7eOoKAmG01OoKAmG00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`002oooool0
0ol0003oooooooooo`08ooooo`03o`000?mCA:;oDdBR00ooDdBR00?o0000of]@XOm[D:404?m[D:40
0ol0003oSffWohm]Y`0Cohm]Y`03o`000?nfTK7o]Y6a01Go]Y6a00?o0000om:e_?oB]K`05OoB]K`0
0ol0003ohLo6on7?aP0Eon7?aP03o`000?oTg/koi=k>01;oi=k>00?o0000on;Re?oRh]@04_oRh]@0
0ol0003of]WFom[IeP0Aom[IeP03o`000?o<_Lcoc;g<01;oc;g<00?o0000ok6<[onaS:l04onaS:l0
0ol0003oTEN7oi5GQ`0Doi5GQ`03o`000?mi<FOoNC5W01GoNC5W00?o0000ofdOEom]7eL06?m]7eL0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo
00Sooooo00?o0000oe=4X_mCA:803omCA:800ol0003oJe2Qof]@X@0@of]@X@03o`000?n?KJOoSffW
01?oSffW00?o0000okJA/OnfTK405OnfTK400ol0003od[Flom:e_00Eom:e_003o`000?oQclKohLo6
01GohLo600?o0000onCNc_oTg/h04_oTg/h00ol0003oh^;Don;Re00Bon;Re003o`000?oJfMKof]WF
017of]WF00?o0000olbmc?o<_L`04_o<_L`00ol0003o/Hb_ok6<[`0Cok6<[`03o`000?nAEhOoTEN7
01CoTEN700?o0000ogTaIomi<FL05_mi<FL00ol0003oKAmGofdOE`0GofdOE`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
DdBRoe=4XP0?oe=4XP03o`000?m[D:7oJe2Q013oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0003o
]Y6aokJA/@0EokJA/@03o`000?oB]Kcod[Fl01God[Fl00?o0000on7?a_oQclH05OoQclH00ol0003o
i=k>onCNcP0BonCNcP03o`000?oRh]Coh^;D00goh^;D>_l0000:ok6<[`03o`000?nAEhOoTEN701Go
TEN700?o0000ogTaIomi<FL05Omi<FL00ol0003oKAmGofdOE`0GofdOE`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oDdBR
oe=4XP0?oe=4XP03o`000?m[D:7oJe2Q013oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0003o]Y6a
okJA/@0EokJA/@03o`000?oB]Kcod[Fl01God[Fl00?o0000on7?a_oQclH05OoQclH00ol0003oi=k>
onCNcP0BonCNcP03o`000?oRh]Coh^;D00;oh^;D2ol00005on7Ld@03o`000?o@`Lcod<7<017od<7<
00?o0000ojn</On_S;404_n_S;400ol0003oRE:9ohUBR@09ohUBRAOo00002onAEhL00ol0003oNC5W
ogTaI`0EogTaI`03o`000?m]7eOoKAmG01OoKAmG00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?mCA:;oDdBR00ooDdBR00?o
0000of]@XOm[D:404?m[D:400ol0003oSffWohm]Y`0Cohm]Y`03o`000?nfTK7o]Y6a01Go]Y6a00?o
0000om:e_?oB]K`05OoB]K`00ol0003ohLo6on7?aP0Eon7?aP03o`000?oTg/koi=k>00goi=k>2_l0
000@on7Ld@03o`000?o@`Lcod<7<017od<7<00?o0000ojn</On_S;404_n_S;400ol0003oRE:9ohUB
R@0CohUBR@03o`000?m`;F[oL2eZ00[oL2eZ4?l0000CogTaI`03o`000?m]7eOoKAmG01SoKAmG00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08
ooooo`Co00003_mCA:800ol0003oJe2Qof]@X@0@of]@X@03o`000?n?KJOoSffW01?oSffW00?o0000
okJA/OnfTK405OnfTK400ol0003od[Flom:e_00Eom:e_003o`000?oQclKohLo601GohLo600?o0000
onCNc_oTg/h00_oTg/h;o`0000Goj>;<00?o0000on7LdOoQg=404_oQg=400ol0003od<7<om31c00A
om31c003o`000?n_S;7o[hba01;o[hba00?o0000ohUBROn9DXT04on9DXT00ol0003oL2eZog0]JP0E
og0]JP03o`000?mX7egoJ1mM00;oJ1mM2Ol0000:ogTaI`03o`000?m]7eOoKAmG01SoKAmG00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`002oooool2o`0000Wooooo00Co0000odLj
W_m7>YkoAcZN1_l00008oe=4XP03o`000?m[D:7oJe2Q013oJe2Q00?o0000ohm]Yon?KJL04on?KJL0
0ol0003o]Y6aokJA/@0EokJA/@03o`000?oB]Kcod[Fl01God[Fl00?o0000on7?a_oQclH03ooQclH;
o`00013oj>;<00?o0000on7LdOoQg=404_oQg=400ol0003od<7<om31c00Aom31c003o`000?n_S;7o
[hba01;o[hba00?o0000ohUBROn9DXT04on9DXT00ol0003oL2eZog0]JP0Eog0]JP03o`000?mX7ego
J1mM00_oJ1mM2?l00003ogTaI`03o`000?m]7eOoKAmG01OoKAmG00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?m7>YkoAcZN
00OoAcZN1_l00002oe=4XP03o`000?m[D:7oJe2Q013oJe2Q00?o0000ohm]Yon?KJL04on?KJL00ol0
003o]Y6aokJA/@0EokJA/@03o`000?oB]Kcod[Fl01God[Fl00?o0000on7?a_oQclH00ooQclH<o`00
00KojMW400?o0000onSRc?oXh/`04_oXh/`00ol0003ohMcAon7Ld@0Bon7Ld@03o`000?o@`Lcod<7<
017od<7<00?o0000ojn</On_S;404_n_S;400ol0003oRE:9ohUBR@0CohUBR@03o`000?m`;F[oL2eZ
01GoL2eZ00?o0000ofPOGOmX7ed04omX7edBo`0000coKAmG00Go0000ooooooooooooooooo`00000E
ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?m7>YkoAcZN00goAcZN3Ol00008of]@
X@03o`000?n?KJOoSffW01?oSffW00?o0000okJA/OnfTK405OnfTK400ol0003od[Flom:e_009om:e
_1;o00004_oYfL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA01;ohMcA00?o0000om31
c?o@`L`04Oo@`L`00ol0003o[hbaojn</@0Bojn</@03o`000?n9DXWoRE:901CoRE:900?o0000og0]
J_m`;FX05Om`;FX00ol0003oJ1mMofPOG@0EofPOG@03o`000?m`:FCoL2UT00coL2UT3Ol00003oooo
o`03o`000?oooooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000odLjW_m7
>Yh03om7>Yh00ol0003oIdjQofM>X@08ofM>XACo00002_n?KJL00ol0003o]Y6aokJA/@09okJA/ASo
00003?oO`kd00ol0003ojMW4onWIa00EonWIa003o`000?oXh/coj>;<01;oj>;<00?o0000on7LdOoQ
g=404_oQg=400ol0003od<7<om31c00Aom31c003o`000?n_S;7o[hba01;o[hba00?o0000ohUBROn9
DXT05?n9DXT00ol0003oL2eZog0]JP0Eog0]JP03o`000?mX7egoJ1mM01GoJ1mM00?o0000og0YI?m`
:F@06?m`:F@01Ol0003ooooooooooooooooo000001Gooooo000;ooooo`03o`000?oooooooooo00So
oooo00?o0000odLjW_m7>Yh03om7>Yh00ol0003oIdjQofM>X@0@ofM>X@03o`000?nGM:WoUgBY00Wo
UgBY5_l0000<olBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05OoYfL@00ol0003o
j>;<onSRc00BonSRc003o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@`L`04Oo@`L`00ol0003o
[hbaojn</@0Bojn</@03o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05Om`;FX00ol0003o
J1mMofPOG@0FofPOG@03o`000?m`:FCoL2UT01OoL2UT00Go0000ooooooooooooooooo`00000Eoooo
o`002oooool00ol0003oooooooooo`08ooooo`03o`000?m7>YkoAcZN00ooAcZN00?o0000ofM>XOmW
CZ404?mWCZ400ol0003oUgBYoiMdZ@0CoiMdZ@03o`000?o4X;Coa:2d01Goa:2d00?o0000omo3_OoO
`kd05OoO`kd00ol0003ojMW4onWIa00EonWIa003o`000?oXh/coj>;<01;oj>;<00?o0000on7LdOoQ
g=404_oQg=400ol0003od<7<om31c00Aom31c003o`000?n_S;7o[hba01;o[hba00?o0000ohUBROn9
DXT05?n9DXT00ol0003oL2eZog0]JP0Eog0]JP03o`000?mX7egoJ1mM01KoJ1mM00?o0000og0YI?m`
:F@05om`:F@01Ol0003ooooooooooooooooo000001Gooooo000;ooooo`03o`000?oooooooooo00So
oooo00?o0000odLjW_m7>Yh03om7>Yh00ol0003oIdjQofM>X@0@ofM>X@03o`000?nGM:WoUgBY01?o
UgBY00?o0000olBP]?o4X;@05Oo4X;@00ol0003ogl>momo3_@0Eomo3_@03o`000?oYfLCojMW401Go
jMW400?o0000onSRc?oXh/`04_oXh/`00ol0003ohMcAon7Ld@0Bon7Ld@03o`000?o@`Lcod<7<017o
d<7<00?o0000ojn</On_S;404_n_S;400ol0003oRE:9ohUBR@0DohUBR@03o`000?m`;F[oL2eZ01Go
L2eZ00?o0000ofPOGOmX7ed05_mX7ed00ol0003oL2UTog0YI00Gog0YI005o`000?oooooooooooooo
ool000005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oAcZNodLjWP0?odLjWP03
o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00EolBP]003
o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05OoYfL@00ol0003oj>;<onSRc00BonSRc003
o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@`L`04Oo@`L`00ol0003o[hbaojn</@0Bojn</@03
o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03
o`000?m`:FCoL2UT01SoL2UT00Co0000oooooooooooo00005Oooool000_ooooo00?o0000oooooooo
ool02?ooool00ol0003oAcZNodLjWP0?odLjWP03o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnG
M:T04onGM:T00ol0003oa:2dolBP]00EolBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oY
fL@05OoYfL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@
`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03o`000?n9DXWoRE:901?oRE:900?o0000og0]J_m`
;FX05_m`;FX00ol0003oJ1mMofPOG@0EofPOG@03o`000?m`:FCoL2UT01SoL2UT00Co0000oooooooo
oooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oAcZNodLjWP0?odLjWP03
o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00EolBP]003
o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05OoYfL@00ol0003oj>;<onSRc00BonSRc003
o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03
o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03
o`000?m`:FCoL2UT01OoL2UT00Co0000oooooooooooo00005Oooool000_ooooo00?o0000oooooooo
ool02?ooool00ol0003oAcZNodLjWP0?odLjWP03o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnG
M:T04onGM:T00ol0003oa:2dolBP]00EolBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oY
fL@05OoYfL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@
`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`
;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03o`000?m`:FCoL2UT01OoL2UT00Co0000oooooooo
oooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oAcZNodLjWP0?odLjWP03
o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00EolBP]003
o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05OoYfL@00ol0003oj>;<onSRc00BonSRc003
o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03
o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03
o`000?m`:FCoL2UT01OoL2UT00Co0000oooooooooooo00005Oooool000_ooooo00?o0000oooooooo
ool02?ooool00ol0003oAcZNodLjWP0?odLjWP03o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnG
M:T04onGM:T00ol0003oa:2dolBP]00EolBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oY
fL@05OoYfL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@
`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`
;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03o`000?m`:FCoL2UT01OoL2UT00Co0000oooooooo
oooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oAcZNodLjWP0?odLjWP03
o`000?mWCZ7oIdjQ013oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00EolBP]003
o`000?oO`kgogl>m01Kogl>m00?o0000onWIa?oYfL@05?oYfL@00ol0003oj>;<onSRc00BonSRc003
o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03
o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03
o`000?m`:FCoL2UT01OoL2UT00Co0000oooooooooooo00005Oooool000_ooooo00?o0000oooooooo
ool02?ooool00ol0003oAcZNodLjWP0>odLjWP03o`000?mWCZ7oIdjQ017oIdjQ00?o0000oiMdZOnG
M:T04onGM:T00ol0003oa:2dolBP]00EolBP]003o`000?oO`kgogl>m01Kogl>m00?o0000onWIa?oY
fL@05?oYfL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@
`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`
;FX05Om`;FX00ol0003oJ1mMofPOG@0GofPOG@03o`000?m`:FCoL2UT01KoL2UT00Co0000oooooooo
oooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003oAcZNodLjWP0>odLjWP03
o`000?mWCZ7oIdjQ017oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00FolBP]003
o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05?oYfL@00ol0003oj>;<onSRc00BonSRc003
o`000?oQg=7ohMcA01;ohMcA00?o0000om31c?o@`L`04Oo@`L`00ol0003o[hbaojn</@0Cojn</@03
o`000?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05_m`;FX00ol0003oJ1mMofPOG@0FofPOG@03
o`000?m`:FCoL2UT01OoL2UT00?o0000ooooool000005Oooool000_ooooo00?o0000ooooooooool0
2?ooool00ol0003oAcZNodLjWP0>odLjWP03o`000?mWCZ7oIdjQ017oIdjQ00?o0000oiMdZOnGM:T0
4onGM:T00ol0003oa:2dolBP]00FolBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@0
5?oYfL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA00gohMcA8?l0000?ojn</@03o`00
0?n9DXWoRE:901CoRE:900?o0000og0]J_m`;FX05_m`;FX00ol0003oJ1mMofPOG@0FofPOG@03o`00
0?m`:FCoL2UT01OoL2UT00?o0000ooooool000005Oooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oAcZNodLjWP0>odLjWP03o`000?mWCZ7oIdjQ017oIdjQ00?o0000oiMdZOnGM:T04onG
M:T00ol0003oa:2dolBP]00FolBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05?oY
fL@00ol0003oj>;<onSRc00BonSRc003o`000?oQg=7ohMcA00;ohMcA2ol00005omW<c@03o`000?ne
V;Wo]IRi017o]IRi00?o0000ohMGTOn7Ei401?n7Ei4;o`0000Co[hba00?o0000ohUBROn9DXT05On9
DXT00ol0003oL2eZog0]JP0Eog0]JP03o`000?mX7egoJ1mM01KoJ1mM00?o0000og0YI?m`:F@05om`
:F@00ol0003oooooo`00000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?m7>Yko
AcZN00koAcZN00?o0000ofM>XOmWCZ404OmWCZ400ol0003oUgBYoiMdZ@0CoiMdZ@03o`000?o4X;Co
a:2d01Koa:2d00?o0000omo3_OoO`kd05OoO`kd00ol0003ojMW4onWIa00DonWIa003o`000?oXh/co
j>;<00goj>;<2_l0000@omW<c@03o`000?neV;Wo]IRi017o]IRi00?o0000ohMGTOn7Ei403on7Ei4;
o`00017oRE:900?o0000og0]J_m`;FX05Om`;FX00ol0003oJ1mMofPOG@0FofPOG@03o`000?m`:FCo
L2UT01OoL2UT00?o0000ooooool000005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003oAcZNodLjWP0>odLjWP03o`000?mWCZ7oIdjQ017oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0
003oa:2dolBP]00FolBP]003o`000?oO`kgogl>m01Gogl>m00?o0000onWIa?oYfL@05?oYfL@00ol0
003oj>;<onSRc002onSRc0_o00001OoXh<X00ol0003ofLc=omW<c@0BomW<c@03o`000?neV;Wo]IRi
017o]IRi00?o0000ohMGTOn7Ei404on7Ei400ol0003oJRe`ofX]L004ofX]L0co00001On9DXT00ol0
003oL2eZog0]JP0Eog0]JP03o`000?mX7egoJ1mM01OoJ1mM00?o0000og0YI?m`:F@05_m`:F@00ol0
003oooooo`00000Eooooo`002oooool2o`0000Wooooo00?o0000odLjW_m7>Yh03_m7>Yh00ol0003o
IdjQofM>X@0AofM>X@03o`000?nGM:WoUgBY01?oUgBY00?o0000olBP]?o4X;@05_o4X;@00ol0003o
gl>momo3_@0Eomo3_@03o`000?oYfLCojMW4013ojMW42Ol0000@onSPbP03o`000?oIc<gofLc=01;o
fLc=00?o0000okFH^OneV;T04OneV;T00ol0003oQeNAohMGT@0CohMGT@03o`000?mZ;G3oJRe`013o
JRe`2_l0000Cog0]JP03o`000?mX7egoJ1mM01OoJ1mM00?o0000og0YI?m`:F@05_m`:F@00ol0003o
ooooo`00000Eooooo`002oooool00ol0003oooooooooo`08ooooo`Co00003Om7>Yh00ol0003oIdjQ
ofM>X@0AofM>X@03o`000?nGM:WoUgBY01?oUgBY00?o0000olBP]?o4X;@05_o4X;@00ol0003ogl>m
omo3_@0Eomo3_@03o`000?oYfLCojMW400SojMW42?l00004ongN`P03o`000?oXh<[oj>3:01;oj>3:
00?o0000omW<cOoIc<d04_oIc<d00ol0003o]IRiokFH^@0AokFH^@03o`000?n7Ei7oQeNA01?oQeNA
00?o0000ofX]L?mZ;G005OmZ;G000ol0003oHb1Sof<PH`02of<PH`Wo00002om`;FX00ol0003oJ1mM
ofPOG@0FofPOG@03o`000?m`:FCoL2UT01KoL2UT00?o0000ooooool000005Oooool000_ooooo00?o
0000ooooooooool02?ooool01?l0003o>c2Joc/`V_lk<9X6o`0000OoAcZN00?o0000ofM>XOmWCZ40
4OmWCZ400ol0003oUgBYoiMdZ@0CoiMdZ@03o`000?o4X;Coa:2d01Koa:2d00?o0000omo3_OoO`kd0
5OoO`kd01?l0003ojMW4onWIa?oYfL@7o`0000cokMk200?o0000onSPb_oXh<X04_oXh<X00ol0003o
fLc=omW<c@0BomW<c@03o`000?neV;Wo]IRi017o]IRi00?o0000ohMGTOn7Ei404on7Ei400ol0003o
JRe`ofX]L00EofX]L003o`000?mS86?oHb1S00_oHb1S2?l00003og0]JP03o`000?mX7egoJ1mM01Ko
J1mM00?o0000og0YI?m`:F@05_m`:F@00ol0003oooooo`00000Eooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?lk<9[o>c2J00Oo>c2J1Ol00002odLjWP03o`000?mWCZ7oIdjQ017oIdjQ
00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00FolBP]003o`000?oO`kgogl>m017ogl>m
2?l0000CongN`P03o`000?oXh<[oj>3:01;oj>3:00?o0000omW<cOoIc<d04_oIc<d00ol0003o]IRi
okFH^@0AokFH^@03o`000?n7Ei7oQeNA01?oQeNA00?o0000ofX]L?mZ;G005OmZ;G000ol0003oHb1S
of<PH`0Cof<PH`So00005?mX7ed00ol0003oL2UTog0YI00Fog0YI003o`000?oooooo000001Gooooo
000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oc/`V_lk<9X03?lk<9X6o`00013oIdjQ00?o
0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP]00FolBP]003o`000?oO`kgogl>m00Wogl>m2?l0
0004onS>_003o`000?o]g/;okMk201CokMk200?o0000onSPb_oXh<X04_oXh<X00ol0003ofLc=omW<
c@0BomW<c@03o`000?neV;Wo]IRi017o]IRi00?o0000ohMGTOn7Ei404on7Ei400ol0003oJRe`ofX]
L00EofX]L003o`000?mS86?oHb1S01KoHb1S00?o0000og0^K?m`;V`00_m`;V`9o`0000coJ1mM00?o
0000og0YI?m`:F@05_m`:F@2o`0001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
oc/`V_lk<9X03_lk<9X01?l0003oITfPofI=X?mVCJ07o`0000WoIdjQ00?o0000oiMdZOnGM:T04onG
M:T00ol0003oa:2dolBP]00FolBP]004o`000?oO`kgogl>momo3_@So00003?oXc[`00ol0003okMk2
ongN`P0DongN`P03o`000?oXh<[oj>3:01;oj>3:00?o0000omW<cOoIc<d04_oIc<d00ol0003o]IRi
okFH^@0AokFH^@03o`000?n7Ei7oQeNA01CoQeNA00?o0000ofX]L?mZ;G005OmZ;G000ol0003oHb1S
of<PH`0Eof<PH`03o`000?m`;VcoL2i/00_oL2i/2Ol00003ofPOG@03o`000?m`:FCoL2UT01KoL2UT
0_l0000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?lk<9[o>c2J00ko>c2J00?o
0000ofI=X?mVCJ002?mVCJ07o`0000;oIdjQ00?o0000oiMdZOnGM:T04onGM:T00ol0003oa:2dolBP
]00:olBP]13o00005?oXc[`00ol0003okMk2ongN`P0DongN`P03o`000?oXh<[oj>3:01;oj>3:00?o
0000omW<cOoIc<d04_oIc<d00ol0003o]IRiokFH^@0AokFH^@03o`000?n7Ei7oQeNA01CoQeNA00?o
0000ofX]L?mZ;G005OmZ;G000ol0003oHb1Sof<PH`0Eof<PH`03o`000?m`;VcoL2i/01CoL2i/4Ol0
000;og0YI0;o00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o>c2Joc/`VP0>
oc/`VP03o`000?mVCJ3oITfP00ooITfP9Ol0000<om6^]P03o`000?oXc[coj<jl01Goj<jl00?o0000
ongN`_o]g/805?o]g/800ol0003oj>3:onSPbP0BonSPbP03o`000?oIc<gofLc=01;ofLc=00?o0000
okFH^OneV;T04OneV;T00ol0003oQeNAohMGT@0DohMGT@03o`000?mZ;G3oJRe`01GoJRe`00?o0000
of<PHomS86<05OmS86<00ol0003oL2i/og0^K00Gog0^K003o`000?nBGi;oTUnB00_oTUnB3Ol0000E
ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?lk<9[o>c2J00ko>c2J00?o0000ofI=
X?mVCJ004OmVCJ000ol0003oXWj]oj9n[@0Coj9n[@03o`000?oA[[KodJjf01KodJjf00?o0000onS>
_?oXc[`05OoXc[`00ol0003okMk2ongN`P0DongN`P03o`000?oXh<[oj>3:01;oj>3:00?o0000omW<
cOoIc<d04_oIc<d00ol0003o]IRiokFH^@0BokFH^@03o`000?n7Ei7oQeNA01?oQeNA00?o0000ofX]
L?mZ;G005OmZ;G000ol0003oHb1Sof<PH`0Fof<PH`03o`000?m`;VcoL2i/01KoL2i/00?o0000oi9O
T_nBGi805_nBGi82o`0001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oc/`V_lk
<9X03_lk<9X00ol0003oITfPofI=X00AofI=X003o`000?nROZgoXWj]01?oXWj]00?o0000om6^]_oA
[[H05_oA[[H00ol0003oj<jlonS>_00EonS>_003o`000?o]g/;okMk201CokMk200?o0000onSPb_oX
h<X04_oXh<X00ol0003ofLc=omW<c@0BomW<c@03o`000?neV;Wo]IRi01;o]IRi00?o0000ohMGTOn7
Ei404on7Ei400ol0003oJRe`ofX]L00EofX]L003o`000?mS86?oHb1S01KoHb1S00?o0000og0^K?m`
;V`05_m`;V`00ol0003oTUnBoi9OTP0Foi9OTP;o00005Oooool000_ooooo00?o0000ooooooooool0
2?ooool00ol0003o>c2Joc/`VP0>oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd0
4onROZd00ol0003odJjfom6^]P0Fom6^]P03o`000?oXc[coj<jl01Goj<jl00?o0000ongN`_o]g/80
5?o]g/800ol0003oj>3:onSPbP0BonSPbP03o`000?oIc<gofLc=01;ofLc=00?o0000okFH^OneV;T0
4_neV;T00ol0003oQeNAohMGT@0CohMGT@03o`000?mZ;G3oJRe`01GoJRe`00?o0000of<PHomS86<0
5_mS86<00ol0003oL2i/og0^K00Fog0^K003o`000?nBGi;oTUnB01KoTUnB0_l0000Eooooo`002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?lk<9[o>c2J00ko>c2J00?o0000ofI=X?mVCJ004OmV
CJ000ol0003oXWj]oj9n[@0Coj9n[@03o`000?oA[[KodJjf01KodJjf00?o0000onS>_?oXc[`05OoX
c[`00ol0003okMk2ongN`P0DongN`P03o`000?oXh<[oj>3:01;oj>3:00?o0000omW<cOoIc<d04_oI
c<d00ol0003o]IRiokFH^@0BokFH^@03o`000?n7Ei7oQeNA01?oQeNA00?o0000ofX]L?mZ;G005OmZ
;G000ol0003oHb1Sof<PH`0Fof<PH`03o`000?m`;VcoL2i/01KoL2i/00?o0000oi9OT_nBGi805_nB
Gi82o`0001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oc/`V_lk<9X03_lk<9X0
0ol0003oITfPofI=X00AofI=X003o`000?nROZgoXWj]01?oXWj]00?o0000om6^]_oA[[H05_oA[[H0
0ol0003oj<jlonS>_00EonS>_003o`000?o]g/;okMk201CokMk200?o0000onSPb_oXh<X04_oXh<X0
0ol0003ofLc=omW<c@0BomW<c@03o`000?neV;Wo]IRi01;o]IRi00?o0000ohMGTOn7Ei404on7Ei40
0ol0003oJRe`ofX]L00EofX]L003o`000?mS86?oHb1S01KoHb1S00?o0000og0^K?m`;V`05_m`;V`0
0ol0003oTUnBoi9OTP0Foi9OTP;o00005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003o>c2Joc/`VP0>oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd04onROZd00ol0
003odJjfom6^]P0Fom6^]P03o`000?oXc[coj<jl01Goj<jl00?o0000ongN`_o]g/805?o]g/800ol0
003oj>3:onSPbP0BonSPbP03o`000?oIc<gofLc=01;ofLc=00?o0000okFH^OneV;T04_neV;T00ol0
003oQeNAohMGT@0CohMGT@03o`000?mZ;G3oJRe`01GoJRe`00?o0000of<PHomS86<05_mS86<00ol0
003oL2i/og0^K00Gog0^K003o`000?nBGi;oTUnB01CoTUnB00?o0000ooooool000005Oooool000_o
oooo00?o0000ooooooooool02?ooool00ol0003o>c2Joc/`VP0>oc/`VP03o`000?mVCJ3oITfP017o
ITfP00?o0000oj9n[OnROZd04onROZd00ol0003odJjfom6^]P0Fom6^]P03o`000?oXc[coj<jl01Ko
j<jl00?o0000ongN`_o]g/804oo]g/800ol0003oj>3:onSPbP0BonSPbP03o`000?oIc<gofLc=01;o
fLc=00?o0000okFH^OneV;T04_neV;T00ol0003oQeNAohMGT@0CohMGT@03o`000?mZ;G3oJRe`01Ko
JRe`00?o0000of<PHomS86<05OmS86<00ol0003oL2i/og0^K00Gog0^K003o`000?nBGi;oTUnB01Co
TUnB00?o0000ooooool000005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o>c2J
oc/`VP0>oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd04onROZd00ol0003odJjf
om6^]P0Fom6^]P03o`000?oXc[coj<jl01Koj<jl00?o0000ongN`_o]g/804oo]g/800ol0003oj>3:
onSPbP0BonSPbP03o`000?oIc<gofLc=01;ofLc=00?o0000okFH^OneV;T04_neV;T00ol0003oQeNA
ohMGT@0CohMGT@03o`000?mZ;G3oJRe`01KoJRe`00?o0000of<PHomS86<05OmS86<00ol0003oL2i/
og0^K00Gog0^K003o`000?nBGi;oTUnB01CoTUnB00?o0000ooooool000005Oooool000_ooooo00?o
0000ooooooooool02?ooool00ol0003o>c2Joc/`VP0>oc/`VP03o`000?mVCJ3oITfP017oITfP00?o
0000oj9n[OnROZd04onROZd00ol0003odJjfom6^]P0Fom6^]P03o`000?oXc[coj<jl01Koj<jl00?o
0000ongN`_o]g/804oo]g/800ol0003oj>3:onSPbP0BonSPbP03o`000?oIc<gofLc=01;ofLc=00?o
0000okFH^OneV;T04_neV;T00ol0003oQeNAohMGT@0DohMGT@03o`000?mZ;G3oJRe`01GoJRe`00?o
0000of<PHomS86<05OmS86<00ol0003oL2i/og0^K00Gog0^K003o`000?nBGi;oTUnB01CoTUnB00?o
0000ooooool000005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o>c2Joc/`VP0>
oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd04onROZd00ol0003odJjfom6^]P0F
om6^]P03o`000?oXc[coj<jl01Koj<jl00?o0000ongN`_o]g/804oo]g/800ol0003oj>3:onSPbP0?
onSPbRCo00002OneV;T00ol0003oQeNAohMGT@0DohMGT@03o`000?mZ;G3oJRe`01GoJRe`00?o0000
of<PHomS86<05_mS86<00ol0003oL2i/og0^K00Fog0^K003o`000?nBGi;oTUnB01CoTUnB00?o0000
ooooool000005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o>c2Joc/`VP0>oc/`
VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd04onROZd00ol0003odJjfom6^]P0Fom6^
]P03o`000?oXc[coj<jl01Koj<jl00?o0000ongN`_o]g/804oo]g/800ol0003oj>3:onSPbP08onSP
bPOo00000ooTf<T00ol0003oa:g4olB]a00BolB]a003o`000?n>IIkoSVFN00WoSVFN3_l0000BohMG
T@03o`000?mZ;G3oJRe`01GoJRe`00?o0000of<PHomS86<05_mS86<00ol0003oL2i/og0^K00Fog0^
K003o`000?nBGi;oTUnB01CoTUnB00?o0000ooooool000005Oooool000_ooooo00?o0000oooooooo
ool02?ooool00ol0003o>c2Joc/`VP0>oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnR
OZd05?nROZd00ol0003odJjfom6^]P0Eom6^]P03o`000?oXc[coj<jl01Koj<jl00?o0000ongN`_o]
g/804oo]g/801?l0003oj>3:onSPb_oXh<X7o`0000[oi=S900?o0000olB]a?o4[L@04_o4[L@00ol0
003oSVFNohiUWP0BohiUWP03o`000?mW<GWoIc5i00;oIc5i2?l0000:ohMGT@03o`000?mZ;G3oJRe`
01GoJRe`00?o0000of<PHomS86<05_mS86<00ol0003oL2i/og0^K00Fog0^K003o`000?nBGi;oTUnB
01CoTUnB00?o0000ooooool000005Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
>c2Joc/`VP0>oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd05?nROZd00ol0003o
dJjfom6^]P0Eom6^]P03o`000?oXc[coj<jl01Koj<jl00?o0000ongN`_o]g/804?o]g/87o`00017o
i=S900?o0000olB]a?o4[L@04_o4[L@00ol0003oSVFNohiUWP0BohiUWP03o`000?mW<GWoIc5i00[o
Ic5i1ol00003ohMGT@03o`000?mZ;G3oJRe`01GoJRe`00?o0000of<PHomS86<05_mS86<00ol0003o
L2i/og0^K00Fog0^K003o`000?nBGi;oTUnB01CoTUnB00?o0000ooooool000005Oooool000_ooooo
0_l00009ooooo`03o`000?lk<9[o>c2J00ko>c2J00?o0000ofI=X?mVCJ004OmVCJ000ol0003oXWj]
oj9n[@0Doj9n[@03o`000?oA[[KodJjf01GodJjf00?o0000onS>_?oXc[`05_oXc[`00ol0003okMk2
ongN`P0;ongN`PGo00000oo_hL000ol0003oi=S9onCHb@0BonCHb@03o`000?o4[LCoa:g401;oa:g4
00?o0000ohiUW_n>IIh04_n>IIh00ol0003oIc5iofLaN@0AofLaN@Oo00005?mZ;G000ol0003oHb1S
of<PH`0Fof<PH`03o`000?m`;VcoL2i/01KoL2i/00?o0000oi9OT_nBGi805?nBGi800ol0003ooooo
o`00000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?lk<9[o>c2J00ko>c2J00?o
0000ofI=X?mVCJ004OmVCJ000ol0003oXWj]oj9n[@0Doj9n[@03o`000?oA[[KodJjf01GodJjf00?o
0000onS>_?oXc[`05_oXc[`00ol0003okMk2ongN`P05ongN`PKo00002?o_hL000ol0003oi=S9onCH
b@0BonCHb@03o`000?o4[LCoa:g401;oa:g400?o0000ohiUW_n>IIh04_n>IIh00ol0003oIc5iofLa
N@0DofLaN@04o`000?mM7fSoGAmXoedOJ0Go00003omZ;G000ol0003oHb1Sof<PH`0Fof<PH`03o`00
0?m`;VcoL2i/01KoL2i/00?o0000oi9OT_nBGi805?nBGi800ol0003oooooo`00000Eooooo`002ooo
ool00ol0003oooooooooo`08ooooo`?o00003_lk<9X00ol0003oITfPofI=X00AofI=X003o`000?nR
OZgoXWj]01CoXWj]00?o0000om6^]_oA[[H05OoA[[H00ol0003oj<jlonS>_00FonS>_003o`000?o]
g/;okMk200Go00003_o_hL000ol0003oi=S9onCHb@0BonCHb@03o`000?o4[LCoa:g401;oa:g400?o
0000ohiUW_n>IIh04_n>IIh00ol0003oIc5iofLaN@0DofLaN@03o`000?mM7fSoGAmX00KoGAmX1Ol0
000;ofX]L003o`000?mS86?oHb1S01GoHb1S00?o0000og0^K?m`;V`05_m`;V`00ol0003oTUnBoi9O
TP0Doi9OTP03o`000?oooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000
oc0WUOl`9iD01?l0000:oc/`VP03o`000?mVCJ3oITfP017oITfP00?o0000oj9n[OnROZd05?nROZd0
0ol0003odJjfom6^]P0Eom6^]P03o`000?oXc[coj<jl01?oj<jl1_l0000ConoQ`003o`000?oTf<Wo
i=S901;oi=S900?o0000olB]a?o4[L@04_o4[L@00ol0003oSVFNohiUWP0BohiUWP03o`000?mW<GWo
Ic5i01CoIc5i00?o0000oedOJ?mM7fP02omM7fP5o`0000KoJRe`00?o0000of<PHomS86<05OmS86<0
0ol0003oL2i/og0^K00Fog0^K003o`000?nBGi;oTUnB01?oTUnB00Co0000oooooooooooo00005Ooo
ool000_ooooo00?o0000ooooooooool02?ooool00ol0003o<2NEoc0WU@04oc0WU@Go00001Olk<9X0
0ol0003oITfPofI=X00AofI=X003o`000?nROZgoXWj]01CoXWj]00?o0000om6^]_oA[[H05OoA[[H0
0ol0003oj<jlonS>_00=onS>_0Ko00000oo_e[T00ol0003okn70onoQ`00ConoQ`003o`000?oTf<Wo
i=S901;oi=S900?o0000olB]a?o4[L@04_o4[L@00ol0003oSVFNohiUWP0BohiUWP03o`000?mW<GWo
Ic5i01CoIc5i00?o0000oedOJ?mM7fP04?mM7fP5o`000003ofX]L?l0003oHb1S01KoHb1S00?o0000
og0^K?m`;V`05om`;V`00ol0003oTUnBoi9OTP0Boi9OTP04o`000?ooooooooooo`0001Gooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000oc0WUOl`9iD02Ol`9iD4o`000003oc/`V_l0003o
ITfP01;oITfP00?o0000oj9n[OnROZd05?nROZd00ol0003odJjfom6^]P0Eom6^]P03o`000?oXc[co
j<jl00Koj<jl1ol00009onoF^@03o`000?o_hL3okn7001?okn7000?o0000onCHbOoTf<T04_oTf<T0
0ol0003oa:g4olB]a00BolB]a003o`000?n>IIkoSVFN01;oSVFN00?o0000ofLaNOmW<GT05?mW<GT0
0ol0003oGAmXoedOJ00EoedOJ0Ko00005?mS86<00ol0003oL2i/og0^K00Fog0^K003o`000?nBGi;o
TUnB01;oTUnB00Co0000oooooooooooo00005Oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o<2NEoc0WU@0=oc0WU@Go00004?mVCJ000ol0003oXWj]oj9n[@0Doj9n[@03o`000?oA[[Ko
dJjf01GodJjf00?o0000onS>_?oXc[`01_l0000@onoF^@03o`000?o_hL3okn7001?okn7000?o0000
onCHbOoTf<T04_oTf<T00ol0003oa:g4olB]a00BolB]a003o`000?n>IIkoSVFN01;oSVFN00?o0000
ofLaNOmW<GT05?mW<GT00ol0003oGAmXoedOJ00FoedOJ003o`000?m/;W3oK2i`00;oK2i`2Ol0000;
of<PH`03o`000?m`;VcoL2i/01KoL2i/00?o0000oi9OT_nBGi804_nBGi801?l0003oooooooooool0
000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?l`9iGo<2NE00ko<2NE00Co0000
ofI=XOmVCJ7oITfQ1ol00009ofI=X003o`000?nROZgoXWj]01CoXWj]00?o0000om6^]_oA[[H03ooA
[[H9o`0001KokmJi00?o0000onoQ`?o_hL004oo_hL000ol0003oi=S9onCHb@0BonCHb@03o`000?o4
[LCoa:g401;oa:g400?o0000ohiUW_n>IIh04_n>IIh00ol0003oIc5iofLaN@0EofLaN@03o`000?mM
7fSoGAmX01GoGAmX00?o0000of`^L?m/;W002om/;W08o`0000?oHb1S00?o0000og0^K?m`;V`05_m`
;V`00ol0003oTUnBoi9OTP0Boi9OTP04o`000?ooooooooooo`0001Gooooo000;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000oc0WUOl`9iD03_l`9iD00ol0003oITfQofI=X@08ofI=X@Oo00000_mV
CJ000ol0003oXWj]oj9n[@0Doj9n[@03o`000?oA[[KodJjf00?odJjf3?l00006omjk]@03o`000?o_
e[WokmJi01KokmJi00?o0000onoQ`?o_hL004oo_hL000ol0003oi=S9onCHb@0BonCHb@03o`000?o4
[LCoa:g401;oa:g400?o0000ohiUW_n>IIh04_n>IIh00ol0003oIc5iofLaN@0EofLaN@03o`000?mM
7fSoGAmX01GoGAmX00?o0000of`^L?m/;W004om/;W0Ao`0000_oL2i/00?o0000oi9OT_nBGi802?nB
Gi8;o`0000;ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o<2NEoc0WU@0>oc0WU@03o`000?mVCJ7oITfQ00ooITfQ7ol0000Bomjk]@03o`000?o_e[Wo
kmJi01KokmJi00?o0000onoQ`?o_hL005?o_hL000ol0003oi=S9onCHb@0AonCHb@03o`000?o4[LCo
a:g401;oa:g400?o0000ohiUW_n>IIh04_n>IIh00ol0003oIc5iofLaN@0EofLaN@03o`000?mM7fSo
GAmX01GoGAmX00?o0000of`^L?m/;W005_m/;W000ol0003oUVFFoiIUUP0;oiIUUQKo00002_o?bMD0
1?l0003oooooooooool0000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?l`9iGo
<2NE00ko<2NE00?o0000ofI=XOmVCJ404OmVCJ400ol0003o[XZ_ojj:[`0Dojj:[`03o`000?oN^kGo
g[^e01Gog[^e00?o0000onoF^Oo_e[T05_o_e[T00ol0003okn70onoQ`00DonoQ`003o`000?oTf<Wo
i=S9017oi=S900?o0000olB]a?o4[L@04_o4[L@00ol0003oSVFNohiUWP0CohiUWP03o`000?mW<GWo
Ic5i01CoIc5i00?o0000oedOJ?mM7fP05OmM7fP00ol0003oK2i`of`^L00Fof`^L003o`000?nFIIKo
UVFF01KoUVFF00?o0000olo9eOo?bMD04Oo?bMD01Ol0003ooooooooooooooooo000001Gooooo000;
ooooo`03o`000?oooooooooo00Sooooo00?o0000oc0WUOl`9iD03_l`9iD00ol0003oITfQofI=X@0A
ofI=X@03o`000?n^RZoo[XZ_01Co[XZ_00?o0000omjk]OoN^kD05OoN^kD00ol0003okmJionoF^@0F
onoF^@03o`000?o_hL3okn7001Cokn7000?o0000onCHbOoTf<T04OoTf<T00ol0003oa:g4olB]a00B
olB]a003o`000?n>IIkoSVFN01?oSVFN00?o0000ofLaNOmW<GT05?mW<GT00ol0003oGAmXoedOJ00E
oedOJ003o`000?m/;W3oK2i`01KoK2i`00?o0000oiIUU_nFIIH05_nFIIH00ol0003oclWEolo9e@0A
olo9e@05o`000?ooooooooooooooool000005Oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o<2NEoc0WU@0>oc0WU@03o`000?mVCJ7oITfQ017oITfQ00?o0000ojj:[on^RZl05?n^RZl0
0ol0003og[^eomjk]@0Eomjk]@03o`000?o_e[WokmJi01KokmJi00?o0000onoQ`?o_hL005?o_hL00
0ol0003oi=S9onCHb@0AonCHb@03o`000?o4[LCoa:g401;oa:g400?o0000ohiUW_n>IIh04on>IIh0
0ol0003oIc5iofLaN@0DofLaN@03o`000?mM7fSoGAmX01KoGAmX00?o0000of`^L?m/;W005Om/;W00
0ol0003oUVFFoiIUUP0FoiIUUP03o`000?o?bMGoclWE017oclWE00Go0000ooooooooooooooooo`00
000Eooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?l`9iGo<2NE00ko<2NE00?o0000
ofI=XOmVCJ404OmVCJ400ol0003o[XZ_ojj:[`0Dojj:[`03o`000?oN^kGog[^e01Gog[^e00?o0000
onoF^Oo_e[T05_o_e[T00ol0003okn70onoQ`00DonoQ`003o`000?oTf<Woi=S9017oi=S900?o0000
olB]a?o4[L@04_o4[L@00ol0003oSVFNohiUWP0CohiUWP03o`000?mW<GWoIc5i01CoIc5i00?o0000
oedOJ?mM7fP05_mM7fP00ol0003oK2i`of`^L00Eof`^L003o`000?nFIIKoUVFF01KoUVFF00?o0000
olo9eOo?bMD04?o?bMD00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo000;oooo
o`03o`000?oooooooooo00Sooooo00?o0000oc0WUOl`9iD03_l`9iD00ol0003oITfQofI=X@0AofI=
X@03o`000?n^RZoo[XZ_01Co[XZ_00?o0000omjk]OoN^kD05OoN^kD00ol0003okmJionoF^@0FonoF
^@03o`000?o_hL3okn7001Cokn7000?o0000onCHbOoTf<T04OoTf<T00ol0003oa:g4olB]a00BolB]
a003o`000?n>IIkoSVFN01?oSVFN00?o0000ofLaNOmW<GT05?mW<GT00ol0003oGAmXoedOJ00FoedO
J003o`000?m/;W3oK2i`01GoK2i`00?o0000oiIUU_nFIIH05_nFIIH00ol0003oclWEolo9e@0@olo9
e@03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool000_ooooo00?o0000oooooooo
ool02?ooool00ol0003o<2NEoc0WU@0>oc0WU@03o`000?mVCJ7oITfQ017oITfQ00?o0000ojj:[on^
RZl05?n^RZl00ol0003og[^eomjk]@0Eomjk]@03o`000?o_e[WokmJi01KokmJi00?o0000onoQ`?o_
hL005?o_hL000ol0003oi=S9onCHb@0AonCHb@03o`000?o4[LCoa:g401;oa:g400?o0000ohiUW_n>
IIh04on>IIh00ol0003oIc5iofLaN@0DofLaN@03o`000?mM7fSoGAmX01KoGAmX00?o0000of`^L?m/
;W005_m/;W000ol0003oUVFFoiIUUP0DoiIUUP03o`000?o?bMGoclWE017oclWE00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`00
0?l`9iGo<2NE00ko<2NE00?o0000ofI=XOmVCJ404OmVCJ400ol0003o[XZ_ojj:[`0Dojj:[`03o`00
0?oN^kGog[^e01Gog[^e00?o0000onoF^Oo_e[T05_o_e[T00ol0003okn70onoQ`00DonoQ`003o`00
0?oTf<Woi=S900coi=S94Ol00009olB]a003o`000?n>IIkoSVFN01?oSVFN00?o0000ofLaNOmW<GT0
5?mW<GT00ol0003oGAmXoedOJ00FoedOJ003o`000?m/;W3oK2i`01KoK2i`00?o0000oiIUU_nFIIH0
5?nFIIH00ol0003oclWEolo9e@0@olo9e@03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o<2NEoc0WU@0>oc0WU@03o`000?mV
CJ7oITfQ017oITfQ00?o0000ojj:[on^RZl05?n^RZl00ol0003og[^eomjk]@0Eomjk]@03o`000?o_
e[WokmJi01KokmJi00?o0000onoQ`?o_hL005?o_hL000ol0003oi=S9onCHb@02onCHb@[o00001OoI
b<P00ol0003oXH6aoj61/@09oj61/@go00004_n>IIh00ol0003oIc5iofLaN@0DofLaN@03o`000?mM
7fSoGAmX01KoGAmX00?o0000of`^L?m/;W005_m/;W000ol0003oUVFFoiIUUP0DoiIUUP03o`000?o?
bMGoclWE013oclWE00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`002oooool0
0ol0003oooooooooo`08ooooo`03o`000?l`9iGo<2NE00ko<2NE00?o0000ofI=XOmVCJ404OmVCJ40
0ol0003o[XZ_ojj:[`0Dojj:[`03o`000?oN^kGog[^e01Kog[^e00?o0000onoF^Oo_e[T05Oo_e[T0
0ol0003okn70onoQ`00BonoQ`0Oo00003ooIb<P00ol0003oXH6aoj61/@0Boj61/@04o`000?mZ>hGo
JS^5ofXkQ@Go00003On>IIh00ol0003oIc5iofLaN@0DofLaN@03o`000?mM7fSoGAmX01KoGAmX00?o
0000of`^L?m/;W005_m/;W000ol0003oUVFFoiIUUP0DoiIUUP03o`000?o?bMGoclWE013oclWE00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08
ooooo`03o`000?l`9iGo<2NE00ko<2NE00?o0000ofI=XOmVCJ404OmVCJ400ol0003o[XZ_ojj:[`0D
ojj:[`03o`000?oN^kGog[^e01Kog[^e00?o0000onoF^Oo_e[T05Oo_e[T00ol0003okn70onoQ`00=
onoQ`0Go00000_o_gl000ol0003ofLS8omW8b00AomW8b003o`000?nQPK7oXH6a01;oXH6a00?o0000
ofXkQOmZ>hD01_mZ>hD6o`0000OoSVFN00?o0000ofLaNOmW<GT05?mW<GT00ol0003oGAmXoedOJ00F
oedOJ003o`000?m/;W3oK2i`01KoK2i`00?o0000oiIUU_nFIIH05?nFIIH00ol0003oclWEolo9e@0?
olo9e@03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool000_ooooo00?o0000oooo
ooooool02?ooool00ol0003o<2NEoc0WU@0>oc0WU@03o`000?mVCJ7oITfQ017oITfQ00?o0000ojj:
[on^RZl05?n^RZl00ol0003og[^eomjk]@0Fomjk]@03o`000?o_e[WokmJi01GokmJi00?o0000onoQ
`?o_hL002?o_hL05o`0000Ookmo000?o0000omW8b?oIb<P04OoIb<P00ol0003oXH6aoj61/@0Boj61
/@03o`000?mZ>hGoJS^500coJS^51Ol00002ohiUWP03o`000?mW<GWoIc5i01GoIc5i00?o0000oedO
J?mM7fP05OmM7fP00ol0003oK2i`of`^L00Fof`^L003o`000?nFIIKoUVFF01CoUVFF00?o0000olo9
eOo?bMD03oo?bMD00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo000;ooooo`;o
00002Oooool00ol0003o<2NEoc0WU@0>oc0WU@03o`000?mVCJ7oITfQ013oITfQ00?o0000ojj:[on^
RZl05On^RZl00ol0003og[^eomjk]@0Fomjk]@03o`000?o_e[WokmJi01GokmJi00?o0000onoQ`?o_
hL001?o_hL04o`0000cokmo000?o0000omW8b?oIb<P04OoIb<P00ol0003oXH6aoj61/@0Boj61/@03
o`000?mZ>hGoJS^5017oJS^51Ol0000EofLaN@03o`000?mM7fSoGAmX01GoGAmX00?o0000of`^L?m/
;W005_m/;W000ol0003oUVFFoiIUUP0DoiIUUP03o`000?o?bMGoclWE00ooclWE00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`00
0?l`9iGo<2NE00ko<2NE00?o0000ofI=XOmVCJ404?mVCJ400ol0003o[XZ_ojj:[`0Eojj:[`03o`00
0?oN^kGog[^e01Kog[^e00?o0000onoF^Oo_e[T05Oo_e[T00ol0003okn70o`000004o`00013okmo0
00?o0000omW8b?oIb<P04OoIb<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^5
00?o0000oeLOKOmG7fd01Ol0000@ofLaN@03o`000?mM7fSoGAmX01GoGAmX00?o0000of`^L?m/;W00
5_m/;W000ol0003oUVFFoiIUUP0DoiIUUP03o`000?o?bMGoclWE00koclWE00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?l`
9iGo<2NE00ko<2NE00?o0000ofI=XOmVCJ404?mVCJ400ol0003o[XZ_ojj:[`0Eojj:[`03o`000?oN
^kGog[^e01Kog[^e00?o0000onoF^Oo_e[T04oo_e[T4o`0001Gokmo000?o0000omW8b?oIb<P04OoI
b<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^500?o0000oeLOKOmG7fd01OmG
7fd5o`0000_oIc5i00?o0000oedOJ?mM7fP05OmM7fP00ol0003oK2i`of`^L00Fof`^L003o`000?nF
IIKoUVFF01CoUVFF00?o0000olo9eOo?bMD03_o?bMD00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo0ol0000>oc0WU@03o`000?mVCJ7o
ITfQ013oITfQ00?o0000ojj:[on^RZl05On^RZl00ol0003og[^eomjk]@0Fomjk]@03o`000?o_e[Wo
kmJi00kokmJi1Ol00002oo?K]P03o`000?o_gl3okmo001Cokmo000?o0000omW8b?oIb<P04OoIb<P0
0ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^500?o0000oeLOKOmG7fd02_mG7fd5
o`0000KoIc5i00?o0000oedOJ?mM7fP05OmM7fP00ol0003oK2i`of`^L00Fof`^L003o`000?nFIIKo
UVFF01CoUVFF00?o0000olo9eOo?bMD03_o?bMD00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT7Y400ol0000;oc0W
U@03o`000?mVCJ7oITfQ013oITfQ00?o0000ojj:[on^RZl05On^RZl00ol0003og[^eomjk]@0Fomjk
]@03o`000?o_e[WokmJi00WokmJi1Ol00007oo?K]P03o`000?o_gl3okmo001Cokmo000?o0000omW8
b?oIb<P04OoIb<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^500?o0000oeLO
KOmG7fd03omG7fd5o`000003ofLaNOl0003oGAmX01OoGAmX00?o0000of`^L?m/;W005Om/;W000ol0
003oUVFFoiIUUP0DoiIUUP03o`000?o?bMGoclWE00goclWE00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?lT7Y7o91jA00?o
91jA1?l00007oc0WU@03o`000?mVCJ7oITfQ013oITfQ00?o0000ojj:[on^RZl05On^RZl00ol0003o
g[^eomjk]@0Fomjk]@03o`000?o_e[WokmJi00CokmJi1Ol0000<oo?K]P03o`000?o_gl3okmo001Co
kmo000?o0000omW8b?oIb<P04OoIb<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?o
JS^500?o0000oeLOKOmG7fd05?mG7fd5o`0001GoGAmX00?o0000of`^L?m/;W005Om/;W000ol0003o
UVFFoiIUUP0CoiIUUP03o`000?o?bMGoclWE00coclWE0ol00008ooooo`03o`000?oooooooooo01?o
oooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT7Y401olT7Y43o`0000Co<2NE
00?o0000ofI=XOmVCJ404?mVCJ400ol0003o[XZ_ojj:[`0Eojj:[`03o`000?oN^kGog[^e01Kog[^e
00?o0000onoF^Ol000001?l0000Aoo?K]P03o`000?o_gl3okmo001Cokmo000?o0000omW8b?oIb<P0
4OoIb<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^500?o0000oeLOKOmG7fd0
5OmG7fd01?l0003oI2U`of@YL?mT:G05o`00013oGAmX00?o0000of`^L?m/;W005Om/;W000ol0003o
UVFFoiIUUP0CoiIUUP03o`000?o?bMGoclWE00WoclWE0ol00002omCoe003o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o91jA
ob@NT@0:ob@NT@?o000000?o<2NEo`000?mVCJ404OmVCJ400ol0003o[XZ_ojj:[`0Eojj:[`03o`00
0?oN^kGog[^e01?og[^e1Ol0000Foo?K]P03o`000?o_gl3okmo001Cokmo000?o0000omW8b?oIb<P0
4OoIb<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^500?o0000oeLOKOmG7fd0
5OmG7fd00ol0003oI2U`of@YL006of@YL0Go00002omM7fP00ol0003oK2i`of`^L00Fof`^L003o`00
0?nFIIKoUVFF01;oUVFF00?o0000olo9eOo?bMD01Oo?bMD4o`0000Coe?oD00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?lT
7Y7o91jA00go91jA1Ol0000?ofI=X@03o`000?n^RZoo[XZ_01Go[XZ_00?o0000omjk]OoN^kD03OoN
^kD6o`0000?oj<Fc00?o0000oo?K]_ocfkH05OocfkH00ol0003okmo0onoO`00DonoO`003o`000?oI
b<SofLS8017ofLS800?o0000oj61/OnQPK404_nQPK400ol0003oJS^5ofXkQ@0CofXkQ@03o`000?mG
7fgoEam]01GoEam]00?o0000of@YL?mT:G002omT:G05o`0000KoGAmX00?o0000of`^L?m/;W005_m/
;W000ol0003oUVFFoiIUUP0BoiIUUP03o`000?o?bMGoclWE00;oclWE0ol00008omCoe003o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003o91jAob@NT@0>ob@NT@04o`000?mXCj;oJ4nRofQ?XPOo00002?mVCJ400ol0003o[XZ_ojj:
[`0Eojj:[`03o`000?oN^kGog[^e00Kog[^e1ol00009onS5/`03o`000?ocfkKolm^f01Golm^f00?o
0000onoO`?o_gl005?o_gl000ol0003ofLS8omW8b00AomW8b003o`000?nQPK7oXH6a01;oXH6a00?o
0000ofXkQOmZ>hD04omZ>hD00ol0003oEam]oeLOK@0EoeLOK@03o`000?mT:G3oI2U`013oI2U`1Ol0
00000omM7fSo0000of`^L00Gof`^L003o`000?nFIIKoUVFF01;oUVFF00?o0000olo9eOl000000_l0
000;omCoe003o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool000_ooooo00?o0000
ooooooooool02?ooool00ol0003o91jAob@NT@0>ob@NT@03o`000?mXCj;oJ4nR00SoJ4nR1_l00002
ofI=X@03o`000?n^RZoo[XZ_01Go[XZ_00?o0000omjk]OoN^kD01_l0000@onS5/`03o`000?ocfkKo
lm^f01Golm^f00?o0000onoO`?o_gl005?o_gl000ol0003ofLS8omW8b00AomW8b003o`000?nQPK7o
XH6a01;oXH6a00?o0000ofXkQOmZ>hD04omZ>hD00ol0003oEam]oeLOK@0EoeLOK@03o`000?mT:G3o
I2U`01GoI2U`2?l0000Bof`^L003o`000?nFIIKoUVFF00goUVFF1ol0000=omCoe003o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04oooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003o91jAob@NT@0>ob@NT@03o`000?mXCj;oJ4nR00koJ4nR7Ol0000FonS5/`03o`000?ocfkKolm^f
01Golm^f00?o0000onoO`?o_gl005?o_gl000ol0003ofLS8omW8b00AomW8b003o`000?nQPK7oXH6a
01;oXH6a00?o0000ofXkQOmZ>hD04omZ>hD00ol0003oEam]oeLOK@0EoeLOK@03o`000?mT:G3oI2U`
01KoI2U`00?o0000oi9OT_nBGi801?nBGi8=o`0000GoK2i`00?o0000oiIUU_nFIIH00_nFIIH;o`00
00GoeLW?00?o0000omCoe?oDom@03?oDom@00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01?ooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT7Y403_lT7Y400ol0003o
J4nRofQ?XP0@ofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<05_oXaK<00ol0003o
lm^foo?K]P0Foo?K]P03o`000?o_gl3okmo001?okmo000?o0000omW8b?oIb<P04OoIb<P00ol0003o
XH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501?oJS^500?o0000oeLOKOmG7fd05OmG7fd00ol0003o
I2U`of@YL00Fof@YL003o`000?nBGi;oTUnB017oTUnB2_l0000@omG9c`03o`000?oDomCoe?oD00co
e?oD00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?lT7Y7o91jA00ko91jA00?o0000ofQ?X_mXCj804?mXCj800ol0003o^iJa
ok^F/@0Eok^F/@03o`000?oXaK?oj<Fc01Koj<Fc00?o0000oo?K]_ocfkH05_ocfkH00ol0003okmo0
onoO`00ConoO`003o`000?oIb<SofLS8017ofLS800?o0000oj61/OnQPK404_nQPK400ol0003oJS^5
ofXkQ@0DofXkQ@03o`000?mG7fgoEam]01GoEam]00?o0000of@YL?mT:G005OmT:G000ol0003oTUnB
oi9OTP0Foi9OTP03o`000?oEbLooeLW?017oeLW?00?o0000omCoe?oDom@03?oDom@00ol0003ooooo
ooooo`03ooooo`Co000000?o410@ooooool000005Oooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003o91jAob@NT@0>ob@NT@03o`000?mXCj;oJ4nR013oJ4nR00?o0000ok^F/OnkU[405Onk
U[400ol0003oj<FconS5/`0FonS5/`03o`000?ocfkKolm^f01Kolm^f00?o0000onoO`?o_gl004oo_
gl000ol0003ofLS8omW8b00AomW8b003o`000?nQPK7oXH6a01;oXH6a00?o0000ofXkQOmZ>hD05?mZ
>hD00ol0003oEam]oeLOK@0EoeLOK@03o`000?mT:G3oI2U`01GoI2U`00?o0000oi9OT_nBGi805_nB
Gi800ol0003oeLW?omG9c`0AomG9c`03o`000?oDomCoe?oD00coe?oD00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ob@NTOlT7Y403_lT7Y400ol0003oJ4nRofQ?XP0@ofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o
0000onS5/ooXaK<05_oXaK<00ol0003olm^foo?K]P0Foo?K]P03o`000?o_gl3okmo001?okmo000?o
0000omW8b?oIb<P04OoIb<P00ol0003oXH6aoj61/@0Boj61/@03o`000?mZ>hGoJS^501CoJS^500?o
0000oeLOKOmG7fd05OmG7fd00ol0003oI2U`of@YL00Eof@YL003o`000?nBGi;oTUnB01KoTUnB00?o
0000omG9cooEbLl04OoEbLl00ol0003oe?oDomCoe00;omCoe0Co00001Oooool01Ol0003ooooooooo
oooooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT7Y403_lT
7Y400ol0003oJ4nRofQ?XP0@ofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<05_oX
aK<00ol0003olm^foo?K]P0Foo?K]P03o`000?o_gl3okmo0017okmo06ol0000@oj61/@03o`000?mZ
>hGoJS^501CoJS^500?o0000oeLOKOmG7fd05OmG7fd00ol0003oI2U`of@YL00Eof@YL003o`000?nB
Gi;oTUnB01KoTUnB00?o0000omG9cooEbLl04?oEbLl00ol0003oe?oDomCoe00<omCoe003o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00000Eooooo`002oooool00ol0003ooooooooo
o`08ooooo`03o`000?lT7Y7o91jA00ko91jA00?o0000ofQ?X_mXCj804?mXCj800ol0003o^iJaok^F
/@0Eok^F/@03o`000?oXaK?oj<Fc01Koj<Fc00?o0000oo?K]_ocfkH05_ocfkH00ol0003okmo0onoO
`00<onoO`0Go00006oooool7o`0000WoXH6a00?o0000ofXkQOmZ>hD05?mZ>hD00ol0003oEam]oeLO
K@0EoeLOK@03o`000?mT:G3oI2U`01GoI2U`00?o0000oi9OT_nBGi805_nBGi800ol0003oeLW?omG9
c`0@omG9c`03o`000?oDomCoe?oD00coe?oD00?o0000ooooooooool01_ooool00ol0003ok^k^oc8b
<P02o`000003onk^k_oooooooooo00?ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0oooool00005oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`08ooooo`03o`00
0?lT7Y7o91jA00ko91jA00?o0000ofQ?X_mXCj804?mXCj800ol0003o^iJaok^F/@0Eok^F/@03o`00
0?oXaK?oj<Fc01Ooj<Fc00?o0000oo?K]_ocfkH05OocfkH00ol0003okmo0onoO`008onoO`0Co0000
9oooool7o`0000;oXH6a00?o0000ofXkQOmZ>hD05?mZ>hD00ol0003oEam]oeLOK@0EoeLOK@03o`00
0?mT:G3oI2U`01GoI2U`00?o0000oi9OT_nBGi805OnBGi800ol0003oeLW?omG9c`0AomG9c`03o`00
0?oDomCoe?oD00_oe?oD00?o0000ooooooooool01oooool01_l0003oMgMgoiRHV?oooooo0000ogMg
M`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;ooooo00001Ol@413o^[ZjoooooomgMgOo<S8b
00Kooooo00?o0000ooooooooool02?ooool00ol0003o91jAob@NT@0>ob@NT@03o`000?mXCj;oJ4nR
013oJ4nR00?o0000ok^F/OnkU[405OnkU[400ol0003oj<FconS5/`0GonS5/`03o`000?ocfkKolm^f
01Golm^f00?o0000onoO`?o_gl001?o_gl04o`0003;ooooo1Ol0000DofXkQ@03o`000?mG7fgoEam]
01GoEam]00?o0000of@YL?mT:G005OmT:G000ol0003oTUnBoi9OTP0Eoi9OTP03o`000?oEbLooeLW?
013oeLW?00?o0000omCoe?oDom@03?oDom@00ol0003oooooooooo`06o`000003ooooool0003o410@
00;ooooo00?o0000oa0@4?ooool03oooool00ol0003oooooooooo`01ooooo`001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT7Y403OlT7Y400ol0003o
J4nRofQ?XP0AofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<05ooXaK<00ol0003o
lm^foo?K]P0Eoo?K]P03o`000?o_gl3o000000Co0000>oooool4o`00013oJS^500?o0000oeLOKOmG
7fd05OmG7fd00ol0003oI2U`of@YL00Eof@YL003o`000?nBGi;oTUnB01GoTUnB00?o0000omG9cooE
bLl04?oEbLl00ol0003oe?oDomCoe00<omCoe003o`000?oooooooooo00Gooooo00CoEEEEofIVI_l0
003o00000_ooool2o`0000oooooo00?oMgMgoc8b<_ooool00_ooool000?ooooo00?oZJVYoa0@4?oo
ool01Oooool3o`0000Sooooo00?o0000ob@NTOlT7Y403OlT7Y400ol0003oJ4nRofQ?XP0AofQ?XP03
o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<05ooXaK<00ol0003olm^foo?K]P0Coo?K]PCo
0000A?ooool4o`0000coJS^500?o0000oeLOKOmG7fd05OmG7fd00ol0003oI2U`of@YL00Eof@YL003
o`000?nBGi;oTUnB01GoTUnB00?o0000omG9cooEbLl04?oEbLl00ol0003oe?oDomCoe00:omCoe0?o
00002_ooool00ol0003oooooooooo`02o`0000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c003oooo
o`000_ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT
7Y403OlT7Y400ol0003oJ4nRofQ?XP0AofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooX
aK<05ooXaK<00ol0003olm^foo?K]P0@oo?K]P?o0000C?ooool3o`0000WoJS^500?o0000oeLOKOmG
7fd05OmG7fd00ol0003oI2U`of@YL00Eof@YL003o`000?nBGi;oTUnB01GoTUnB00?o0000omG9cooE
bLl04?oEbLl00ol0003oe?oDomCoe007omCoe0?o000000Coooooo`000?l0003o00001_ooool02?o^
k^ko<S8bo`000?l30`?ok^k^ooooool0003o410@3?ooool00ol0003oooooooooo`05ooooo`000ooo
ool00onj^[[o8B4Qooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ob@NTOlT7Y403OlT
7Y400ol0003oJ4nRofQ?XP0AofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<05ooX
aK<00ol0003olm^foo?K]P0<oo?K]PCo0000D_ooool4o`0000GoJS^500?o0000oeLOKOmG7fd05OmG
7fd00ol0003oI2U`of@YL00Fof@YL003o`000?nBGi;oTUnB01CoTUnB00?o0000omG9cooEbLl03ooE
bLl00ol0003oe?oDomCoe005omCoe0?o00001Oooool3o`0000Gooooo00SoMgMgoiRHV?ooooooAdM7
odI6A_oooooo0000ogMgM`cooooo00?o0000ooooooooool01Oooool00005oa0@4?nHV9SooooookZj
^_l000001_ooool00ol0003oooooooooo`08ooooo`03o`000?lT7Y7o91jA00go91jA00?o0000ofQ?
X_mXCj804OmXCj800ol0003o^iJaok^F/@0Eok^F/@03o`000?oXaK?oj<Fc01Ooj<Fc00?o0000oo?K
]_ocfkH02OocfkH3o`0005[ooooo1?l000000omZ>hGo0000oeLOK@0FoeLOK@03o`000?mT:G3oI2U`
01KoI2U`00?o0000oi9OT_nBGi805?nBGi800ol0003oeLW?omG9c`0?omG9c`03o`000?oDomCoe?oD
00?oe?oD0_l00009ooooo`?o00001?ooool01Ol@413oooooooooooo^k^ko0`<300;o000000?ok^k^
ooooooooool02_ooool4o`0000Cooooo00001OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool01oooool3o`0000ko91jA00?o0000ofQ?X_mXCj804OmXCj800ol0003o^iJaok^F/@0E
ok^F/@03o`000?oXaK?oj<Fc01Ooj<Fc00?o0000oo?K]_ocfkH01_ocfkH3o`00067ooooo1?l0000E
oeLOK@03o`000?mT:G3oI2U`01KoI2U`00?o0000oi9OT_nBGi805?nBGi800ol0003oeLW?omG9c`0?
omG9c`03o`000?oDomCoe?oD00?o00002oooool4o`0000?ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000001Gooooo000;ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo
0ol0000;ob@NT@03o`000?mXCj;oJ4nR017oJ4nR00?o0000ok^F/OnkU[405OnkU[400ol0003oj<Fc
onS5/`0GonS5/`03o`000?ocfkKolm^f00;olm^f1?l0001Xooooo`?o00004omG7fd00ol0003oI2U`
of@YL00Eof@YL003o`000?nBGi;oTUnB01CoTUnB00?o0000omG9cooEbLl03_oEbLl4o`00013ooooo
0ol00002ooooo`07o`000?ooooooooooooooool0003oooooo`00000Eooooo`002oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0ol00008ob@NT@03o`000?mXCj;oJ4nR017o
J4nR00?o0000ok^F/OnkU[405OnkU[400ol0003oj<FconS5/`0GonS5/`03o`000?ocfkKo000000;o
0000Koooool4o`0000ooEam]00?o0000of@YL?mT:G005OmT:G000ol0003oTUnBoi9OTP0Doi9OTP03
o`000?oEbLooeLW?00goeLW?0_l0000Dooooo`?o000000?ooooooa0@4?ooool00_ooool01_l@413o
k^k^o`000?l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00Ooo
ool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`;o00001_lT7Y40
0ol0003oJ4nRofQ?XP0AofQ?XP03o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<05?oXaK<5
o`0007Kooooo1?l0000;oeLOK@03o`000?mT:G3oI2U`01GoI2U`00?o0000oi9OT_nBGi805?nBGi80
0ol0003oeLW?omG9c`0:omG9c`?o00005oooool3o`000004ogMgMonHV9SooooooiRHV0;oMgMg00Co
0000oooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo0OmgMgL1oc8b<P7ooooo000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03?ooool3o`0000?o91jA00?o0000ofQ?X_mXCj804OmX
Cj800ol0003o^iJaok^F/@0Eok^F/@03o`000?oXaK?oj<Fc00ooj<Fc1Ol0001oooooo`?o00002?mG
7fd00ol0003oI2U`of@YL00Eof@YL003o`000?nBGi;oTUnB01?oTUnB00?o0000omG9cooEbLl02?oE
bLl3o`0001_ooooo0ol000001_lb<S;o0000oc8b<_o^k^ko410@o`0000;ooooo00?o410@oooooooo
ool03_ooool1o`00007ooooo000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4?ooool4o`0001?oJ4nR00?o0000ok^F/OnkU[405OnkU[400ol0003oj<FconS5/`0:onS5/`Go0000
Qoooool4o`0000CoEam]00?o0000of@YL?mT:G005OmT:G000ol0003oTUnBoi9OTP0Coi9OTP03o`00
0?oEbLooeLW?00GoeLW?0ol0000Nooooo`Co00000oooool2o`0000;ooooo00?o0000ooooooooool0
3Oooool1ogMgM`7o<S8b0Oooool000_ooooo00Go0000ooooooooooooooooo`00000Fooooo`Co0000
4?mXCj800ol0003o^iJaok^F/@0Eok^F/@03o`000?oXaK?oj<Fc00Goj<Fc1Ol0002@ooooo`?o0000
00?oEam]o`000?mT:G005_mT:G000ol0003oTUnBoi9OTP0Coi9OTP03o`000?oEbLooeLW?00;oeLW?
0ol0000Sooooo`?o00000_ooool2o`0000;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<007ooooo000;ooooo`04o`000?ooooooooooo`0001_ooooo1Ol0000;ofQ?XP03
o`000?nkU[7o^iJa01Go^iJa00?o0000onS5/ooXaK<01Ol0002Hooooo`Ko00004omT:G000ol0003o
TUnBoi9OTP0Coi9OTP03o`000?oEbLoo000000;o00009oooool3o`000003ooooool@413o000000;o
oooo00?o410@ooooool000000ol000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo000;ooooo`03o`000?oooooo0000027ooooo1Ol00006ofQ?XP03o`000?nkU[7o^iJa00oo^iJa
2Ol0002Sooooo`So00002omT:G000ol0003oTUnBoi9OTP0>oi9OTPOo0000:oooool3o`000005ogMg
Mol0003ooooooiRHV?mgMgL00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo000;ooooo`;o00009oooool5o`000003ofQ?X_l0003o^iJa00Co^iJa3?l0002dooooo`So0000
0omT:G000ol0003oTUnBoi9OTP03oi9OTP_o0000<oooool5o`000003oc8b<_o^k^kooooo00;ooooo
00?o0000ooooooooool01_ooool4o`0000;ooooo000;oooooooo0000BOl00006ooooo`03o`000?oo
oooooooo00cooooo003ooooooe[ooooo00?o0000ooooooooool03?ooool00?ooooooF_ooool00ol0
003oooooooooo`0<ooooo`00oooooomJooooo`03o`000?oooooooooo00cooooo003ooooooeSooooo
00?oEEEEofIVI_l000003_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["ViewPoint->{0., 0., 3.}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " moves the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  " position of the viewpoint for the graph to the location ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0, 3)\)\)]],
  ", i.e. a point on the z axis."
}], "Text"],

Cell[TextData[{
  "\tIt is also possible to rotate 3D graphics interactively using the mouse \
(on most platforms that can run ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). To implement this feature, type"
}], "Text",
  CellTags->"i:54"],

Cell[BoxData[
    \(<< RealTime3D`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.83"],

Cell[TextData[{
  "Now if you show a 3D plot, you can rotate it with the mouse to a new \
viewpoint. Try it with the example in Cell ",
  ButtonBox["9.84",
    ButtonData:>"Cell 9.84",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[plt]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.84"],

Cell[BoxData[
  SurfaceGraphics[{
  {0.000000,0.000000,0.000000,0.000000,0.000000,0.000000,0.000000,0.000000,
    0.000000,0.000000,0.000000,0.000000,0.000000,0.000000,0.000000},{0.000000,
    0.050521,0.100913,0.151050,0.200804,0.250049,0.298660,0.346514,0.393489,
    0.439467,0.484330,0.527966,0.570264,0.611116,0.650418},{0.000000,0.100913,
    0.200804,0.298660,0.393489,0.484330,0.570264,0.650418,0.723981,0.790208,
    0.848425,0.898047,0.938566,0.969574,0.990757},{0.000000,0.151050,0.298660,
    0.439467,0.570264,0.688073,0.790208,0.874345,0.938566,0.981409,1.001899,
    0.999568,0.974469,0.927174,0.858761},{0.000000,0.200804,0.393489,0.570264,
    0.723981,0.848425,0.938566,0.990757,1.002888,0.974469,0.906649,0.802170,
    0.665257,0.501445,0.317359},{0.000000,0.250049,0.484330,0.688073,0.848425,
    0.955281,1.001899,0.985340,0.906649,0.770787,0.586322,0.364886,
    0.120441,-0.131599,-0.375340},{0.000000,0.298660,0.570264,0.790208,
    0.938566,1.001899,0.974469,0.858761,0.665257,0.411487,
    0.120441,-0.181516,-0.467030,-0.710235,-0.889100},{0.000000,0.346514,
    0.650418,0.874345,0.990757,0.985340,0.858761,0.626584,
    0.317359,-0.030890,-0.375340,-0.673636,-0.889100,-0.995235,-0.978990},{
    0.000000,0.393489,0.723981,0.938566,1.002888,0.906649,0.665257,
    0.317359,-0.081347,-0.467030,-0.777942,-0.964308,-0.996289,-0.868767,-0.\
602155},{0.000000,0.439467,0.790208,0.981409,0.974469,0.770787,
    0.411487,-0.030890,-0.467030,-0.808879,-0.987420,-0.966605,-0.750636,-0.\
383118,0.061750},{0.000000,0.484330,0.848425,1.001899,0.906649,0.586322,
    0.120441,-0.375340,-0.777942,-0.987420,-0.951770,-0.679841,-0.239141,
    0.260925,0.696217},{0.000000,0.527966,0.898047,0.999568,0.802170,
    0.364886,-0.181516,-0.673636,-0.964308,-0.966605,-0.679841,-0.189772,
    0.357047,0.797093,0.998770},{0.000000,0.570264,0.938566,0.974469,0.665257,
    0.120441,-0.467030,-0.889100,-0.996289,-0.750636,-0.239141,0.357047,
    0.826786,1.003712,0.825169},{0.000000,0.611116,0.969574,0.927174,
    0.501445,-0.131599,-0.710235,-0.995235,-0.868767,-0.383118,0.260925,
    0.797093,1.003712,0.795360,0.258176},{0.000000,0.650418,0.990757,0.858761,
    0.317359,-0.375340,-0.889100,-0.978990,-0.602155,0.061750,0.696217,
    0.998770,0.825169,0.258176,-0.431899}},
    Mesh -> True,
    Boxed -> True,
    Lighting -> True,
    SphericalRegion -> False,
    BoxRatios -> {1.000000, 1.000000, 0.400000},
    ViewPoint -> {1.300000, -2.400000, 2.000000}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00iP3oool200000800oooo003T0?ooo`80000000<0oooo000000000000
O`3oool00>40oooo0`0000030?ooo`800000O`3oool00=l0oooo0P0000060?ooo`030000003oool0
000007h0oooo003L0?ooo`<00000203oool010000000oooo0?ooo`00001m0?ooo`00fP3oool20000
00/0oooo00@000000?ooo`3oool00000O@3oool00=L0oooo0`00000=0?ooo`050000003oool0oooo
0?ooo`000000O03oool00=D0oooo0P00000@0?ooo`050000003oool0oooo0?ooo`000000O03oool0
0=80oooo0`00000C0?ooo`050000003oool0oooo0?ooo`000000N`3oool00=00oooo0P00000F0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool00<d0oooo0`00000H0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0N03oool00<X0oooo0`00000K0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0M`3oool00<P0oooo0P00000N0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0MP3oool00<D0oooo0`00000P0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0MP3oool00<<0oooo0P00000S0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0M@3oool00<00oooo0`00000U0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0M@3oool00;h0oooo0P00000X0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0M03oool00;/0oooo0`00000Z0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0L`3oool00;T0oooo0P00000]0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0L`3oool00;H0oooo0`00000_0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0LP3oool00;@0oooo0P00000b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0L@3oool00;40oooo0`00000d0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
L@3oool00:l0oooo0P00000g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0L03o
ool00:`0oooo0`00000j0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L03oool0
0:X0oooo0P00000m0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K`3oool00:L0
oooo0`00000o0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0KP3oool00:D0oooo
0P0000120?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0KP3oool00:80oooo0`00
00140?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0K@3oool00:00oooo0P000017
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0K03oool009d0oooo0`0000190?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0K03oool009X0oooo0`00001<0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0J`3oool009P0oooo0P00001?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0J`3oool009D0oooo0`00001A0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0JP3oool009<0oooo0P00001D0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0J@3oool00900oooo0`00001F0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0J@3oool008h0oooo0P00001I0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0J03oool008/0oooo0`00001K0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0I`3oool008T0oooo0P00001N0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0I`3oool008H0oooo0`00001P0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0IP3oool008@0oooo0P00001T0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0IP3oool00840oooo0`00001V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0I@3oool007l0oooo0P00001Y0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
I03oool007`0oooo0`00001[0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0I03o
ool007X0oooo0P00001^0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H`3oool0
07L0oooo0`00001`0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0HP3oool007D0
oooo0P00001c0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0HP3oool00780oooo
0`00001e0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0H@3oool00700oooo0P00
001h0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0H@3oool006d0oooo0`00001b
0?ooo`8000001P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0600oooo001[0?oo
o`800000LP3oool30000000308Hc<`000000oooo00D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1O0?ooo`00J03oool300000740oooo0`00000508Hc<`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1O0?ooo`00I@3oool300000740oooo
0`00000808Hc<`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`1N0?ooo`00H`3oool200000740oooo0`00000;08Hc<`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`1M0?ooo`00H03oool300000700oooo0`00000>
08Hc<`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1M
0?ooo`00GP3oool200000740oooo0P0000000`27<c<0000008Hc<`0?08Hc<`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1L0?ooo`00F`3oool300000700
oooo0`00000308Lc<`0300000026<c<0QS<c00h0QS<c00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo05`0oooo001I0?ooo`800000L@3oool2000000L0Qc<c
00<0000008Hc<`26<c<03@26<c<00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0F`3oool005H0oooo0`00001`0?ooo`<000002@27<c<00`000000QS<c08Hc
<`0=08Hc<`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1J0?ooo`00E03oool200000740oooo0P00000<08Lc<`0300000026<c<0QS<c00h0QS<c00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo001A0?oo
o`<00000L03oool3000000h0Qc<c00<0000008Hc<`26<c<03P26<c<00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0F@3oool004l0oooo0P00001`0?ooo`<0
000000<0RC<c00000027<c<03`27<c<00`000000QS<c08Hc<`0=08Hc<`030000003oool0oooo0080
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1H0?ooo`00C03oool3000006l0oooo
0`00000508Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<03P26<c<01@000000oooo
0?ooo`3oool000000240oooo00<000000?ooo`3oool0F03oool004X0oooo0P00001`0?ooo`800000
2029<c<00`000000Qc<c08Lc<`0=08Lc<`0300000026<c<0QS<c00h0QS<c00D000000?ooo`3oool0
oooo0000000R0?ooo`030000003oool0oooo05L0oooo00170?ooo`<00000K`3oool3000000X0RC<c
00<0000008Lc<`27<c<03@27<c<00`000000QS<c08Hc<`0>08Hc<`050000003oool0oooo0?ooo`00
00008P3oool00`000000oooo0?ooo`1G0?ooo`00A@3oool2000006l0oooo0`00000=08Tc<`030000
0027<c<0Qc<c00h0Qc<c00<0000008Hc<`26<c<03@26<c<01@000000oooo0?ooo`3oool0000002<0
oooo00<000000?ooo`3oool0EP3oool00480oooo0`00001^0?ooo`<0000000<0S3<c00000029<c<0
3P29<c<00`000000Qc<c08Lc<`0=08Lc<`0300000026<c<0QS<c00h0QS<c00@000000?ooo`3oool0
0000903oool00`000000oooo0?ooo`1E0?ooo`00@03oool2000006h0oooo0`00000408`c<`030000
0029<c<0RC<c00d0RC<c00<0000008Lc<`27<c<03@27<c<00`000000QS<c08Hc<`0>08Hc<`040000
003oool0oooo000002@0oooo00<000000?ooo`3oool0E@3oool003d0oooo0`00001]0?ooo`<00000
202<<c<00`000000RC<c08Tc<`0<08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<0
3P26<c<010000000oooo0?ooo`00000U0?ooo`030000003oool0oooo05@0oooo000k0?ooo`800000
K@3oool3000000/0S3<c00<0000008Tc<`29<c<03029<c<00`000000Qc<c08Lc<`0>08Lc<`030000
0026<c<0QS<c00d0QS<c00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1C0?ooo`00
>03oool3000006`0oooo0`00000>08`c<`0300000029<c<0RC<c00d0RC<c00<0000008Lc<`27<c<0
3@27<c<00`000000QS<c08Hc<`0>08Hc<`040000003oool0oooo000002D0oooo00<000000?ooo`3o
ool0D`3oool003D0oooo0`00001]0?ooo`80000000<0T3<c0000002<<c<03P2<<c<00`000000RC<c
08Tc<`0=08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<03P26<c<010000000oooo
0?ooo`00000V0?ooo`030000003oool0oooo0580oooo000c0?ooo`800000KP3oool2000000@0T3<c
00<0000008`c<`2<<c<03@2<<c<00`000000RC<c08Tc<`0<08Tc<`0300000027<c<0Qc<c00d0Qc<c
00<0000008Hc<`26<c<03P26<c<010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo0540
oooo000`0?ooo`<00000K@3oool3000000H0T3<c00<0000008`c<`2<<c<03@2<<c<00`000000RC<c
08Tc<`0=08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<03P26<c<00`000000oooo
0000000W0?ooo`030000003oool0oooo0540oooo000^0?ooo`800000KP3oool2000000T0T3<c00<0
000008`c<`2<<c<03@2<<c<00`000000RC<c08Tc<`0=08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0
000008Hc<`26<c<03P26<c<00`000000oooo0000000X0?ooo`030000003oool0oooo0500oooo000[
0?ooo`<00000KP3oool2000000/0T3<c00<0000008`c<`2<<c<03@2<<c<00`000000RC<c08Tc<`0=
08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<03P26<c<00`000000oooo0000000X
0?ooo`030000003oool0oooo0500oooo000Y0?ooo`800000KP3oool3000000h0T3<c00<0000008`c
<`2<<c<03@2<<c<00`000000RC<c08Tc<`0<08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc
<`26<c<03P26<c<00`000000oooo0000000Y0?ooo`030000003oool0oooo04l0oooo000V0?ooo`<0
0000K@3oool30000000309Dc>0000000T3<c00h0T3<c00<0000008`c<`2<<c<03@2<<c<00`000000
RC<c08Tc<`0=08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<03P26<c<2000001X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1>0?ooo`00903oool2000006d0oooo
0`00000509Dc>0030000002@<c<0T3<c00`0T3<c00<0000008`c<`2<<c<03@2<<c<00`000000RC<c
08Tc<`0=08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<02`26<c<4000000030?oo
o`000000oooo01L0oooo00<000000<_Cd`0000003P3oool00`000000oooo0?ooo`1>0?ooo`008@3o
ool3000006d0oooo0P00000809Dc>0030000002@<c<0T3<c00d0T3<c00<0000008`c<`2<<c<0302<
<c<00`000000RC<c08Tc<`0=08Tc<`0300000027<c<0Qc<c00d0Qc<c00<0000008Hc<`26<c<02026
<c<3000000<0QS<c00<000000?ooo`0000005P3oool300000080bm?C00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1=0?ooo`007`3oool2000006d0oooo0`00000:09Dc>0030000002@<c<0
T3<c00d0T3<c00<0000008`c<`2<<c<03@2<<c<00`000000RC<c08Tc<`0=08Tc<`0300000027<c<0
Qc<c00`0Qc<c00<0000008Hc<`26<c<01P26<c<2000000H0QS<c00@000000?ooo`3oool00000503o
ool00`000000<c<c000000040<_Cd`030000003oool0oooo00`0oooo00<000000?ooo`3oool0C03o
ool001d0oooo0P00001/0?ooo`<000003P2E<cP00`000000T3<c090c<`0<090c<`030000002<<c<0
S3<c00d0S3<c00<0000008Tc<`29<c<03@29<c<00`000000Qc<c08Lc<`0=08Lc<`0300000026<c<0
QS<c0080QS<c0`00000908Hc<`040000003oool0oooo00000180oooo00@0000003<c<`0c<c<00000
1@3;dm<00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo000M0?ooo`800000JP3o
ool20000000309Xj@`000000UC<h00h0UC<h00<00000090c<`2@<c<03@2@<c<00`000000S3<c08`c
<`0<08`c<`0300000029<c<0RC<c00d0RC<c00<0000008Lc<`27<c<03@27<c<00`000000QS<c0000
0002000000/0QS<c0P0000030?ooo`030000003oool0oooo00d0oooo0P00000203<c<`030000003;
dm<0bm?C00D0bm?C00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1;0?ooo`007@3oool0
0`000000oooo0000001V0?ooo`<00000102J>T<00`000000UC<h09Dc>00<09Dc>0030000002@<c<0
T3<c00d0T3<c00<0000008`c<`2<<c<0302<<c<00`000000RC<c08Tc<`0=08Tc<`0300000027<c<0
Qc<c00`0Qc<c0`00000:08Hc<`@0000000<0XfEk0000003oool00P3oool00`000000oooo0?ooo`0<
0?ooo`030000000c<c<0<c<c0080<c<c00<000000<_Cd`3;dm<01@3;dm<2000000`0oooo00<00000
0?ooo`3oool0B`3oool001d0oooo00@000000?ooo`3oool00000HP3oool3000000L0VSY300<00000
09Dc>02E<cP03@2E<cP00`000000T3<c090c<`0<090c<`030000002<<c<0S3<c00d0S3<c00<00000
08Tc<`29<c<03@29<c<00`000000Qc<c08Lc<`0808Lc<`<0000000<0Qc<c00000026<c<01@26<c<5
000000H0XfEk00D000000?ooo`3oool0oooo0000000<0?ooo`030000000c<c<0<c<c0080<c<c00<0
00000<_Cd`3;dm<00P3;dm<40000000309MMM`000000oooo00`0oooo00<000000?ooo`3oool0BP3o
ool001`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1M0?ooo`8000002P2J>T<0
0`000000UC<h09Dc>00=09Dc>0030000002@<c<0T3<c00`0T3<c00<0000008`c<`2<<c<03@2<<c<0
0`000000RC<c08Tc<`0=08Tc<`0300000027<c<0Qc<c00D0Qc<c0`00000508Lc<`0300000026<c<0
000000@000002P2SIG/00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P000004
03<c<`80000000@0bm?C00000000000000001P2GGGL00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo04T0oooo000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F@3oool3
000000d0VSY300<0000009Dc>02E<cP0302E<cP00`000000T3<c090c<`0=090c<`030000002<<c<0
S3<c00`0S3<c00<0000008Tc<`29<c<03@29<c<00`000000Qc<c08Lc<`0208Lc<`<000001P27<c<5
000000h0XfEk00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000000c<c<0
<c<c00<0<c<c1000000909MMM`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B@3oool0
01`0oooo00<000000?ooo`3oool0103oool2000005H0oooo0`0000000`2PAU80000009Xj@`0=09Xj
@`030000002E<cP0UC<h00d0UC<h00<00000090c<`2@<c<0302@<c<00`000000S3<c08`c<`0<08`c
<`0300000029<c<0RC<c00d0RC<c00<0000008Lc<`27<c<00P00000408Lc<`D000000P2OEV/00`00
0000XfEk0:=UN`0?0:=UN`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000<c<c03<c<`0303<c<`030000000c<c<0000000/0Ueeg00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`180?ooo`00703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500
oooo0`0000050:16DP030000002J>T<0VSY300`0VSY300<0000009Dc>02E<cP0302E<cP00`000000
T3<c090c<`0<090c<`030000002<<c<0S3<c00d0S3<c00<0000008Tc<`29<c<03029<c<300000003
08Lc<`000000000000<00000202OEV/00`000000XfEk0:=UN`0>0:=UN`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool2000000@0<c<c00@0000003<c<`0c<c<00000302GGGL00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo000L0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0C@3oool2000000P0X4IB00<0000009Xj@`2J>T<0302J>T<00`000000
UC<h09Dc>00<09Dc>0030000002@<c<0T3<c00d0T3<c00<0000008`c<`2<<c<0302<<c<00`000000
RC<c08Tc<`0908Tc<`L000003@2OEV/00`000000XfEk0:=UN`0?0:=UN`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0P00000403<c<`050000000c<c<0<c<c03<c<`000000302GGGL0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo000L0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0B@3oool3000000X0X4IB00<0000009Xj@`2J>T<0302J>T<00`00
0000UC<h09Dc>00=09Dc>0030000002@<c<0T3<c00`0T3<c00<0000008`c<`2<<c<0302<<c<00`00
0000RC<c08Tc<`0608Tc<`H0000000<0VdYN0000002OEV/03P2OEV/00`000000XfEk0:=UN`0?0:=U
N`030000003oool0oooo00<0oooo00D000000?ooo`000000<c<c0000000303<c<`050000000c<c<0
<c<c03<c<`0000003@2GGGL00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04H0oooo000K
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0A@3oool3000000h0X4IB00<00000
09Xj@`2J>T<0302J>T<00`000000UC<h09Dc>00<09Dc>0030000002@<c<0T3<c00`0T3<c00<00000
08`c<`2<<c<0302<<c<00`000000RC<c08Tc<`0308Tc<`D000001P2KBUh00`000000WeI[09mFJ`0=
09mFJ`030000002SIG/0XfEk00h0XfEk00<000000?ooo`3oool0103oool00`000000<c<c00000003
03<c<`030000000c<c<0<c<c0080<c<c00<0000009MMM`2GGGL0302GGGL00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo04H0oooo000K0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0@P3oool2000000030:ICH`000000X4IB00h0X4IB00<0000009Xj@`2J>T<0302J>T<00`00
0000UC<h09Dc>00<09Dc>0030000002@<c<0T3<c00d0T3<c00<0000008`c<`2<<c<0302<<c<00`00
0000RC<c00000003000000X0VdYN00<0000009mFJ`2OEV/03@2OEV/00`000000XfEk0:=UN`0?0:=U
N`030000003oool0oooo0080oooo00@0000003<c<`00000000000P0c<c<00`000000<c<c03<c<`03
03<c<`8000003@2GGGL00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0oooo000K0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0?P3oool3000000@0YU=S00<000000:16
DP2PAU80302PAU800`000000VSY309Xj@`0<09Xj@`030000002E<cP0UC<h00d0UC<h00<00000090c
<`2@<c<0302@<c<00`000000S3<c08`c<`0;08`c<`<000003P2KBUh00`000000WeI[09mFJ`0>09mF
J`030000002SIG/0XfEk00h0XfEk00<000000?ooo`3oool00P00000203<c<`80000000<0<c<c0000
000c<c<0100c<c<00`000000`K6j0000000>09MMM`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0A03oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0j0?ooo`<0
00001`2VDf<00`000000X4IB0:16DP0=0:16DP030000002J>T<0VSY300`0VSY300<0000009Dc>02E
<cP0302E<cP00`000000T3<c090c<`0<090c<`030000002<<c<0S3<c00L0S3<c1P00000@09]:GP03
0000002OEV/0WeI[00d0WeI[00<000000:=UN`2SIG/03P2SIG/010000000oooo0000003oool303<c
<`<000001P0c<c<010000000`K6j00000000000=09MMM`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0A03oool001/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0g0?oo
o`8000002`2VDf<00`000000X4IB0:16DP0<0:16DP030000002J>T<0VSY300`0VSY300<0000009Dc
>02E<cP0302E<cP00`000000T3<c090c<`0<090c<`030000002<<c<0S3<c00@0S3<c1@00000409M1
E@030000002KBUh0VdYN00d0VdYN00<0000009mFJ`2OEV/03@2OEV/00`000000XfEk0:=UN`0?0:=U
N`030000000c<c<0<c<c00<0<c<c0`00000603<c<`0400000031/KX0`K6j000000d0Ueeg00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`130?ooo`006`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo03<0oooo0`00000=0:ICH`030000002PAU80X4IB00`0X4IB00<0000009Xj
@`2J>T<0302J>T<00`000000UC<h09Dc>00=09Dc>0030000002@<c<0T3<c00`0T3<c00<0000008`c
<`0000001@00000709M1E@030000002KBUh0VdYN00d0VdYN00<0000009mFJ`2OEV/03P2OEV/00`00
0000XfEk0:=UN`0>0:=UN`030000000c<c<0<c<c0080<c<c0P0000000`0c<c<0000003<c<`0503<c
<`0300000031/KX0`K6j008000003@2GGGL00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0480oooo000J0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;`3oool300000003
0:aSM`000000YU=S00h0YU=S00<000000:16DP2PAU80302PAU800`000000VSY309Xj@`0<09Xj@`03
0000002E<cP0UC<h00`0UC<h00<00000090c<`2@<c<02P2@<c<7000000X0Ud5E00<0000009]:GP2K
BUh03P2KBUh00`000000WeI[09mFJ`0=09mFJ`030000002SIG/0XfEk00h0XfEk00<0000003<c<`0c
<c<00P0c<c<01@000000<c<c03<c<`0c<c<0000000@0<c<c00<000000<6a^P31/KX00P31/KX00`00
0000Ueeg09MMM`0;09MMM`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@P3oool001X0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Z0?ooo`@000001@2/HgL00`000000
YU=S0:ICH`0<0:ICH`030000002PAU80X4IB00`0X4IB00<0000009Xj@`2J>T<0302J>T<00`000000
UC<h09Dc>00<09Dc>0030000002@<c<0T3<c00H0T3<c10000000102D?E40000000000000000>09M1
E@030000002KBUh0VdYN00d0VdYN00<0000009mFJ`2OEV/03@2OEV/00`000000XfEk0:=UN`0?0:=U
N`030000000c<c<0<c<c00800000100c<c<01@000000<c<c03<c<`0c<c<0000000@0`K6j0P00000<
09MMM`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool001X0oooo00<000000?oo
o`3oool04`3oool2000002L0oooo0`0000090:aSM`030000002VDf<0YU=S00`0YU=S00<000000:16
DP2PAU80302PAU800`000000VSY309Xj@`0=09Xj@`030000002E<cP0UC<h00`0UC<h00<00000090c
<`2@<c<01@00000309@mD@8000000P2D?E400`000000Ud5E09M1E@0<09M1E@030000002KBUh0VdYN
00d0VdYN00<0000009mFJ`2OEV/03P2OEV/00`000000XfEk0:=UN`0>0:=UN`040000000c<c<00000
000000D0<c<c00<0000003<c<`0c<c<02@00000<09MMM`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0@@3oool001X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?oo
o`<000003@2/HgL00`000000YU=S0:ICH`0<0:ICH`030000002PAU80X4IB00`0X4IB00<0000009Xj
@`2J>T<0302J>T<00`000000UC<h09Dc>00:09Dc>0D000001@2D?E43000000@0U3eA00<0000009M1
E@2G@ED03@2G@ED00`000000VdYN09]:GP0=09]:GP030000002OEV/0WeI[00d0WeI[00<000000:=U
N`2SIG/03`2SIG/00`000000<c<c0000000603<c<`<000001P1g=Eh00`000000AS<c000000030000
00P0Ueeg00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`100?ooo`006P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo01h0oooo0P0000000`2bM8`000000:aSM`0=0:aSM`03
0000002VDf<0YU=S00`0YU=S00<000000:16DP2PAU80302PAU800`000000VSY309Xj@`0<09Xj@`03
0000002E<cP0UC<h00H0UC<h1000000209<lD@030000002D?E40U3eA0080U3eA0`00000709@mD@03
0000002G@ED0Ud5E00d0Ud5E00<0000009]:GP2KBUh03@2KBUh00`000000WeI[09mFJ`0=09mFJ`03
0000002SIG/0XfEk00l0XfEk0P00000603<c<`@000001`1g=Eh00`000000AS<c04Hc<`0204Hc<`@0
0000102GGGL00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03l0oooo000J0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool06P3oool3000000@0/WB<00<000000:aSM`2/HgL0
302/HgL00`000000YU=S0:ICH`0<0:ICH`030000002PAU80X4IB00/0X4IB00<0000009Xj@`2J>T<0
3@2J>T<00`000000UC<h09Dc>005000000L0TcaA1000000;09@mD@030000002G@ED0Ud5E00`0Ud5E
00<0000009]:GP2KBUh03P2KBUh00`000000WeI[09mFJ`0=09mFJ`030000002SIG/0XfEk00h0XfEk
0P00000503<c<`030000000c<c<0<c<c008000001`1g=Eh00`000000AS<c04Hc<`0604Hc<`@00000
00<0Ueeg0000003oool0403oool00`000000oooo0?ooo`0o0?ooo`006@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo01L0oooo0P0000070;9dS0030000002/HgL0[6=g00`0[6=g00<0
00000:ICH`2VDf<0302VDf<00`000000X4IB0:16DP0<0:16DP030000002J>T<0VSY300/0VSY31000
000:09<lD@<000003P2D?E400`000000Ud5E09M1E@0=09M1E@030000002KBUh0VdYN00d0VdYN00<0
000009mFJ`2OEV/03@2OEV/00`000000XfEk0:=UN`0?0:=UN`030000000c<c<0<c<c0080<c<c00@0
000003<c<`0c<c<0<c<c0P00000707LeGP0300000016<c<0AS<c00X0AS<c0P00000B0?ooo`030000
003oool0oooo03h0oooo000I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0503o
ool2000000X0/WB<00<000000:aSM`2/HgL0302/HgL00`000000YU=S0:ICH`0;0:ICH`030000002P
AU80X4IB00`0X4IB00<0000009Xj@`2J>T<01`2J>T<40000000309@nE@000000TcaA00P0TcaA0`00
000209<lD@030000002D?E40U3eA00d0U3eA00<0000009M1E@2G@ED0302G@ED00`000000VdYN09]:
GP0=09]:GP030000002OEV/0WeI[00h0WeI[00<000000:=UN`2SIG/03@2SIG/2000000<0<c<c00D0
000003<c<`0c<c<0<c<c0000000207LeGP030000001g=Eh0McEN00D0McEN00<0000004Hc<`16<c<0
2P16<c<00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03d0oooo000I0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0403oool3000000`0/WB<00<000000:aSM`2/HgL0302/
HgL00`000000YU=S0:ICH`0<0:ICH`030000002PAU80X4IB00/0X4IB00<0000009Xj@`2J>T<0102J
>T<3000000H0U3iE00<0000009<lD@2C?5400`2C?543000000H0TcaA00<0000009@mD@2D?E40302D
?E400`000000Ud5E09M1E@0<09M1E@030000002KBUh0VdYN00h0VdYN00<0000009mFJ`2OEV/03@2O
EV/00`000000XfEk0:=UN`090:=UN`@000000P2`a>@3000000@0<c<c00D0000007LeGP1g=Eh0McEN
0000000607LeGP0300000016<c<0AS<c00X0AS<c00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0m0?ooo`006@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo0P00
00020;N6X`030000002bM8`0/WB<00/0/WB<00<000000:aSM`2/HgL0302/HgL00`000000YU=S0:IC
H`0;0:ICH`030000002PAU80X4IB00`0X4IB00<0000009Xj@`0000000`00000909@nE@040000002C
?540TcaA09<lD@8000002@2C?5400`000000U3eA09@mD@0<09@mD@030000002G@ED0Ud5E00d0Ud5E
00<0000009]:GP2KBUh03@2KBUh00`000000WeI[09mFJ`0=09mFJ`030000002SIG/0XfEk00D0XfEk
100000080;34i0050000000c<c<0<c<c03<c<`000000101g=Eh00`000000McEN07LeGP0407LeGP03
00000016<c<0AS<c00/0AS<c00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0l0?ooo`00
6@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo0`0000040;N6X`030000
002bM8`0/WB<00/0/WB<00<000000:aSM`2/HgL0302/HgL00`000000YU=S0:ICH`0<0:ICH`030000
002PAU80X4IB00T0X4IB1000000>09@nE@<000002`2C?5400`000000U3eA09@mD@0=09@mD@030000
002G@ED0Ud5E00`0Ud5E00<0000009]:GP2KBUh03@2KBUh00`000000WeI[09mFJ`0>09mFJ`030000
002SIG/0XfEk00@000003@2`a>@20000000303<c<`000000McEN00@0McEN00<0000007LeGP1g=Eh0
0`1g=Eh00`000000AS<c04Hc<`0;04Hc<`030000003oool0oooo0140oooo00<000000?ooo`3oool0
?03oool001T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`<00000202g
QZ<00`000000/WB<0;9dS00;0;9dS0030000002/HgL0[6=g00`0[6=g00<000000:ICH`2VDf<02`2V
Df<00`000000X4IB0:16DP050:16DP@000000P2EA5d00`000000U3iE09@nE@0:09@nE@@000003P2C
?5400`000000U3eA09@mD@0<09@mD@030000002G@ED0Ud5E00`0Ud5E00<0000009]:GP2KBUh03P2K
BUh00`000000WeI[09mFJ`0<09mFJ`@000004`2`a>@2000000H0McEN00<0000007LeGP1g=Eh00`1g
=Eh00`000000AS<c04Hc<`0:04Hc<`030000003oool0oooo0180oooo00<000000?ooo`3oool0>`3o
ool001P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`8000002`2gQZ<0
0`000000/WB<0;9dS00;0;9dS08000003@2/HgL00`000000YU=S0:ICH`0<0:ICH`030000002PAU80
X4IB00@000001`2EA5d00`000000U3iE09@nE@0609@nE@<000000`2D?UD00`000000TcaA09<lD@0<
09<lD@030000002D?E40U3eA00`0U3eA00<0000009M1E@2G@ED03@2G@ED00`000000VdYN09]:GP0=
09]:GP030000002OEV/0WeI[00P0WeI[100000020;Bcd@030000002`a>@0/<CT0100/<CT0P000002
0;:EZP030000001g=Eh0McEN00<0McEN00<0000007LeGP1g=Eh00`1g=Eh00`000000AS<c04Hc<`0:
04Hc<`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>P3oool001P0oooo00<000000?oo
o`3oool08@3oool4000000h0]hJS00<000000;9dS02bM8`02`2bM8`00`000000[6=g0:aSM`0<0:aS
M`030000002VDf<0YU=S00T0YU=S1@00000;09E4G@030000002D?UD0U3iE00<0U3iE0`00000709@n
E@030000002C?540TcaA00/0TcaA00<0000009@mD@2D?E403@2D?E400`000000Ud5E09M1E@0<09M1
E@030000002KBUh0VdYN00d0VdYN00<0000009mFJ`2OEV/0102OEV/4000000L0];?A00<000000;34
i02`a>@03@2`a>@2000000@0/YFZ00<0000007LeGP1g=Eh0101g=Eh00`000000McEN07LeGP0207Le
GP0300000016<c<0AS<c00/0AS<c00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0j0?oo
o`00603oool00`000000oooo0?ooo`0O0?ooo`<000000P2iV;T00`000000]hJS0;N6X`0=0;N6X`03
0000002bM8`0/WB<00X0/WB<0P00000=0:aSM`030000002VDf<0YU=S00D0YU=S1000000209Q<JP03
0000002EA5d0UDAM00`0UDAM00<0000009@nE@0000000P00000:09@nE@030000002C?540TcaA00`0
TcaA00<0000009@mD@2D?E40302D?E400`000000Ud5E09M1E@0=09M1E@030000002KBUh0VdYN00d0
VdYN00<0000009mFJ`0000000`00000<0;Bcd@030000002`a>@0/<CT00X0/<CT0P0000060;:EZP03
0000001g=Eh0McEN00D0McEN00<0000007LeGP1g=Eh00P1g=Eh00`000000AS<c04Hc<`0:04Hc<`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0>@3oool001P0oooo00<000000?ooo`3oool0
703oool3000000H0^IRi00<000000;N6X`2gQZ<0302gQZ<00`000000/WB<0;9dS00;0;9dS0030000
002/HgL0[6=g00`0[6=g00<000000:ICH`2VDf<01000000709Q<JP030000002EA5d0UDAM00/0UDAM
0P00000=09@nE@030000002C?540TcaA00`0TcaA00<0000009@mD@2D?E40302D?E400`000000Ud5E
09M1E@0=09M1E@030000002KBUh0VdYN00/0VdYN1000000@0;Bcd@8000002@2`a>@2000000T0/YFZ
00<0000007LeGP1g=Eh01@1g=Eh01@000000McEN07LeGP1g=Eh0000000`0AS<c00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0h0?ooo`00603oool00`000000oooo0?ooo`0I0?ooo`<00000
2@2iV;T00`000000]hJS0;N6X`0=0;N6X`030000002bM8`0/WB<00X0/WB<0P00000;0:aSM`D00000
2`2HC6X00`000000UDAM09E4G@0809E4G@<0000000<0UDAM0000002D?UD03@2D?UD00`000000TcaA
09<lD@0;09<lD@030000002D?E40U3eA00d0U3eA00<0000009M1E@2G@ED0302G@ED00`000000VdYN
09]:GP0609]:GPD000000`2dWkd00`000000];?A0;Bcd@0?0;Bcd@030000002`a>@0/<CT00D0/<CT
0P000002064cF0@000001@2bUJX00`000000McEN07LeGP0507LeGP050000001g=Eh0McEN07LeGP00
00003016<c<00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03P0oooo000H0?ooo`030000
003oool0oooo01H0oooo0`00000=0;VH^@030000002gQZ<0]hJS00d0]hJS00<000000;9dS02bM8`0
2P2bM8`00`000000[6=g0:aSM`050:aSM`@000000P2KEgT2000000d0V4aZ00<0000009E4G@2EA5d0
102EA5d3000000@0UDAM00<0000009@nE@2D?UD0302D?UD00`000000TcaA09<lD@0<09<lD@030000
002D?E40U3eA00`0U3eA00<0000009M1E@2G@ED03@2G@ED00`000000VdYN09]:GP05000000P0]9nm
00<000000;Bcd@2d/m40402d/m400`000000/<CT0;34i0020;34i08000000P2XRjP00`000000HC=H
064cF003064cF0@000000P2bUJX00`000000McEN07LeGP0507LeGP050000001g=Eh0McEN07LeGP00
00003016<c<00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03L0oooo000G0?ooo`030000
003oool0oooo01D0oooo0P0000020;ZQa`030000002iV;T0^IRi00`0^IRi00<000000;N6X`2gQZ<0
302gQZ<00`000000/WB<0;9dS00:0;9dS08000000P2/HgL4000000L0VeMi00<0000009Q<JP2HC6X0
2`2HC6X010000000UDAM09E4G@2EA5d3000000L0UDAM00<0000009@nE@2D?UD03@2D?UD00`000000
TcaA09<lD@0;09<lD@030000002D?E40U3eA00d0U3eA00<0000009M1E@2G@ED02`2G@ED4000000h0
]9nm00<000000;Bcd@2d/m40402d/m4010000000/<CT0000000000040:R;Z0030000001Q<eP0HC=H
00L0HC=H1000000707LeGP040000001g=Eh0McEN000000`0AS<c00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0g0?ooo`005`3oool00`000000oooo0?ooo`0B0?ooo`<000001@2jXLL00`00
0000^IRi0;VH^@0<0;VH^@030000002gQZ<0]hJS00`0]hJS00<000000;9dS02bM8`0202bM8`50000
00/0VeMi00<0000009Q<JP2HC6X0302HC6X3000000/0UDAM00<0000009@nE@2D?UD0302D?UD00`00
0000TcaA09<lD@0;09<lD@030000002D?E40U3eA00d0U3eA00<0000009M1E@2G@ED01`2G@ED40000
0080/8RV00<000000;BO_@2dWkd03P2dWkd00`000000];?A0;Bcd@0?0;Bcd@8000001P2XRjP00`00
0000HC=H064cF009064cF0@000001@1g=Eh010000000McEN07LeGP00000<04Hc<`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0=P3oool001L0oooo00<000000?ooo`3oool0403oool20000
00T0^Z7700<000000;VH^@2iV;T0302iV;T00`000000]hJS0;N6X`0;0;N6X`030000002bM8`0/WB<
0080/WB<1P00000309iUS0030000002KEgT0VeMi00/0VeMi00<0000009Q<JP2HC6X0202HC6X40000
00d0UDAM00<0000009@nE@2D?UD0302D?UD00`000000TcaA09<lD@0<09<lD@030000002D?E40U3eA
00`0U3eA00<0000009M1E@2G@ED0102G@ED3000000H0/8RV00<000000;BO_@2dWkd03`2dWkd?0;Bc
d@8000002@2XRjP00`000000HC=H064cF009064cF0030000000c<c<0000000800000101g=Eh00`00
0000McEN0000000<04Hc<`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=@3oool001L0
oooo00<000000?ooo`3oool03P3oool2000000`0^Z7700<000000;VH^@2iV;T0302iV;T00`000000
]hJS0;N6X`0:0;N6X`D000002@2NIH`00`000000VeMi09]GN@0;09]GN@030000002HC6X0V4aZ00D0
V4aZ0`00000409Q<JP030000002EA5d0UDAM00/0UDAM00<0000009@nE@2D?UD0302D?UD00`000000
TcaA09<lD@0;09<lD@030000002D?E40U3eA00d0U3eA00<0000009M1E@0000000`00000:0;28YP03
0000002dWkd0]9nm00h0]9nm00<000000;Bcd@2d/m402@2d/m43000000/0Z8^X00<00000064cF01Q
<eP02@1Q<eP010000000<c<c03<c<`0c<c<3000000<0McEN00<0000007LeGP0000003016<c<00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo03D0oooo000G0?ooo`030000003oool0oooo00`0
oooo0P00000>0;ZQa`030000002iV;T0^IRi00`0^IRi00<000000;N6X`2gQZ<01P2gQZ<400000080
XGJQ00<0000009iUS02NIH`02P2NIH`00`000000VeMi09]GN@0;09]GN@030000002HC6X0V4aZ0080
V4aZ0P00000709Q<JP030000002EA5d0UDAM00/0UDAM00<0000009@nE@2D?UD0302D?UD00`000000
TcaA09<lD@0;09<lD@030000002D?E40U3eA00X0U3eA1@00000>0;28YP030000002dWkd0]9nm00l0
]9nm00<000000;Bcd@2d/m401P2d/m44000000d0Z8^X00<00000064cF01Q<eP0201Q<eP00`000000
<c<c03<c<`0303<c<`<0000000@0McEN0000001g=Eh000003016<c<00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo03@0oooo000G0?ooo`030000003oool0oooo00d0oooo00<000000;ZQa`2j
XLL03@2jXLL00`000000^IRi0;VH^@0<0;VH^@040000002gQZ<0]hJS0;N6X`@000001P2QMZ400`00
0000WVF<09iUS00:09iUS0030000002KEgT0VeMi00/0VeMi00<0000009Q<JP0000000P00000:09Q<
JP030000002EA5d0UDAM00X0UDAM00<0000009@nE@2D?UD0302D?UD00`000000TcaA09<lD@0<09<l
D@040000002D?E40U3eA09@mD@P000000`2XLI02000000l0/8RV00<000000;BO_@2dWkd03`2dWkd0
0`000000];?A0;Bcd@020;Bcd@@000000`3Ii]L00`000000Z8^X0:R;Z00:0:R;Z0030000001Q<eP0
HC=H00T0HC=H00<0000003<c<`0c<c<0100c<c<5000000`0AS<c00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0c0?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`030000002jXLL0^Z77
00d0^Z7700<000000;VH^@2iV;T02`2iV;T4000000/0XGJQ00<0000009iUS02NIH`02P2NIH`00`00
0000VeMi09]GN@0909]GN@<000003@2HC6X00`000000UDAM09E4G@0;09E4G@030000002D?UD0U3iE
00`0U3iE00<0000009<lD@2C?5402@2C?546000000`0Z76@00<000000;28YP2`R:H03P2`R:H00`00
0000]9nm0;BO_@0>0;BO_@030000002d/m40];?A00D000001@3Ii]L00`000000Z8^X0:R;Z0090:R;
Z0030000001Q<eP0HC=H00T0HC=H00<0000003<c<`0c<c<01P0c<c<4000000/0AS<c00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0c0?ooo`005P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0^Z7700d0^Z7700<000000;VH^@2iV;T01P2iV;T400000080XhJg00<000000:5fX@2Q
MZ402P2QMZ400`000000WVF<09iUS00:09iUS0030000002KEgT0VeMi00H0VeMi0`00000209]GN@03
0000002HC6X0V4aZ00`0V4aZ00<0000009E4G@2EA5d02P2EA5d00`000000U3iE09@nE@0<09@nE@03
0000002C?540TcaA00D0TcaA100000020:1OO`030000002XLI00Z76@00d0Z76@0P00000?0;28YP03
0000002dWkd0]9nm00h0]9nm0`0000020;WTo`030000003Ii]L0fNKG00H0fNKG302XRjP00`000000
HC=H064cF008064cF0030000000c<c<0<c<c00P0<c<c0P00000<04Hc<`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0<P3oool001H0oooo00<000000?ooo`3oool04@3oool2000000h0^Z77
00@000000;VH^@2iV;T0^IRi100000060:>6]`030000002QMZ40XGJQ00/0XGJQ00<0000009iUS02N
IH`02P2NIH`00`000000VeMi09]GN@0209]GN@<000001P2KEgT00`000000V4aZ09Q<JP0;09Q<JP03
0000002EA5d0UDAM00/0UDAM00<0000009@nE@2D?UD0302D?UD00`000000TcaA09<lD@04000000L0
X5mo00<000000:QaT02XLI003@2XLI000`000000/8RV0;28YP0>0;28YP030000002dWkd0]9nm00/0
]9nm0P0000040;WTo`030000003Ii]L0fNKG00L0fNKG00<000000:R;Z02XRjP02@2XRjP00`000000
HC=H064cF008064cF0030000000c<c<0<c<c00T0<c<c0`00000:04Hc<`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0<P3oool001H0oooo00<000000?ooo`3oool04`3oool00`000000^Z77
0;ZQa`0;0;ZQa`@000002`2SQ[L00`000000XGJQ0:5fX@0;0:5fX@030000002NIH`0WVF<00X0WVF<
1000000909]GN@030000002HC6X0V4aZ00`0V4aZ00<0000009E4G@2EA5d02P2EA5d00`000000U3iE
09@nE@0909@nE@H000002`2PGgl00`000000Z76@0:QaT00=0:QaT0800000402`R:H00`000000]9nm
0;BO_@080;BO_@800000102ii?l2000000X0fNKG0`0000090:R;Z0030000001Q<eP0HC=H00T0HC=H
00<0000003<c<`0c<c<02@0c<c<00`000000<c<c0000000904Hc<`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0<@3oool001H0oooo00<000000?ooo`3oool0503oool00`000000^Z770;ZQ
a`060;ZQa`@000000P2SSl800`000000XhJg0:>6]`0;0:>6]`030000002QMZ40XGJQ00X0XGJQ00<0
000009iUS02NIH`02@2NIH`2000000d0VeMi00<0000009Q<JP2HC6X02`2HC6X00`000000UDAM09E4
G@0;09E4G@040000002D?UD0U3iE09@nE@L000000`2HDW@00`000000X5mo0:1OO`0<0:1OO`030000
002XLI00Z76@00d0Z76@00<000000;28YP2`R:H03P2`R:H00`000000]9nm0;BO_@050;BO_@<00000
1@2ii?l00`000000fNKG0=WVe`060=WVe`@0000000<0ZYFb0000001H<f400`0000070:R;Z0030000
001Q<eP0HC=H00P0HC=H00<0000003<c<`0c<c<02@0c<c<20000000303<c<`000000000000L0AS<c
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0`0?ooo`005P3oool00`000000oooo0?oo
o`0E0?ooo`040000002jXLL0^Z770;ZQa`@000001`2SSl800`000000XhJg0:>6]`0;0:>6]`030000
002QMZ40XGJQ00X0XGJQ00<0000009iUS02NIH`01@2NIH`300000080WVF<00<0000009]GN@2KEgT0
2P2KEgT00`000000V4aZ09Q<JP0<09Q<JP030000002EA5d0UDAM00@0UDAM2P00000;09QBM0030000
002PGgl0X5mo00/0X5mo00<000000:QaT02XLI003@2XLI0200000100/8RV00<000000;BO_@2dWkd0
0P2dWkd2000000H0^NCo0`0000040=WVe`@000001P2ZUK8010000000F3=Q05PcH@1H<f44000000<0
Z8^X00<00000064cF01Q<eP0201Q<eP00`000000<c<c03<c<`0903<c<`8000000`0c<c<00`000000
AS<c04Hc<`0504Hc<`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<03oool001D0oooo
00<000000?ooo`3oool05`3oool3000000`0Xho200<000000:>6]`2SQ[L02P2SQ[L00`000000XGJQ
0:5fX@0;0:5fX@040000002NIH`0WVF<09iUS0<000001@2NIH`00`000000VeMi09]GN@0;09]GN@03
0000002HC6X0V4aZ00P0V4aZ2P000006099<L@030000002HDW@0V59d00`0V59d00<000000:1OO`2P
Ggl0302PGgl00`000000Z76@0:QaT00=0:QaT0030000002`R:H0/8RV00h0/8RV00<000000;BO_@2d
Wkd00P0000070;WTo`040000003TomD0i?oE0>Coe@@000002P2ZUK800`000000F3=Q05PcH@0505Pc
H@<0000000<0Z8^X0000001Q<eP02@1Q<eP00`000000<c<c03<c<`0803<c<`030000000c<c<00000
00<0<c<c0P00000504Hc<`030000003oool0oooo01T0oooo00<000000?ooo`3oool0;`3oool001D0
oooo00<000000?ooo`3oool0603oool00`000000Xho20:>?`P0<0:>?`P030000002SQ[L0XhJg00X0
XhJg00<000000:5fX@2QMZ402P2QMZ44000000T0WVF<00<0000009]GN@2KEgT02P2KEgT00`000000
V4aZ09Q<JP0209Q<JPH00000102?C7@=099<L@030000002HDW@0V59d00`0V59d00<000000:1OO`2P
Ggl02`2PGgl00`000000Z76@0:QaT00=0:QaT08000003`2`R:H3000000L0^NCo0P0000040>Coe@03
0000003PlMH0000000`0ZYFb00<0000005PcH@1H<f401`1H<f42000000X0HC=H00<0000003<c<`0c
<c<02@0c<c<00`000000<c<c0000000403<c<`0300000016<c<0AS<c0080AS<c00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0^0?ooo`005@3oool00`000000oooo0?ooo`0I0?ooo`800000
3@2SSl800`000000XhJg0:>6]`0:0:>6]`030000002QMZ40XGJQ00L0XGJQ1000000;09iUS0030000
002KEgT0VeMi00D0VeMi2P00000:08m<M0030000002BC740TTaa00X0TTaa00<0000009QBM02HDW@0
302HDW@00`000000X5mo0:1OO`0<0:1OO`030000002XLI00Z76@00d0Z76@00<000000;28YP2`R:H0
2P2`R:H3000000<0`=Ko100000020;WTo`800000103TomD010000000h?7F0>3aeP3PlMH<0:ZE/P03
0000001H<f40F3=Q00P0F3=Q0`000008064cF0030000000c<c<0<c<c00T0<c<c00<0000003<c<`00
00001@0c<c<200000080AS<c00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0^0?ooo`00
5@3oool00`000000oooo0?ooo`0K0?ooo`030000002SSl80Xho200/0Xho200<000000:>6]`2SQ[L0
2P2SQ[L00`000000XGJQ0:5fX@030:5fX@<000000`2QMZ400`000000WVF<09iUS00509iUS0`00000
1`2=D7h00`000000Sdad08m<M00;08m<M0d0TTaa00<0000009QBM02HDW@0302HDW@00`000000X5mo
0:1OO`0;0:1OO`8000003P2XLI02000000P0/8RV0`00000:0<3Fo`800000103TomD2000000@0h?7F
00<000000:ZE/P2ZUK802@2ZUK800`000000F3=Q05PcH@0905PcH@030000000c<c<0000000P0HC=H
00<0000003<c<`0c<c<0200c<c<010000000<c<c03<c<`00000603<c<`0400000016<c<0AS<c0000
01`0oooo00<000000?ooo`3oool0;@3oool001D0oooo00<000000?ooo`3oool0703oool00`000000
Xho20:>?`P0;0:>?`P030000002SQ[L0XhJg00T0XhJg00<000000:5fX@2QMZ400`0000020:5fX@`0
00001P2<FH`00`000000SE1n08e@OP0:08e@OP030000002?C7@0Sdad00/0Sdad00<00000099<L@2B
C7402P2BC7400`000000V59d09QBM00<09QBM0030000002PGgl0X5mo00`0X5mo00<000000:QaT02X
LI003@2XLI000`000000/8RV0;28YP030;28YP<000003030e_l2000000@0i?oE00<000000>3aeP3P
lMH01@3PlMH00`000000ZYFb0:ZE/P090:ZE/P030000001H<f40F3=Q00P0F3=Q00@0000003<c<`0c
<c<000001`1Q<eP00`000000<c<c03<c<`0903<c<`040000000c<c<0<c<c000000H0<c<c0`00000L
0?ooo`030000003oool0oooo02d0oooo000E0?ooo`030000003oool0oooo01d0oooo0P00000<0:>?
`P030000002SQ[L0XhJg00@0XhJg3000000608aUWP030000002<FH`0S5V<00T0S5V<00<0000008e@
OP2=D7h02`2=D7h00`000000Sdad08m<M00;08m<M0d0TTaa00<0000009QBM02HDW@02`2HDW@20000
00d0X5mo0P00000>0:QaT080000000@0/8RV00000000000000003@30e_l3000000@0i?oE00<00000
0>3aeP3PlMH01`3PlMH00`000000ZYFb0:ZE/P080:ZE/P030000001H<f40F3=Q00P0F3=Q00@00000
03<c<`0c<c<0<c<c0P000005064cF0030000000c<c<0<c<c00T0<c<c00D0000003<c<`0c<c<0<c<c
0000000703<c<`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;03oool001@0oooo00<0
00000?ooo`3oool0803oool00`000000Xho20:>?`P050:>?`P/000000P2<M;830000000308ad/P00
0000S6FN00X0S6FN00<0000008aIS02<FH`02P2<FH`00`000000SE1n08e@OP0:08e@OP030000002?
C7@0Sdad00/0Sdad00<00000099<L@2BC7402P2BC7400`000000V59d09QBM00<09QBM0030000002P
Ggl0X5mo00`0X5mo00<000000:QaT02XLI00302XLI03000000h0`=Ko0P0000000`3NomD000000>Co
e@030>Coe@030000003PlMH0h?7F00P0h?7F00<000000:ZE/P2ZUK802@2ZUK800`000000F3=Q05Pc
H@0805PcH@030000000c<c<0<c<c0080<c<c00<00000064cF01Q<eP00P1Q<eP00`000000<c<c03<c
<`0903<c<`050000000c<c<0<c<c03<c<`0000001`0c<c<00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo02/0oooo000D0?ooo`030000003oool0oooo0240oooo1`00000608al_0040000002<
M;80S7Bb08ad/P<00000102<M;800`000000S6FN08aUWP0:08aUWP030000002<FH`0S5V<00T0S5V<
00<0000008e@OP2=D7h02`2=D7h00`000000Sdad08m<M00;08m<M0d0TTaa00<0000009QBM02HDW@0
2`2HDW@00`000000X5mo0:1OO`0<0:1OO`8000002@2XLI0400000080_kOJ0P00000;0<3Fo`0503<c
<`00000000000=koe@000000103TomD00`000000h?7F0>3aeP0:0>3aeP030000002ZUK80ZYFb00P0
ZYFb00<0000005PcH@1H<f40201H<f400`000000<c<c03<c<`0303<c<`8000000`1Q<eP00`000000
<c<c03<c<`0803<c<`030000000c<c<0<c<c0080<c<c00<0000003<c<`0c<c<01@0c<c<00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo02/0oooo000D0?ooo`030000003oool0oooo0280oooo
00<0000008al_02<O;`02P2<O;`3000000P0S7Bb00<0000008aUWP2<IIh02@2<IIh00`000000S5V<
08aIS00:08aIS0030000002=D7h0SE1n00X0SE1n00<0000008m<M02?C7@02`2?C7@00`000000TTaa
099<L@0:099<L@030000002HDW@0V59d00`0V59d00<000000:1OO`2PGgl0302PGgl00`000000Z76@
0:QaT0040:QaT0<00000202o]mX2000000P0`=Ko0`0000000`3NomD000000>Coe@020>Coe@800000
3@3PlMH3000000P0ZYFb00<0000005PcH@1H<f40201H<f400`000000<c<c03<c<`0503<c<`040000
001Q<eP0HC=H000000/0<c<c00<0000003<c<`0c<c<00P0c<c<00`000000<c<c03<c<`0403<c<`03
0000003oool0oooo01/0oooo0P00000/0?ooo`00503oool00`000000oooo0?ooo`0S0?ooo`030000
002<O;`0S7bl00H0S7bl1000000;08ad/P030000002<IIh0S6FN00T0S6FN00<0000008aIS02<FH`0
2@2<FH`00`000000SE1n08e@OP0;08e@OP030000002?C7@0Sdad00/0Sdad3@2BC7400`000000V59d
09QBM00;09QBM0030000002PGgl0X5mo00`0X5mo0P0000000`2XLI00000000000002000000`0_kOJ
0P0000050<3Fo`@0000000<0g_oE0000003TomD00P3TomD00`000000h?7F0>3aeP090>3aeP@00000
00<0^[710000001N=GL00`0000060:ZE/P030000001H<f40F3=Q00L0F3=Q00<0000003<c<`0c<c<0
1P0c<c<00`000000HC=H0000000;03<c<`030000000c<c<0<c<c0080<c<c00<0000003<c<`0c<c<0
100c<c<00`000000oooo0?ooo`0G0?ooo`@0000000<0oooo0000003oool0:`3oool001@0oooo00<0
00000?ooo`3oool0903oool00`000000S7bl08al_00208al_0<00000102<O;`00`000000S7Bb08ad
/P0908ad/P030000002<IIh0S6FN00T0S6FN00<0000008aIS02<FH`02@2<FH`00`000000SE1n08e@
OP0:08e@OP030000002?C7@0Sdad00/0Sdad00<00000099<L@2BC7402P2BC7400`000000V59d09QB
M00<09QBM0030000002PGgl0X5mo00X0X5mo1000000B0;ngfP80000000<0`=Ko0000000000000`00
00020=koe@030000003TomD0000000@000001@3PlMH4000000H0^[7100@0000005heM`1N=GL0GSEg
0`0000030:ZE/P030000001H<f40F3=Q00P0F3=Q00<0000003<c<`0c<c<01P0c<c<3000000X0<c<c
00<0000003<c<`0c<c<00`0c<c<00`000000<c<c03<c<`0303<c<`030000003oool0oooo01@0oooo
0`0000050?ooo`030000003oool0oooo02X0oooo000D0?ooo`030000003oool0oooo02D0oooo1000
000808al_0030000002<M;80S7Bb00P0S7Bb00<0000008aUWP2<IIh02@2<IIh00`000000S5V<08aI
S00:08aIS0030000002=D7h0SE1n00X0SE1n00<0000008m<M02?C7@02`2?C7@=099<L@030000002H
DW@0V59d00/0V59d00<000000:1OO`2PGgl01@2PGgl5000000<0]iVi00<000000;ngfP2o]mX04P2o
]mX6000000030=koe@0000000000008000000`3ZoLP6000000X0^[7100<0000005heM`1N=GL0101N
=GL3000000030:ZE/P000000F3=Q00P0F3=Q00<0000003<c<`0c<c<0200c<c<00`000000<c<c03<c
<`0903<c<`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<00`0c<c<00`000000oooo0?oo
o`0@0?ooo`<00000203oool00`000000oooo0?ooo`0Z0?ooo`004`3oool00`000000oooo0?ooo`0U
0?ooo`@000002P2<O;`00`000000S7Bb08ad/P0808ad/P030000002<IIh0S6FN00T0S6FN00<00000
08aIS02<FH`02@2<FH`00`000000SE1n08e@OP0:08e@OP030000002?C7@0Sdad00/0Sdad00<00000
099<L@2BC7402P2BC7400`000000V59d09QBM00<09QBM0030000002PGgl0X5mo00D00000202gVKT0
0`000000_kOJ0;ngfP0?0;ngfP80000000H0b_om000000000000f_oJ0000003NomD200000080i_k8
00<000000>[mb03ZoLP00`3ZoLP00`000000j_S>0000000<0;Za`@030000001N=GL0GSEg00H0GSEg
0P00000905PcH@030000000c<c<0<c<c00P0<c<c0P00000:03<c<`030000000c<c<0<c<c00<0<c<c
00<0000003<c<`0c<c<00`0c<c<00`000000oooo0?ooo`0<0?ooo`@00000303oool00`000000oooo
0?ooo`0Y0?ooo`004`3oool00`000000oooo0?ooo`0R0?ooo`<00000103oool00`000000S7bl08al
_00808al_0030000002<M;80S7Bb00P0S7Bb00<0000008aUWP2<IIh02@2<IIh00`000000S5V<08aI
S00908aIS0030000002=D7h0SE1n00X0SE1n00<0000008m<M02?C7@02`2?C7@=099<L@030000002H
DW@0V59d00P0V59d1P00000>0;NI^@030000002o]mX0_kOJ00`0_kOJ0P000000203:ood000000000
00000000f_oJ0000003NomD000000`3Vo/P00`000000j_g80>[mb0030>[mb0050000003Zn<h0j_S>
0>[hcP0000002`2j/L400`000000GSEg05heM`0705heM`8000002@1H<f400`000000<c<c03<c<`08
03<c<`<00000200c<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c0080<c<c00<00000
0?ooo`3oool02@3oool300000100oooo00<000000?ooo`3oool0:@3oool001<0oooo00<000000?oo
o`3oool07`3oool3000000P0oooo00<0000008al_02<O;`01`2<O;`00`000000S7Bb08ad/P0908ad
/P030000002<IIh0S6FN00P0S6FN00<0000008aIS02<FH`02@2<FH`00`000000SE1n08e@OP0:08e@
OP030000002?C7@0Sdad00/0Sdad00<00000099<L@2BC7402P2BC7400`000000V59d09QBM00209QB
M0H00000102ZNil00`000000]iVi0;NI^@0>0;NI^@030000002o]mX0_kOJ00T0_kOJ0P0000020<[o
o@060000003<oNl000000=[ofP000000g_oE0P0000020>Knb0030000003ZoLP0j_g800<0j_g800<0
00000>[hcP3Zn<h00`3Zn<h<0;Za`@030000001N=GL0GSEg00L0GSEg0P00000805PcH@030000000c
<c<0<c<c00P0<c<c00@0000003<c<`0c<c<000001`0c<c<00`000000<c<c03<c<`0503<c<`030000
000c<c<0<c<c0080<c<c00<000000?ooo`3oool01@3oool3000001<0oooo00<000000?ooo`3oool0
:@3oool001<0oooo00<000000?ooo`3oool0703oool3000000`0oooo1P00000408al_0030000002<
M;80S7Bb00P0S7Bb00<0000008aUWP2<IIh02@2<IIh00`000000S5V<08aIS00908aIS0030000002=
D7h0SE1n00X0SE1n00<0000008m<M02?C7@02`2?C7@7099<L@X000002`2ZNil00`000000]iVi0;NI
^@0>0;NI^@030000002o]mX0_kOJ00D0_kOJ0`0000030<[oo@P000000`3Vo/P00`000000j_g80>[m
b0020>[mb0030000003Zn<h0j_S>00@0j_S>00<000000;Za`@2j/L402@2j/L400`000000GSEg05he
M`0705heM`040000000c<c<00000000000H0F3=Q00<0000003<c<`0c<c<0200c<c<01@000000<c<c
03<c<`0c<c<0000000L0<c<c00<0000003<c<`0c<c<01@0c<c<01@000000<c<c03<c<`0c<c<00000
00<0oooo1000000F0?ooo`030000003oool0oooo02T0oooo000C0?ooo`030000003oool0oooo01T0
oooo0`00000@0?ooo`030000001fJKD0MVVe0080MVVe5`00000408aUWP030000002<FH`0S5V<00T0
S5V<00<0000008e@OP2=D7h02P2=D7h00`000000Sdad08m<M00508m<M0d000001`2KI8d00`000000
ZW^O0:YkW`0;0:YkW`030000002gVKT0]iVi00l0]iVi00<000000;ngfP2o]mX00P2o]mX3000000<0
b_om1@000000103JomX000000>GocP0000030>Knb0030000003ZoLP0j_g80080j_g800<000000>[h
cP3Zn<h01P3Zn<h00`000000^[710;Za`@090;Za`@030000001N=GL0GSEg00H0GSEg00D0000003<c
<`0c<c<0<c<c0000000605PcH@030000000c<c<0<c<c00L0<c<c00<0000003<c<`0c<c<00P0c<c<0
0`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c00D0<c<c00@0000003<c<`0c<c<0<c<c1000
000J0?ooo`030000003oool0oooo02T0oooo000C0?ooo`030000003oool0oooo01L0oooo0P00000D
0?ooo`030000001fJKD0MVVe00L0MVVe00<0000007MS[01gHj`0201gHj`00`000000NENK07UGV`02
07UGVbH000001`2>EH@00`000000VfB=09]TS@0:09]TS@030000002ZNil0ZW^O00`0ZW^O00<00000
0;NI^@2gVKT03`2gVKT00`000000_kOJ00000002000000@0b_om0P0000001@3Fond000000000003J
omX000000080iOo>00@000000>Knb03Vo/P00000103ZoLP00`000000j_S>0>[hcP080>[hcP800000
2@2j/L400`000000GSEg05heM`0705heM`050000000c<c<0<c<c03<c<`0000001@1H<f400`000000
<c<c03<c<`0803<c<`030000000c<c<0<c<c0080<c<c0P00000403<c<`030000000c<c<0<c<c00H0
<c<c00@0000003<c<`0c<c<000007@3oool00`000000oooo0?ooo`0Y0?ooo`004P3oool00`000000
oooo0?ooo`0E0?ooo`<000005`3oool2000000P0MVVe00<0000007MS[01gHj`01`1gHj`00`000000
NENK07UGV`0907UGV`030000001nD8d0OU2=00T0OU2=00<0000008A?Q024Ch@02P24Ch@00`000000
SUF408iEQ00:08iEQ0030000002KI8d0VfB=00/0VfB=00<000000:YkW`2ZNil0302ZNil00`000000
]iVi0;NI^@0>0;NI^@T000000P3Fond2000000050=[ofP000000iOo>0>GocP0000000P3Vo/P20000
00@0j_g800<000000>[hcP3Zn<h01P3Zn<h2000000030=?Cb`0000000000008000001`2j/L400`00
0000GSEg05heM`0605heM`030000000c<c<0<c<c0080<c<c00<0000005PcH@1H<f400P1H<f400`00
0000<c<c03<c<`0803<c<`030000000c<c<0<c<c00@0<c<c00<0000003<c<`0c<c<00P0c<c<00`00
0000<c<c03<c<`0603<c<`040000000c<c<0<c<c000001`0oooo00<000000?ooo`3oool0:@3oool0
0180oooo00<000000?ooo`3oool04P3oool3000001`0oooo00<0000007IY]@1fJKD01P1fJKD00`00
0000Mf>/07MS[00707MS[0030000001iEi/0NENK00P0NENK00<0000007i@S@1nD8d02@1nD8d00`00
0000Q4n408A?Q00:08A?Q0030000002>EH@0SUF400/0SUF400<0000009]TS@2KI8d02P2KI8d00`00
0000ZW^O0:YkW`0=0:YkW`030000002gVKT0]iVi00X0]iVi0`0000060<gYoP8000000P3Fond20000
00050=[ofP000000iOo>0>GocP0000000`3Vo/P00`000000j_g80>[mb0020>[mb0030000003Zn<h0
j_S>00H0j_S>00D000000=?Cb`3Cdl/0dm?;0000000307MMU`@000000`2j/L400`000000GSEg05he
M`0605heM`030000000c<c<0<c<c00<0<c<c00D0000005PcH@1H<f40F3=Q0000000:03<c<`030000
000c<c<0<c<c00D0<c<c00D0000003<c<`0c<c<0<c<c0000000803<c<`040000000c<c<0<c<c0000
01d0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3oool03`3oool300000200
oooo00<0000007IY]@1fJKD01P1fJKD00`000000Mf>/07MS[00707MS[0030000001iEi/0NENK00P0
NENK00<0000007i@S@1nD8d02@1nD8d00`000000Q4n408A?Q00:08A?Q0030000002>EH@0SUF400X0
SUF400<0000009]TS@2KI8d02`2KI8d00`000000ZW^O0:YkW`0=0:YkW`030000002gVKT0]iVi00L0
]iVi0P0000080<gYoP040000003Fond0e_o]0=Kok@D000000P3Uolh010000000i_k80>Knb0000004
0>[mb0030000003Zn<h0j_S>00D0j_S>0P0000050=?Cb`030000001gGIL0MefG00@0MefG0`000000
0`2j/L40000005heM`0705heM`030000000c<c<0<c<c00<0<c<c00D0000005PcH@1H<f40F3=Q0000
000903<c<`030000000c<c<0<c<c00H0<c<c00@0000003<c<`0c<c<000002@0c<c<00`000000<c<c
0000000M0?ooo`030000003oool0oooo02P0oooo000B0?ooo`030000003oool0oooo00`0oooo0`00
000T0?ooo`030000001fJKD0MVVe00D0MVVe00<0000007MS[01gHj`0201gHj`00`000000NENK07UG
V`0807UGV`030000001nD8d0OU2=00P0OU2=00<0000008A?Q024Ch@02P24Ch@00`000000SUF408iE
Q00;08iEQ0030000002KI8d0VfB=00X0VfB=0P00000>0:YkW`030000002gVKT0]iVi00@0]iVi0`00
00080<gYoP8000000P3Fond2000000040=Soi0000000i?oH00000080iOo>00@000000>Knb03Vo/P0
0000103ZoLP00`000000j_S>0>[hcP040>[hcP8000001`3Cdl/00`000000MefG07MMU`0707MMU`80
0000201N=GL00`000000<c<c03<c<`0403<c<`80000000<0F3=Q0000000c<c<02@0c<c<00`000000
<c<c03<c<`0603<c<`<000002P0c<c<00`000000<c<c0000000L0?ooo`030000003oool0oooo02P0
oooo000B0?ooo`030000003oool0oooo00T0oooo0`00000X0?ooo`8000001P1fJKD00`000000Mf>/
07MS[00707MS[0030000001iEi/0NENK00P0NENK00<0000007i@S@1nD8d02@1nD8d00`000000Q4n4
08A?Q00:08A?Q0030000002>EH@0SUF400X0SUF400<0000009]TS@2KI8d02`2KI8d00`000000ZW^O
0:YkW`0=0:YkW`030000002gVKT0]iVi00<000002P3=jOh01@000000e_o]0=Kok@3Fond000000080
f?oT00<000000>Cof00000000P3Uolh01@000000i_k80>Knb03Vo/P0000000<0j_g800<000000>[h
cP3Zn<h0103Zn<h00`000000dm?;0=?Cb`080=?Cb`030000001gGIL0MefG00L0MefG0P00000705he
M`030000000c<c<0<c<c00H0<c<c0P00000:03<c<`030000000c<c<0<c<c00P0<c<c0P00000903<c
<`030000000c<c<0000001`0oooo00<000000?ooo`3oool0:03oool00180oooo00<000000?ooo`3o
ool01P3oool3000002`0oooo1@00000307IY]@030000001gHj`0Mf>/00L0Mf>/00<0000007UGV`1i
Ei/0201iEi/00`000000OU2=07i@S@0907i@S@0300000024Ch@0Q4n400X0Q4n400<0000008iEQ02>
EH@02P2>EH@00`000000VfB=09]TS@0;09]TS@030000002ZNil0ZW^O00`0ZW^O0`00000;0<gYoP80
00000`3Fond01P000000f?oT0=Soi0000000i?oH000000<0iOo>00@000000>Knb03Vo/P000000`3Z
oLP00`000000j_S>0>[hcP030>[hcP8000002`3Cdl/00`000000MefG07MMU`0807MMU`8000001`1N
=GL00`000000<c<c03<c<`0603<c<`8000002@0c<c<00`000000<c<c03<c<`0903<c<`030000000c
<c<0<c<c00P0<c<c0P00000L0?ooo`030000003oool0oooo02P0oooo000A0?ooo`030000003oool0
oooo00D0oooo0P00000`0?ooo`040000001QF:h0HER^065H[PD000002@1gHj`00`000000NENK07UG
V`0807UGV`030000001nD8d0OU2=00P0OU2=00<0000008A?Q024Ch@02P24Ch@00`000000SUF408iE
Q00:08iEQ0030000002KI8d0VfB=00/0VfB=00<000000:YkW`2ZNil0202ZNil400000080a;3=0P00
00080<gYoP800000103Fond010000000f?oT0000000000020>Cof0040000003Uolh0iOo>00000080
i_k800<000000>[mb03ZoLP02@00000=0=?Cb`030000001gGIL0MefG00L0MefG00<0000003<cAP00
00001P1N=GL00`000000<c<c03<c<`0703<c<`030000000c<c<0<c<c00L0<c<c00<0000003<c<`0c
<c<02@0c<c<3000000T0<c<c00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0X0?ooo`00
4@3oool00`000000oooo0?ooo`020?ooo`<00000<`3oool2000000D0HER^1000000707MS[0030000
001iEi/0NENK00L0NENK00<0000007i@S@1nD8d02@1nD8d00`000000Q4n408A?Q00:08A?Q0030000
002>EH@0SUF400X0SUF400<0000009]TS@2KI8d02`2KI8d00`000000ZW^O0:YkW`040:YkW`<00000
2034/<d2000000D0cNWn00<000000<gYoP3Fond00`3Fond400000080i?oH00@000000>GocP3Uolh0
00000`3Vo/P4000000D0k_Vg00<000000>oh^`0000000P00000;0=?Cb`030000001gGIL0MefG00L0
MefG00@0000003<cAP0c<dH000001@1N=GL00`000000<c<c03<c<`0703<c<`8000002@0c<c<00`00
0000<c<c03<c<`0903<c<`030000000c<c<0000000T0<c<c00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0X0?ooo`004@3oool00`000000oooo00000002000003P0oooo00<00000065H[P1Q
F:h0101QF:h00`000000He>V000000050000000307MS[0000000NENK00T0NENK00<0000007i@S@1n
D8d02@1nD8d00`000000Q4n408A?Q00:08A?Q0030000002>EH@0SUF400T0SUF400<0000009]TS@2K
I8d02`2KI8d00`000000ZW^O0:YkW`04000000d0a;3=0P0000000`3=jOh00000000000050=Kok@80
000000D0h_oR0000003TomP0i?oH000000030>GocP030000003Vo/P0i_k8008000000P3]n[X00`00
0000k_Vg0>ki]`030>ki]`040000003_n;/0koRk0>oh^`<000002P3Cdl/00`000000MefG07MMU`07
07MMU`040000000c<dH0<c=6000000D0GSEg00<0000003<c<`0c<c<01`0c<c<2000000P0<c<c00<0
000003<c<`0c<c<02@0c<c<00`000000<c<c03<c<`02000000L0<c<c00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo000A0?ooo`800000?03oool0
0`000000HER^065H[P04065H[P030000001SDjH0He>V00@0He>V1P00000707UGV`030000001nD8d0
OU2=00P0OU2=00<0000008A?Q024Ch@02P24Ch@00`000000SUF408iEQ00:08iEQ0030000002KI8d0
VfB=00P0VfB=1@00000C0<B`c@030000003=jOh0000000D000000`3Ron800`000000i?oH00000003
0>GocP040000003Vo/P00000000000<0kOZj00<000000>ki]`3^nKL00`3^nKL00`000000koRk0>oh
^`040>oh^`L00000103Cdl/00`000000MefG07MMU`0707MMU`040000000c<dH0<c=603<cAP800000
0`1N=GL00`000000<c<c03<c<`0703<c<`030000000c<c<0000000L0<c<c00<0000003<c<`0c<c<0
2@0c<c<00`000000<c<c03<c<`0203<c<`030000000c<c<0<c<c00@0<c<c0P00000?0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00180oooo00<000000?ooo`3oool0>`3o
ool00`000000HER^065H[P04065H[P030000001SDjH0He>V00H0He>V00<0000006Y<V00000001P00
00000`1iEi/0000007i@S@0:07i@S@0300000024Ch@0Q4n400X0Q4n400<0000008iEQ02>EH@02@2>
EH@00`000000VfB=09]TS@0209]TS@H00000102`RZh00`000000a;3=0<B`c@0?0<B`c@8000001P3L
onl01@000000h_oR0>;ohP3Ron8000000080i?oH00P000000>GocP3Uolh000000>Knb0000000k__1
000000<0kOZj00<000000>ki]`3^nKL00P3^nKL00`000000koRk0>oh^`050>oh^`030000003`mkl0
000000@0_[S41P00000807MMU`030000000c<dH0<c=600<0<c=600@0000005heM`1N=GL000002@0c
<c<010000000<c<c03<c<`00000703<c<`030000000c<c<0<c<c00P0<c<c00<0000003<c<`0c<c<0
0`0c<c<2000000D0<c<c0P00000=0?ooo`8000002`3oool00`000000oooo0?ooo`0W0?ooo`004`3o
ool2000003`0oooo0P000005065H[P030000001SDjH0He>V00H0He>V00<0000006Y<V01ZC9P0101Z
C9P:000000@0OU2=00<0000008A?Q024Ch@02P24Ch@00`000000SUF408iEQ00508iEQ0T000002`2`
RZh00`000000a;3=0<B`c@0<0<B`c@8000001P3Lonl2000000<0h_oR00@000000>Cof03TomP00000
0`3Uolh2000000030>kk`@000000kOZj0080kOZj00<000000>ki]`3^nKL00`3^nKL00`000000koRk
0>oh^`040>oh^`040000003`mkl0l?No000000T0_[S40P00000807MMU`030000000c<dH0<c=600<0
<c=600@0000005heM`1N=GL00000200c<c<01@000000<c<c03<c<`0c<c<0000000H0<c<c00<00000
03<c<`0c<c<02@0c<c<00`000000<c<c03<c<`0403<c<`030000000c<c<0<c<c0080<c<c0P00000=
0?ooo`8000002`3oool00`000000oooo0?ooo`0W0?ooo`005@3oool00`000000oooo0?ooo`0j0?oo
o`@000000`1QF:h00`000000He>V06=CYP0506=CYP030000001ZC9P0JTbH00P0JTbH00<0000007A<
S`1dC8l00P1dC8lJ000000H0VFZI00<000000;2:[P2`RZh0302`RZh2000000X0a;3=0P0000070=co
k`030000003Ron80h_oR0080h_oR00@000000>Cof03TomP000000`3Uolh010000000k__10>kk`@00
00030>gj^P030000003^nKL0k_Vg00<0k_Vg00<000000>oh^`3_n;/0103_n;/00`000000l?No0?3g
_`020?3g_`030000002n^<@0_[S400L0_[S40`00000607MMU`030000000c<dH0<c=600@0<c=600<0
000005heM`0000002@0c<c<010000000<c<c03<c<`0c<c<2000000@0<c<c00<0000003<c<`0c<c<0
2@0c<c<00`000000<c<c03<c<`0503<c<`8000000P0c<c<00`000000oooo0000000;0?ooo`800000
303oool00`000000oooo0?ooo`0W0?ooo`005P3oool00`000000oooo0?ooo`0j0?ooo`030000001>
BJH0CTVV008000000P1QF:h00`000000He>V06=CYP0506=CYP030000001ZC9P0JTbH00L0JTbH00<0
000007A<S`1dC8l02@1dC8l00`000000Q5F>08AESP0:08AESP030000002IJYT0VFZI00X0VFZI00<0
00000;2:[P2`RZh0302`RZh2000000L0a;3=0P0000080=cok`030000003Ron80h_oR0080h_oR00@0
00000>Cof03TomP000000P3Uolh2000000<0k__100D000000>gj^P3]n[X0kOZj000000040>ki]`03
0000003_n;/0koRk00@0koRk00<000000?3g_`3`mkl0103`mkl00`000000_[S40;jha0060;jha004
0000001A<gh0DC=n000000H0MefG00<0000003<cAP0c<dH0100c<dH2000000T0<c<c00<0000003<c
<`0c<c<00P0c<c<2000000<0<c<c00<0000003<c<`0c<c<02@0c<c<00`000000<c<c03<c<`0703<c
<`030000000c<c<000000080oooo00<000000?ooo`3oool0203oool2000000`0oooo00<000000?oo
o`3oool09`3oool001L0oooo0P00000k0?ooo`8000000P1>BJH4000000L0He>V00<0000006Y<V01Z
C9P01`1ZC9P00`000000M4b?07A<S`0807A<S`0300000024EHh0Q5F>00X0Q5F>00<0000009UZV@2I
JYT02P2IJYT00`000000/8Z^0;2:[P0>0;2:[P0300000034/<d0a;3=0080a;3=0P0000080=cok`80
0000103Ron8010000000i?oH0>Cof03TomP3000000050>omc0000000k__10>kk`@0000000`3]n[X0
0`000000k_Vg0>ki]`020>ki]`8000001@3_n;/00`000000l?No0?3g_`060?3g_`030000002n^<@0
_[S400H0_[S400@00000054cOP1A<gh000001@1gGIL00`000000<c=603<cAP0503<cAP800000200c
<c<00`000000<c<c03<c<`0403<c<`050000000c<c<0<c<c03<c<`0000002`0c<c<00`000000<c<c
03<c<`0703<c<`<0000000<0oooo0000003oool02@3oool2000000`0oooo00<000000?ooo`3oool0
9`3oool001T0oooo00<000000?ooo`3oool0>P3oool00`000000CTVV04i9YP0204i9YP<000001P1S
DjH00`000000JTbH06Y<V00706Y<V0030000001dC8l0M4b?00P0M4b?00<0000008AESP24EHh02P24
EHh00`000000VFZI09UZV@0:09UZV@030000002`RZh0/8Z^00h0/8Z^00@000000<B`c@0000000000
2@3Lonl00`000000h_oR0>;ohP030>;ohP040000003TomP0i?oH0>Cof08000000P3_oL`01@000000
k__10>kk`@3^nl4000000080kOZj0P0000040>ki]`030000003_n;/0koRk00<0koRk00<000000?3g
_`3`mkl01`3`mkl00`000000_[S40;jha0060;jha0040000001A<gh0DC=n054cOP8000000`1gGIL0
0`000000<c=603<cAP0603<cAP030000000c<c<0<c<c00L0<c<c00<0000003<c<`0c<c<0100c<c<0
10000000<c<c03<c<`00000;03<c<`030000000c<c<0<c<c00T0<c<c00@000000?ooo`3oool00000
203oool00`000000<c<c0000000=0?ooo`030000003oool0oooo02H0oooo000J0?ooo`030000003o
ool0oooo03X0oooo00<0000004i9YP1>BJH00`1>BJH4000000@0He>V00<0000006Y<V01ZC9P01`1Z
C9P00`000000M4b?07A<S`0807A<S`0300000024EHh0Q5F>00X0Q5F>00<0000009UZV@2IJYT02P2I
JYT00`000000/8Z^0;2:[P0=0;2:[P<000002@3Lonl00`000000h_oR0>;ohP040>;ohP040000003T
omP0i?oH000000<0kog<00D000000>kk`@3^nl40k__1000000030>gj^P030000003^nKL0k_Vg0080
k_Vg00<000000>oh^`3_n;/00`3_n;/00`000000l?No0?3g_`090?3g_`030000002n^<@0_[S400H0
_[S400<00000054cOP1A<gh00P1A<gh01@000000MefG07MMU`1gGIL0000000L0<c=60P00000803<c
<`030000000c<c<0<c<c00D0<c<c00<0000003<c<`0000002`0c<c<00`000000<c<c03<c<`0903<c
<`050000003oool0oooo0?ooo`0000001`3oool00`000000<c<c0000000=0?ooo`030000003oool0
oooo02H0oooo000K0?ooo`030000003oool0oooo03X0oooo00<0000004i9YP1>BJH00`1>BJH00`00
0000DTJP0596X00200000080He>V00<0000006Y<V01ZC9P01`1ZC9P00`000000M4b?07A<S`0807A<
S`0300000024EHh0Q5F>00X0Q5F>00<0000009UZV@2IJYT02`2IJYT00`000000/8Z^0;2:[P0:0;2:
[P8000000`3?^Ll2000000D0g?o_0P0000060>;ohP040000003TomP00000000000@0kog<00@00000
0>kk`@3^nl4000000`3]n[X00`000000k_Vg0>ki]`020>ki]`030000003_n;/0koRk00<0koRk00<0
00000?3g_`3`mkl0203`mkl2000000030?ooo`000000000000H0_[S400<00000054cOP1A<gh00`1A
<gh010000000MefG07MMU`00000803<cAP8000001`0c<c<00`000000<c<c03<c<`0603<c<`800000
2`0c<c<00`000000<c<c03<c<`0:03<c<`050000003oool0oooo0?ooo`0000001@3oool010000000
<c<c03<c<`00000=0?ooo`030000003oool0oooo02H0oooo000L0?ooo`800000>`3oool00`000000
CTVV04i9YP0304i9YP040000001BAZ00DTJP0596X0@000002@1ZC9P00`000000M4b?07A<S`0807A<
S`0300000024EHh0Q5F>00X0Q5F>00<0000009UZV@2IJYT02`2IJYT00`000000/8Z^0;2:[P060;2:
[P<000001`3?^Ll200000080g?o_00<000000=cok`3Ron801@3Ron84000000@0kog<00D000000>kk
`@3^nl40k__1000000030>gj^P030000003^nKL0k_Vg0080k_Vg00<000000>oh^`3_n;/00P3_n;/0
0`000000l?No0?3g_`070?3g_`H0000000<0oooo0000002n^<@0102n^<@00`000000DC=n054cOP04
054cOP<00000200c<dH00`000000<c<c0000000603<c<`030000000c<c<0<c<c00L0<c<c0P00000;
03<c<`030000000c<c<0<c<c00T0<c<c00D000000?ooo`3oool0oooo000000050?ooo`040000000c
<c<0<c<c000000d0oooo00<000000?ooo`3oool09P3oool001h0oooo00<000000?ooo`3oool0>@3o
ool2000000@0CTVV00<000000596X01BAZ000`1BAZ04000000L0JTbH00<0000007A<S`1dC8l0201d
C8l00`000000Q5F>08AESP0908AESP030000002IJYT0VFZI00/0VFZI00<000000;2:[P2`RZh00`2`
RZh3000000`0ckW?2`0000020>goeP050000003_oL`0kog<0>omc00000000`3^nl401@000000kOZj
0>gj^P3]n[X0000000@0k_Vg00<000000>oh^`3_n;/00P3_n;/00`000000l?No0?3g_`060?3g_`@0
00001P3oool2000000@0_[S400<00000054cOP1A<gh01@1A<gh2000000L0<c=600@0000003<c<`0c
<c<000001P0c<c<00`000000<c<c03<c<`0703<c<`030000000c<c<0<c<c00T0<c<c00<0000003<c
<`0c<c<02P0c<c<01@000000oooo0?ooo`3oool0000000@0oooo00<0000003<c<`0000003P3oool0
0`000000oooo0?ooo`0V0?ooo`007`3oool00`000000oooo0?ooo`0i0?ooo`<000000P1>BJH00`00
0000DTJP0596X0050596X0H00000101ZC9P00`000000M4b?07A<S`0707A<S`0300000024EHh0Q5F>
00X0Q5F>00<0000009UZV@2IJYT02`2IJYT00`000000/8Z^0;2:[P02000000h0ckW?0P0000070>oo
g0050000003]omH0kOoF0>goeP0000000`3_oL`01@3^nl4000000>kk`@3^nl40000000<0kOZj00<0
00000>ki]`3^nKL00P3^nKL00`000000koRk0>oh^`020>oh^`030000003`mkl0l?No00D0l?No0`00
000;0?ooo`050000002n^<@0_[S40;jha0000000201A<gh00`000000<c=603<cAP0503<cAP050000
000c<c<0<c<c03<c<`0000001@0c<c<00`000000<c<c03<c<`0703<c<`<000002@0c<c<00`000000
<c<c03<c<`0:03<c<`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P0c<c<00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo000P0?ooo`030000003oool0oooo03T0
oooo100000000`1>BJH000000596X0060596X0040000001MA9D0GDBE05e4U@H000002P1dC8l00`00
0000Q5F>08AESP0:08AESP030000002IJYT0VFZI00P0VFZI1@00000>0<nic`800000203_om`01@00
0000kOoF0>goeP3]omH0000000@0kog<00D000000>kk`@3^nl40k__1000000030>gj^P030000003^
nKL0k_Vg0080k_Vg00<000000>oh^`0000001@0000030?3g_`8000003`3oool200000080_[S400<0
0000054cOP1A<gh01@1A<gh2000000L0<c=600D0000003<c<`0c<c<0<c<c0000000403<c<`030000
000c<c<0<c<c00P0<c<c00<0000003<c<`000000200c<c<00`000000<c<c03<c<`0:03<c<`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P0c<c<00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02H0oooo000Q0?ooo`800000>`3oool00`000000?SbO00000002000000H0DTJP
00<0000005e4U@1MA9D01@1MA9D6000000L0M4b?00<0000008AESP24EHh02@24EHh00`000000VFZI
09UZV@0209UZV@H00000102^R[000`000000ckW?0<nic`0;0<nic`030000003?^Ll0kooL00L0kooL
00D000000>goeP3]omH0kOoF000000040>omc0050000003^nl40k__10>kk`@0000000`3]n[X01000
0000k_Vg0>ki]`3^nKL400000080l_6V00<000000?7aY03alJ@01000000C0?ooo`030000002n^<@0
000000P0DC=n0P00000603<cAP030000000c<c<0<c<c0080<c<c00<0000003<c<`0c<c<00P0c<c<0
0`000000<c<c03<c<`0703<c<`040000000c<c<0<c<c000000P0<c<c00<0000003<c<`0c<c<02P0c
<c<00`000000oooo0?ooo`020?ooo`8000000`0c<c<00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02D0oooo000S0?ooo`030000003oool0oooo03T0oooo00<0000003hlW`0n?9l00P000006
0596X0030000001MA9D0GDBE00L0GDBE00<00000075<TP0000001P0000000`1dC8l0000008AESP06
08AESPT000002`2^R[000`000000ckW?0<nic`080<nic`8000002@3_om`01@000000kOoF0>goeP3]
omH0000000@0kog<00<0k__10000003^nl400P3^nl4010000000kOZj0>gj^P3]n[X5000000@0l_6V
00<000000?7aY03alJ@00`3alJ@00`000000oooo0?ooo`0C0?ooo`<000001`1A<gh2000000H0<c=6
00<0000003<c<`0c<c<00P0c<c<00`000000<c<c03<c<`0203<c<`030000000c<c<0<c<c00L0<c<c
00@0000003<c<`0c<c<0<c<c0P00000603<c<`030000000c<c<0<c<c00X0<c<c00<000000?ooo`3o
ool00`3oool00`000000<c<c03<c<`02000000l0oooo00<000000?ooo`3oool09@3oool002@0oooo
00<000000?ooo`3oool0>@3oool010000000?SbO03hlW`0n?9l2000000D0DTJP00<0000005e4U@1M
A9D01P1MA9D00`000000LDbB075<TP05075<TPX000001P2=I9/00`000000[XZ`0:j:/00<0:j:/080
00001`3?^Ll00`000000ckW?0>oog0070>oog0030>goeP000000kOoF00<0kOoF00<000000>omc03_
oL`00P3_oL`01@000000k__10>kk`@3^nl40000000<0kOZj0P0000030??c[0030000003blJH0l_6V
0080l_6V00<000000?7aY03alJ@00`3alJ@00`000000oooo0?ooo`0E0?ooo`030000001A<gh0DC=n
00D0DC=n00<0000003<c=P0000001@0c<dH00`000000<c<c03<c<`0303<c<`050000000c<c<0<c<c
03<c<`0000002P0c<c<00`000000<c<c03<c<`0203<c<`030000000c<c<0<c<c00<0<c<c00<00000
03<c<`0c<c<02`0c<c<00`000000oooo0?ooo`020?ooo`030000000c<c<0<c<c008000003`3oool0
0`000000oooo0?ooo`0U0?ooo`009@3oool2000003X0oooo00@0000003hlW`0n?9l0?SbO0`000004
0596X0030000001MA9D0GDBE00H0GDBE00<00000075<TP1aC980201aC9800`000000SFBK08eTV`0:
08eTV`030000002^R[00[XZ`00d0[XZ`00<000000<nic`3?^Ll00P3?^Ll2000000T0kooL0P000004
0>goeP030000003_oL`0kog<0080kog<00D000000>kk`@3^nl40k__1000000020>gj^P800000103c
lj`00`000000l_6V0?;aYP020?;aYP030000003alJ@0lO6T00<0lO6T00<000000?ooo`3oool05`3o
ool00`000000DC=n054cOP04054cOP040000000c<cH0<c<f000000D0<c=600<0000003<c<`0c<c<0
0`0c<c<01@000000<c<c03<c<`0c<c<0000000T0<c<c00<0000003<c<`0c<c<00`0c<c<00`000000
<c<c03<c<`0303<c<`030000000c<c<0<c<c00X0<c<c00H000000?ooo`3oool0oooo0000000c<c<2
0000000303<c<`000000oooo00h0oooo00<000000?ooo`3oool09@3oool002L0oooo00<000000?oo
o`3oool0>03oool200000080?SbO00@0000004<jVP00000000000`1BAZ000`000000GDBE05e4U@06
05e4U@030000001aC980LDbB00L0LDbB00<0000008eTV`2=I9/02`2=I9/00`000000[XZ`0:j:/00=
0:j:/0040000003?^Ll00000000000X0kooL00<000000>goeP3]omH00`3]omH00`000000kog<0>om
c0020>omc0030>kk`@000000k__10080k__10`0000000`3fm;D000000??c[0030??c[0030000003b
lJH0l_6V0080l_6V00<000000?7aY03alJ@00`3alJ@00`000000oooo0?ooo`0H0?ooo`030000001A
<gh0DC=n00@0DC=n00@0000003<c=P0c<cH00000100c<dH00`000000<c<c03<c<`0403<c<`040000
000c<c<0<c<c000000T0<c<c00<0000003<c<`0c<c<0100c<c<2000000<0<c<c00<0000003<c<`0c
<c<02P0c<c<01@000000oooo0?ooo`3oool000000080<c<c0P00000@0?ooo`030000003oool0oooo
02D0oooo000X0?ooo`030000003oool0oooo03P0oooo0P00000203hlW`0300000013>YX0@cZJ0080
000000<0DTJP0000001MA9D01`1MA9D00`000000LDbB075<TP08075<TP030000002=I9/0SFBK00/0
SFBK00<000000:j:/02^R[00302^R[02000000030<nic`3_om`0kooL00P0kooL00<000000>goeP3]
omH00`3]omH00`000000kog<0>omc0030>omc0040000003^nl40k__10>kk`@8000000P3fm;D00`00
0000lo>/0??c[0020??c[0030000003blJH0l_6V0080l_6V00<000000?7aY03alJ@00`3alJ@00`00
0000oooo0?ooo`0I0?ooo`030000001A<gh0DC=n00@0DC=n00@0000003<c=P0c<cH00000100c<dH0
0`000000<c<c03<c<`0503<c<`030000000c<c<0000000T0<c<c00<0000003<c<`0c<c<01P0c<c<0
10000000<c<c03<c<`00000=03<c<`030000003oool0000000@0<c<c00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0U0?ooo`00:@3oool00`000000oooo0?ooo`0h0?ooo`@000001013>YX3
000000P0GDBE00<00000075<TP1aC980201aC9800`000000SFBK08eTV`0:08eTV`030000002^R[00
[XZ`00X0[XZ`0P0000020<f`a0<000001`3_om`00`000000kOoF0>goeP030>goeP030000003_oL`0
kog<00<0kog<00<000000>kk`@0000000P0000040?Kd]@030000003clj`0lo>/0080lo>/00<00000
0?;aYP3blJH00P3blJH00`000000lO6T0?7aY0020?7aY0030000003oool0oooo01/0oooo00<00000
054cOP1A<gh00`1A<gh01@000000<c<f03<c=P0c<cH0000000@0<c=600<0000003<c<`0c<c<01@0c
<c<2000000X0<c<c00<0000003<c<`0c<c<01P0c<c<00`000000<c<c0000000=03<c<`030000003o
ool0000000@0<c<c00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0T0?ooo`00:P3oool2
000003X0oooo0`00000504<jVP<000001P1MA9D00`000000LDbB075<TP08075<TP800000302=I9/0
0`000000[XZ`0:j:/0070:j:/08000001P3=/<@3000000@0kooL00<000000>goeP3]omH0103]omH0
0`000000kog<0>omc0020>omc0060>kk`@00000000000000003fmL0000000`3fm;D00`000000lo>/
0??c[0020??c[0030000003blJH0l_6V0080l_6V00<000000?7aY03alJ@00`3alJ@00`000000oooo
0?ooo`0L0?ooo`030000001A<gh0DC=n00<0DC=n00D0000003<c=P0c<cH0<c<f0000000303<cAP03
0000000c<c<0<c<c00H0<c<c0P00000903<c<`030000000c<c<0<c<c00L0<c<c0`00000<03<c<`03
0000003oool0000000@0<c<c0P00000@0?ooo`030000003oool0oooo02@0oooo000/0?ooo`030000
003oool0oooo03P0oooo0`00000604<jVP@00000101MA9D00`000000LDbB075<TP08075<TP030000
002=I9/0SFBK00/0SFBK00<000000:j:/02^R[000`2^R[03000000X0cK340`0000000`3_om`00000
0>goeP050>goeP030000003_oL`0kog<00D000000P3fmL000`000000m_Be0?Kd]@020?Kd]@030000
003clj`0lo>/0080lo>/00<000000?;aYP3blJH00P3blJH00`000000lO6T0?7aY0020?7aY0030000
003oool0oooo01h0oooo00<00000054cOP1A<gh00P1A<gh00`000000<c<f03<c=P0203<c=P040000
000c<dH0<c=6000000T0<c<c00<0000003<c<`0c<c<01`0c<c<00`000000<c<c03<c<`0903<c<`<0
00002`0c<c<00`000000<c<c03<c<`0303<c<`030000003oool0000000l0oooo00<000000?ooo`3o
ool0903oool002d0oooo00<000000?ooo`3oool0>03oool3000000H0@cZJ00<0000005DnU01E?Y@0
0P00000305e4U@030000001aC980LDbB00P0LDbB00<0000008eTV`2=I9/02`2=I9/00`000000[XZ`
0:j:/002000000l0cK34300000020?gobP050000003fmL00m_G00?Ke`0000000103fm;D00`000000
lo>/0??c[0020??c[0030000003blJH0l_6V0080l_6V00<000000?7aY03alJ@00P3alJ@00`000000
oooo0?ooo`0P0?ooo`050000001A<gh0DC=n054cOP000000100c<cH010000000<c=603<cAP000009
03<c<`8000002@0c<c<00`000000<c<c03<c<`0803<c<`030000001fBgH0MT]f00D000001P0c<c<0
0`000000<c<c03<c<`0303<c<`030000003oool0000000l0oooo00<000000?ooo`3oool0903oool0
02h0oooo0P00000i0?ooo`030000000c<iP0000000D0@cZJ00<0000005DnU01E?Y@00P1E?Y@40000
00/0LDbB00<0000008eTV`2=I9/0202=I9/500000100cK340P0000060?kYc@030000003molX0oOo:
00<0oOo:00<000000?Ke`03fmL000P3fmL001@000000m_Be0?Kd]@3fm;D0000000D0lo>/00<00000
0?;aYP3blJH00P3blJH00`000000lO6T0?7aY0020?7aY0030000003oool0oooo0200oooo00<00000
054cOP1A<gh00P1A<gh00`000000<c<f03<c=P0203<c=P040000000c<dH0<c=6000000T0<c<c0P00
000803<c<`030000000c<c<0<c<c00T0<c<c00<0000007I;MP1fBgH0101fBgH500000080<c<c00D0
000003<c<`0c<c<0<c<c000000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
903oool00300oooo00<000000?ooo`3oool0=`3oool4000000@0@cZJ00<0000005DnU01E?Y@0101E
?Y@8000000@0LDbB00<0000008eTV`2=I9/00P2=I9/6000000@0Wg^Z00<000000<f`a03=/<@0303=
/<@2000000L0o^W=00<000000?gobP3molX00`3molX00`000000m_G00?Ke`0020?Ke`0030000003f
m;D0m_Be0080m_Be00<000000??c[03clj`00P3clj`00`000000l_6V0?;aYP020?;aYP030000003a
lJ@0lO6T0080lO6T00<000000?ooo`3oool08P3oool01@000000DC=n054cOP1A<gh0000000D0<c<f
00<0000003<cAP0000002@0c<c<010000000<c<c00000000000603<c<`030000000c<c<0<c<c00T0
<c<c00<0000007I;MP1fBgH02@1fBgH400000080<c<c00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02@0oooo000a0?ooo`030000003oool0oooo03L0oooo
1@00000304<jVP030000001E?Y@0ECjD00D0ECjD00<0000007ABV01dDYP00P1dDYP:000000/0Wg^Z
00<000000<f`a03=/<@02P3=/<@00`000000o^W=0?kYc@060?kYc@030000003molX0oOo:00<0oOo:
00<0m_G00000003fmL000P3fmL000`000000m_Be0?Kd]@020?Kd]@030000003clj`0lo>/00<0lo>/
00<000000?;aYP3blJH00P3blJH00`000000lO6T0?7aY0020?7aY0030000003oool0oooo02<0oooo
00@00000054cOP1A<gh000001P0c<cH2000000T0<c<c00D0000003<c<`0c<c<0<c<c0000000603<c
<`030000000c<c<0<c<c00T0<c<c00<0000007I;MP1fBgH0301fBgH3000000@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?ooo`0h0?ooo`80
000000<0>3>E0000000000000P13>YX00`000000ECjD05DnU00505DnU0030000001dDYP0M5:H00P0
M5:H00<0000009mkZP2ONjX0302ONjX00`000000cK340<f`a0070<f`a0800000203njLd00`000000
oOo:0?gobP040?gobP030000003fmL00m_G00080m_G000<000000?Kd]@3fm;D00P3fm;D00`000000
lo>/0??c[0020??c[0030000003blJH0l_6V0080l_6V00<000000?7aY03alJ@00P3alJ@00`000000
oooo0?ooo`0U0?ooo`030000001A<gh0000000H0<c<f0P00000903<c<`030000000c<c<0<c<c0080
<c<c00<0000003<c<`0c<c<00`0c<c<00`000000<c<c03<c<`0903<c<`030000001fBgH0MT]f00d0
MT]f00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0
oooo000c0?ooo`800000>@3oool200000080>3>E0`00000805DnU0030000001dDYP0M5:H00P0M5:H
00<0000009mkZP2ONjX0302ONjX00`000000cK340<f`a0050<f`a0030000003njLd0o^W=00L0o^W=
00<000000?gobP3molX0103molX00`000000m_G00?Ke`0020?Ke`0030000003fm;D0m_Be0080m_Be
00<000000??c[03clj`00`3clj`00`000000l_6V0?;aYP020?;aYP050000003alJ@0lO6T0?7aY000
0000:@3oool00`000000DC=n0000000603<c=P8000002@0c<c<00`000000<c<c03<c<`0203<c<`03
0000000c<c<0<c<c0080<c<c00<0000003<c<`0c<c<02P0c<c<00`000000MT]f07I;MP0:07I;MP80
0000203oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo000e0?ooo`030000
003oool0oooo03L0oooo0P00000303PcU@800000201E?Y@00`000000M5:H07ABV00807ABV0030000
002ONjX0Wg^Z00`0Wg^Z00<000000<f`a03=/<@00P3=/<@2000000P0o^W=0P0000060?gobP030000
003fmL00m_G00080m_G000<000000?Kd]@3fm;D00`3fm;D00`000000lo>/0??c[0020??c[0030000
003blJH0l_6V0080l_6V00<000000?7aY03alJ@00P3alJ@00`000000oooo0?ooo`0X0?ooo`800000
1`0c<cH00`000000<c<c03<c<`0703<c<`030000000c<c<0<c<c00<0<c<c00D0000003<c<`0c<c<0
<c<c0000000<03<c<`030000001fBgH0MT]f00T0MT]f00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo000f0?ooo`030000003oool0oooo03L0oooo
0P00000403PcU@8000001P1E?Y@00`000000M5:H07ABV00907ABV0030000002ONjX0Wg^Z00`0Wg^Z
00@000000<f`a000000000002@3njLd00`000000oOo:0?gobP050?gobP030000003fmL00m_G000<0
m_G000<000000?Kd]@3fm;D00P3fm;D00`000000lo>/0??c[0030??c[0030000003blJH0l_6V0080
l_6V00D000000?7aY03alJ@0lO6T0000000[0?ooo`8000001`0c<cH2000000P0<c<c00<0000003<c
<`0c<c<0100c<c<01@000000<c<c03<c<`0c<c<0000000/0<c<c00<0000007I;MP1fBgH0201fBgH0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool0
03L0oooo00<000000?ooo`3oool0=`3oool2000000@0>3>E1000000405DnU0030000001dDYP0M5:H
00P0M5:H00<0000009mkZP2ONjX0302ONjX2000000X0o^W=00<000000?gobP3molX01@3molX00`00
0000m_G00?Ke`0030?Ke`0030000003fm;D0m_Be0080m_Be00<000000??c[03clj`00`3clj`00`00
0000l_6V0?;aYP020?;aYP030000003alJ@0lO6T0080lO6T00<000000?ooo`3oool0:P3oool20000
00L0<c<f0P00000803<c<`030000000c<c<0<c<c00@0<c<c0P0000000`0c<c<0000003<c<`0;03<c
<`030000001fBgH0MT]f00D0MT]f0P00000>0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool08`3oool003P0oooo0P00000h0?ooo`800000100h<iD00`000000DCbC054lT`0300000080
ECjD00<0000007ABV01dDYP0201dDYP00`000000Wg^Z09mkZP0809mkZP<000000P2iVKL2000000L0
o^W=00<000000?gobP3molX01@3molX00`000000m_G00?Ke`0030?Ke`0030000003fm;D0m_Be00<0
m_Be00<000000??c[03clj`00`3clj`00`000000l_6V0?;aYP020?;aYP030000003alJ@0lO6T0080
0000;P3oool00`000000<c<f03<c=P0503<c=P030000000c<c<0000000L0<c<c00<0000003<c<`0c
<c<01P0c<c<2000000`0<c<c00<0000007I;MP1fBgH0101fBgH200000100oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0S0?ooo`00>P3oool00`000000oooo0?ooo`0f0?ooo`<00000
0`0h<iD00`000000DCbC054lT`02054lT`@000002P1dDYP00`000000Wg^Z09mkZP0409mkZP<00000
1`2iVKL2000000@0o^W=00<000000?gobP3molX01@3molX00`000000m_G00?Ke`0040?Ke`0030000
003fm;D0m_Be0080m_Be00<000000??c[03clj`00`3clj`00`000000l_6V0?;aYP020?;aYP060000
003alJ@000000000003ijYl00000;`3oool00`000000<c<f03<c=P0403<c=P040000000c<c<0<c<c
000000H0<c<c00<0000003<c<`0c<c<01`0c<c<2000000`0<c<c00<0000007I;MP1fBgH00P1fBgH3
00000100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`00>`3oool00`00
0000oooo0?ooo`0f0?ooo`<000000`0h<iD00`000000DCbC054lT`04054lT`P00000101dDYP00`00
0000Wg^Z09mkZP03000000`0^IVg0P0000000`3njLd000000?gobP070?gobP030000003fmL00m_G0
00<0m_G000<000000?Kd]@3fm;D00`3fm;D00`000000lo>/0??c[0030??c[0030000003blJH00000
00@000000P3ijYl00`000000oooo0?ooo`0_0?ooo`030000000c<cH0<c<f00@0<c<f00@0000003<c
<`0c<c<000001@0c<c<00`000000<c<c03<c<`0803<c<`@000002@0c<c<00`000000MT]f07I;MP02
0000000303<c<`000000oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R
0?ooo`00?03oool2000003L0oooo100000000`0h<iD00000054lT`07054lT`030000001oGj00OenP
0080OenP2000000A0;VI]`8000001`3molX00`000000m_G00?Ke`0030?Ke`0030000003fm;D0m_Be
00<0m_Be00<000000??c[03clj`00P3clj`5000000030?[ZY0000000nNZO00<0nNZO00<000000?oo
o`3oool0;`3oool00`000000<c<f03<c=P0403<c=P050000000c<c<0<c<c03<c<`0000001@0c<c<0
0`000000<c<c03<c<`0703<c<`8000000P1fBgH7000000<0<c<c0P00000203<c<`8000004`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo000n0?ooo`030000003oool0oooo
03D0oooo00<0000003<cT00c<i000`000008054lT`030000001oGj00OenP00P0OenP00<000000;VI
]`2iVKL03@2iVKL200000080f[No100000020?gobP030000003fmL00m_G000@0m_G000<000000?Kd
]@3fm;D00`3fm;D6000000D0n^ZT00D000000?WZW`3ijYl0nNZO0000000c0?ooo`030000000c<cH0
<c<f00<0<c<f00<0000003<c<`0c<c<00P0c<c<00`000000<c<c03<c<`0203<c<`030000000c<c<0
<c<c00P0<c<c00<0000007I;MP1fBgH01`1fBgH8000001@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0R0?ooo`00?`3oool00`000000oooo0?ooo`0e0?ooo`040000000c<i00<c>@
03PcU@8000001`1A?9<00`000000OenP07mOX00907mOX0030000002iVKL0^IVg00X0^IVg0P000008
0=Zg_a000000103jj:l00`000000n^ZT0?[ZY0020?[ZY0030000003ijYl0nNZO0080nNZO00<00000
0?ooo`3oool0<P3oool00`000000<c<f03<c=P0303<c=P030000000c<c<0<c<c0080<c<c00D00000
03<c<`0c<c<0<c<c0000000:03<c<`8000003P1fBgH00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08P3oool00400oooo00<000000?ooo`3oool0=@3oool0
10000000<c>@03<cT00c<i02000000L0DCbC00<0000007mOX01oGj002@1oGj000`000000^IVg0;VI
]`080;VI]`030000003J]kl0f[No00P0f[No00<000000?oF`03oe/00103oe/000`000000onBi0?oT
^@030?oT^@030000003jj:l0n^R_00<0n^R_00<000000?[ZY03jjZ@00`3jjZ@01@000000nNZO0?WZ
W`3ijYl0000003H0oooo00<0000003<c=P0c<cH00P0c<cH00`000000<c<c03<c<`0303<c<`050000
000c<c<0<c<c03<c<`0000002P0c<c<00`000000MT]f07I;MP0;07I;MP030000003oool0oooo01H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`00@@3oool2000003H0oooo
00D0000003<cT00c<i00<c>@03PcU@02000000H0DCbC00<0000007mOX01oGj002@1oGj000`000000
^IVg0;VI]`050;VI]`8000002P3J]kl00`000000omK00?oF`0040?oF`0030000003oi;T0onBi00@0
onBi00<000000?[X[`3jj:l00`3jj:l00`000000n^ZT0?[ZY0020?[ZY0030000003ijYl0nNZO0080
nNZO00<000000?ooo`3oool0=@3oool01@000000<c<f03<c=P0c<cH0000000H0<c<c00@0000003<c
<`0c<c<000002P0c<c<2000000X0MT]f0P00000J0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool08P3oool004<0oooo00<000000?ooo`3oool0=03oool00`000000<c>@03<cT00203<c
T0@00000101A?9<00`000000OenP07mOX00907mOX0030000002iVKL0^IVg0080^IVg0P00000:0=Zg
_`8000001P3oe/000`000000onBi0?oT^@040?oT^@030000003jj:l0n^R_00<0n^R_00<000000?[Z
Y03jjZ@00`3jjZ@01@000000nNZO0?WZW`3ijYl0000003T0oooo00D0000003<c=P0c<cH0<c<f0000
000603<c<`030000000c<c<0000000/0<c<c00<0000007I;MP1fBgH01`1fBgH00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool004@0oooo00<00000
0?ooo`3oool0=03oool200000080<c>@00@0DCfD0000001A?I@0DCfD0P000002054lT`030000001o
Gj00OenP00X0OenP00@000000;VI]`00000000002`3J]kl00`000000omK00?oF`0060?oF`0030000
003oi;T0onBi00<0onBi00<000000?[X[`3jj:l0103jj:l00`000000n^ZT0?[ZY0020?[ZY0030000
003ijYl0nNZO0080nNZO00<000000?ooo`3oool0=`3oool01@000000<c<f03<c=P0c<cH0000000L0
<c<c0P00000;03<c<`8000001`1fBgH2000001d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0Q0?ooo`00A@3oool2000003D0oooo0P00000203<cT0030000001A?I@0DCfD0080DCfD
1000000707mOX0H00000303J]kl00`000000omK00?oF`0060?oF`0030000003oi;T0onBi00@0onBi
00<000000?[X[`3jj:l00`3jj:l00`000000n^ZT0?[ZY0030?[ZY0050000003ijYl0nNZO0?WZW`00
0000>`3oool01@000000<c<f03<c=P0c<cH0000000L0<c<c0P00000;03<c<`030000001fBgH0MT]f
00@0MT]f0P00000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool004L0
oooo00<000000?ooo`3oool0<`3oool200000080<c>@00<00000054mU01A?I@0101A?I@8000000H0
T76X0P0000090=Zg_`030000003oe/00omK000H0omK000<000000?oT^@3oi;T0103oi;T00`000000
n^R_0?[X[`030?[X[`030000003jjZ@0n^ZT00<0n^ZT00<000000?WZW`3ijYl00P3ijYl00`000000
oooo0?ooo`0j0?ooo`040000000c<cH0<c<f000000P0<c<c0`00000903<c<`800000101fBgH00`00
0000<c<c0000000O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool004P0
oooo00<000000?ooo`3oool0<P3oool01P000000<c><000000000000<c>@000000L0DCfD00<00000
091aZ02@LJP02`2@LJP00`000000f[No0=Zg_`050=Zg_`030000003oe/00omK000H0omK000<00000
0?oT^@3oi;T0103oi;T00`000000n^R_0?[X[`040?[X[`030000003jjZ@0n^ZT00<0n^ZT00D00000
0?WZW`3ijYl0nNZO0000000n0?ooo`030000000c<cH0000000P0<c<c00<0000003XcA00j<d@01@00
000503<c<`030000001fBgH0MT]f0080000000<0<c<c0000003oool0803oool01@000000oooo0?oo
o`3oool0000002<0oooo00190?ooo`030000003oool0oooo0380oooo00H0000003<cS00c<h`00000
03<cT0000007054mU0030000002@LJP0T76X00/0T76X00<000000=Zg_`3J]kl00P3J]kl2000000P0
omK000<000000?oT^@3oi;T01@3oi;T00`000000n^R_0?[X[`030?[X[`030000003jjZ@0n^ZT00<0
n^ZT00<000000?WZW`3ijYl00P3ijYl00`000000oooo0?ooo`0m0?ooo`030000000c<cH0000000P0
<c<c00<0000003XcA00j<d@00`0j<d@50000000403<c<`0000000000000000<0<c<c00<000000?oo
o`3oool0803oool010000000oooo0?ooo`00000S0?ooo`00BP3oool2000003<0oooo00<0000003<c
S00c<h`00P000008054mU0030000002@LJP0T76X00/0T76X0P0000000`3J]kl000000?oF`0080?oF
`0030000003oi;T0onBi00D0onBi00<000000?[X[`3jj:l0103jj:l00`000000n^ZT0?[ZY0020?[Z
Y0030000003ijYl0nNZO00<0nNZO00<000000?ooo`3oool0?P3oool2000000P0<c<c00<0000003Xc
A00j<d@0200j<d@7000002<0oooo00@000000?ooo`3oool000008`3oool004`0oooo00<000000?oo
o`3oool0<@3oool00`000000<c><03<cS002000000L0DCfD0P00000=091aZ08000002@3oe/000`00
0000onBi0?oT^@060?oT^@030000003jj:l0n^R_00<0n^R_00<000000?[ZY03jjZ@00`3jjZ@00`00
0000nNZO0?WZW`020?WZW`030000003oool0oooo03l0oooo0P00000903<c<`030000000j<d@0>S=4
00`0>S=400<000000?ooo`3oool08`3oool00`000000oooo0000000S0?ooo`00C@3oool00`000000
oooo0?ooo`0a0?ooo`040000000c<h`0<c><03<cS08000001P1A?I@00`000000T76X091aZ008091a
Z0<000000P2VR;02000000L0omK000<000000?oT^@3oi;T01@3oi;T00`000000n^R_0?[X[`040?[X
[`030000003jjZ@0n^ZT0080n^ZT00<000000?WZW`3ijYl00`3ijYl00`000000oooo0?ooo`100?oo
o`800000200c<c<00`000000>S=403XcA00;03XcA0030000003oool0oooo02D0oooo00<000000?oo
o`0000008P3oool004h0oooo0P00000b0?ooo`8000000P0c<h`5000000<0DCfD00<00000091aZ02@
LJP0102@LJP3000000L0YXR`0P0000040?oF`0030000003oi;T0onBi00D0onBi00<000000?[X[`3j
j:l0103jj:l00`000000n^ZT0?[ZY0030?[ZY0030000003ijYl0nNZO0080nNZO00<000000?ooo`3o
ool0@P3oool00`000000<c<c03<c<`0703<c<`030000000j<d@0>S=400P0>S=40P00000Y0?ooo`80
00008P3oool00500oooo00<000000?ooo`3oool0<03oool200000080<c><00@0000005E1U`1E@IL0
ED6G1@000002091aZ0<00000302VR;02000000030?oF`0000000onBi00L0onBi00<000000?[X[`3j
j:l00`3jj:l00`000000n^ZT0?[ZY0030?[ZY0030000003ijYl0nNZO00<0nNZO00<000000?ooo`3o
ool0@`3oool2000000L0<c<c00<0000003XcA00j<d@01`0j<d@00`000000oooo0?ooo`0Y0?ooo`80
00008P3oool00540oooo00<000000?ooo`3oool0<03oool200000080<c><00<0000005E1U`1E@IL0
101E@IL300000140YXR`0P0000070?oT^@030000003jj:l0n^R_00@0n^R_00<000000?[ZY03jjZ@0
0`3jjZ@00`000000nNZO0?WZW`020?WZW`030000003oool0oooo04H0oooo0P00000603<c<`030000
000j<d@0>S=400D0>S=400<000000?ooo`3oool0:P3oool200000280oooo001B0?ooo`030000003o
ool0oooo0300oooo1000000805E1U`030000002VR;00YXR`00d0YXR`0P0000020;fO]0800000103o
i;T00`000000n^R_0?[X[`040?[X[`030000003jjZ@0n^ZT00<0n^ZT00<000000?WZW`3ijYl00`3i
jYl00`000000oooo0?ooo`180?ooo`800000100c<c<00`000000>S=403XcA00403XcA0030000003o
ool0oooo02L0oooo1000000T0?ooo`00D`3oool200000340oooo00@0000003<cR@0000000000201E
@IL00`000000YXR`0:J8/00:0:J8/08000001P2mWk@200000080onBi00<000000?[X[`3jj:l0103j
j:l00`000000n^ZT0?[ZY0030?[ZY0030000003ijYl0nNZO0080nNZO00<000000?ooo`3oool0B`3o
ool2000000<0<c<c00<0000003XcA00j<d@00P0j<d@00`000000oooo0?ooo`0T0?ooo`@00000:03o
ool005D0oooo00<000000?ooo`3oool0;`3oool010000000<c>900000000000805E1U`030000002V
R;00YXR`00P0YXR`00<000000;fO]02mWk@0202mWk@3000000D0n^R_00<000000?[ZY03jjZ@00`3j
jZ@00`000000nNZO0?WZW`030?WZW`030000003oool0oooo04d0oooo0P000000100c<c<0000003Xc
A00j<d@2000002<0oooo1000000/0?ooo`00EP3oool00`000000oooo0?ooo`0_0?ooo`040000000c
<hT00000000000P0ED6G00<000000:J8/02VR;001@2VR;02000000/0_Ind00<000000=6c]03A/k@0
0`0000020?[X[`030000003jjZ@0n^ZT00<0n^ZT00<000000?WZW`3ijYl00P3ijYl00`000000oooo
0?ooo`1@0?ooo`@000008@3oool400000300oooo001G0?ooo`030000003oool0oooo02l0oooo00<0
000003<cR@0c<hT00`00000605E1U`030000002VR;00YXR`0080YXR`0P00000<0;fO]0030000003A
/k@0dK>d00@0dK>d3P00001D0?ooo`030000003oool0oooo01`0oooo1000000d0?ooo`00F03oool2
00000300oooo00D0000003<cR@0c<hT0000005i:V`060000000305E1U`000000YXR`00800000302m
Wk@2000000L0dK>d00<000000>C4/03Ta;000`3Ta;000`000000k<b^0>c<[P030>c<[P030000003o
ool0oooo06h0oooo1000000h0?ooo`00FP3oool00`000000oooo0?ooo`0^0?ooo`030000000c<hT0
000000L0GTZK0`00000=0;fO]0030000003A/k@0dK>d00H0dK>d00<000000>C4/03Ta;00103Ta;00
0`000000k<b^0>c<[P030>c<[P030000003oool0oooo06X0oooo1000000l0?ooo`00F`3oool00`00
0000oooo0?ooo`0]0?ooo`@000002@1NBY/00`000000_Ind0;fO]0090;fO]0030000003A/k@0dK>d
00H0dK>d00<000000>C4/03Ta;00103Ta;000`000000k<b^0>c<[P030>c<[P030000003oool0oooo
06L0oooo100000100?ooo`00G03oool2000002h0oooo1000000905i:V`030000002mWk@0_Ind00L0
_Ind00<000000=6c]03A/k@01P3A/k@00`000000i<B`0>C4/0040>C4/0030000003/c:h0k<b^00@0
k<b^00<000000?ooo`3oool0H`3oool4000004@0oooo001N0?ooo`030000003oool0oooo02`0oooo
00@0000003<cQ`00000000002@1NBY/2000000H0_Ind00<000000=6c]03A/k@01P3A/k@00`000000
i<B`0>C4/0050>C4/0030000003/c:h0k<b^00<0k<b^00<000000?ooo`3oool0H03oool4000004P0
oooo001O0?ooo`030000003oool0oooo02`0oooo00@0000003<cQ`00000000002P1NBY/010000000
_Ind0;fO]02mWk@2000000P0dK>d00<000000>C4/03Ta;001@3Ta;000`000000k<b^0>c<[P040>c<
[P030000003oool0oooo05`0oooo1000001<0?ooo`00H03oool00`000000oooo0?ooo`0[0?ooo`80
000000<0<c>70000001NBY/02P1NBY/00`000000_Ind0000000:0=6c]0030000003Ta;00i<B`00@0
i<B`00<000000>c<[P3/c:h0103/c:h00`000000oooo0?ooo`1J0?ooo`<00000D03oool00640oooo
0P00000[0?ooo`030000003oool0000000h000002P3A/k@00`000000i<B`0>C4/0050>C4/0030000
003/c:h0k<b^00@0k<b^00<000000?ooo`3oool0EP3oool4000005<0oooo001S0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool00`00000;06]FW`030000003A/k@0dK>d00H0dK>d00<0
00000>C4/03Ta;001@3Ta;000`000000k<b^0>c<[P040>c<[P030000003oool0oooo05<0oooo1000
001G0?ooo`00I03oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo0?ooo`<000002`1[
EYl2000000D0dK>d00<000000>C4/03Ta;001P3Ta;000`000000k<b^0>c<[P030>c<[P030000003o
ool0oooo0500oooo1000001K0?ooo`00I@3oool2000002L0oooo00<000000?ooo`3oool00P3oool3
000000/0JeJO0P0000030=6c]0030000003Ta;00i<B`00H0i<B`00<000000>c<[P3/c:h0103/c:h0
0`000000oooo0?ooo`1<0?ooo`@00000G`3oool006L0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`030?ooo`<00000301[EYl00`000000dK>d000000080>C4/0030000003/c:h0k<b^
00@0k<b^00<000000?ooo`3oool0B@3oool4000006<0oooo001X0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0103oool3000000X0JeJO0`0000000`1kIJ<0i<B`0>C4/0060>C4/003
0000003/c:h0k<b^00@0k<b^00<000000?ooo`3oool0A@3oool4000006L0oooo001Y0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01@3oool3000000<0JeJO1P00000307]UX`800000
1P3Ta;000`000000k<b^0>c<[P040>c<[P030000003oool0oooo0480oooo1000001[0?ooo`00JP3o
ool200000280oooo00<000000?ooo`3oool01P3oool5000000/0NfFS0P0000030>C4/0030000003/
c:h0k<b^00D0k<b^00<000000?ooo`3oool0?P3oool4000006l0oooo001/0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01`3oool3000000h0NfFS0P0000000`3Ta;0000000>c<[P05
0>c<[P030000003oool0oooo03/0oooo1000001c0?ooo`00K@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00@0000003<cQ@00000000003P1kIJ<3000000H0k<b^00<00000
0?ooo`3oool0=`3oool4000007L0oooo001^0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0203oool00`000000<c>503<cQ@02000000T0NfFS0`00000208A]Y0<000000`3/c:h00`00
0000oooo0?ooo`0e0?ooo`<00000N`3oool006l0oooo0P00000M0?ooo`030000003oool0oooo00T0
oooo00<0000003<cQ@0c<hD00P00000607]UX`8000001`24KJ@3000000030>c<[P000000oooo0380
oooo1000001n0?ooo`00L@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo
00<0000003<cQ@0c<hD00P00000207]UX`<000002`24KJ@200000300oooo100000220?ooo`00LP3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo0P00000203<cQ@8000003@24
KJ@2000002d0oooo100000260?ooo`00L`3oool2000001T0oooo00<000000?ooo`3oool03@3oool0
10000000<c>503<cQ@00000<08A]Y0030000003oool0oooo02T0oooo1000002:0?ooo`00M@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo0P0000000`0c<hD0000008A]Y008
08A]Y0800000:03oool4000008h0oooo001f0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0403oool3000000H0Q6fT0P00000V0?ooo`@00000TP3oool007L0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0B0?ooo`8000001024KJ@00`000000oooo0?ooo`0R0?ooo`@0
0000UP3oool007P0oooo0P00000C0?ooo`030000003oool0oooo01@0oooo0P0000000`24KJ@00000
0000000Q0?ooo`@00000VP3oool007X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01d0oooo1000002N0?ooo`00N`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0380oooo1000002R0?ooo`00O03oool2000000l0oooo00<000000?oo
o`3oool0;P3oool400000:H0oooo001n0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0:`3oool300000:X0oooo001o0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
9`3oool400000:d0oooo00200?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3o
ool400000;40oooo00210?ooo`8000002P3oool00`000000oooo0?ooo`0O0?ooo`@00000]@3oool0
08<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`@00000^@3oool008@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`@00000_@3oool008D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`@00000`@3oool008H0oooo0P00
00050?ooo`030000003oool0oooo00l0oooo100000350?ooo`00R03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo100000390?ooo`00R@3oool01@000000oooo0?ooo`3oool0
000000T0oooo1000003=0?ooo`00RP3oool2000000030?ooo`000000oooo00@0oooo1000003A0?oo
o`00S03oool2000000030?ooo`000000000000800000e@3oool008d0oooo0P00003I0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00\
\>"]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Note that in the RealTime format of plotting, you can't get any \
information about axis scales in the plot. To turn this form of plotting off, \
use the command\
\>", "Text",
  CellTags->"i:55"],

Cell[BoxData[
    \(<< Default3D`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.85"],

Cell["which takes us back to the ordinary sort of 3D plots. ", "Text"],

Cell[TextData[{
  "\tAnother  method to display information about a surface is to make a \
contour plot.  The function ",
  StyleBox["ContourPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the same arguments as ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and displays 10 contours in grayscale, with lighter grays indicating \
higher areas of the surface, as in Cell ",
  ButtonBox["9.86",
    ButtonData:>"Cell 9.86",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:49"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ContourPlot[Sin[x\ y\ ], {x, 0, Pi}, {y, 0, Pi}, 
      PlotPoints \[Rule] 25]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.86"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.306067 0.0192308 0.306067 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.17226 -0.0125 -9 -9 ]
[.17226 -0.0125 9 0 ]
[.3253 -0.0125 -3 -9 ]
[.3253 -0.0125 3 0 ]
[.47833 -0.0125 -9 -9 ]
[.47833 -0.0125 9 0 ]
[.63137 -0.0125 -3 -9 ]
[.63137 -0.0125 3 0 ]
[.7844 -0.0125 -9 -9 ]
[.7844 -0.0125 9 0 ]
[.93743 -0.0125 -3 -9 ]
[.93743 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17226 -18 -4.5 ]
[-0.0125 .17226 0 4.5 ]
[-0.0125 .3253 -6 -4.5 ]
[-0.0125 .3253 0 4.5 ]
[-0.0125 .47833 -18 -4.5 ]
[-0.0125 .47833 0 4.5 ]
[-0.0125 .63137 -6 -4.5 ]
[-0.0125 .63137 0 4.5 ]
[-0.0125 .7844 -18 -4.5 ]
[-0.0125 .7844 0 4.5 ]
[-0.0125 .93743 -6 -4.5 ]
[-0.0125 .93743 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.17226 0 m
.17226 .00625 L
s
[(0.5)] .17226 -0.0125 0 1 Mshowa
.3253 0 m
.3253 .00625 L
s
[(1)] .3253 -0.0125 0 1 Mshowa
.47833 0 m
.47833 .00625 L
s
[(1.5)] .47833 -0.0125 0 1 Mshowa
.63137 0 m
.63137 .00625 L
s
[(2)] .63137 -0.0125 0 1 Mshowa
.7844 0 m
.7844 .00625 L
s
[(2.5)] .7844 -0.0125 0 1 Mshowa
.93743 0 m
.93743 .00625 L
s
[(3)] .93743 -0.0125 0 1 Mshowa
.125 Mabswid
.04984 0 m
.04984 .00375 L
s
.08044 0 m
.08044 .00375 L
s
.11105 0 m
.11105 .00375 L
s
.14166 0 m
.14166 .00375 L
s
.20287 0 m
.20287 .00375 L
s
.23348 0 m
.23348 .00375 L
s
.26408 0 m
.26408 .00375 L
s
.29469 0 m
.29469 .00375 L
s
.3559 0 m
.3559 .00375 L
s
.38651 0 m
.38651 .00375 L
s
.41712 0 m
.41712 .00375 L
s
.44772 0 m
.44772 .00375 L
s
.50894 0 m
.50894 .00375 L
s
.53955 0 m
.53955 .00375 L
s
.57015 0 m
.57015 .00375 L
s
.60076 0 m
.60076 .00375 L
s
.66197 0 m
.66197 .00375 L
s
.69258 0 m
.69258 .00375 L
s
.72319 0 m
.72319 .00375 L
s
.75379 0 m
.75379 .00375 L
s
.81501 0 m
.81501 .00375 L
s
.84561 0 m
.84561 .00375 L
s
.87622 0 m
.87622 .00375 L
s
.90683 0 m
.90683 .00375 L
s
.96804 0 m
.96804 .00375 L
s
.99865 0 m
.99865 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .17226 m
.00625 .17226 L
s
[(0.5)] -0.0125 .17226 1 0 Mshowa
0 .3253 m
.00625 .3253 L
s
[(1)] -0.0125 .3253 1 0 Mshowa
0 .47833 m
.00625 .47833 L
s
[(1.5)] -0.0125 .47833 1 0 Mshowa
0 .63137 m
.00625 .63137 L
s
[(2)] -0.0125 .63137 1 0 Mshowa
0 .7844 m
.00625 .7844 L
s
[(2.5)] -0.0125 .7844 1 0 Mshowa
0 .93743 m
.00625 .93743 L
s
[(3)] -0.0125 .93743 1 0 Mshowa
.125 Mabswid
0 .04984 m
.00375 .04984 L
s
0 .08044 m
.00375 .08044 L
s
0 .11105 m
.00375 .11105 L
s
0 .14166 m
.00375 .14166 L
s
0 .20287 m
.00375 .20287 L
s
0 .23348 m
.00375 .23348 L
s
0 .26408 m
.00375 .26408 L
s
0 .29469 m
.00375 .29469 L
s
0 .3559 m
.00375 .3559 L
s
0 .38651 m
.00375 .38651 L
s
0 .41712 m
.00375 .41712 L
s
0 .44772 m
.00375 .44772 L
s
0 .50894 m
.00375 .50894 L
s
0 .53955 m
.00375 .53955 L
s
0 .57015 m
.00375 .57015 L
s
0 .60076 m
.00375 .60076 L
s
0 .66197 m
.00375 .66197 L
s
0 .69258 m
.00375 .69258 L
s
0 .72319 m
.00375 .72319 L
s
0 .75379 m
.00375 .75379 L
s
0 .81501 m
.00375 .81501 L
s
0 .84561 m
.00375 .84561 L
s
0 .87622 m
.00375 .87622 L
s
0 .90683 m
.00375 .90683 L
s
0 .96804 m
.00375 .96804 L
s
0 .99865 m
.00375 .99865 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17226 .99375 m
.17226 1 L
s
.3253 .99375 m
.3253 1 L
s
.47833 .99375 m
.47833 1 L
s
.63137 .99375 m
.63137 1 L
s
.7844 .99375 m
.7844 1 L
s
.93743 .99375 m
.93743 1 L
s
.125 Mabswid
.04984 .99625 m
.04984 1 L
s
.08044 .99625 m
.08044 1 L
s
.11105 .99625 m
.11105 1 L
s
.14166 .99625 m
.14166 1 L
s
.20287 .99625 m
.20287 1 L
s
.23348 .99625 m
.23348 1 L
s
.26408 .99625 m
.26408 1 L
s
.29469 .99625 m
.29469 1 L
s
.3559 .99625 m
.3559 1 L
s
.38651 .99625 m
.38651 1 L
s
.41712 .99625 m
.41712 1 L
s
.44772 .99625 m
.44772 1 L
s
.50894 .99625 m
.50894 1 L
s
.53955 .99625 m
.53955 1 L
s
.57015 .99625 m
.57015 1 L
s
.60076 .99625 m
.60076 1 L
s
.66197 .99625 m
.66197 1 L
s
.69258 .99625 m
.69258 1 L
s
.72319 .99625 m
.72319 1 L
s
.75379 .99625 m
.75379 1 L
s
.81501 .99625 m
.81501 1 L
s
.84561 .99625 m
.84561 1 L
s
.87622 .99625 m
.87622 1 L
s
.90683 .99625 m
.90683 1 L
s
.96804 .99625 m
.96804 1 L
s
.99865 .99625 m
.99865 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17226 m
1 .17226 L
s
.99375 .3253 m
1 .3253 L
s
.99375 .47833 m
1 .47833 L
s
.99375 .63137 m
1 .63137 L
s
.99375 .7844 m
1 .7844 L
s
.99375 .93743 m
1 .93743 L
s
.125 Mabswid
.99625 .04984 m
1 .04984 L
s
.99625 .08044 m
1 .08044 L
s
.99625 .11105 m
1 .11105 L
s
.99625 .14166 m
1 .14166 L
s
.99625 .20287 m
1 .20287 L
s
.99625 .23348 m
1 .23348 L
s
.99625 .26408 m
1 .26408 L
s
.99625 .29469 m
1 .29469 L
s
.99625 .3559 m
1 .3559 L
s
.99625 .38651 m
1 .38651 L
s
.99625 .41712 m
1 .41712 L
s
.99625 .44772 m
1 .44772 L
s
.99625 .50894 m
1 .50894 L
s
.99625 .53955 m
1 .53955 L
s
.99625 .57015 m
1 .57015 L
s
.99625 .60076 m
1 .60076 L
s
.99625 .66197 m
1 .66197 L
s
.99625 .69258 m
1 .69258 L
s
.99625 .72319 m
1 .72319 L
s
.99625 .75379 m
1 .75379 L
s
.99625 .81501 m
1 .81501 L
s
.99625 .84561 m
1 .84561 L
s
.99625 .87622 m
1 .87622 L
s
.99625 .90683 m
1 .90683 L
s
.99625 .96804 m
1 .96804 L
s
.99625 .99865 m
1 .99865 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .02999 m
.94071 .03006 L
.90064 .03025 L
.86058 .03054 L
.82051 .03092 L
.78045 .03139 L
.74038 .03195 L
.70032 .03261 L
.66026 .03338 L
.62019 .03426 L
.58013 .0353 L
.54006 .0365 L
.5 .03791 L
.45994 .03959 L
.41987 .04161 L
.37981 .04409 L
.33974 .04719 L
.29968 .05118 L
.25962 .05651 L
.24289 .05929 L
.21955 .06396 L
.17949 .07515 L
.13942 .09378 L
.13106 .09936 L
.09936 .13106 L
.09378 .13942 L
.07515 .17949 L
.06396 .21955 L
.05929 .24289 L
.05651 .25962 L
.05118 .29968 L
.04719 .33974 L
.04409 .37981 L
.04161 .41987 L
.03959 .45994 L
.03791 .5 L
.0365 .54006 L
.0353 .58013 L
.03426 .62019 L
.03338 .66026 L
.03261 .70032 L
.03195 .74038 L
.03139 .78045 L
.03092 .82051 L
.03054 .86058 L
.03025 .90064 L
.03006 .94071 L
.02999 .98077 L
.98077 .98077 L
F
0 g
.98077 .02999 m
.94071 .03006 L
.90064 .03025 L
.86058 .03054 L
.82051 .03092 L
.78045 .03139 L
.74038 .03195 L
.70032 .03261 L
.66026 .03338 L
.62019 .03426 L
.58013 .0353 L
.54006 .0365 L
.5 .03791 L
.45994 .03959 L
.41987 .04161 L
.37981 .04409 L
.33974 .04719 L
.29968 .05118 L
.25962 .05651 L
.24289 .05929 L
.21955 .06396 L
.17949 .07515 L
.13942 .09378 L
.13106 .09936 L
.09936 .13106 L
.09378 .13942 L
.07515 .17949 L
.06396 .21955 L
.05929 .24289 L
.05651 .25962 L
.05118 .29968 L
.04719 .33974 L
.04409 .37981 L
.04161 .41987 L
.03959 .45994 L
.03791 .5 L
.0365 .54006 L
.0353 .58013 L
.03426 .62019 L
.03338 .66026 L
.03261 .70032 L
.03195 .74038 L
.03139 .78045 L
.03092 .82051 L
.03054 .86058 L
.03025 .90064 L
.03006 .94071 L
.02999 .98077 L
s
.7 g
.98077 .04859 m
.94071 .04949 L
.90064 .05059 L
.86058 .05188 L
.82051 .05338 L
.78045 .05508 L
.74038 .057 L
.70032 .05918 L
.69841 .05929 L
.66026 .06166 L
.62019 .06448 L
.58013 .06771 L
.54006 .07144 L
.5 .0758 L
.45994 .08095 L
.41987 .08714 L
.37981 .09469 L
.35882 .09936 L
.33974 .10412 L
.29968 .11625 L
.25962 .13243 L
.24562 .13942 L
.21955 .15506 L
.18902 .17949 L
.17949 .18902 L
.15506 .21955 L
.13942 .24562 L
.13243 .25962 L
.11625 .29968 L
.10412 .33974 L
.09936 .35882 L
.09469 .37981 L
.08714 .41987 L
.08095 .45994 L
.0758 .5 L
.07144 .54006 L
.06771 .58013 L
.06448 .62019 L
.06166 .66026 L
.05929 .69841 L
.05918 .70032 L
.057 .74038 L
.05508 .78045 L
.05338 .82051 L
.05188 .86058 L
.05059 .90064 L
.04949 .94071 L
.04859 .98077 L
.98077 .98077 L
F
0 g
.98077 .04859 m
.94071 .04949 L
.90064 .05059 L
.86058 .05188 L
.82051 .05338 L
.78045 .05508 L
.74038 .057 L
.70032 .05918 L
.69841 .05929 L
.66026 .06166 L
.62019 .06448 L
.58013 .06771 L
.54006 .07144 L
.5 .0758 L
.45994 .08095 L
.41987 .08714 L
.37981 .09469 L
.35882 .09936 L
.33974 .10412 L
.29968 .11625 L
.25962 .13243 L
.24562 .13942 L
.21955 .15506 L
.18902 .17949 L
.17949 .18902 L
.15506 .21955 L
.13942 .24562 L
.13243 .25962 L
.11625 .29968 L
.10412 .33974 L
.09936 .35882 L
.09469 .37981 L
.08714 .41987 L
.08095 .45994 L
.0758 .5 L
.07144 .54006 L
.06771 .58013 L
.06448 .62019 L
.06166 .66026 L
.05929 .69841 L
.05918 .70032 L
.057 .74038 L
.05508 .78045 L
.05338 .82051 L
.05188 .86058 L
.05059 .90064 L
.04949 .94071 L
.04859 .98077 L
s
.8 g
.98077 .06707 m
.94071 .06924 L
.90064 .07162 L
.86058 .07421 L
.82051 .07707 L
.78045 .08021 L
.74038 .08368 L
.70032 .08755 L
.66026 .09188 L
.62019 .09677 L
.60094 .09936 L
.58013 .10229 L
.54006 .10865 L
.5 .11612 L
.45994 .12496 L
.41987 .13556 L
.40704 .13942 L
.37981 .14848 L
.33974 .16464 L
.31009 .17949 L
.29968 .18543 L
.25962 .21313 L
.25191 .21955 L
.21955 .25191 L
.21313 .25962 L
.18543 .29968 L
.17949 .31009 L
.16464 .33974 L
.14848 .37981 L
.13942 .40704 L
.13556 .41987 L
.12496 .45994 L
.11612 .5 L
.10865 .54006 L
.10229 .58013 L
.09936 .60094 L
.09677 .62019 L
.09188 .66026 L
.08755 .70032 L
.08368 .74038 L
.08021 .78045 L
.07707 .82051 L
.07421 .86058 L
.07162 .90064 L
.06924 .94071 L
.06707 .98077 L
.98077 .98077 L
F
0 g
.98077 .06707 m
.94071 .06924 L
.90064 .07162 L
.86058 .07421 L
.82051 .07707 L
.78045 .08021 L
.74038 .08368 L
.70032 .08755 L
.66026 .09188 L
.62019 .09677 L
.60094 .09936 L
.58013 .10229 L
.54006 .10865 L
.5 .11612 L
.45994 .12496 L
.41987 .13556 L
.40704 .13942 L
.37981 .14848 L
.33974 .16464 L
.31009 .17949 L
.29968 .18543 L
.25962 .21313 L
.25191 .21955 L
.21955 .25191 L
.21313 .25962 L
.18543 .29968 L
.17949 .31009 L
.16464 .33974 L
.14848 .37981 L
.13942 .40704 L
.13556 .41987 L
.12496 .45994 L
.11612 .5 L
.10865 .54006 L
.10229 .58013 L
.09936 .60094 L
.09677 .62019 L
.09188 .66026 L
.08755 .70032 L
.08368 .74038 L
.08021 .78045 L
.07707 .82051 L
.07421 .86058 L
.07162 .90064 L
.06924 .94071 L
.06707 .98077 L
s
.9 g
.98077 .08987 m
.94071 .09327 L
.90064 .09689 L
.87474 .09936 L
.86058 .10037 L
.82051 .10398 L
.78045 .10844 L
.74038 .11358 L
.70032 .11937 L
.66026 .12587 L
.62019 .13319 L
.58957 .13942 L
.58013 .14136 L
.54006 .15063 L
.5 .16166 L
.45994 .17474 L
.44698 .17949 L
.41987 .19025 L
.37981 .2093 L
.36142 .21955 L
.33974 .23306 L
.30439 .25962 L
.29968 .26365 L
.26365 .29968 L
.25962 .30439 L
.23306 .33974 L
.21955 .36142 L
.2093 .37981 L
.19025 .41987 L
.17949 .44698 L
.17474 .45994 L
.16166 .5 L
.15063 .54006 L
.14136 .58013 L
.13942 .58957 L
.13319 .62019 L
.12587 .66026 L
.11937 .70032 L
.11358 .74038 L
.10844 .78045 L
.10398 .82051 L
.10037 .86058 L
.09936 .87474 L
.09689 .90064 L
.09327 .94071 L
.08987 .98077 L
.98077 .98077 L
F
0 g
.98077 .08987 m
.94071 .09327 L
.90064 .09689 L
.87474 .09936 L
.86058 .10037 L
.82051 .10398 L
.78045 .10844 L
.74038 .11358 L
.70032 .11937 L
.66026 .12587 L
.62019 .13319 L
.58957 .13942 L
.58013 .14136 L
.54006 .15063 L
.5 .16166 L
.45994 .17474 L
.44698 .17949 L
.41987 .19025 L
.37981 .2093 L
.36142 .21955 L
.33974 .23306 L
.30439 .25962 L
.29968 .26365 L
.26365 .29968 L
.25962 .30439 L
.23306 .33974 L
.21955 .36142 L
.2093 .37981 L
.19025 .41987 L
.17949 .44698 L
.17474 .45994 L
.16166 .5 L
.15063 .54006 L
.14136 .58013 L
.13942 .58957 L
.13319 .62019 L
.12587 .66026 L
.11937 .70032 L
.11358 .74038 L
.10844 .78045 L
.10398 .82051 L
.10037 .86058 L
.09936 .87474 L
.09689 .90064 L
.09327 .94071 L
.08987 .98077 L
s
1 g
.98077 .12002 m
.94071 .11756 L
.90064 .12601 L
.86058 .13326 L
.82472 .13942 L
.82051 .14006 L
.78045 .14644 L
.74038 .14819 L
.70032 .15875 L
.66026 .16933 L
.62334 .17949 L
.62019 .17986 L
.58013 .19005 L
.54006 .20431 L
.50251 .21955 L
.5 .22042 L
.45994 .23826 L
.42195 .25962 L
.41987 .26078 L
.37981 .28751 L
.36431 .29968 L
.33974 .32107 L
.32107 .33974 L
.29968 .36431 L
.28751 .37981 L
.26078 .41987 L
.25962 .42195 L
.23826 .45994 L
.22042 .5 L
.21955 .50251 L
.20431 .54006 L
.19005 .58013 L
.17986 .62019 L
.17949 .62334 L
.16933 .66026 L
.15875 .70032 L
.14819 .74038 L
.14644 .78045 L
.14006 .82051 L
.13942 .82472 L
.13326 .86058 L
.12601 .90064 L
.11756 .94071 L
.12002 .98077 L
.98077 .98077 L
F
0 g
.98077 .12002 m
.94071 .11756 L
.90064 .12601 L
.86058 .13326 L
.82472 .13942 L
.82051 .14006 L
.78045 .14644 L
.74038 .14819 L
.70032 .15875 L
.66026 .16933 L
.62334 .17949 L
.62019 .17986 L
.58013 .19005 L
.54006 .20431 L
.50251 .21955 L
.5 .22042 L
.45994 .23826 L
.42195 .25962 L
.41987 .26078 L
.37981 .28751 L
.36431 .29968 L
.33974 .32107 L
.32107 .33974 L
.29968 .36431 L
.28751 .37981 L
.26078 .41987 L
.25962 .42195 L
.23826 .45994 L
.22042 .5 L
.21955 .50251 L
.20431 .54006 L
.19005 .58013 L
.17986 .62019 L
.17949 .62334 L
.16933 .66026 L
.15875 .70032 L
.14819 .74038 L
.14644 .78045 L
.14006 .82051 L
.13942 .82472 L
.13326 .86058 L
.12601 .90064 L
.11756 .94071 L
.12002 .98077 L
s
.9 g
.98077 .22616 m
.94071 .2394 L
.90064 .2432 L
.86058 .25392 L
.84085 .25962 L
.82051 .26679 L
.78045 .28304 L
.74038 .29305 L
.72355 .29968 L
.70032 .31034 L
.66026 .33049 L
.63556 .33974 L
.62019 .3485 L
.58013 .37301 L
.56726 .37981 L
.54006 .39944 L
.51245 .41987 L
.5 .43042 L
.46757 .45994 L
.45994 .46757 L
.43042 .5 L
.41987 .51245 L
.39944 .54006 L
.37981 .56726 L
.37301 .58013 L
.3485 .62019 L
.33974 .63556 L
.33049 .66026 L
.31034 .70032 L
.29968 .72355 L
.29305 .74038 L
.28304 .78045 L
.26679 .82051 L
.25962 .84085 L
.25392 .86058 L
.2432 .90064 L
.2394 .94071 L
.22616 .98077 L
.98077 .98077 L
F
0 g
.98077 .22616 m
.94071 .2394 L
.90064 .2432 L
.86058 .25392 L
.84085 .25962 L
.82051 .26679 L
.78045 .28304 L
.74038 .29305 L
.72355 .29968 L
.70032 .31034 L
.66026 .33049 L
.63556 .33974 L
.62019 .3485 L
.58013 .37301 L
.56726 .37981 L
.54006 .39944 L
.51245 .41987 L
.5 .43042 L
.46757 .45994 L
.45994 .46757 L
.43042 .5 L
.41987 .51245 L
.39944 .54006 L
.37981 .56726 L
.37301 .58013 L
.3485 .62019 L
.33974 .63556 L
.33049 .66026 L
.31034 .70032 L
.29968 .72355 L
.29305 .74038 L
.28304 .78045 L
.26679 .82051 L
.25962 .84085 L
.25392 .86058 L
.2432 .90064 L
.2394 .94071 L
.22616 .98077 L
s
.8 g
.98077 .25599 m
.95828 .25962 L
.94071 .26449 L
.90064 .27632 L
.86058 .28885 L
.82418 .29968 L
.82051 .30101 L
.78045 .3164 L
.74038 .33287 L
.7236 .33974 L
.70032 .35097 L
.66026 .3718 L
.64537 .37981 L
.62019 .39514 L
.5827 .41987 L
.58013 .42173 L
.54006 .45283 L
.53157 .45994 L
.5 .48894 L
.48894 .5 L
.45994 .53157 L
.45283 .54006 L
.42173 .58013 L
.41987 .5827 L
.39514 .62019 L
.37981 .64537 L
.3718 .66026 L
.35097 .70032 L
.33974 .7236 L
.33287 .74038 L
.3164 .78045 L
.30101 .82051 L
.29968 .82418 L
.28885 .86058 L
.27632 .90064 L
.26449 .94071 L
.25962 .95828 L
.25599 .98077 L
.98077 .98077 L
F
0 g
.98077 .25599 m
.95828 .25962 L
.94071 .26449 L
.90064 .27632 L
.86058 .28885 L
.82418 .29968 L
.82051 .30101 L
.78045 .3164 L
.74038 .33287 L
.7236 .33974 L
.70032 .35097 L
.66026 .3718 L
.64537 .37981 L
.62019 .39514 L
.5827 .41987 L
.58013 .42173 L
.54006 .45283 L
.53157 .45994 L
.5 .48894 L
.48894 .5 L
.45994 .53157 L
.45283 .54006 L
.42173 .58013 L
.41987 .5827 L
.39514 .62019 L
.37981 .64537 L
.3718 .66026 L
.35097 .70032 L
.33974 .7236 L
.33287 .74038 L
.3164 .78045 L
.30101 .82051 L
.29968 .82418 L
.28885 .86058 L
.27632 .90064 L
.26449 .94071 L
.25962 .95828 L
.25599 .98077 L
s
.7 g
.98077 .27733 m
.94071 .28861 L
.9024 .29968 L
.90064 .30025 L
.86058 .31389 L
.82051 .32868 L
.79202 .33974 L
.78045 .34468 L
.74038 .36293 L
.70615 .37981 L
.70032 .38292 L
.66026 .40578 L
.63748 .41987 L
.62019 .43146 L
.58125 .45994 L
.58013 .46082 L
.54006 .49483 L
.53445 .5 L
.5 .53445 L
.49483 .54006 L
.46082 .58013 L
.45994 .58125 L
.43146 .62019 L
.41987 .63748 L
.40578 .66026 L
.38292 .70032 L
.37981 .70615 L
.36293 .74038 L
.34468 .78045 L
.33974 .79202 L
.32868 .82051 L
.31389 .86058 L
.30025 .90064 L
.29968 .9024 L
.28861 .94071 L
.27733 .98077 L
.98077 .98077 L
F
0 g
.98077 .27733 m
.94071 .28861 L
.9024 .29968 L
.90064 .30025 L
.86058 .31389 L
.82051 .32868 L
.79202 .33974 L
.78045 .34468 L
.74038 .36293 L
.70615 .37981 L
.70032 .38292 L
.66026 .40578 L
.63748 .41987 L
.62019 .43146 L
.58125 .45994 L
.58013 .46082 L
.54006 .49483 L
.53445 .5 L
.5 .53445 L
.49483 .54006 L
.46082 .58013 L
.45994 .58125 L
.43146 .62019 L
.41987 .63748 L
.40578 .66026 L
.38292 .70032 L
.37981 .70615 L
.36293 .74038 L
.34468 .78045 L
.33974 .79202 L
.32868 .82051 L
.31389 .86058 L
.30025 .90064 L
.29968 .9024 L
.28861 .94071 L
.27733 .98077 L
s
.6 g
.98077 .29711 m
.97156 .29968 L
.94071 .30917 L
.90064 .32244 L
.86058 .33675 L
.85254 .33974 L
.82051 .35264 L
.78045 .37021 L
.75996 .37981 L
.74038 .38964 L
.70032 .41144 L
.68589 .41987 L
.66026 .43594 L
.62528 .45994 L
.62019 .46367 L
.58013 .49543 L
.57478 .5 L
.54006 .53206 L
.53206 .54006 L
.5 .57478 L
.49543 .58013 L
.46367 .62019 L
.45994 .62528 L
.43594 .66026 L
.41987 .68589 L
.41144 .70032 L
.38964 .74038 L
.37981 .75996 L
.37021 .78045 L
.35264 .82051 L
.33974 .85254 L
.33675 .86058 L
.32244 .90064 L
.30917 .94071 L
.29968 .97156 L
.29711 .98077 L
.98077 .98077 L
F
0 g
.98077 .29711 m
.97156 .29968 L
.94071 .30917 L
.90064 .32244 L
.86058 .33675 L
.85254 .33974 L
.82051 .35264 L
.78045 .37021 L
.75996 .37981 L
.74038 .38964 L
.70032 .41144 L
.68589 .41987 L
.66026 .43594 L
.62528 .45994 L
.62019 .46367 L
.58013 .49543 L
.57478 .5 L
.54006 .53206 L
.53206 .54006 L
.5 .57478 L
.49543 .58013 L
.46367 .62019 L
.45994 .62528 L
.43594 .66026 L
.41987 .68589 L
.41144 .70032 L
.38964 .74038 L
.37981 .75996 L
.37021 .78045 L
.35264 .82051 L
.33974 .85254 L
.33675 .86058 L
.32244 .90064 L
.30917 .94071 L
.29968 .97156 L
.29711 .98077 L
s
.5 g
.98077 .31602 m
.94071 .32896 L
.90948 .33974 L
.90064 .34295 L
.86058 .35841 L
.82051 .37536 L
.81056 .37981 L
.78045 .39409 L
.74038 .41492 L
.73143 .41987 L
.70032 .43819 L
.66668 .45994 L
.66026 .46435 L
.62019 .49404 L
.61273 .5 L
.58013 .52796 L
.56708 .54006 L
.54006 .56708 L
.52796 .58013 L
.5 .61273 L
.49404 .62019 L
.46435 .66026 L
.45994 .66668 L
.43819 .70032 L
.41987 .73143 L
.41492 .74038 L
.39409 .78045 L
.37981 .81056 L
.37536 .82051 L
.35841 .86058 L
.34295 .90064 L
.33974 .90948 L
.32896 .94071 L
.31602 .98077 L
.98077 .98077 L
F
0 g
.98077 .31602 m
.94071 .32896 L
.90948 .33974 L
.90064 .34295 L
.86058 .35841 L
.82051 .37536 L
.81056 .37981 L
.78045 .39409 L
.74038 .41492 L
.73143 .41987 L
.70032 .43819 L
.66668 .45994 L
.66026 .46435 L
.62019 .49404 L
.61273 .5 L
.58013 .52796 L
.56708 .54006 L
.54006 .56708 L
.52796 .58013 L
.5 .61273 L
.49404 .62019 L
.46435 .66026 L
.45994 .66668 L
.43819 .70032 L
.41987 .73143 L
.41492 .74038 L
.39409 .78045 L
.37981 .81056 L
.37536 .82051 L
.35841 .86058 L
.34295 .90064 L
.33974 .90948 L
.32896 .94071 L
.31602 .98077 L
s
.4 g
.98077 .33461 m
.96535 .33974 L
.94071 .34824 L
.90064 .36324 L
.86058 .37966 L
.86023 .37981 L
.82051 .39764 L
.78045 .4176 L
.77613 .41987 L
.74038 .4397 L
.70731 .45994 L
.70032 .46445 L
.66026 .49229 L
.64998 .5 L
.62019 .52382 L
.60145 .54006 L
.58013 .55986 L
.55986 .58013 L
.54006 .60145 L
.52382 .62019 L
.5 .64998 L
.49229 .66026 L
.46445 .70032 L
.45994 .70731 L
.4397 .74038 L
.41987 .77613 L
.4176 .78045 L
.39764 .82051 L
.37981 .86023 L
.37966 .86058 L
.36324 .90064 L
.34824 .94071 L
.33974 .96535 L
.33461 .98077 L
.98077 .98077 L
F
0 g
.98077 .33461 m
.96535 .33974 L
.94071 .34824 L
.90064 .36324 L
.86058 .37966 L
.86023 .37981 L
.82051 .39764 L
.78045 .4176 L
.77613 .41987 L
.74038 .4397 L
.70731 .45994 L
.70032 .46445 L
.66026 .49229 L
.64998 .5 L
.62019 .52382 L
.60145 .54006 L
.58013 .55986 L
.55986 .58013 L
.54006 .60145 L
.52382 .62019 L
.5 .64998 L
.49229 .66026 L
.46445 .70032 L
.45994 .70731 L
.4397 .74038 L
.41987 .77613 L
.4176 .78045 L
.39764 .82051 L
.37981 .86023 L
.37966 .86058 L
.36324 .90064 L
.34824 .94071 L
.33974 .96535 L
.33461 .98077 L
s
.3 g
.98077 .35331 m
.94071 .36801 L
.91083 .37981 L
.90064 .38387 L
.86058 .40121 L
.82168 .41987 L
.82051 .42044 L
.78045 .44147 L
.74871 .45994 L
.74038 .46497 L
.70032 .49122 L
.68792 .5 L
.66026 .5207 L
.63646 .54006 L
.62019 .55414 L
.59237 .58013 L
.58013 .59237 L
.55414 .62019 L
.54006 .63646 L
.5207 .66026 L
.5 .68792 L
.49122 .70032 L
.46497 .74038 L
.45994 .74871 L
.44147 .78045 L
.42044 .82051 L
.41987 .82168 L
.40121 .86058 L
.38387 .90064 L
.37981 .91083 L
.36801 .94071 L
.35331 .98077 L
.98077 .98077 L
F
0 g
.98077 .35331 m
.94071 .36801 L
.91083 .37981 L
.90064 .38387 L
.86058 .40121 L
.82168 .41987 L
.82051 .42044 L
.78045 .44147 L
.74871 .45994 L
.74038 .46497 L
.70032 .49122 L
.68792 .5 L
.66026 .5207 L
.63646 .54006 L
.62019 .55414 L
.59237 .58013 L
.58013 .59237 L
.55414 .62019 L
.54006 .63646 L
.5207 .66026 L
.5 .68792 L
.49122 .70032 L
.46497 .74038 L
.45994 .74871 L
.44147 .78045 L
.42044 .82051 L
.41987 .82168 L
.40121 .86058 L
.38387 .90064 L
.37981 .91083 L
.36801 .94071 L
.35331 .98077 L
s
.2 g
.98077 .3736 m
.96467 .37981 L
.94071 .38862 L
.90064 .40568 L
.87007 .41987 L
.86058 .42415 L
.82051 .44441 L
.7927 .45994 L
.78045 .46682 L
.74038 .49184 L
.72825 .5 L
.70032 .51955 L
.67366 .54006 L
.66026 .55087 L
.62692 .58013 L
.62019 .58639 L
.58639 .62019 L
.58013 .62692 L
.55087 .66026 L
.54006 .67366 L
.51955 .70032 L
.5 .72825 L
.49184 .74038 L
.46682 .78045 L
.45994 .7927 L
.44441 .82051 L
.42415 .86058 L
.41987 .87007 L
.40568 .90064 L
.38862 .94071 L
.37981 .96467 L
.3736 .98077 L
.98077 .98077 L
F
0 g
.98077 .3736 m
.96467 .37981 L
.94071 .38862 L
.90064 .40568 L
.87007 .41987 L
.86058 .42415 L
.82051 .44441 L
.7927 .45994 L
.78045 .46682 L
.74038 .49184 L
.72825 .5 L
.70032 .51955 L
.67366 .54006 L
.66026 .55087 L
.62692 .58013 L
.62019 .58639 L
.58639 .62019 L
.58013 .62692 L
.55087 .66026 L
.54006 .67366 L
.51955 .70032 L
.5 .72825 L
.49184 .74038 L
.46682 .78045 L
.45994 .7927 L
.44441 .82051 L
.42415 .86058 L
.41987 .87007 L
.40568 .90064 L
.38862 .94071 L
.37981 .96467 L
.3736 .98077 L
s
.1 g
.98077 .39455 m
.94071 .41255 L
.92477 .41987 L
.90064 .4293 L
.86058 .45001 L
.84241 .45994 L
.82051 .47097 L
.78045 .49573 L
.77385 .5 L
.74038 .52179 L
.71564 .54006 L
.70032 .55138 L
.66591 .58013 L
.66026 .58494 L
.62284 .62019 L
.62019 .62284 L
.58494 .66026 L
.58013 .66591 L
.55138 .70032 L
.54006 .71564 L
.52179 .74038 L
.5 .77385 L
.49573 .78045 L
.47097 .82051 L
.45994 .84241 L
.45001 .86058 L
.4293 .90064 L
.41987 .92477 L
.41255 .94071 L
.39455 .98077 L
.98077 .98077 L
F
0 g
.98077 .39455 m
.94071 .41255 L
.92477 .41987 L
.90064 .4293 L
.86058 .45001 L
.84241 .45994 L
.82051 .47097 L
.78045 .49573 L
.77385 .5 L
.74038 .52179 L
.71564 .54006 L
.70032 .55138 L
.66591 .58013 L
.66026 .58494 L
.62284 .62019 L
.62019 .62284 L
.58494 .66026 L
.58013 .66591 L
.55138 .70032 L
.54006 .71564 L
.52179 .74038 L
.5 .77385 L
.49573 .78045 L
.47097 .82051 L
.45994 .84241 L
.45001 .86058 L
.4293 .90064 L
.41987 .92477 L
.41255 .94071 L
.39455 .98077 L
s
.98077 .42602 m
.94071 .43593 L
.90612 .45994 L
.90064 .46296 L
.86058 .47907 L
.83172 .5 L
.82051 .50734 L
.78045 .53186 L
.76956 .54006 L
.74038 .55815 L
.71481 .58013 L
.70032 .58932 L
.66761 .62019 L
.66026 .62609 L
.62609 .66026 L
.62019 .66761 L
.58932 .70032 L
.58013 .71481 L
.55815 .74038 L
.54006 .76956 L
.53186 .78045 L
.50734 .82051 L
.5 .83172 L
.47907 .86058 L
.46296 .90064 L
.45994 .90612 L
.43593 .94071 L
.42602 .98077 L
.98077 .98077 L
F
.98077 .42602 m
.94071 .43593 L
.90612 .45994 L
.90064 .46296 L
.86058 .47907 L
.83172 .5 L
.82051 .50734 L
.78045 .53186 L
.76956 .54006 L
.74038 .55815 L
.71481 .58013 L
.70032 .58932 L
.66761 .62019 L
.66026 .62609 L
.62609 .66026 L
.62019 .66761 L
.58932 .70032 L
.58013 .71481 L
.55815 .74038 L
.54006 .76956 L
.53186 .78045 L
.50734 .82051 L
.5 .83172 L
.47907 .86058 L
.46296 .90064 L
.45994 .90612 L
.43593 .94071 L
.42602 .98077 L
s
.1 g
.98077 .53062 m
.96352 .54006 L
.94071 .55801 L
.90064 .57718 L
.89731 .58013 L
.86058 .6037 L
.83914 .62019 L
.82051 .63595 L
.787 .66026 L
.78045 .66606 L
.7414 .70032 L
.74038 .70129 L
.70129 .74038 L
.70032 .7414 L
.66606 .78045 L
.66026 .787 L
.63595 .82051 L
.62019 .83914 L
.6037 .86058 L
.58013 .89731 L
.57718 .90064 L
.55801 .94071 L
.54006 .96352 L
.53062 .98077 L
.98077 .98077 L
F
0 g
.98077 .53062 m
.96352 .54006 L
.94071 .55801 L
.90064 .57718 L
.89731 .58013 L
.86058 .6037 L
.83914 .62019 L
.82051 .63595 L
.787 .66026 L
.78045 .66606 L
.7414 .70032 L
.74038 .70129 L
.70129 .74038 L
.70032 .7414 L
.66606 .78045 L
.66026 .787 L
.63595 .82051 L
.62019 .83914 L
.6037 .86058 L
.58013 .89731 L
.57718 .90064 L
.55801 .94071 L
.54006 .96352 L
.53062 .98077 L
s
.2 g
.98077 .56182 m
.94608 .58013 L
.94071 .5838 L
.90064 .61084 L
.88497 .62019 L
.86058 .63827 L
.83074 .66026 L
.82051 .6686 L
.78285 .70032 L
.78045 .70249 L
.74038 .74038 L
.74038 .74038 L
.70249 .78045 L
.70032 .78285 L
.6686 .82051 L
.66026 .83074 L
.63827 .86058 L
.62019 .88497 L
.61084 .90064 L
.5838 .94071 L
.58013 .94608 L
.56182 .98077 L
.98077 .98077 L
F
0 g
.98077 .56182 m
.94608 .58013 L
.94071 .5838 L
.90064 .61084 L
.88497 .62019 L
.86058 .63827 L
.83074 .66026 L
.82051 .6686 L
.78285 .70032 L
.78045 .70249 L
.74038 .74038 L
.74038 .74038 L
.70249 .78045 L
.70032 .78285 L
.6686 .82051 L
.66026 .83074 L
.63827 .86058 L
.62019 .88497 L
.61084 .90064 L
.5838 .94071 L
.58013 .94608 L
.56182 .98077 L
s
.3 g
.98077 .58297 m
.94071 .608 L
.92123 .62019 L
.90064 .63446 L
.86477 .66026 L
.86058 .66348 L
.82051 .69585 L
.81513 .70032 L
.78045 .7315 L
.77102 .74038 L
.74038 .77102 L
.7315 .78045 L
.70032 .81513 L
.69585 .82051 L
.66348 .86058 L
.66026 .86477 L
.63446 .90064 L
.62019 .92123 L
.608 .94071 L
.58297 .98077 L
.98077 .98077 L
F
0 g
.98077 .58297 m
.94071 .608 L
.92123 .62019 L
.90064 .63446 L
.86477 .66026 L
.86058 .66348 L
.82051 .69585 L
.81513 .70032 L
.78045 .7315 L
.77102 .74038 L
.74038 .77102 L
.7315 .78045 L
.70032 .81513 L
.69585 .82051 L
.66348 .86058 L
.66026 .86477 L
.63446 .90064 L
.62019 .92123 L
.608 .94071 L
.58297 .98077 L
s
.4 g
.98077 .60334 m
.95325 .62019 L
.94071 .62854 L
.90064 .65627 L
.89505 .66026 L
.86058 .68666 L
.84357 .70032 L
.82051 .71998 L
.79778 .74038 L
.78045 .75682 L
.75682 .78045 L
.74038 .79778 L
.71998 .82051 L
.70032 .84357 L
.68666 .86058 L
.66026 .89505 L
.65627 .90064 L
.62854 .94071 L
.62019 .95325 L
.60334 .98077 L
.98077 .98077 L
F
0 g
.98077 .60334 m
.95325 .62019 L
.94071 .62854 L
.90064 .65627 L
.89505 .66026 L
.86058 .68666 L
.84357 .70032 L
.82051 .71998 L
.79778 .74038 L
.78045 .75682 L
.75682 .78045 L
.74038 .79778 L
.71998 .82051 L
.70032 .84357 L
.68666 .86058 L
.66026 .89505 L
.65627 .90064 L
.62854 .94071 L
.62019 .95325 L
.60334 .98077 L
s
.5 g
.98077 .62205 m
.94071 .64835 L
.92349 .66026 L
.90064 .6769 L
.87029 .70032 L
.86058 .70818 L
.823 .74038 L
.82051 .74262 L
.7807 .78045 L
.78045 .7807 L
.74262 .82051 L
.74038 .823 L
.70818 .86058 L
.70032 .87029 L
.6769 .90064 L
.66026 .92349 L
.64835 .94071 L
.62205 .98077 L
.98077 .98077 L
F
0 g
.98077 .62205 m
.94071 .64835 L
.92349 .66026 L
.90064 .6769 L
.87029 .70032 L
.86058 .70818 L
.823 .74038 L
.82051 .74262 L
.7807 .78045 L
.78045 .7807 L
.74262 .82051 L
.74038 .823 L
.70818 .86058 L
.70032 .87029 L
.6769 .90064 L
.66026 .92349 L
.64835 .94071 L
.62205 .98077 L
s
.6 g
.98077 .64062 m
.9514 .66026 L
.94071 .66763 L
.90064 .69718 L
.89658 .70032 L
.86058 .72945 L
.84782 .74038 L
.82051 .76495 L
.8042 .78045 L
.78045 .8042 L
.76495 .82051 L
.74038 .84782 L
.72945 .86058 L
.70032 .89658 L
.69718 .90064 L
.66763 .94071 L
.66026 .9514 L
.64062 .98077 L
.98077 .98077 L
F
0 g
.98077 .64062 m
.9514 .66026 L
.94071 .66763 L
.90064 .69718 L
.89658 .70032 L
.86058 .72945 L
.84782 .74038 L
.82051 .76495 L
.8042 .78045 L
.78045 .8042 L
.76495 .82051 L
.74038 .84782 L
.72945 .86058 L
.70032 .89658 L
.69718 .90064 L
.66763 .94071 L
.66026 .9514 L
.64062 .98077 L
s
.7 g
.98077 .65966 m
.97988 .66026 L
.94071 .68738 L
.9233 .70032 L
.90064 .71769 L
.87304 .74038 L
.86058 .75099 L
.8281 .78045 L
.82051 .78764 L
.78764 .82051 L
.78045 .8281 L
.75099 .86058 L
.74038 .87304 L
.71769 .90064 L
.70032 .9233 L
.68738 .94071 L
.66026 .97988 L
.65966 .98077 L
.98077 .98077 L
F
0 g
.98077 .65966 m
.97988 .66026 L
.94071 .68738 L
.9233 .70032 L
.90064 .71769 L
.87304 .74038 L
.86058 .75099 L
.8281 .78045 L
.82051 .78764 L
.78764 .82051 L
.78045 .8281 L
.75099 .86058 L
.74038 .87304 L
.71769 .90064 L
.70032 .9233 L
.68738 .94071 L
.66026 .97988 L
.65966 .98077 L
s
.8 g
.98077 .67924 m
.95194 .70032 L
.94071 .70803 L
.90064 .73989 L
.90004 .74038 L
.86058 .7741 L
.85359 .78045 L
.82051 .81182 L
.81182 .82051 L
.78045 .85359 L
.7741 .86058 L
.74038 .90004 L
.73989 .90064 L
.70803 .94071 L
.70032 .95194 L
.67924 .98077 L
.98077 .98077 L
F
0 g
.98077 .67924 m
.95194 .70032 L
.94071 .70803 L
.90064 .73989 L
.90004 .74038 L
.86058 .7741 L
.85359 .78045 L
.82051 .81182 L
.81182 .82051 L
.78045 .85359 L
.7741 .86058 L
.74038 .90004 L
.73989 .90064 L
.70803 .94071 L
.70032 .95194 L
.67924 .98077 L
s
.9 g
.98077 .70152 m
.94071 .73186 L
.93014 .74038 L
.90064 .76382 L
.88182 .78045 L
.86058 .79922 L
.8384 .82051 L
.82051 .8384 L
.79922 .86058 L
.78045 .88182 L
.76382 .90064 L
.74038 .93014 L
.73186 .94071 L
.70152 .98077 L
.98077 .98077 L
F
0 g
.98077 .70152 m
.94071 .73186 L
.93014 .74038 L
.90064 .76382 L
.88182 .78045 L
.86058 .79922 L
.8384 .82051 L
.82051 .8384 L
.79922 .86058 L
.78045 .88182 L
.76382 .90064 L
.74038 .93014 L
.73186 .94071 L
.70152 .98077 L
s
1 g
.98077 .72902 m
.97033 .74038 L
.94071 .76314 L
.91454 .78045 L
.90064 .79694 L
.87467 .82051 L
.86058 .83395 L
.83395 .86058 L
.82051 .87467 L
.79694 .90064 L
.78045 .91454 L
.76314 .94071 L
.74038 .97033 L
.72902 .98077 L
.98077 .98077 L
F
0 g
.98077 .72902 m
.97033 .74038 L
.94071 .76314 L
.91454 .78045 L
.90064 .79694 L
.87467 .82051 L
.86058 .83395 L
.83395 .86058 L
.82051 .87467 L
.79694 .90064 L
.78045 .91454 L
.76314 .94071 L
.74038 .97033 L
.72902 .98077 L
s
.9 g
.98077 .83664 m
.95363 .86058 L
.94071 .87664 L
.91416 .90064 L
.90064 .91416 L
.87664 .94071 L
.86058 .95363 L
.83664 .98077 L
.98077 .98077 L
F
0 g
.98077 .83664 m
.95363 .86058 L
.94071 .87664 L
.91416 .90064 L
.90064 .91416 L
.87664 .94071 L
.86058 .95363 L
.83664 .98077 L
s
.8 g
.98077 .86652 m
.94204 .90064 L
.94071 .90309 L
.90309 .94071 L
.90064 .94204 L
.86652 .98077 L
.98077 .98077 L
F
0 g
.98077 .86652 m
.94204 .90064 L
.94071 .90309 L
.90309 .94071 L
.90064 .94204 L
.86652 .98077 L
s
.7 g
.98077 .88965 m
.95874 .90064 L
.94071 .92736 L
.92736 .94071 L
.90064 .95874 L
.88965 .98077 L
.98077 .98077 L
F
0 g
.98077 .88965 m
.95874 .90064 L
.94071 .92736 L
.92736 .94071 L
.90064 .95874 L
.88965 .98077 L
s
.6 g
.98077 .90922 m
.9474 .94071 L
.94071 .9474 L
.90922 .98077 L
.98077 .98077 L
F
0 g
.98077 .90922 m
.9474 .94071 L
.94071 .9474 L
.90922 .98077 L
s
.5 g
.98077 .92821 m
.96659 .94071 L
.94071 .96659 L
.92821 .98077 L
.98077 .98077 L
F
0 g
.98077 .92821 m
.96659 .94071 L
.94071 .96659 L
.92821 .98077 L
s
.4 g
.98077 .94669 m
.94669 .98077 L
.98077 .98077 L
F
0 g
.98077 .94669 m
.94669 .98077 L
s
.3 g
.98077 .96562 m
.96562 .98077 L
.98077 .98077 L
F
0 g
.98077 .96562 m
.96562 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`007P3oool01@3^k^h0<c<c0000000c<c<0k^k^02D0
oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0
gMgM02H0oooo100000000`0A4A40oooo0?ooo`0T0?ooo`@0000000<04A4A0?ooo`3oool00P3oool2
028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@0U0?ooo`D000009P3oool5000000D0oooo0P0R
8R850?ooo`0504A4A0000000000003<c<`3MgMd09@3oool01@2IVIT04A4A0000000c<c<0c<c<01@0
oooo000N0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL09@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo02L0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`0T0?ooo`0509VIV@0R8R80k^k^
0?ooo`14A4@09P3oool01@2IVIT08R8R0>k^kP3oool0A4A400D0oooo0P0R8R880?ooo`0307MgM`0c
<c<0oooo02@0oooo00D04A4A0;^k^`3oool0MgMg03<c<`0D0?ooo`007P3oool01@0A4A40oooo0?oo
o`3oool04A4A02D0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02@0
oooo00<0VIVI028R8P3^k^h0:03oool00`2IVIT08R8R0>k^kP0A0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool04P3oool001h0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`0W0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool03P3oool00`1gMgL0<c<c0?ooo`0V0?ooo`0309VIV@0R8R80k^k^
02P0oooo00<0VIVI028R8P3^k^h03`3oool00`1gMgL0<c<c0?ooo`0W0?ooo`030:ZZZP0A4A40oooo
01<0oooo000N0?ooo`050000003oool0oooo0?ooo`0000009@3oool01@000000oooo0?ooo`3oool0
000000`0oooo00D00000028R8P000000<c<c0<c<c00X0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool02`3oool01@0000008R8R0000000c<c<0c<c<02P0oooo00<0MgMg06IVIP3oool0
:03oool00`1gMgL0IVIV0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`09`3oool00`0A4A40
00000;^k^`0D0?ooo`007P3oool01@0A4A40oooo0?ooo`3oool04A4A02D0oooo00D04A4A0?ooo`3o
ool0oooo014A4@0<0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo00<0^k^k028R8P3oool04`3oool001h0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`0U0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0W0?ooo`050000002k^k/0oooo09VIV@0A4A409P3oool01@000000^k^k0?oo
o`2IVIT04A4A00`0oooo00<000000?ooo`3oool09`3oool01@0A4A40VIVI0?ooo`2k^k/0000001@0
oooo000N0?ooo`050>k^kP0c<c<0000003<c<`3^k^h09@3oool01@3^k^h0<c<c0000000c<c<0k^k^
00`0oooo1000000W0?ooo`80EEEE00<000000?ooo`3oool09P3oool205EEE@030000003oool0oooo
00/0oooo1000000V0?ooo`0509VIV@0A4A400000028R8P3<c<`09P3oool01@2IVIT04A4A0000000R
8R80c<c<00`0oooo1000000V0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0503oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool001X0ooooo`00001>00000040oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0A0?ooo`4000000@3oool000l0oooo00D0k^k^03<c<`000000
<c<c0>k^kP060?ooo`030000003oool0oooo0?l0ooooBP3oool100000040oooo000?0?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`3o0?ooodX0oooo0@0000010?ooo`00
3`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`40
00000@3oool000l0oooo00D000000?ooo`3oool0oooo000000060?ooo`<00000o`3ooom80?ooo`<0
00000@3oool000l0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0
ooooo`1oOgm007moO`H0oooo0@0000010?ooo`003`3oool01@0A4A40oooo0?ooo`3oool04A4A00H0
oooo00<000000?ooo`3oool0103ooooo07moOd00Ogmo1P3oool100000040oooo000?0?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`040?ooool0Ogmo@01oOgl60?ooo`40
00000@3oool000l0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000003oool0oooo00@0
oooof`1oOgmU000000D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oook@0Ogmo
9`00001T09VIV@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oooiT0Ogmo6`00
002;09VIV@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooogh0Ogmo6`00002V
09VIV@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooog40Ogmo3@00003109VI
V@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooofL0Ogmo2P00003>09VIV@H0
oooo0@0000010?ooo`006P3oool2000000D0ooooH01oOgl700000;L0VIVI8P0000040?ooo`800000
0@3oool001X0oooo00<000000?ooo`3oool0103ooomF07moO`X00000X`2IVITK00000240/k>c1P3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0ooooC@1oOgl900000:00VIVI3@00000l
0;>c/`H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooodP0Ogmo1@00002>09VI
VA/00000B@2c/k<60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103ooom407moO`@0
0000QP2IVIT=000006@0/k>c1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
@01oOgl4000007d0VIVI3@00001a0;>c/`H0oooo0@0000010?ooo`006P3oool00`000000oooo0?oo
o`040?ooocd0Ogmo0`00001d09VIV@d00000N02c/k<7000000D0oooo0@0000010?ooo`006P3oool0
0`000000oooo0?ooo`040?ooocX0Ogmo0`00001]09VIV@X00000JP2c/k<K000000H0c<c<1P3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo=`1oOgl3000006T0VIVI1`00001W0;>c
/`d000008@3<c<`60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103ooold07moO`<0
0000HP2IVIT:00000600/k>c3P00000^0<c<c0H0oooo0@0000010?ooo`006P3oool2000000D0oooo
<@1oOgl3000005`0VIVI2@00001M0;>c/`d00000?03<c<`50?ooo`8000000@3oool001X0oooo00<0
00000?ooo`3oool0103oool_07moO`800000FP2IVIT5000005`0/k>c2P0000190<c<c0H0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooobd0Ogmo0P00001H09VIV@@00000FP2c/k<7
000005<0c<c<1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo:P1oOgl30000
05D0VIVI1@00001D0;>c/`X00000E`3<c<`4000000D0oooo0@0000010?ooo`006P3oool00`000000
oooo0?ooo`040?ooobP0Ogmo0P00001A09VIV@L00000C`2c/k<:000005X0c<c<1`0000030>KViPH0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooobL0Ogmo00<0000009VIV@2IVIT0
B`2IVIT6000004l0/k>c1`00001J0<c<c0X000002P3Vi^H60?ooo`4000000@3oool001X0oooo00<0
00000?ooo`3oool0103ooolV07moO`030000002IVIT0VIVI04T0VIVI0`00001?0;>c/`H00000EP3<
c<`;000001@0i^KV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo901oOgl2
000004L0VIVI1@00001<0;>c/`H00000C@3<c<`?000001l0i^KV1P3oool100000040oooo000J0?oo
o`030000003oool0oooo00@0oooo8`1oOgl00`000000VIVI09VIV@1209VIV@D00000BP2c/k<70000
04T0c<c<2P00000^0>KViPH0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooob80
Ogmo00<0000009VIV@2IVIT0@02IVIT3000004P0/k>c1`0000190<c<c0L00000>03Vi^H60?ooo`40
00000@3oool001X0oooo0P0000050?ooob40Ogmo00<0000009VIV@2IVIT0?P2IVIT3000004D0/k>c
1P0000160<c<c0X00000?`3Vi^H50?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103o
oolP07moO`030000002IVIT0VIVI03`0VIVI0`0000110;>c/`L00000@P3<c<`:000004T0i^KV1P3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo7`1oOgl00`000000VIVI09VIV@0j
09VIV@<00000?P2c/k<600000480c<c<1`00001C0>KViPH0oooo0@0000010?ooo`006P3oool00`00
0000oooo0?ooo`040?oooah0Ogmo00<0000009VIV@2IVIT0>02IVIT3000003`0/k>c1@0000120<c<
c0H00000BP3Vi^HA000000D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oooad0
Ogmo00<0000009VIV@2IVIT0=`2IVIT2000003/0/k>c100000100<c<c0L00000B@3Vi^H7000001H0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oooa`0Ogmo00<0000009VIV@2IVIT0
=P2IVIT2000003T0/k>c1000000n0<c<c0H00000BP3Vi^H6000001d0oooo0@0000010?ooo`006P3o
ool00`000000oooo0?ooo`040?oooa/0Ogmo00<0000009VIV@2IVIT0=02IVIT3000003P0/k>c0`00
000m0<c<c0D00000B`3Vi^H5000002<0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`04
0?oooaX0Ogmo00<0000009VIV@2IVIT0<`2IVIT2000003P0/k>c0`00000l0<c<c0@00000C03Vi^H4
000002P0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oooaX0Ogmo00<0000009VI
V@2IVIT0<@2IVIT2000003L0/k>c0`00000k0<c<c0@00000B`3Vi^H5000002`0oooo0@0000010?oo
o`006P3oool00`000000oooo0?ooo`040?oooaT0Ogmo00<0000009VIV@2IVIT0<02IVIT2000003D0
/k>c1000000i0<c<c0D00000B@3Vi^H600000340oooo0@0000010?ooo`006P3oool00`000000oooo
0?ooo`040?oooaP0Ogmo00<0000009VIV@2IVIT0;`2IVIT2000003<0/k>c1000000i0<c<c0@00000
A`3Vi^H7000003L0oooo0@0000010?ooo`006P3oool2000000D0oooo601oOgl00`000000VIVI09VI
V@0]09VIV@800000<P2c/k<3000003T0c<c<100000140>KViPL00000?@3oool200000040oooo000J
0?ooo`030000003oool0oooo00@0oooo5`1oOgl00`000000VIVI09VIV@0/09VIV@800000<@2c/k<3
000003L0c<c<1@00000n0>KViPX00000A@3oool100000040oooo000J0?ooo`030000003oool0oooo
00@0oooo5`1oOgl00`000000VIVI09VIV@0[09VIV@030000002c/k<0/k>c02h0/k>c0`00000f0<c<
c0@00000>P3Vi^H9000004l0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oooaH0
Ogmo00<0000009VIV@2IVIT0:P2IVIT2000002h0/k>c0`00000e0<c<c0@00000>@3Vi^H5000005P0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oooaH0Ogmo00<0000009VIV@2IVIT0
:02IVIT2000002d0/k>c0`00000c0<c<c0D00000>@3Vi^H4000005d0oooo0@0000010?ooo`006P3o
ool00`000000oooo0?ooo`040?oooaD0Ogmo00<0000009VIV@2IVIT0:02IVIT00`000000/k>c0;>c
/`0[0;>c/`800000<@3<c<`5000003X0i^KV1000001Q0?ooo`4000000@3oool001X0oooo00<00000
0?ooo`3oool0103ooolE07moO`030000002IVIT0VIVI02L0VIVI00<000000;>c/`2c/k<0:@2c/k<3
00000300c<c<0`00000l0>KViP<00000I@3oool100000040oooo0000100c<c<0000003<c<`3^k^h5
0?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0103o
oolE07moO`030000002IVIT0VIVI02H0VIVI00<000000;>c/`2c/k<0:02c/k<200000300c<c<0`00
000k0>KViP@00000J03oool100000040oooo0000102IVIT0oooo09VIV@1gMgL50?ooo`808R8R203o
ool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo00@0oooo501oOgl00`000000VIVI09VI
V@0U09VIV@800000:@2c/k<2000002l0c<c<0`00000k0>KViP<00000K03oool100000040oooo0003
0?ooo`03014A4@3oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?oooa@0Ogmo00<0000009VIV@2IVIT0902IVIT00`000000/k>c0;>c/`0W0;>c/`800000;`3<c<`2
000003X0i^KV1000001_0?ooo`4000000@3oool000<0oooo00<000000?ooo`3oool03@3oool00`1g
MgL0<c<c0?ooo`040?ooo`<00000103ooolC07moO`030000002IVIT0VIVI02@0VIVI00<000000;>c
/`2c/k<09P2c/k<2000002h0c<c<0`00000h0>KViP@00000L@3oool300000040oooo00030?ooo`03
0000003oool0oooo00X0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo
00@0oooo4`1oOgl00`000000VIVI09VIV@0S09VIV@030000002c/k<0/k>c02D0/k>c0P00000]0<c<
c0<00000=`3Vi^H4000007L0oooo0@0000010?ooo`000`3oool00`0A4A40oooo0?ooo`0:0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103ooolB07moO`030000002IVIT0VIVI02<0
VIVI00<000000;>c/`2c/k<0902c/k<2000002`0c<c<0`00000e0>KViPD00000N`3oool100000040
oooo0000102IVIT0oooo09VIV@1gMgL<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103ooolB07moO`030000002IVIT0VIVI0280VIVI00<000000;>c/`2c/k<0902c/k<00`000000
c<c<0<c<c00Z0<c<c0800000=@3Vi^H300000800oooo0@0000010?ooo`0000@0<c<c0000000c<c<0
k^k^303oool4000000H0oooo00<000000?ooo`3oool0103ooolB07moO`030000002IVIT0VIVI0240
VIVI00<000000;>c/`2c/k<08`2c/k<2000002X0c<c<0`00000d0>KViP<00000P`3oool100000040
oooo000J0?ooo`030000003oool0oooo00@0oooo4@1oOgl00`000000VIVI09VIV@0Q09VIV@030000
002c/k<0/k>c02<0/k>c00<000000<c<c03<c<`0:03<c<`2000003@0i^KV0`0000260?ooo`400000
0@3oool001X0oooo00<000000?ooo`3oool0103ooolA07moO`030000002IVIT0VIVI0240VIVI00<0
00000;>c/`2c/k<08@2c/k<2000002T0c<c<0P00000b0>KViP@00000R@3oool100000040oooo000J
0?ooo`030000003oool0oooo00@0oooo4@1oOgl00`000000VIVI09VIV@0P09VIV@030000002c/k<0
/k>c0240/k>c00<000000<c<c03<c<`09P3<c<`300000340i^KV0`00002=0?ooo`4000000@3oool0
01X0oooo00<000000?ooo`3oool0103oool@07moO`030000002IVIT0VIVI0200VIVI00<000000;>c
/`2c/k<0802c/k<2000002L0c<c<0P00000a0>KViP<00000T03oool100000040oooo000J0?ooo`03
0000003oool0oooo00@0oooo401oOgl00`000000VIVI09VIV@0O09VIV@030000002c/k<0/k>c01l0
/k>c0P00000W0<c<c0800000<03Vi^H3000009<0oooo0@0000010?ooo`006P3oool2000000D0oooo
401oOgl00`000000VIVI09VIV@0O09VIV@030000002c/k<0/k>c01h0/k>c00<000000<c<c03<c<`0
903<c<`3000002l0i^KV0`00002E0?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool@07moO`030000002IVIT0VIVI01h0VIVI00<000000;>c/`2c/k<07@2c/k<2000002D0c<c<0P00
000`0>KViP800000V@3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo3`1oOgl0
0`000000VIVI09VIV@0N09VIV@030000002c/k<0/k>c01d0/k>c00<000000<c<c03<c<`08`3<c<`2
00000300i^KV0P00002K0?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool?07mo
O`030000002IVIT0VIVI01h0VIVI00<000000;>c/`2c/k<0702c/k<00`000000c<c<0<c<c00S0<c<
c0030000003Vi^H0i^KV02d0i^KV0`00002M0?ooo`4000000@3oool001X0oooo00<000000?ooo`3o
ool0103oool?07moO`030000002IVIT0VIVI01d0VIVI00<000000;>c/`2c/k<07@2c/k<00`000000
c<c<0<c<c00Q0<c<c0800000;P3Vi^H200000:00oooo0@0000010?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`h0Ogmo00<0000009VIV@2IVIT07@2IVIT00`000000/k>c0;>c/`0M0;>c/`030000
003<c<`0c<c<0240c<c<00<000000>KViP3Vi^H0;03Vi^H200000:80oooo0@0000010?ooo`006P3o
ool00`000000oooo0?ooo`040?ooo`h0Ogmo00<0000009VIV@2IVIT0702IVIT00`000000/k>c0;>c
/`0L0;>c/`8000008P3<c<`2000002`0i^KV0`00002T0?ooo`4000000@3oool001X0oooo00<00000
0?ooo`3oool0103oool>07moO`030000002IVIT0VIVI01`0VIVI00<000000;>c/`2c/k<06`2c/k<0
0`000000c<c<0<c<c00P0<c<c0800000;03Vi^H200000:L0oooo0@0000010?ooo`006P3oool00`00
0000oooo0?ooo`040?ooo`h0Ogmo00<0000009VIV@2IVIT06`2IVIT00`000000/k>c0;>c/`0K0;>c
/`030000003<c<`0c<c<0200c<c<00<000000>KViP3Vi^H0:P3Vi^H200000:40oooo0`0000050?oo
o`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool>07moO`030000002IVIT0VIVI01X0
VIVI00<000000;>c/`2c/k<06`2c/k<00`000000c<c<0<c<c00O0<c<c0800000:P3Vi^H300000:00
oooo0`0000020>KViPH0oooo0@0000010?ooo`006P3oool2000000D0oooo3@1oOgl00`000000VIVI
09VIV@0J09VIV@030000002c/k<0/k>c01/0/k>c00<000000<c<c03<c<`07P3<c<`2000002X0i^KV
0P00002P0?ooo`<000001@3Vi^H50?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool=07moO`030000002IVIT0VIVI01X0VIVI00<000000;>c/`2c/k<06P2c/k<00`000000c<c<0<c<
c00N0<c<c0030000003Vi^H0i^KV02P0i^KV0P00002O0?ooo`<00000203Vi^H60?ooo`4000000@3o
ool001X0oooo00<000000?ooo`3oool0103oool=07moO`030000002IVIT0VIVI01T0VIVI00<00000
0;>c/`2c/k<06P2c/k<00`000000c<c<0<c<c00N0<c<c0030000003Vi^H0i^KV02L0i^KV0P00002H
0?ooo`T000002`3Vi^H60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool=07mo
O`030000002IVIT0VIVI01P0VIVI00<000000;>c/`2c/k<06P2c/k<00`000000c<c<0<c<c00M0<c<
c0800000:03Vi^H200000940oooo2@00000D0>KViPH0oooo0@0000010?ooo`006P3oool00`000000
oooo0?ooo`040?ooo`d0Ogmo00<0000009VIV@2IVIT05`2IVIT00`000000/k>c0;>c/`0J0;>c/`03
0000003<c<`0c<c<01d0c<c<00<000000>KViP3Vi^H09P3Vi^H200000900oooo0`00000M0>KViPH0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`d0Ogmo00<0000009VIV@2IVIT0
5`2IVIT00`000000/k>c0;>c/`0I0;>c/`030000003<c<`0c<c<01d0c<c<00<000000>KViP3Vi^H0
9@3Vi^H2000008l0oooo0`00000P0>KViPH0oooo0@0000010?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`d0Ogmo00<0000009VIV@2IVIT05P2IVIT00`000000/k>c0;>c/`0I0;>c/`030000003<
c<`0c<c<01`0c<c<0P00000W0>KViP030000003oool0oooo08`0oooo0`00000S0>KViPH0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo``0Ogmo00<0000009VIV@2IVIT05`2IVIT0
0`000000/k>c0;>c/`0I0;>c/`030000003<c<`0c<c<01/0c<c<00<000000>KViP3Vi^H09@3Vi^H2
000008/0oooo1000000V0>KViPH0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oo
o``0Ogmo00<0000009VIV@2IVIT05`2IVIT00`000000/k>c0;>c/`0H0;>c/`030000003<c<`0c<c<
01/0c<c<00<000000>KViP3Vi^H0903Vi^H2000008X0oooo0`00000V0>KViPD000001@3oool10000
0040oooo000J0?ooo`030000003oool0oooo00@0oooo301oOgl00`000000VIVI09VIV@0F09VIV@03
0000002c/k<0/k>c01P0/k>c00<000000<c<c03<c<`06`3<c<`00`000000i^KV0>KViP0S0>KViP80
0000R@3oool3000002<0i^KV1P0000040<c<c0H0oooo0@0000010?ooo`006P3oool2000000D0oooo
301oOgl00`000000VIVI09VIV@0F09VIV@030000002c/k<0/k>c01P0/k>c00<000000<c<c03<c<`0
6P3<c<`00`000000i^KV0>KViP0S0>KViP030000003oool0oooo08H0oooo0`00000Q0>KViPD00000
2P3<c<`50?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103oool<07moO`030000002I
VIT0VIVI01D0VIVI00<000000;>c/`2c/k<0602c/k<00`000000c<c<0<c<c00J0<c<c0030000003V
i^H0i^KV0280i^KV0P0000260?ooo`<000008@3Vi^H3000000l0c<c<1P3oool100000040oooo000J
0?ooo`030000003oool0oooo00@0oooo301oOgl00`000000VIVI09VIV@0E09VIV@030000002c/k<0
/k>c01L0/k>c00<000000<c<c03<c<`06P3<c<`00`000000i^KV0>KViP0R0>KViP030000003oool0
oooo08<0oooo0`00000P0>KViP@000004P3<c<`60?ooo`4000000@3oool001X0oooo00<000000?oo
o`3oool0103oool;07moO`030000002IVIT0VIVI01H0VIVI00<000000;>c/`2c/k<05`2c/k<00`00
0000c<c<0<c<c00I0<c<c0030000003Vi^H0i^KV0240i^KV0P0000240?ooo`800000803Vi^H30000
01H0c<c<1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo2`1oOgl00`000000
VIVI09VIV@0E09VIV@030000002c/k<0/k>c01L0/k>c00<000000<c<c03<c<`06@3<c<`00`000000
i^KV0>KViP0P0>KViP800000Q03oool2000001l0i^KV0`00000I0<c<c0H0oooo0@0000010?ooo`00
6P3oool00`000000oooo0?ooo`040?ooo`/0Ogmo00<0000009VIV@2IVIT05@2IVIT00`000000/k>c
0;>c/`0F0;>c/`030000003<c<`0c<c<01T0c<c<00<000000>KViP3Vi^H0803Vi^H00`000000oooo
0?ooo`210?ooo`<000007P3Vi^H3000001X0c<c<0`0000050?ooo`4000000@3oool001X0oooo00<0
00000?ooo`3oool0103oool;07moO`030000002IVIT0VIVI01@0VIVI00<000000;>c/`2c/k<05P2c
/k<00`000000c<c<0<c<c00I0<c<c0030000003Vi^H0i^KV01l0i^KV0P0000220?ooo`8000007P3V
i^H3000001P0c<c<1@0000020;>c/`H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`/0Ogmo00<0000009VIV@2IVIT0502IVIT00`000000/k>c0;>c/`0F0;>c/`030000003<c<`0
c<c<01P0c<c<00<000000>KViP3Vi^H07`3Vi^H00`000000oooo0?ooo`1o0?ooo`<000007P3Vi^H2
000001L0c<c<100000070;>c/`H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`/0Ogmo00<0000009VIV@2IVIT0502IVIT00`000000/k>c0;>c/`0E0;>c/`030000003<c<`0c<c<
01P0c<c<00<000000>KViP3Vi^H07P3Vi^H2000007d0oooo1@00000N0>KViP<000005@3<c<`40000
00/0/k>c1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo2`1oOgl00`000000
VIVI09VIV@0C09VIV@030000002c/k<0/k>c01D0/k>c00<000000<c<c03<c<`0603<c<`00`000000
i^KV0>KViP0N0>KViP030000003oool0oooo07T0oooo1000000P0>KViP<000005@3<c<`3000000l0
/k>c1P3oool100000040oooo000J0?ooo`8000001@3oool:07moO`030000002IVIT0VIVI01@0VIVI
00<000000;>c/`2c/k<05@2c/k<00`000000c<c<0<c<c00G0<c<c0030000003Vi^H0i^KV01h0i^KV
00<000000?ooo`3oool0M`3oool300000200i^KV1000000E0<c<c0<000004P2c/k<50?ooo`800000
0@3oool001X0oooo00<000000?ooo`3oool0103oool:07moO`030000002IVIT0VIVI01@0VIVI00<0
00000;>c/`2c/k<0502c/k<00`000000c<c<0<c<c00G0<c<c0030000003Vi^H0i^KV01h0i^KV00<0
00000?ooo`3oool0M@3oool3000001l0i^KV1000000F0<c<c0<00000502c/k<2000000D0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`X0Ogmo00<0000009VIV@2IVIT04`2IVIT0
0`000000/k>c0;>c/`0D0;>c/`030000003<c<`0c<c<01L0c<c<00<000000>KViP3Vi^H07@3Vi^H2
000007H0oooo0P00000P0>KViP8000005P3<c<`4000001<0/k>c100000000`2IVIT0oooo0?ooo`04
0?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool:07moO`030000002IVIT0VIVI
01<0VIVI00<000000;>c/`2c/k<0502c/k<00`000000c<c<0<c<c00F0<c<c0030000003Vi^H0i^KV
01d0i^KV00<000000?ooo`3oool0M03oool200000200i^KV0P00000E0<c<c0<00000502c/k<30000
00D0VIVI1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo2P1oOgl00`000000
VIVI09VIV@0C09VIV@030000002c/k<0/k>c01<0/k>c00<000000<c<c03<c<`05P3<c<`00`000000
i^KV0>KViP0M0>KViP030000003oool0oooo07<0oooo0P00000O0>KViP<00000503<c<`3000001@0
/k>c0`00000809VIV@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`X0Ogmo
00<0000009VIV@2IVIT04P2IVIT00`000000/k>c0;>c/`0D0;>c/`030000003<c<`0c<c<01H0c<c<
00<000000>KViP3Vi^H0703Vi^H00`000000oooo0?ooo`1b0?ooo`8000007P3Vi^H3000001D0c<c<
0P00000D0;>c/`<000002`2IVIT60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool:07moO`030000002IVIT0VIVI0180VIVI00<000000;>c/`2c/k<04`2c/k<00`000000c<c<0<c<
c00F0<c<c0030000003Vi^H0i^KV01`0i^KV00<000000?ooo`3oool0L@3oool2000001d0i^KV0`00
000E0<c<c0<000004`2c/k<3000000h0VIVI1P3oool100000040oooo000J0?ooo`030000003oool0
oooo00@0oooo2P1oOgl00`000000VIVI09VIV@0B09VIV@030000002c/k<0/k>c01<0/k>c00<00000
0<c<c03<c<`05@3<c<`00`000000i^KV0>KViP0L0>KViP030000003oool0oooo06l0oooo0`00000L
0>KViP<000005P3<c<`2000001<0/k>c0`00000A09VIV@H0oooo0@0000010?ooo`00403oool40000
0003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0103oool:07moO`030000002IVIT0VIVI
0140VIVI00<000000;>c/`2c/k<04`2c/k<00`000000c<c<0<c<c00E0<c<c0030000003Vi^H0i^KV
01`0i^KV00<000000?ooo`3oool0KP3oool2000001d0i^KV0P00000F0<c<c0<000004P2c/k<30000
0180VIVI0`0000050?ooo`4000000@3oool00180oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`T0Ogmo00<0000009VIV@2IVIT04P2IVIT00`000000/k>c0;>c/`0C0;>c/`03
0000003<c<`0c<c<01D0c<c<00<000000>KViP3Vi^H06`3Vi^H00`000000oooo0?ooo`1]0?ooo`80
0000703Vi^H3000001D0c<c<0`00000B0;>c/`<000004P2IVIT300000080Ogmo1P3oool100000040
oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool907moO`030000
002IVIT0VIVI0180VIVI00<000000;>c/`2c/k<04P2c/k<00`000000c<c<0<c<c00E0<c<c0030000
003Vi^H0i^KV01/0i^KV00<000000?ooo`3oool0J`3oool3000001/0i^KV0`00000F0<c<c0800000
4P2c/k<300000180VIVI0`00000507moO`H0oooo0@0000010?ooo`004P3oool00`000000oooo0?oo
o`050?ooo`<00000103oool907moO`030000002IVIT0VIVI0140VIVI00<000000;>c/`2c/k<04P2c
/k<00`000000c<c<0<c<c00E0<c<c0030000003Vi^H0i^KV01/0i^KV00<000000?ooo`3oool0JP3o
ool2000001`0i^KV0P00000F0<c<c0<000004@2c/k<300000180VIVI0`00000807moO`@0oooo0`00
00010?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo2@1oOgl0
0`000000VIVI09VIV@0A09VIV@030000002c/k<0/k>c0180/k>c00<000000<c<c03<c<`05@3<c<`0
0`000000i^KV0>KViP0J0>KViP030000003oool0oooo06T0oooo0P00000K0>KViP<000005@3<c<`3
00000140/k>c0`00000A09VIV@@000002`1oOgl60?ooo`4000000@3oool00180oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`T0Ogmo00<0000009VIV@2IVIT04@2IVIT00`00
0000/k>c0;>c/`0A0;>c/`030000003<c<`0c<c<01D0c<c<00<000000>KViP3Vi^H06P3Vi^H00`00
0000oooo0?ooo`1W0?ooo`<000006`3Vi^H2000001D0c<c<0`00000A0;>c/`<00000402IVIT40000
00l0Ogmo1P3oool100000040oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool907moO`030000002IVIT0VIVI0100VIVI00<000000;>c/`2c/k<04P2c/k<00`000000
c<c<0<c<c00D0<c<c0030000003Vi^H0i^KV01X0i^KV00<000000?ooo`3oool0I@3oool3000001/0
i^KV0`00000D0<c<c0<000004@2c/k<300000100VIVI0`00000A07moO`<000001@3oool100000040
oooo000@0?ooo`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`T0Ogmo
00<0000009VIV@2IVIT0402IVIT00`000000/k>c0;>c/`0A0;>c/`030000003<c<`0c<c<01@0c<c<
00<000000>KViP3Vi^H06P3Vi^H00`000000oooo0?ooo`1T0?ooo`800000703Vi^H2000001@0c<c<
0`00000A0;>c/`<00000402IVIT300000100Ogmo1000000206IVIPH0oooo0@0000010?ooo`006P3o
ool00`000000oooo0?ooo`040?ooo`T0Ogmo00<0000009VIV@2IVIT0402IVIT00`000000/k>c0;>c
/`0A0;>c/`030000003<c<`0c<c<01@0c<c<00<000000>KViP3Vi^H06P3Vi^H00`000000oooo0?oo
o`1R0?ooo`800000703Vi^H2000001@0c<c<0P00000B0;>c/`8000004P2IVIT00`000000Ogmo07mo
O`0>07moO`<000001P1VIVH60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool9
07moO`030000002IVIT0VIVI0100VIVI00<000000;>c/`2c/k<0402c/k<00`000000c<c<0<c<c00D
0<c<c0030000003Vi^H0i^KV01X0i^KV00<000000?ooo`3oool0HP3oool00`000000i^KV0>KViP0J
0>KViP800000503<c<`200000180/k>c0P00000B09VIV@8000003P1oOgl3000000T0IVIV1P3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo2@1oOgl00`000000VIVI09VIV@0?09VI
V@030000002c/k<0/k>c0140/k>c00<000000<c<c03<c<`04`3<c<`00`000000i^KV0>KViP0J0>KV
iP030000003oool0oooo0640oooo0P00000K0>KViP800000503<c<`200000180/k>c0P00000A09VI
V@<000003P1oOgl2000000`0IVIV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0
oooo2@1oOgl00`000000VIVI09VIV@0?09VIV@030000002c/k<0/k>c0100/k>c00<000000<c<c03<
c<`0503<c<`00`000000i^KV0>KViP0I0>KViP030000003oool0oooo0640oooo00<000000>KViP3V
i^H06@3Vi^H2000001@0c<c<0P00000B0;>c/`800000402IVIT3000000h0Ogmo0`00000>06IVIPH0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`T0Ogmo00<0000009VIV@2IVIT0
3`2IVIT00`000000/k>c0;>c/`0@0;>c/`030000003<c<`0c<c<01<0c<c<00<000000>KViP3Vi^H0
6@3Vi^H00`000000oooo0?ooo`1P0?ooo`8000006P3Vi^H2000001<0c<c<0`00000B0;>c/`800000
402IVIT2000000h0Ogmo0`00000@06IVIP8000001@3oool100000040oooo000J0?ooo`8000001@3o
ool907moO`030000002IVIT0VIVI00h0VIVI00<000000;>c/`2c/k<04@2c/k<00`000000c<c<0<c<
c00C0<c<c0030000003Vi^H0i^KV01T0i^KV00<000000?ooo`3oool0G`3oool00`000000i^KV0>KV
iP0H0>KViP8000004`3<c<`200000180/k>c0`00000?09VIV@<000003@1oOgl300000100IVIV0`00
00000`1<C4`0oooo0?ooo`030?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103oool9
07moO`030000002IVIT0VIVI00h0VIVI00<000000;>c/`2c/k<0402c/k<00`000000c<c<0<c<c00C
0<c<c0030000003Vi^H0i^KV01T0i^KV00<000000?ooo`3oool0GP3oool2000001T0i^KV0P00000C
0<c<c08000004P2c/k<200000100VIVI0P00000=07moO`<00000401VIVH3000000@0C4a<1P3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo201oOgl00`000000VIVI09VIV@0?09VI
V@030000002c/k<0/k>c0100/k>c00<000000<c<c03<c<`04P3<c<`00`000000i^KV0>KViP0I0>KV
iP030000003oool0oooo05h0oooo00<000000>KViP3Vi^H05`3Vi^H2000001<0c<c<0P00000B0;>c
/`8000003`2IVIT3000000d0Ogmo0P00000A06IVIP8000001`1<C4`60?ooo`4000000@3oool001X0
oooo00<000000?ooo`3oool0103oool807moO`030000002IVIT0VIVI00l0VIVI00<000000;>c/`2c
/k<03`2c/k<00`000000c<c<0<c<c00C0<c<c0030000003Vi^H0i^KV01P0i^KV00<000000?ooo`3o
ool0GP3oool00`000000i^KV0>KViP0F0>KViP8000004`3<c<`200000140/k>c0`00000>09VIV@<0
00003P1oOgl200000100IVIV0`00000904a<C0H0oooo0@0000010?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`P0Ogmo00<0000009VIV@2IVIT03`2IVIT00`000000/k>c0;>c/`0?0;>c/`030000
003<c<`0c<c<0180c<c<00<000000>KViP3Vi^H06@3Vi^H00`000000oooo0?ooo`1L0?ooo`800000
5`3Vi^H2000001<0c<c<0P00000A0;>c/`8000003`2IVIT2000000l0Ogmo0P00000@06IVIP800000
301<C4`60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool807moO`030000002I
VIT0VIVI00h0VIVI00<000000;>c/`2c/k<03`2c/k<00`000000c<c<0<c<c00C0<c<c0030000003V
i^H0i^KV01P0i^KV00<000000?ooo`3oool0G03oool00`000000i^KV0>KViP0E0>KViP800000503<
c<`00`000000/k>c0;>c/`0?0;>c/`8000003P2IVIT3000000h0Ogmo0`00000?06IVIP<000003P1<
C4`60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool807moO`030000002IVIT0
VIVI00h0VIVI00<000000;>c/`2c/k<03`2c/k<00`000000c<c<0<c<c00B0<c<c0030000003Vi^H0
i^KV01P0i^KV00<000000?ooo`3oool0F`3oool2000001L0i^KV00<000000<c<c03<c<`04P3<c<`2
00000100/k>c0P00000>09VIV@8000003`1oOgl200000100IVIV0P00000@04a<C08000001@3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo201oOgl00`000000VIVI09VIV@0>09VI
V@030000002c/k<0/k>c00l0/k>c00<000000<c<c03<c<`04P3<c<`00`000000i^KV0>KViP0G0>KV
iP030000003oool0oooo05X0oooo0P00000H0>KViP030000003<c<`0c<c<0140c<c<0P00000@0;>c
/`8000003P2IVIT2000000l0Ogmo0P00000?06IVIP<000003`1<C4`30000000303<c<`3oool0oooo
00@0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`P0Ogmo00<0000009VIV@2I
VIT03P2IVIT00`000000/k>c0;>c/`0>0;>c/`030000003<c<`0c<c<0180c<c<00<000000>KViP3V
i^H05`3Vi^H00`000000oooo0?ooo`1I0?ooo`800000603Vi^H200000180c<c<0P00000@0;>c/`80
00003P2IVIT2000000l0Ogmo0P00000>06IVIP<00000401<C4`2000000@0<c<c1P3oool100000040
oooo000J0?ooo`030000003oool0oooo00@0oooo201oOgl00`000000VIVI09VIV@0>09VIV@030000
002c/k<0/k>c00h0/k>c00<000000<c<c03<c<`04P3<c<`00`000000i^KV0>KViP0G0>KViP030000
003oool0oooo05P0oooo00<000000>KViP3Vi^H05P3Vi^H200000180c<c<0P00000?0;>c/`<00000
3P2IVIT2000000l0Ogmo0P00000=06IVIP<00000401<C4`3000000H0<c<c1P3oool100000040oooo
000J0?ooo`8000001@3oool807moO`030000002IVIT0VIVI00h0VIVI00<000000;>c/`2c/k<03@2c
/k<00`000000c<c<0<c<c00B0<c<c0030000003Vi^H0i^KV01L0i^KV00<000000?ooo`3oool0E`3o
ool2000001L0i^KV0P00000B0<c<c08000003`2c/k<2000000l0VIVI0P00000?07moO`8000003@1V
IVH200000100C4a<0`00000903<c<`D0oooo0P0000010?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`P0Ogmo00<0000009VIV@2IVIT03@2IVIT00`000000/k>c0;>c/`0>0;>c/`030000003<c<`0
c<c<0180c<c<00<000000>KViP3Vi^H05P3Vi^H00`000000oooo0?ooo`1G0?ooo`030000003Vi^H0
i^KV01H0i^KV00<000000<c<c03<c<`0403<c<`2000000l0/k>c0P00000?09VIV@8000003P1oOgl3
000000d0IVIV0P00000@04a<C0800000300c<c<60?ooo`4000000@3oool001X0oooo00<000000?oo
o`3oool0103oool807moO`030000002IVIT0VIVI00d0VIVI00<000000;>c/`2c/k<03P2c/k<00`00
0000c<c<0<c<c00A0<c<c0030000003Vi^H0i^KV01L0i^KV00<000000?ooo`3oool0E@3oool20000
01L0i^KV0P00000A0<c<c08000003`2c/k<2000000l0VIVI0P00000>07moO`8000003@1VIVH30000
00l0C4a<0`00000>03<c<`H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`P0
Ogmo00<0000009VIV@2IVIT03@2IVIT00`000000/k>c0;>c/`0=0;>c/`030000003<c<`0c<c<0180
c<c<00<000000>KViP3Vi^H05P3Vi^H00`000000oooo0?ooo`1E0?ooo`030000003Vi^H0i^KV01D0
i^KV0P00000A0<c<c08000003`2c/k<2000000l0VIVI0P00000>07moO`8000003@1VIVH2000000l0
C4a<0`00000@03<c<`8000001@3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
201oOgl00`000000VIVI09VIV@0=09VIV@030000002c/k<0/k>c00d0/k>c00<000000<c<c03<c<`0
4@3<c<`00`000000i^KV0>KViP0F0>KViP030000003oool0oooo05@0oooo0P00000G0>KViP030000
003<c<`0c<c<00l0c<c<0P00000?0;>c/`8000003`2IVIT2000000h0Ogmo0P00000=06IVIP800000
3P1<C4`300000140<c<c0P0000000`0I6AT0oooo0?ooo`040?ooo`4000000@3oool001X0oooo00<0
00000?ooo`3oool0103oool707moO`030000002IVIT0VIVI00d0VIVI00<000000;>c/`2c/k<03P2c
/k<00`000000c<c<0<c<c00@0<c<c0030000003Vi^H0i^KV01H0i^KV00<000000?ooo`3oool0E03o
ool00`000000i^KV0>KViP0E0>KViP800000403<c<`200000100/k>c00<0000009VIV@2IVIT03@2I
VIT2000000d0Ogmo0`00000=06IVIP8000003@1<C4`300000180<c<c0P00000301TI6@H0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`L0Ogmo00<0000009VIV@2IVIT03@2IVIT0
0`000000/k>c0;>c/`0=0;>c/`030000003<c<`0c<c<0140c<c<00<000000>KViP3Vi^H05P3Vi^H0
0`000000oooo0?ooo`1B0?ooo`8000005`3Vi^H00`000000c<c<0<c<c00>0<c<c0800000402c/k<2
000000d0VIVI0`00000=07moO`8000003P1VIVH2000000d0C4a<0P00000B03<c<`<000001@0I6AT6
0?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool707moO`030000002IVIT0VIVI
00d0VIVI00<000000;>c/`2c/k<03@2c/k<00`000000c<c<0<c<c00@0<c<c0030000003Vi^H0i^KV
01H0i^KV00<000000?ooo`3oool0DP3oool00`000000i^KV0>KViP0E0>KViP800000403<c<`00`00
0000/k>c0;>c/`0>0;>c/`8000003@2IVIT2000000h0Ogmo0P00000>06IVIP8000003@1<C4`20000
0180<c<c0P00000801TI6@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`L0
Ogmo00<0000009VIV@2IVIT03@2IVIT00`000000/k>c0;>c/`0=0;>c/`030000003<c<`0c<c<0100
c<c<00<000000>KViP3Vi^H05@3Vi^H00`000000oooo0?ooo`1B0?ooo`030000003Vi^H0i^KV01D0
i^KV00<000000<c<c03<c<`03P3<c<`2000000l0/k>c0P00000=09VIV@8000003@1oOgl3000000d0
IVIV0`00000=04a<C08000004P0c<c<2000000X06ATI1P3oool100000040oooo000J0?ooo`030000
003oool0oooo00@0oooo1`1oOgl00`000000VIVI09VIV@0=09VIV@030000002c/k<0/k>c00d0/k>c
00<000000<c<c03<c<`03`3<c<`00`000000i^KV0>KViP0F0>KViP030000003oool0oooo0500oooo
0P00000F0>KViP800000403<c<`00`000000/k>c0;>c/`0=0;>c/`8000003@2IVIT2000000d0Ogmo
0P00000>06IVIP8000003P1<C4`200000180<c<c0P00000<01TI6@H0oooo0@0000010?ooo`006P3o
ool2000000D0oooo1`1oOgl00`000000VIVI09VIV@0<09VIV@030000002c/k<0/k>c00d0/k>c00<0
00000<c<c03<c<`0403<c<`00`000000i^KV0>KViP0E0>KViP030000003oool0oooo0500oooo00<0
00000>KViP3Vi^H05@3Vi^H00`000000c<c<0<c<c00?0<c<c0030000002c/k<0/k>c00d0/k>c00<0
000009VIV@2IVIT0302IVIT00`000000Ogmo07moO`0<07moO`030000001VIVH0IVIV00`0IVIV0P00
000>04a<C08000004@0c<c<3000000h06ATI1@3oool200000040oooo000J0?ooo`030000003oool0
oooo00@0oooo1`1oOgl00`000000VIVI09VIV@0<09VIV@030000002c/k<0/k>c00d0/k>c00<00000
0<c<c03<c<`03`3<c<`00`000000i^KV0>KViP0E0>KViP030000003oool0oooo0500oooo00<00000
0>KViP3Vi^H05@3Vi^H00`000000c<c<0<c<c00>0<c<c08000003P2c/k<2000000d0VIVI0P00000=
07moO`8000003@1VIVH2000000h0C4a<0P00000@03<c<`<000004@0I6AT60?ooo`4000000@3oool0
01X0oooo00<000000?ooo`3oool0103oool707moO`030000002IVIT0VIVI00`0VIVI00<000000;>c
/`2c/k<03@2c/k<00`000000c<c<0<c<c00?0<c<c0030000003Vi^H0i^KV01@0i^KV00<000000?oo
o`3oool0D03oool00`000000i^KV0>KViP0D0>KViP800000403<c<`00`000000/k>c0;>c/`0<0;>c
/`8000003@2IVIT2000000d0Ogmo0P00000=06IVIP8000003`1<C4`00`000000<c<c03<c<`0=03<c
<`<00000500I6AT60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool707moO`03
0000002IVIT0VIVI00`0VIVI00<000000;>c/`2c/k<03@2c/k<00`000000c<c<0<c<c00>0<c<c003
0000003Vi^H0i^KV01D0i^KV00<000000?ooo`3oool0C`3oool00`000000i^KV0>KViP0D0>KViP03
0000003<c<`0c<c<00h0c<c<0P00000=0;>c/`8000003P2IVIT00`000000Ogmo07moO`0<07moO`03
0000001VIVH0IVIV00/0IVIV0P00000?04a<C08000003@0c<c<3000001D06ATI0`0000050?ooo`40
00000@3oool001X0oooo00<000000?ooo`3oool0103oool707moO`030000002IVIT0VIVI00`0VIVI
00<000000;>c/`2c/k<0302c/k<00`000000c<c<0<c<c00?0<c<c0030000003Vi^H0i^KV01@0i^KV
00<000000?ooo`3oool0C`3oool00`000000i^KV0>KViP0D0>KViP030000003<c<`0c<c<00h0c<c<
00<000000;>c/`2c/k<0302c/k<00`000000VIVI09VIV@0<09VIV@8000003@1oOgl2000000`0IVIV
0P00000?04a<C08000003@0c<c<2000001<06ATI1`0000060?ooo`4000000@3oool001X0oooo00<0
00000?ooo`3oool0103oool707moO`030000002IVIT0VIVI00/0VIVI00<000000;>c/`2c/k<03@2c
/k<00`000000c<c<0<c<c00?0<c<c0030000003Vi^H0i^KV01@0i^KV00<000000?ooo`3oool0C@3o
ool2000001D0i^KV0P00000?0<c<c08000003@2c/k<2000000d0VIVI0P00000=07moO`800000301V
IVH2000000l0C4a<0P00000=03<c<`8000004@0I6AT;000000H0oooo0@0000010?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`L0Ogmo00<0000009VIV@2IVIT02`2IVIT00`000000/k>c0;>c/`0=
0;>c/`030000003<c<`0c<c<00h0c<c<00<000000>KViP3Vi^H0503Vi^H00`000000oooo0?ooo`1=
0?ooo`030000003Vi^H0i^KV01@0i^KV00<000000<c<c03<c<`03P3<c<`00`000000/k>c0;>c/`0;
0;>c/`8000003P2IVIT00`000000Ogmo07moO`0<07moO`030000001VIVH0IVIV00X0IVIV0P00000>
04a<C0<000003@0c<c<2000001006ATI3P0000060?ooo`4000000@3oool001X0oooo00<000000?oo
o`3oool0103oool707moO`030000002IVIT0VIVI00/0VIVI00<000000;>c/`2c/k<03@2c/k<00`00
0000c<c<0<c<c00>0<c<c0030000003Vi^H0i^KV01<0i^KV00<000000?ooo`3oool0C@3oool00`00
0000i^KV0>KViP0D0>KViP030000003<c<`0c<c<00d0c<c<0P00000=0;>c/`030000002IVIT0VIVI
00`0VIVI0P00000=07moO`8000002`1VIVH2000000h0C4a<0P00000>03<c<`8000004@0I6AT?0000
00H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`H0Ogmo00<0000009VIV@2I
VIT0302IVIT00`000000/k>c0;>c/`0<0;>c/`030000003<c<`0c<c<00l0c<c<00<000000>KViP3V
i^H04`3Vi^H00`000000oooo0?ooo`1<0?ooo`030000003Vi^H0i^KV01@0i^KV00<000000<c<c03<
c<`03@3<c<`00`000000/k>c0;>c/`0<0;>c/`030000002IVIT0VIVI00`0VIVI00<0000007moO`1o
Ogl02`1oOgl2000000/0IVIV0P00000>04a<C08000003`0c<c<00`0000006ATI01TI6@0?01TI6A40
00001P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI
09VIV@0<09VIV@030000002c/k<0/k>c00`0/k>c00<000000<c<c03<c<`03P3<c<`00`000000i^KV
0>KViP0C0>KViP030000003oool0oooo04/0oooo0P00000E0>KViP8000003P3<c<`2000000d0/k>c
0P00000=09VIV@800000301oOgl2000000/0IVIV0P00000>04a<C08000003`0c<c<2000001406ATI
4P0000060?ooo`4000000@3oool001X0oooo0P0000050?ooo`H0Ogmo00<0000009VIV@2IVIT0302I
VIT00`000000/k>c0;>c/`0<0;>c/`030000003<c<`0c<c<00h0c<c<00<000000>KViP3Vi^H04`3V
i^H00`000000oooo0?ooo`1:0?ooo`030000003Vi^H0i^KV01@0i^KV00<000000<c<c03<c<`03@3<
c<`00`000000/k>c0;>c/`0<0;>c/`030000002IVIT0VIVI00/0VIVI0P00000<07moO`800000301V
IVH00`000000C4a<04a<C00<04a<C08000003`0c<c<2000001406ATI500000050?ooo`8000000@3o
ool001X0oooo00<000000?ooo`3oool0103oool607moO`030000002IVIT0VIVI00`0VIVI00<00000
0;>c/`2c/k<0302c/k<00`000000c<c<0<c<c00>0<c<c0030000003Vi^H0i^KV0180i^KV00<00000
0?ooo`3oool0BP3oool00`000000i^KV0>KViP0D0>KViP030000003<c<`0c<c<00d0c<c<00<00000
0;>c/`2c/k<02`2c/k<2000000d0VIVI00<0000007moO`1oOgl02`1oOgl00`000000IVIV06IVIP0:
06IVIP8000003@1<C4`2000000l0<c<c0P00000B01TI6AD000001P3oool100000040oooo000J0?oo
o`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0;09VIV@030000002c/k<0/k>c
00d0/k>c00<000000<c<c03<c<`03@3<c<`00`000000i^KV0>KViP0B0>KViP030000003oool0oooo
04X0oooo00<000000>KViP3Vi^H04`3Vi^H2000000h0c<c<0P00000=0;>c/`030000002IVIT0VIVI
00/0VIVI0P00000<07moO`8000002`1VIVH2000000d0C4a<0P00000?03<c<`8000004P0I6ATG0000
00H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`H0Ogmo00<0000009VIV@2I
VIT02`2IVIT00`000000/k>c0;>c/`0<0;>c/`030000003<c<`0c<c<00h0c<c<00<000000>KViP3V
i^H04P3Vi^H00`000000oooo0?ooo`190?ooo`030000003Vi^H0i^KV01<0i^KV00<000000<c<c03<
c<`03@3<c<`00`000000/k>c0;>c/`0<0;>c/`030000002IVIT0VIVI00/0VIVI00<0000007moO`1o
Ogl02P1oOgl2000000`0IVIV00<0000004a<C01<C4`02`1<C4`2000000l0<c<c0P00000C01TI6AP0
00001P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI
09VIV@0;09VIV@030000002c/k<0/k>c00`0/k>c00<000000<c<c03<c<`03@3<c<`00`000000i^KV
0>KViP0B0>KViP030000003oool0oooo04T0oooo00<000000>KViP3Vi^H04P3Vi^H2000000l0c<c<
00<000000;>c/`2c/k<0302c/k<00`000000VIVI09VIV@0:09VIV@800000301oOgl00`000000IVIV
06IVIP0:06IVIP800000301<C4`2000000l0<c<c0P00000C01TI6AX000001P3oool100000040oooo
000J0?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0;09VIV@030000002c
/k<0/k>c00`0/k>c00<000000<c<c03<c<`03@3<c<`00`000000i^KV0>KViP0B0>KViP030000003o
ool0oooo04T0oooo00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c00>0<c<c08000003@2c
/k<00`000000VIVI09VIV@0:09VIV@030000001oOgl0Ogmo00/0Ogmo00<0000006IVIP1VIVH02P1V
IVH00`000000C4a<04a<C00;04a<C0030000000c<c<0<c<c00d0<c<c0P00000C01TI6A`000001P3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0;
09VIV@030000002c/k<0/k>c00`0/k>c00<000000<c<c03<c<`03@3<c<`00`000000i^KV0>KViP0A
0>KViP030000003oool0oooo04T0oooo00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c00>
0<c<c0030000002c/k<0/k>c00/0/k>c0P00000;09VIV@800000301oOgl2000000/0IVIV0P00000=
04a<C0030000000c<c<0<c<c00d0<c<c00<0000001TI6@0I6AT04@0I6ATN000000H0oooo0@000001
0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`H0Ogmo00<0000009VIV@2IVIT02`2IVIT00`00
0000/k>c0;>c/`0;0;>c/`030000003<c<`0c<c<00d0c<c<00<000000>KViP3Vi^H04P3Vi^H00`00
0000oooo0?ooo`180?ooo`030000003Vi^H0i^KV0140i^KV00<000000<c<c03<c<`03P3<c<`00`00
0000/k>c0;>c/`0;0;>c/`030000002IVIT0VIVI00X0VIVI00<0000007moO`1oOgl02`1oOgl00`00
0000IVIV06IVIP0:06IVIP030000001<C4`0C4a<00/0C4a<0P00000>03<c<`8000004P0I6ATP0000
00H0oooo0@0000010?ooo`00100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@0
00000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0103oool607moO`030000002IVIT0VIVI
00X0VIVI00<000000;>c/`2c/k<0302c/k<00`000000c<c<0<c<c00=0<c<c0030000003Vi^H0i^KV
0140i^KV00<000000?ooo`3oool0B@3oool00`000000i^KV0>KViP0@0>KViP030000003<c<`0c<c<
00h0c<c<00<000000;>c/`2c/k<02`2c/k<00`000000VIVI09VIV@0:09VIV@030000001oOgl0Ogmo
00X0Ogmo0P00000;06IVIP8000003@1<C4`00`000000<c<c03<c<`0<03<c<`8000004@0I6ATS0000
00H0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0
<c<c0?ooo`040?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0:09VIV@03
0000002c/k<0/k>c00`0/k>c00<000000<c<c03<c<`03@3<c<`00`000000i^KV0>KViP0A0>KViP03
0000003oool0oooo04P0oooo00<000000>KViP3Vi^H0403Vi^H00`000000c<c<0<c<c00>0<c<c003
0000002c/k<0/k>c00X0/k>c0P00000;09VIV@800000301oOgl00`000000IVIV06IVIP0:06IVIP03
0000001<C4`0C4a<00/0C4a<0P00000=03<c<`8000004@0I6ATU000000H0oooo0@0000010?ooo`00
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool607moO`030000002IVIT0VIVI00X0VIVI00<000000;>c/`2c/k<0302c/k<00`000000c<c<
0<c<c00<0<c<c0030000003Vi^H0i^KV0180i^KV00<000000?ooo`3oool0A`3oool00`000000i^KV
0>KViP0@0>KViP030000003<c<`0c<c<00d0c<c<0P00000<0;>c/`030000002IVIT0VIVI00X0VIVI
00<0000007moO`1oOgl02P1oOgl2000000/0IVIV0P00000<04a<C08000003P0c<c<00`0000006ATI
01TI6@0?01TI6BL000001P3oool100000040oooo00020?ooo`030000003oool0oooo00h0oooo00<0
MgMg03<c<`3oool0103oool3000000@0oooo1P1oOgl00`000000VIVI09VIV@0:09VIV@030000002c
/k<0/k>c00`0/k>c00<000000<c<c03<c<`0303<c<`00`000000i^KV0>KViP0A0>KViP030000003o
ool0oooo04L0oooo00<000000>KViP3Vi^H0403Vi^H00`000000c<c<0<c<c00=0<c<c0030000002c
/k<0/k>c00/0/k>c00<0000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0907moO`800000301V
IVH00`000000C4a<04a<C00;04a<C0030000000c<c<0<c<c00`0<c<c0P00000@01TI6BT00000103o
ool300000040oooo00020?ooo`030000003oool0oooo00/0oooo00D00000028R8P000000<c<c0<c<
c0050?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0:09VIV@030000002c
/k<0/k>c00/0/k>c00<000000<c<c03<c<`03@3<c<`00`000000i^KV0>KViP0A0>KViP030000003o
ool0oooo04H0oooo00<000000>KViP3Vi^H0403Vi^H00`000000c<c<0<c<c00=0<c<c0030000002c
/k<0/k>c00/0/k>c00<0000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0907moO`030000001V
IVH0IVIV00/0IVIV00<0000004a<C01<C4`02P1<C4`2000000d0<c<c0P00000A01TI6BX000001P3o
ool100000040oooo00020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`H0Ogmo00<0000009VIV@2IVIT02P2IVIT00`000000/k>c0;>c/`0;
0;>c/`030000003<c<`0c<c<00d0c<c<00<000000>KViP3Vi^H0403Vi^H00`000000oooo0?ooo`16
0?ooo`030000003Vi^H0i^KV0100i^KV00<000000<c<c03<c<`03@3<c<`00`000000/k>c0;>c/`0:
0;>c/`8000002`2IVIT2000000X0Ogmo0P00000<06IVIP8000002`1<C4`2000000d0<c<c0P00000A
01TI6B`000001P3oool100000040oooo00020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`H0Ogmo00<0000009VIV@2IVIT02P2IVIT00`00
0000/k>c0;>c/`0;0;>c/`030000003<c<`0c<c<00`0c<c<00<000000>KViP3Vi^H04@3Vi^H00`00
0000oooo0?ooo`150?ooo`030000003Vi^H0i^KV0100i^KV00<000000<c<c03<c<`03@3<c<`00`00
0000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI00X0VIVI00<0000007moO`1oOgl02@1oOgl00`00
0000IVIV06IVIP0;06IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<0300c<c<00`00
00006ATI01TI6@0@01TI6Bd000001P3oool100000040oooo000205EEE@030000003oool0oooo00/0
oooo100000060?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0909VIV@03
0000002c/k<0/k>c00`0/k>c00<000000<c<c03<c<`0303<c<`00`000000i^KV0>KViP0@0>KViP03
0000003oool0oooo04D0oooo00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c00<0<c<c003
0000002c/k<0/k>c00X0/k>c00<0000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0907moO`03
0000001VIVH0IVIV00X0IVIV0P00000;04a<C08000003@0c<c<2000001806ATI;P0000060?ooo`40
00000@3oool001X0oooo00<000000?ooo`3oool0103oool607moO`030000002IVIT0VIVI00T0VIVI
00<000000;>c/`2c/k<0302c/k<00`000000c<c<0<c<c00<0<c<c0030000003Vi^H0i^KV0100i^KV
00<000000?ooo`3oool0A03oool00`000000i^KV0>KViP0A0>KViP030000003<c<`0c<c<00`0c<c<
00<000000;>c/`2c/k<02P2c/k<00`000000VIVI09VIV@0:09VIV@030000001oOgl0Ogmo00T0Ogmo
00<0000006IVIP1VIVH02P1VIVH00`000000C4a<04a<C00:04a<C0030000000c<c<0<c<c00`0<c<c
00<0000001TI6@0I6AT0400I6AT`000000H0oooo0@0000010?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`H0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0;0;>c/`030000003<
c<`0c<c<00`0c<c<00<000000>KViP3Vi^H04@3Vi^H00`000000oooo0?ooo`130?ooo`030000003V
i^H0i^KV0140i^KV00<000000<c<c03<c<`0303<c<`00`000000/k>c0;>c/`0:0;>c/`030000002I
VIT0VIVI00X0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP0:06IVIP030000001<
C4`0C4a<00X0C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0@01TI6C4000001P3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@09
09VIV@030000002c/k<0/k>c00/0/k>c00<000000<c<c03<c<`0303<c<`00`000000i^KV0>KViP0@
0>KViP030000003oool0oooo04<0oooo00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c00;
0<c<c08000002`2c/k<2000000/0VIVI0P00000:07moO`8000002`1VIVH2000000/0C4a<0P00000=
03<c<`8000004@0I6ATc000000H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`H0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0;0;>c/`030000003<c<`0c<c<
00`0c<c<00<000000>KViP3Vi^H0403Vi^H00`000000oooo0?ooo`130?ooo`030000003Vi^H0i^KV
0100i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI
00X0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP0:06IVIP030000001<C4`0C4a<
00X0C4a<00<0000003<c<`0c<c<0300c<c<00`0000006ATI01TI6@0@01TI6C@000001P3oool10000
0040oooo000J0?ooo`030000003oool0oooo00@0oooo1P1oOgl00`000000VIVI09VIV@0909VIV@03
0000002c/k<0/k>c00/0/k>c00<000000<c<c03<c<`0303<c<`00`000000i^KV0>KViP0@0>KViP03
0000003oool0oooo0480oooo00<000000>KViP3Vi^H0403Vi^H00`000000c<c<0<c<c00;0<c<c003
0000002c/k<0/k>c00X0/k>c00<0000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0907moO`03
0000001VIVH0IVIV00T0IVIV0P00000;04a<C08000003@0c<c<2000001406ATI=P0000060?ooo`40
00000@3oool001X0oooo0P0000050?ooo`H0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c
0;>c/`0:0;>c/`030000003<c<`0c<c<00`0c<c<00<000000>KViP3Vi^H0403Vi^H00`000000oooo
0?ooo`120?ooo`030000003Vi^H0i^KV0100i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c
0;>c/`0:0;>c/`030000002IVIT0VIVI00X0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV
06IVIP0906IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<02`0c<c<2000001406ATI
>00000050?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103oool607moO`030000002I
VIT0VIVI00T0VIVI00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00<0<c<c0030000003V
i^H0i^KV0100i^KV00<000000?ooo`3oool0@@3oool00`000000i^KV0>KViP0@0>KViP030000003<
c<`0c<c<00/0c<c<00<000000;>c/`2c/k<02P2c/k<00`000000VIVI09VIV@0909VIV@8000002P1o
Ogl2000000/0IVIV00<0000004a<C01<C4`02@1<C4`2000000d0<c<c00<0000001TI6@0I6AT0400I
6ATi000000H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`H0Ogmo00<00000
09VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<00`0c<c<00<00000
0>KViP3Vi^H0403Vi^H00`000000oooo0?ooo`110?ooo`030000003Vi^H0i^KV00l0i^KV00<00000
0<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI00T0VIVI00<00000
07moO`1oOgl02@1oOgl00`000000IVIV06IVIP0906IVIP8000002`1<C4`00`000000<c<c03<c<`0;
03<c<`8000004@0I6ATk000000H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`H0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<
00/0c<c<00<000000>KViP3Vi^H0403Vi^H00`000000oooo0?ooo`110?ooo`030000003Vi^H0i^KV
00l0i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI
00T0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP0906IVIP030000001<C4`0C4a<
00T0C4a<0P00000=03<c<`030000000I6AT06ATI00l06ATI?@0000060?ooo`4000000@3oool001X0
oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI00T0VIVI00<000000;>c/`2c
/k<02P2c/k<00`000000c<c<0<c<c00<0<c<c0030000003Vi^H0i^KV0100i^KV00<000000?ooo`3o
ool0@03oool00`000000i^KV0>KViP0?0>KViP030000003<c<`0c<c<00/0c<c<00<000000;>c/`2c
/k<02P2c/k<00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00T0Ogmo00<0000006IVIP1V
IVH0201VIVH2000000/0C4a<00<0000003<c<`0c<c<02`0c<c<2000001006ATI?`0000060?ooo`40
00000@3oool001X0oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI00T0VIVI
00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00<0<c<c0030000003Vi^H0i^KV00l0i^KV
00<000000?ooo`3oool0@03oool00`000000i^KV0>KViP0?0>KViP030000003<c<`0c<c<00/0c<c<
00<000000;>c/`2c/k<02P2c/k<00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00P0Ogmo
0P00000:06IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI
01TI6@0?01TI6D0000001P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1@1o
Ogl00`000000VIVI09VIV@0909VIV@030000002c/k<0/k>c00X0/k>c00<000000<c<c03<c<`02`3<
c<`00`000000i^KV0>KViP0@0>KViP030000003oool0oooo03l0oooo00<000000>KViP3Vi^H03`3V
i^H00`000000c<c<0<c<c00;0<c<c0030000002c/k<0/k>c00X0/k>c00<0000009VIV@2IVIT02@2I
VIT00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV00T0IVIV00<0000004a<C01<C4`02@1<
C4`2000000d0<c<c00<0000001TI6@0I6AT03P0I6AU2000000H0oooo0@0000010?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0:
0;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3Vi^H03`3Vi^H00`000000oooo0?ooo`10
0?ooo`030000003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`0:
0;>c/`030000002IVIT0VIVI00T0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP09
06IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02`0c<c<2000001006ATIA0000005
0?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI
00T0VIVI00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00;0<c<c0030000003Vi^H0i^KV
00l0i^KV00<000000?ooo`3oool0?`3oool00`000000i^KV0>KViP0?0>KViP030000003<c<`0c<c<
00X0c<c<00<000000;>c/`2c/k<02P2c/k<00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo
00P0Ogmo00<0000006IVIP1VIVH02@1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c
00/0<c<c00<0000001TI6@0I6AT03`0I6AU30000000301TI6@3oool0oooo00@0oooo0@0000010?oo
o`006P3oool00`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000
/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3Vi^H0403Vi^H00`000000
oooo0?ooo`0n0?ooo`030000003Vi^H0i^KV00l0i^KV00<000000<c<c03<c<`02`3<c<`00`000000
/k>c0;>c/`090;>c/`030000002IVIT0VIVI00T0VIVI00<0000007moO`1oOgl0201oOgl00`000000
IVIV06IVIP0906IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02`0c<c<00`000000
6ATI01TI6@0?01TI6D8000000`0I6AT60?ooo`4000000@3oool001X0oooo0P0000050?ooo`D0Ogmo
00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<
00<000000>KViP3Vi^H03`3Vi^H00`000000oooo0?ooo`0n0?ooo`030000003Vi^H0i^KV00l0i^KV
00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00T0VIVI
00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0806IVIP8000002P1<C4`2000000`0<c<c
0P00000@01TI6D8000001@0I6AT50?ooo`8000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool507moO`030000002IVIT0VIVI00T0VIVI00<000000;>c/`2c/k<02@2c/k<00`000000c<c<0<c<
c00;0<c<c0030000003Vi^H0i^KV00l0i^KV00<000000?ooo`3oool0?P3oool00`000000i^KV0>KV
iP0?0>KViP030000003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<02@2c/k<00`000000VIVI09VI
V@0809VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<
C00904a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT03P0I6AU2000000L06ATI1P3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1@1oOgl00`000000VIVI09VIV@09
09VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`02`3<c<`00`000000i^KV0>KViP0>
0>KViP030000003oool0oooo03h0oooo00<000000>KViP3Vi^H03`3Vi^H00`000000c<c<0<c<c00;
0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`08
07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0;
03<c<`030000000I6AT06ATI00h06ATI@P00000801TI6@H0oooo0@0000010?ooo`006P3oool00`00
0000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`090;>c
/`030000003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03`3Vi^H00`000000oooo0?ooo`0m0?oo
o`030000003Vi^H0i^KV00l0i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`090;>c
/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0806IV
IP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0=01TI
6D<000002@0I6AT60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool507moO`03
0000002IVIT0VIVI00T0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00;0<c<c003
0000003Vi^H0i^KV00l0i^KV00<000000?ooo`3oool0?03oool00`000000i^KV0>KViP0?0>KViP03
0000003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0809VIV@03
0000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00804a<C080
0000300c<c<2000000h06ATIA000000:01TI6@H0oooo0@0000010?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`080;>c/`030000
003<c<`0c<c<00/0c<c<00<000000>KViP3Vi^H03P3Vi^H00`000000oooo0?ooo`0l0?ooo`030000
003Vi^H0i^KV00l0i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`090;>c/`030000
002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0706IVIP800000
2P1<C4`00`000000<c<c03<c<`0;03<c<`030000000I6AT06ATI00d06ATIA000000;01TI6@H0oooo
0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT02@2I
VIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3Vi^H03P3V
i^H00`000000oooo0?ooo`0l0?ooo`030000003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`02`3<
c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201o
Ogl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02`0c
<c<00`0000006ATI01TI6@0<01TI6DD00000300I6AT60?ooo`4000000@3oool001X0oooo00<00000
0?ooo`3oool0103oool507moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<02@2c/k<0
0`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00h0i^KV00<000000?ooo`3oool0?03oool0
0`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<02@2c/k<0
0`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo0P00000906IVIP030000001<C4`0
C4a<00T0C4a<00<0000003<c<`0c<c<02P0c<c<2000000h06ATIA000000=01TI6@8000001@3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo1@1oOgl00`000000VIVI09VIV@0809VI
V@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0>0>KV
iP030000003oool0oooo03/0oooo00<000000>KViP3Vi^H03`3Vi^H00`000000c<c<0<c<c00:0<c<
c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707mo
O`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`2000000`0<c<c00<0000001TI
6@0I6AT03@0I6AU2000000h06ATI0P0000000`0c<c<0oooo0?ooo`040?ooo`4000000@3oool001X0
oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c
/k<02@2c/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00h0i^KV00<000000?ooo`3o
ool0>P3oool00`000000i^KV0>KViP0?0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c
/k<02@2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1V
IVH0201VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I
6AT03@0I6AU1000000h06ATI0P00000303<c<`H0oooo0@0000010?ooo`006P3oool2000000D0oooo
1@1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0
2P3<c<`00`000000i^KV0>KViP0=0>KViP030000003oool0oooo03/0oooo00<000000>KViP3Vi^H0
3P3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0
202IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0
201<C4`00`000000<c<c03<c<`0:03<c<`8000003`0I6AU0000000h06ATI0P00000503<c<`D0oooo
0P0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT0202I
VIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3Vi^H03@3V
i^H00`000000oooo0?ooo`0j0?ooo`030000003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`02P3<
c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01`1o
Ogl00`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02P0c
<c<00`0000006ATI01TI6@0>01TI6Ch000003`0I6AT2000000L0<c<c1P3oool100000040oooo000J
0?ooo`030000003oool0oooo00@0oooo1@1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0
/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0>0>KViP030000003oool0
oooo03X0oooo00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0
/k>c00T0/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0
IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT0
6ATI00h06ATI?@00000?01TI6@8000002@0c<c<60?ooo`4000000@3oool001X0oooo00<000000?oo
o`3oool0103oool507moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<0202c/k<00`00
0000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00d0i^KV00<000000?ooo`3oool0>P3oool00`00
0000i^KV0>KViP0=0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<02@2c/k<00`00
0000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH0201VIVH00`00
0000C4a<04a<C00804a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT03@0I6ATn0000
00l06ATI00<0000003<c<`0c<c<02@0c<c<60?ooo`4000000@3oool001X0oooo00<000000?ooo`3o
ool0103oool507moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<0202c/k<00`000000
c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00d0i^KV00<000000?ooo`3oool0>P3oool00`000000
i^KV0>KViP0=0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<02@2c/k<00`000000
VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000
C4a<04a<C00804a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT0300I6ATn00000140
6ATI00<0000003<c<`0c<c<0200c<c<2000000D0oooo0@0000010?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`080;>c/`030000
003<c<`0c<c<00T0c<c<00<000000>KViP3Vi^H03P3Vi^H00`000000oooo0?ooo`0i0?ooo`030000
003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`080;>c/`030000
002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0706IVIP030000
001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02P0c<c<00`0000006ATI01TI6@0<01TI6Ch00000
400I6AT2000000X0<c<c00<0000004a<C03oool01@3oool100000040oooo000J0?ooo`030000003o
ool0oooo00@0oooo1@1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c00P0/k>c00<0
00000<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0=0>KViP030000003oool0oooo03X0oooo00<0
00000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0
000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0
000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI00`06ATI?@00
000A01TI6@030000000c<c<0<c<c00P0<c<c0P00000204a<C0H0oooo0@0000010?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`07
0;>c/`030000003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03@3Vi^H00`000000oooo0?ooo`0i
0?ooo`030000003Vi^H0i^KV00d0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`08
0;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP07
06IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0<
01TI6Cd00000400I6AT2000000X0<c<c00<0000004a<C01<C4`00P1<C4`60?ooo`4000000@3oool0
01X0oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI00P0VIVI00<000000;>c
/`2c/k<01`2c/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00d0i^KV00<000000?oo
o`3oool0>03oool00`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00T0c<c<00<000000;>c
/`2c/k<0202c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IV
IP1VIVH0201VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI
6@0I6AT0300I6ATl000001406ATI00<0000003<c<`0c<c<0200c<c<2000000D0C4a<1P3oool10000
0040oooo000J0?ooo`030000003oool0oooo00@0oooo1@1oOgl00`000000VIVI09VIV@0809VIV@03
0000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0=0>KViP03
0000003oool0oooo03P0oooo00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c00:0<c<c003
0000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707moO`03
0000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0903<c<`03
0000000I6AT06ATI00`06ATI?000000@01TI6@8000002P0c<c<00`000000C4a<04a<C00504a<C0H0
oooo0@0000010?ooo`006P3oool2000000D0oooo1@1oOgl00`000000VIVI09VIV@0809VIV@030000
002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0>0>KViP030000
003oool0oooo03L0oooo00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c00:0<c<c0030000
002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707moO`030000
001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0903<c<`030000
000I6AT06ATI00`06ATI>`00000@01TI6@8000002`0c<c<00`000000C4a<04a<C00604a<C0D0oooo
0P0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT01`2I
VIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00T0c<c<00<000000>KViP3Vi^H03@3V
i^H00`000000oooo0?ooo`0h0?ooo`030000003Vi^H0i^KV00`0i^KV00<000000<c<c03<c<`02P3<
c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl0201o
Ogl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02@0c
<c<00`0000006ATI01TI6@0<01TI6C/00000400I6AT00`000000<c<c03<c<`0903<c<`800000201<
C4`2000000D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`D0Ogmo00<00000
09VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00T0c<c<00<00000
0>KViP3Vi^H03@3Vi^H00`000000oooo0?ooo`0g0?ooo`030000003Vi^H0i^KV00d0i^KV00<00000
0<c<c03<c<`02@3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<00000
07moO`1oOgl0201oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00P0C4a<00<00000
03<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0<01TI6CX00000400I6AT2000000/0<c<c00<00000
04a<C01<C4`01`1<C4`00`000000IVIV0?ooo`050?ooo`4000000@3oool001X0oooo00<000000?oo
o`3oool0103oool507moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`00
0000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV00d0i^KV00<000000?ooo`3oool0=`3oool00`00
0000i^KV0>KViP0<0>KViP030000003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<02@2c/k<00`00
0000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`00
0000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0300I6ATj0000
01006ATI00<0000003<c<`0c<c<02@0c<c<2000000P0C4a<0P00000206IVIPH0oooo0@0000010?oo
o`006P3oool00`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000
/k>c0;>c/`070;>c/`030000003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03@3Vi^H00`000000
oooo0?ooo`0f0?ooo`030000003Vi^H0i^KV00`0i^KV00<000000<c<c03<c<`02P3<c<`00`000000
/k>c0;>c/`080;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0201oOgl00`000000
IVIV06IVIP0706IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02@0c<c<00`000000
6ATI01TI6@0<01TI6CX000003`0I6AT2000000X0<c<c0P00000904a<C0030000001VIVH0IVIV0080
IVIV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo1@1oOgl00`000000VIVI
09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02@3<c<`00`000000i^KV
0>KViP0>0>KViP030000003oool0oooo03D0oooo00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<
0<c<c0090<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo
07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c
03<c<`0903<c<`030000000I6AT06ATI00`06ATI>P00000>01TI6@8000002`0c<c<00`000000C4a<
04a<C00704a<C08000001@1VIVH60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool507moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<
c0090<c<c0030000003Vi^H0i^KV00d0i^KV00<000000?ooo`3oool0=P3oool00`000000i^KV0>KV
iP0<0>KViP030000003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VI
V@0709VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<
C00804a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT0300I6ATj000000h06ATI00<0
000003<c<`0c<c<02@0c<c<2000000T0C4a<00<0000006IVIP1VIVH01@1VIVH60?ooo`4000000@3o
ool001X0oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI00L0VIVI00<00000
0;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV00d0i^KV00<00000
0?ooo`3oool0=@3oool00`000000i^KV0>KViP0<0>KViP030000003<c<`0c<c<00T0c<c<00<00000
0;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0Ogmo00<00000
06IVIP1VIVH01`1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c00<00000
01TI6@0I6AT02`0I6ATk000000d06ATI0P00000:03<c<`8000002@1<C4`2000000L0IVIV0P000005
0?ooo`4000000@3oool000l0oooo1@0000060?ooo`030000003oool0oooo00@0oooo1@1oOgl00`00
0000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02@3<c<`00`00
0000i^KV0>KViP0=0>KViP030000003oool0oooo03D0oooo00<000000>KViP3Vi^H0303Vi^H00`00
0000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT0202IVIT00`00
0000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0903<c<`030000000I6AT06ATI00/06ATI>P00000>01TI6@030000000c<c<0<c<c
00P0<c<c0P00000904a<C0800000201VIVH00`000000Ogmo0?ooo`050?ooo`4000000@3oool000l0
oooo00D0VIVI028R8P3^k^h0oooo04A4A0060?ooo`030000003oool0oooo00@0oooo1@1oOgl00`00
0000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02@3<c<`00`00
0000i^KV0>KViP0=0>KViP030000003oool0oooo03@0oooo00<000000>KViP3Vi^H0303Vi^H00`00
0000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`00
0000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0903<c<`030000000I6AT06ATI00/06ATI>P00000>01TI6@030000000c<c<0<c<c
00P0<c<c00<0000004a<C01<C4`01`1<C4`2000000P0IVIV0P00000207moO`H0oooo0@0000010?oo
o`00403oool00`2IVIT08R8R0>k^kP070?ooo`<00000103oool507moO`030000002IVIT0VIVI00L0
VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV00`0
i^KV00<000000?ooo`3oool0=03oool00`000000i^KV0>KViP0<0>KViP030000003<c<`0c<c<00T0
c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0
Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00P0
<c<c00<0000001TI6@0I6AT02`0I6ATj000000d06ATI0P00000903<c<`8000002@1<C4`00`000000
IVIV06IVIP0706IVIP030000001oOgl0Ogmo0080Ogmo103oool300000040oooo000A0?ooo`0309VI
V@0R8R80k^k^00H0oooo00<000000?ooo`3oool0103oool507moO`030000002IVIT0VIVI00L0VIVI
00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00d0i^KV
00<000000?ooo`3oool0=03oool00`000000i^KV0>KViP0<0>KViP030000003<c<`0c<c<00T0c<c<
00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0Ogmo
00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00P0<c<c
00<0000001TI6@0I6AT02`0I6ATj000000d06ATI00<0000003<c<`0c<c<01`0c<c<2000000T0C4a<
0P00000806IVIP8000001@1oOgl60?ooo`4000000@3oool00180oooo00<0MgMg06IVIP3oool01@3o
ool00`000000oooo0?ooo`040?ooo`D0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c
/`070;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H03@3Vi^H00`000000oooo0?oo
o`0c0?ooo`030000003Vi^H0i^KV00`0i^KV00<000000<c<c03<c<`02@3<c<`00`000000/k>c0;>c
/`080;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IV
IP0706IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI
6@0;01TI6CX000003@0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00P0C4a<00<0
000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0507moO`H0oooo0@0000010?ooo`004`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo1@1oOgl00`000000VIVI09VIV@07
09VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0<
0>KViP030000003oool0oooo03@0oooo00<000000>KViP3Vi^H0303Vi^H00`000000c<c<0<c<c009
0<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`07
07moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`08
03<c<`030000000I6AT06ATI00/06ATI>@00000=01TI6@8000002@0c<c<00`000000C4a<04a<C008
04a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01@1oOgl2000000D0oooo0@000001
0?ooo`003`3oool01@000000^k^k0?ooo`2IVIT04A4A00H0oooo00<000000?ooo`3oool0103oool4
07moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c009
0<c<c0030000003Vi^H0i^KV00`0i^KV00<000000?ooo`3oool0<`3oool00`000000i^KV0>KViP0<
0>KViP030000003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@07
09VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C007
04a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02`0I6ATi000000d06ATI00<00000
03<c<`0c<c<01`0c<c<2000000T0C4a<0P00000806IVIP8000001`1oOgl00`000000VIVI0?ooo`05
0?ooo`4000000@3oool000l0oooo00D0VIVI014A4@0000008R8R0<c<c0060?ooo`030000003oool0
oooo00@0oooo101oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<00000
0<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0<0>KViP030000003oool0oooo03<0oooo00<00000
0>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00P0/k>c00<00000
09VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<00000
04a<C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00/06ATI>@00000<
01TI6@8000002@0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00L0IVIV00<00000
07moO`1oOgl01@1oOgl200000080VIVI1P3oool100000040oooo000J0?ooo`030000003oool0oooo
00@0oooo101oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<
c03<c<`02@3<c<`00`000000i^KV0>KViP0;0>KViP030000003oool0oooo03@0oooo00<000000>KV
iP3Vi^H02`3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<0000004a<
C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00/06ATI>000000=01TI
6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`01`1<C4`2000000P0IVIV0P00000707mo
O`030000002IVIT0VIVI0080VIVI1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0
oooo101oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<
c<`02@3<c<`00`000000i^KV0>KViP0;0>KViP030000003oool0oooo03<0oooo00<000000>KViP3V
i^H02`3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2I
VIT01`2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<
C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00/06ATI>000000=01TI6@03
0000000c<c<0<c<c00L0<c<c0P00000904a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1o
Ogl01P1oOgl00`000000VIVI09VIV@0309VIV@H0oooo0@0000010?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`070;>c/`030000
003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H0303Vi^H00`000000oooo0?ooo`0c0?ooo`030000
003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`02@3<c<`00`000000/k>c0;>c/`070;>c/`030000
002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0606IVIP030000
001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0;01TI6CL00000
3@0I6AT2000000T0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IVIP800000
1`1oOgl2000000H0VIVI1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo101o
Ogl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0203<
c<`00`000000i^KV0>KViP0;0>KViP030000003oool0oooo03@0oooo00<000000>KViP3Vi^H02`3V
i^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2I
VIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01`1<
C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00/06ATI=`00000=01TI6@030000000c
<c<0<c<c00P0<c<c00<0000004a<C01<C4`01`1<C4`2000000P0IVIV00<0000007moO`1oOgl01P1o
Ogl00`000000VIVI09VIV@0609VIV@H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`@0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0
c<c<00P0c<c<00<000000>KViP3Vi^H02`3Vi^H00`000000oooo0?ooo`0c0?ooo`030000003Vi^H0
i^KV00/0i^KV00<000000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0
VIVI00H0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0
C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0;01TI6CL000003@0I6AT0
0`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00H0C4a<0P00000806IVIP8000001`1oOgl2
000000P0VIVI0P0000050?ooo`4000000@3oool001X0oooo0P0000050?ooo`@0Ogmo00<0000009VI
V@2IVIT01`2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KV
iP3Vi^H02`3Vi^H00`000000oooo0?ooo`0c0?ooo`030000003Vi^H0i^KV00/0i^KV00<000000<c<
c03<c<`0203<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007mo
O`1oOgl01`1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c
<`0c<c<0200c<c<00`0000006ATI01TI6@0:01TI6CH000003P0I6AT00`000000<c<c03<c<`0703<c
<`800000201<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01`2IVIT00`000000/k>c0?ooo`040?ooo`8000000@3oool001X0oooo00<000000?ooo`3o
ool0103oool407moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000
c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00/0i^KV00<000000?ooo`3oool0<P3oool00`000000
i^KV0>KViP0;0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000
VIVI09VIV@0609VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000
C4a<04a<C00704a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02P0I6ATf000000h0
6ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00H0
IVIV0P00000707moO`800000202IVIT200000080/k>c1P3oool100000040oooo000J0?ooo`030000
003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00L0/k>c
00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0:0>KViP030000003oool0oooo03<0oooo
00<000000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00L0/k>c
00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV
00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI00X06ATI
=000000>01TI6@8000002@0c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00D0IVIV
0P00000807moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<00P2c/k<60?ooo`400000
0@3oool001X0oooo00<000000?ooo`3oool0103oool407moO`030000002IVIT0VIVI00L0VIVI00<0
00000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00/0i^KV00<0
00000?ooo`3oool0<P3oool00`000000i^KV0>KViP0;0>KViP030000003<c<`0c<c<00P0c<c<00<0
00000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0
000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00T0<c<c00<0
000001TI6@0I6AT02P0I6ATd000000h06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<
C00604a<C08000001`1VIVH00`000000Ogmo07moO`0607moO`800000202IVIT2000000D0/k>c1P3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@07
09VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0;
0>KViP030000003oool0oooo0380oooo00<000000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c007
0<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`07
07moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`08
03<c<`030000000I6AT06ATI00X06ATI=000000>01TI6@030000000c<c<0<c<c00P0<c<c00<00000
04a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP800000201oOgl00`000000VIVI09VIV@07
09VIV@030000002c/k<0/k>c00D0/k>c1P3oool100000040oooo000J0?ooo`030000003oool0oooo
00@0oooo101oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<
c03<c<`0203<c<`00`000000i^KV0>KViP0;0>KViP030000003oool0oooo0340oooo00<000000>KV
iP3Vi^H02`3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV00<0000004a<
C01<C4`01`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00X06ATI=000000=01TI
6@8000002@0c<c<2000000P0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0707mo
O`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<01@2c/k<2000000D0oooo0@0000010?oo
o`006P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000
/k>c0;>c/`070;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H02P3Vi^H00`000000
oooo0?ooo`0a0?ooo`030000003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`0203<c<`00`000000
/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01P1oOgl00`000000
IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00`000000
6ATI01TI6@0:01TI6C@000003@0I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00L0
C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`800000202IVIT2000000L0
/k>c00<000000<c<c03oool01@3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
101oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0
203<c<`00`000000i^KV0>KViP0:0>KViP030000003oool0oooo0340oooo00<000000>KViP3Vi^H0
2`3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT0
1P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`0
1`1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00X06ATI<`00000>01TI6@030000
000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0506IVIP030000
001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`050;>c/`800000
0P3<c<`60?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool407moO`030000002I
VIT0VIVI00H0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0080<c<c0030000003V
i^H0i^KV00X0i^KV00<000000?ooo`3oool0<03oool00`000000i^KV0>KViP0;0>KViP030000003<
c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000001o
Ogl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c
<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02P0I6ATc000000h06ATI00<0000003<c<`0c<c<0200c
<c<00`000000C4a<04a<C00604a<C08000001P1VIVH2000000L0Ogmo0P00000809VIV@8000001`2c
/k<00`000000c<c<0<c<c0020<c<c0H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`04
0?ooo`@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0
c<c<00P0c<c<00<000000>KViP3Vi^H02P3Vi^H00`000000oooo0?ooo`0`0?ooo`030000003Vi^H0
i^KV00/0i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0
VIVI00H0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0
C4a<00L0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6C<000003@0I6AT2
000000X0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0
c<c<00<0c<c<1P3oool100000040oooo000J0?ooo`8000001@3oool407moO`030000002IVIT0VIVI
00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV
00/0i^KV00<000000?ooo`3oool0;`3oool00`000000i^KV0>KViP0;0>KViP030000003<c<`0c<c<
00P0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo
00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c
00L0<c<c00<0000001TI6@0I6AT02P0I6ATc000000d06ATI00<0000003<c<`0c<c<02@0c<c<00`00
0000C4a<04a<C00504a<C08000001`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI
00H0VIVI0P0000070;>c/`8000001P3<c<`50?ooo`8000000@3oool001X0oooo00<000000?ooo`3o
ool0103oool407moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000
c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00X0i^KV00<000000?ooo`3oool0<03oool00`000000
i^KV0>KViP0;0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000
VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000
C4a<04a<C00704a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02P0I6ATc000000d0
6ATI00<0000003<c<`0c<c<0200c<c<2000000L0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000
Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000
c<c<0<c<c0060<c<c0H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo
00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<
00<000000>KViP3Vi^H02P3Vi^H00`000000oooo0?ooo`0_0?ooo`030000003Vi^H0i^KV00/0i^KV
00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<
00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6C<000003@0I6AT00`000000<c<c
03<c<`0703<c<`800000201<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo
0P00000709VIV@800000202c/k<00`000000c<c<0<c<c0070<c<c0H0oooo0@0000010?ooo`006P3o
ool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c
/`060;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H02P3Vi^H00`000000oooo0?oo
o`0_0?ooo`030000003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c
/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IV
IP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI
6@0:01TI6C<00000300I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00L0C4a<00<0
000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI00<0
00000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0070<c<c08000001@3oool100000040oooo000J
0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0
/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0:0>KViP030000003oool0
oooo02h0oooo00<000000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0
/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0
IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT0
6ATI00X06ATI<`00000<01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01`1<C4`0
0`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT0
0`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3oool01@3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0609VI
V@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP090>KV
iP030000003oool0oooo02l0oooo00<000000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0070<c<
c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507mo
O`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00X06ATI<`00000<01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<
C01<C4`01`1<C4`00`000000IVIV06IVIP0506IVIP8000001`1oOgl00`000000VIVI09VIV@0509VI
V@800000202c/k<2000000T0c<c<00<000000>KViP3Vi^H01P3oool100000040oooo000J0?ooo`03
0000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0
/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0:0>KViP030000003oool0oooo02l0
oooo00<000000>KViP3Vi^H02P3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00L0
/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0
IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00X0
6ATI<P00000<01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01`1<C4`00`000000
IVIV06IVIP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000
/k>c0;>c/`070;>c/`030000003<c<`0c<c<00L0c<c<0P0000030>KViPH0oooo0@0000010?ooo`00
6P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c
0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H02P3Vi^H00`000000oooo
0?ooo`0^0?ooo`030000003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c
0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV
06IVIP0506IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI
01TI6@0:01TI6C800000300I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00L0C4a<
00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0507moO`8000001`2IVIT00`000000/k>c
0;>c/`060;>c/`8000002@3<c<`00`000000i^KV0>KViP030>KViPH0oooo0@0000010?ooo`006P3o
ool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c
/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H02@3Vi^H00`000000oooo0?oo
o`0_0?ooo`030000003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`0203<c<`00`000000/k>c0;>c
/`060;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IV
IP0606IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI
6@0:01TI6C400000300I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00L0C4a<00<0
000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI0P00
00080;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H0103Vi^H60?ooo`4000000@3o
ool001X0oooo00<000000?ooo`3oool0103oool407moO`030000002IVIT0VIVI00H0VIVI00<00000
0;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00T0i^KV00<00000
0?ooo`3oool0;`3oool00`000000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00L0c<c<00<00000
0;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00H0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<00000
01TI6@0I6AT02P0I6ATa000000`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C006
04a<C08000001`1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI00<00000
0;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00D0i^KV1P3oool1
00000040oooo000J0?ooo`8000001@3oool407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?oo
o`3oool0;P3oool00`000000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c
/`2c/k<01P2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI
6@0I6AT02P0I6ATa000000`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00604a<
C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VI
V@030000002c/k<0/k>c00H0/k>c0P0000090<c<c0800000203Vi^H50?ooo`8000000@3oool001X0
oooo00<000000?ooo`3oool0103oool407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c
/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3o
ool0;P3oool00`000000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c
/k<01`2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1V
IVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I
6AT02P0I6ATa000000`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00604a<C003
0000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@03
0000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP080>KViPH0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT0
1@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H0
203Vi^H00`000000oooo0?ooo`0^0?ooo`030000003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`0
203<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0
1`0c<c<00`0000006ATI01TI6@0:01TI6C400000300I6AT00`000000<c<c03<c<`0703<c<`030000
001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<2000000X0c<c<00<000000>KViP3Vi^H0
2@3Vi^H00`000000oooo0?ooo`030?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<
c0070<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool0;P3oool00`000000i^KV0>KV
iP0:0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VI
V@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<
C00604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02P0I6AT`000000`06ATI00<0
000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00H0IVIV00<0
000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<0
00000<c<c03<c<`0203<c<`2000000/0i^KV00<000000?ooo`3oool0103oool100000040oooo000J
0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0
/k>c00H0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP090>KViP030000003oool0
oooo02h0oooo00<000000>KViP3Vi^H02P3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0
/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT0
6ATI00X06ATI<000000<01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01P1<C4`0
0`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT0
0`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H02P3Vi^H0
0`000000oooo0?ooo`050?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool407mo
O`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0070<c<
c0030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool0;P3oool00`000000i^KV0>KViP0:0>KV
iP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0509VI
V@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<
C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT`000000/06ATI0P00000903<c
<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507mo
O`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0080<c<
c0030000003Vi^H0i^KV00X0i^KV00<000000?ooo`3oool01P3oool100000040oooo000J0?ooo`03
0000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0
/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02h0
oooo00<000000>KViP3Vi^H02P3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00H0
/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0
IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X0
6ATI<000000<01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`2000000H0
IVIV0`00000607moO`8000001P2IVIT2000000L0/k>c0P0000080<c<c08000002`3Vi^H2000000T0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT0
1@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H0
203Vi^H00`000000oooo0?ooo`0^0?ooo`030000003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`0
1`3<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0
1@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<0
1P0c<c<00`0000006ATI01TI6@0:01TI6C000000300I6AT00`000000<c<c03<c<`0603<c<`030000
001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`030000
002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0070<c<c0030000
003Vi^H0i^KV00X0i^KV00<000000?ooo`3oool02@3oool100000040oooo000J0?ooo`030000003o
ool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<0
00000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02h0oooo00<0
00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00H0/k>c00<0
000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0
000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI<000
000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IV
IP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c
/`060;>c/`030000003<c<`0c<c<00H0c<c<0P00000<0>KViP030000003oool0oooo00X0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0000009VIV@2IVIT01@2IVIT0
0`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3Vi^H0203Vi^H0
0`000000oooo0?ooo`0]0?ooo`030000003Vi^H0i^KV00X0i^KV00<000000<c<c03<c<`01`3<c<`0
0`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl0
0`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0:01TI6C000000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0
VIVI00@0VIVI0P0000080;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02P3Vi^H2
000000d0oooo0@0000010?ooo`006P3oool2000000D0oooo101oOgl00`000000VIVI09VIV@0509VI
V@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KV
iP030000003oool0oooo02d0oooo00<000000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0070<c<
c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507mo
O`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0603<c
<`030000000I6AT06ATI00X06ATI;`00000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<
C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT0102IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KV
iP3Vi^H02P3Vi^H00`000000oooo0?ooo`0<0?ooo`8000000@3oool001X0oooo00<000000?ooo`3o
ool0103oool407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000
c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool0;@3oool00`000000
i^KV0>KViP090>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000
VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000
C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT_000000`0
6ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0
IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00H0
/k>c0P0000070<c<c0800000303Vi^H00`000000oooo0?ooo`0>0?ooo`4000000@3oool001X0oooo
00<000000?ooo`3oool0103oool407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<0
1P2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool0
;03oool00`000000i^KV0>KViP090>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<0
1@2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0
1@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0
2P0I6AT_000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000
001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0409VIV@030000
002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0;0>KViP030000
003oool0oooo00l0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`@0Ogmo00<0
000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0c<c<00<0
00000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0/0?ooo`030000003Vi^H0i^KV00T0i^KV00<0
00000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0
000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00D0C4a<00<0
000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6Bh00000300I6AT00`000000<c<c03<c
<`0603<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07mo
O`0607moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00X0i^KV0P00000B0?ooo`4000000@3oool001X0oooo00<00000
0?ooo`3oool0103oool407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<0
0`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool0;03oool0
0`000000i^KV0>KViP090>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<0102c/k<0
0`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH0
0`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT^
000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0
IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl2000000H0VIVI00<000000;>c/`2c/k<01P2c/k<0
0`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00X0i^KV00<000000?ooo`3oool04P3oool1
00000040oooo000J0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0409VI
V@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP090>KV
iP030000003oool0oooo02/0oooo00<000000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0070<c<
c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507mo
O`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00T06ATI;P00000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<
C01<C4`01P1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VI
V@2IVIT01@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KV
iP3Vi^H02@3Vi^H2000001D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`@0
Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00L0
c<c<00<000000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0[0?ooo`030000003Vi^H0i^KV00T0
i^KV00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00H0
VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0
C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6Bd00000300I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH0101VIVH00`000000
Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000
c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool05@3oool100000040
oooo000J0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0409VIV@030000
002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0:0>KViP030000
003oool0oooo02/0oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0070<c<c0030000
002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000
001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`030000
000I6AT06ATI00X06ATI;@00000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0
1P1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0
1@2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0
203Vi^H2000001P0oooo0@0000010?ooo`00100000050?ooo`808R8R1@3oool01@14A4@000000000
000c<c<0gMgM00D0oooo00<000000?ooo`3oool0103oool407moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00X0i^KV
00<000000?ooo`3oool0:P3oool00`000000i^KV0>KViP090>KViP030000003<c<`0c<c<00L0c<c<
00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c
00<0000001TI6@0I6AT02@0I6AT]000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<
04a<C00604a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI
09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV
0>KViP080>KViP030000003oool0oooo01P0oooo0@0000010?ooo`0000@08R8R0>k^kP3oool0A4A4
1@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`040?ooo`@0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00H0c<c<
00<000000>KViP3Vi^H02P3Vi^H00`000000oooo0?ooo`0Z0?ooo`030000003Vi^H0i^KV00P0i^KV
00<000000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<
00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0901TI6Bd00000300I6AT00`000000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo
07moO`0507moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<2000000L0c<c<
0P00000:0>KViP030000003oool0oooo01T0oooo0@0000010?ooo`0000<0VIVI028R8P3^k^h04@3o
ool00`000000oooo0?ooo`030?ooo`<00000103oool407moO`030000002IVIT0VIVI00@0VIVI00<0
00000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00X0i^KV00<0
00000?ooo`3oool0:P3oool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00L0c<c<00<0
00000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0
000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c00<0
000001TI6@0I6AT02@0I6AT/000000`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<
C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VI
V@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP090>KViP030000003oool0oooo01P0oooo0`0000010?ooo`0000@0oooo09VIV@0R8R80k^k^3`3o
ool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP0:0>KViP030000003oool0oooo02T0oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<
c0070<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07mo
O`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c
<`0703<c<`030000000I6AT06ATI00T06ATI;000000=01TI6@030000000c<c<0<c<c00H0<c<c00<0
000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00@0Ogmo00<0
000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<0
00000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0K0?ooo`4000000@3oool00080oooo00<0MgMg
06IVIP3oool02`3oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0103o
ool407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00X0i^KV00<000000?ooo`3oool0:@3oool00`000000i^KV0>KV
iP080>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VI
V@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<
C00504a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02@0I6AT]000000`06ATI00<0
000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0
000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<0
00000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000003oool0oooo01`0oooo0@00
00010?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0103oool407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<0
0`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool0:P3oool0
0`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<01@2c/k<0
0`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH0
0`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02@0I6AT/
000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0
IVIV00D0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0
/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000003oool0
oooo01d0oooo0@0000010?ooo`0000@0^k^k0?ooo`2IVIT04A4A303oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0
/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000003oool0
oooo02T0oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0
/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT0
6ATI00T06ATI;000000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`0
0`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT0
0`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H0
0`000000oooo0?ooo`0N0?ooo`4000000@3oool00004014A4@0000008R8R0<c<c0`0oooo10000006
0?ooo`030000003oool0oooo00@0oooo101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0
/k>c00H0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000003oool0
oooo02T0oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0
/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT0
6ATI00T06ATI:`00000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`0
0`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT0
0`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H0
0`000000oooo0?ooo`0O0?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool307mo
O`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0060<c<
c0030000003Vi^H0i^KV00X0i^KV00<000000?ooo`3oool0:03oool00`000000i^KV0>KViP080>KV
iP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VI
V@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<
C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02@0I6AT/000000/06ATI00<0000003<c
<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007mo
O`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<
c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000003oool0oooo0200oooo0@0000010?oo
o`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000
/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02P3Vi^H00`000000
oooo0?ooo`0X0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01P3<c<`00`000000
/k>c0;>c/`060;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000
6ATI01TI6@0901TI6B`000002`0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0
C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00D0
VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0
i^KV00<000000?ooo`3oool08@3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
0`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
1P3<c<`00`000000i^KV0>KViP0:0>KViP030000003oool0oooo02P0oooo00<000000>KViP3Vi^H0
203Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0
1@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00T06ATI:`00000;01TI6@030000
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`030000
003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0R0?ooo`400000
0@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00D0VIVI00<0
00000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00X0i^KV00<0
00000?ooo`3oool09`3oool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00L0c<c<00<0
00000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00D0Ogmo00<0
000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<0
000001TI6@0I6AT02@0I6AT/000000X06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<
C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VI
V@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP090>KViP030000003oool0oooo02<0oooo0@0000010?ooo`006P3oool2000000D0oooo0`1oOgl0
0`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`0
0`000000i^KV0>KViP090>KViP030000003oool0oooo02P0oooo00<000000>KViP3Vi^H0203Vi^H0
0`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00T06ATI:`00000:01TI6@030000000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0
c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0S0?ooo`8000000@3oool0
01X0oooo00<000000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<01@2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?oo
o`3oool0:03oool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c
/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI
6@0I6AT02@0I6AT[000000X06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<
C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VI
V@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KV
iP030000003oool0oooo02D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0
c<c<00<000000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0W0?ooo`030000003Vi^H0i^KV00P0
i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0
VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0
C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0901TI6B/000002P0I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000
Ogmo07moO`0407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000
c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool09P3oool100000040
oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VIV@0509VIV@030000
002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000
003oool0oooo02L0oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0060<c<c0030000
002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000
001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000
000I6AT06ATI00T06ATI:`00000:01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0
1@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0
102IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0
2@3Vi^H00`000000oooo0?ooo`0W0?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool307moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool09`3oool00`000000i^KV0>KV
iP090>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VI
V@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02@0I6AT[000000X06ATI00<0
000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0
000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<0
00000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP090>KViP030000003oool0oooo02P0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT01@2IVIT0
0`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H0
0`000000oooo0?ooo`0W0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01P3<c<`0
0`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0801TI6B/000002P0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0
i^KV00T0i^KV00<000000?ooo`3oool0:@3oool100000040oooo000J0?ooo`030000003oool0oooo
00@0oooo0`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<
c03<c<`01@3<c<`00`000000i^KV0>KViP090>KViP030000003oool0oooo02H0oooo00<000000>KV
iP3Vi^H02@3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VI
V@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00H0IVIV00<0000004a<
C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00P06ATI:`00000:01TI
6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IV
IP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H02@3Vi^H00`000000oooo0?ooo`0Z0?oo
o`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00D0
VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00T0
i^KV00<000000?ooo`3oool09P3oool00`000000i^KV0>KViP090>KViP030000003<c<`0c<c<00D0
c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0
Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00D0
<c<c00<0000001TI6@0I6AT02@0I6ATZ000000/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000
C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000
VIVI09VIV@0509VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<c<`00`000000
i^KV0>KViP080>KViP800000;@3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
0`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02L0oooo00<000000>KViP3Vi^H0
203Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00P06ATI:P00000;01TI6@030000
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000
003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0V0?ooo`800000
1@3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KV
iP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<
c0050<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c
<`0603<c<`030000000I6AT06ATI00P06ATI:`00000:01TI6@030000000c<c<0<c<c00H0<c<c00<0
000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0
000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0c<c<00<0
00000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0V0?ooo`030000003Vi^H0oooo00D0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT0
0`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H0
0`000000oooo0?ooo`0V0?ooo`030000003Vi^H0i^KV00T0i^KV00<000000<c<c03<c<`01@3<c<`0
0`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0701TI6B/000002P0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00D0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0
i^KV00P0i^KV00<000000?ooo`3oool09P3oool00`000000i^KV0>KViP060?ooo`4000000@3oool0
01X0oooo0P0000050?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c
/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0V0?oo
o`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`050;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0701TI
6B/000002P0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IV
IP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<0102c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00P0i^KV00<000000?oo
o`3oool09@3oool2000000<0i^KV1@3oool200000040oooo000J0?ooo`030000003oool0oooo00@0
oooo0`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<
c<`01P3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3V
i^H0203Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<
C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00L06ATI:P00000;01TI6@03
0000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`03
0000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0U0?ooo`03
0000003Vi^H0i^KV00<0i^KV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
0`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H0
2@3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00L06ATI:`00000:01TI6@030000
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000
003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0U0?ooo`030000
003Vi^H0i^KV00@0i^KV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1o
Ogl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<
c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H0203V
i^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102I
VIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<
C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00H06ATI:`00000:01TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001o
Ogl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<
c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0U0?ooo`030000003V
i^H0i^KV00D0i^KV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H0203Vi^H0
0`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00H06ATI:`00000:01TI6@030000000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0
c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0
i^KV00H0i^KV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`00
0000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`00`00
0000i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H0203Vi^H00`00
0000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`00
0000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`00
0000<c<c03<c<`0603<c<`030000000I6AT06ATI00H06ATI:`00000:01TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<
00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV
00H0i^KV1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000
VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`00`000000
i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H0203Vi^H00`000000
c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000
Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0503<c<`030000000I6AT06ATI00H06ATI:`00000:01TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0
c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00H0
i^KV0P0000050?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`030000
002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0050<c<c0030000
003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool09@3oool00`000000i^KV0>KViP080>KViP030000
003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000
001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000
000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6ATZ000000X06ATI00<0000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0
0`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0
1P3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02D0oooo00<000000>KViP3Vi^H0
1P3Vi^H00`000000c<c<0?ooo`050?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103o
ool307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<
c0050<c<c0030000003Vi^H0i^KV00L0i^KV00<000000?ooo`3oool09P3oool00`000000i^KV0>KV
iP080>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VI
V@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<
C00504a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01`0I6ATZ000000X06ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00@0/k>c00<0
00000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo02H0oooo00<0
00000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0060?ooo`4000000@3oool001X0oooo00<00000
0?ooo`3oool0103oool307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<0
0`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV00<000000?ooo`3oool09P3oool0
0`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<0
0`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01P0I6ATZ
000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0
IVIV00D0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0
/k>c00@0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP080>KViP030000003oool0
oooo02H0oooo00<000000>KViP3Vi^H01@3Vi^H010000000c<c<0<c<c03<c<`60?ooo`4000000@3o
ool001X0oooo0P0000050?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`05
0;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0U
0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`05
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@07
01TI6BX000002@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI00<00000
0;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00T0i^KV00<00000
0?ooo`3oool0903oool2000000L0i^KV00<000000<c<c03<c<`00P3<c<`50?ooo`8000000@3oool0
01X0oooo00<000000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<01@2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV00<000000?oo
o`3oool09@3oool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c
/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IV
IP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI
6@0I6AT01`0I6ATY000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<
C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0509VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP090>KV
iP030000003oool0oooo02@0oooo00<000000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0030<c<
c0H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2I
VIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3V
i^H01`3Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<
c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1o
Ogl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0701TI6BT000002P0I6AT00`000000<c<c03<c<`0503<c<`03
0000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0307moO`03
0000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c003
0000003Vi^H0i^KV00T0i^KV00<000000?ooo`3oool0903oool00`000000i^KV0>KViP060>KViP03
0000003<c<`0c<c<00@0c<c<1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo
0`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0
1P3<c<`00`000000i^KV0>KViP070>KViP030000003oool0oooo02D0oooo00<000000>KViP3Vi^H0
203Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00L06ATI:@00000901TI6@030000
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000
003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0T0?ooo`030000
003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`01@3<c<`60?ooo`4000000@3oool001X0oooo00<0
00000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c
/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool0903o
ool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<01@2c
/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101V
IVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I
6ATX000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00D0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c
/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP080>KViP030000003o
ool0oooo02@0oooo00<000000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0050<c<c08000001@3o
ool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VIV@04
09VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP07
0>KViP030000003oool0oooo02D0oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c005
0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`04
07moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00L06ATI:@00000901TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00<0Ogmo00<00000
09VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<00000
0>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0T0?ooo`030000003Vi^H0i^KV00H0i^KV00<00000
0<c<c03<c<`0103<c<`2000000030;>c/`3oool0oooo00@0oooo0@0000010?ooo`006P3oool00`00
0000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0U0?oo
o`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI
6BP000002@0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH01@1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00P0i^KV00<000000?oo
o`3oool0903oool00`000000i^KV0>KViP060>KViP030000003<c<`0c<c<00@0c<c<00@000000;>c
/`2c/k<0/k>c1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`00
0000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`00
0000i^KV0>KViP070>KViP030000003oool0oooo02@0oooo00<000000>KViP3Vi^H0203Vi^H00`00
0000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`00
0000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`00
0000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI9`00000:01TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<
00D0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0T0?ooo`030000003Vi^H0i^KV
00H0i^KV00<000000<c<c03<c<`00`3<c<`2000000@0/k>c1P3oool100000040oooo000J0?ooo`03
0000003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0
/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP030000003oool0oooo02@0
oooo00<000000>KViP3Vi^H0203Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0
/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00P0
6ATI9`00000:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000
/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H2000002D0
oooo0P0000080>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0102c/k<60?ooo`40
00000@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV
00<000000?ooo`3oool0903oool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00D0c<c<
00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c
00<0000001TI6@0I6AT0200I6ATW000000X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV
0>KViP060>KViP030000003oool0oooo02@0oooo00<000000>KViP3Vi^H01`3Vi^H2000000D0c<c<
00<000000;>c/`2c/k<0102c/k<60?ooo`4000000@3oool001X0oooo0P0000050?ooo`<0Ogmo00<0
000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<0
00000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0T0?ooo`030000003Vi^H0i^KV00P0i^KV00<0
00000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0801TI6BL000002P0I6AT00`000000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07mo
O`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0050<c<c0030000003Vi^H0i^KV00D0i^KV0P00000V0?ooo`030000003Vi^H0i^KV00L0i^KV00<0
00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`050;>c/`D0oooo0P0000010?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`04
0;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01P3Vi^H00`000000oooo0?ooo`0U
0?ooo`030000003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`04
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@08
01TI6BL000002@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<00000
0;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00D0i^KV00<00000
0?ooo`3oool09@3oool00`000000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<00000
0;>c/`2c/k<01@2c/k<2000000D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<
00D0c<c<00<000000>KViP3Vi^H01P3Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV
00L0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI
00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<
00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0701TI6BL000002P0I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`00
0000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`00
0000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00D0i^KV00<000000?ooo`3oool09@3oool00`00
0000i^KV0>KViP070>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`00
0000VIVI0?ooo`050?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c003
0000003Vi^H0i^KV00H0i^KV00<000000?ooo`3oool09@3oool00`000000i^KV0>KViP070>KViP03
0000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C003
0000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01`0I6ATX000000T06ATI00<0000003<c<`0c
<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl01@1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<
c<`01@3<c<`00`000000i^KV0>KViP060>KViP030000003oool0oooo02D0oooo00<000000>KViP3V
i^H01P3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2I
VIT01P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000VIVI
09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV
0>KViP060>KViP030000003oool0oooo02D0oooo00<000000>KViP3Vi^H01P3Vi^H00`000000c<c<
0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo
07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0603<c<`030000000I6AT06ATI00H06ATI:000000901TI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00D0Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0c<c<
00<000000>KViP3Vi^H01@3Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00H0i^KV
00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`040000002IVIT0VIVI09VIV@H0
oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0
102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H0
1P3Vi^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`0
1@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0
0`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0
1P0c<c<00`0000006ATI01TI6@0601TI6BP00000200I6AT00`000000<c<c03<c<`0503<c<`030000
001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0060<c<c0030000
003Vi^H0i^KV00H0i^KV00<000000?ooo`3oool0903oool00`000000i^KV0>KViP060>KViP030000
003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@H0oooo
0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102I
VIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01P3V
i^H00`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`01@3<
c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101o
Ogl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c
<c<00`0000006ATI01TI6@0601TI6BT00000200I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002I
VIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003V
i^H0i^KV00H0i^KV00<000000?ooo`3oool0903oool00`000000i^KV0>KViP060>KViP030000003<
c<`0c<c<00H0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@H0oooo0@00
00010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT0
0`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01P3Vi^H0
0`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`01@3<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0501TI6BT00000200I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0
i^KV00H0i^KV00<000000?ooo`3oool0903oool00`000000i^KV0>KViP060>KViP030000003<c<`0
c<c<00D0c<c<0P0000050;>c/`030000002IVIT0VIVI00<0VIVI0P0000050?ooo`4000000@3oool0
00l0oooo00D0VIVI014A4@000000<c<c0<c<c0060?ooo`030000003oool0oooo00@0oooo0`1oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`0
0`000000i^KV0>KViP060>KViP030000003oool0oooo02D0oooo00<000000>KViP3Vi^H01P3Vi^H0
0`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00H06ATI:@00000701TI6@030000000c<c<0
<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0
c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0S0?ooo`030000003Vi^H0
i^KV00H0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`3oool01@3oool100000040oooo000?0?ooo`05014A4@2k^k/0oooo
07MgM`0c<c<01P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT0
0`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01P3Vi^H0
0`000000oooo0?ooo`0U0?ooo`030000003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`01@3<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<0
0`0000006ATI01TI6@0601TI6BT00000200I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0
i^KV00L0i^KV00<000000?ooo`3oool08`3oool00`000000i^KV0>KViP060>KViP030000003<c<`0
c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo00H0oooo0@0000010?ooo`004`3oool00`000000oooo0?ooo`040?ooo`<00000103oool307mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<
c0030000003Vi^H0i^KV00D0i^KV00<000000?ooo`3oool09P3oool00`000000i^KV0>KViP050>KV
iP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT01@0I6ATZ000000L06ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007mo
O`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<
c03<c<`01@3<c<`00`000000i^KV0>KViP080>KViP030000003oool0oooo0280oooo00<000000>KV
iP3Vi^H01P3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VI
V@2IVIT00`2IVIT010000000Ogmo07moO`1oOgl40?ooo`<000000@3oool00180oooo00<0ZZZZ014A
4@3oool01@3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`00
0000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01@3Vi^H00`00
0000oooo0?ooo`0V0?ooo`030000003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`01@3<c<`00`00
0000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`00
00006ATI01TI6@0501TI6BX000001`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI
00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV
00P0i^KV00<000000?ooo`3oool08@3oool2000000P0i^KV00<000000<c<c03<c<`0103<c<`20000
00H0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`H0oooo0@0000010?oo
o`004@3oool00`0A4A4000000;^k^`060?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000
VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00`000000
i^KV0>KViP050>KViP030000003oool0oooo02H0oooo00<000000>KViP3Vi^H01@3Vi^H00`000000
c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0503<c<`030000000I6AT06ATI00D06ATI:P00000701TI6@030000000c<c<0<c<c00D0
<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0
Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0
c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo0?ooo`0P0?ooo`030000003Vi^H0i^KV00L0
i^KV00<000000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0
VIVI00<0000007moO`1oOgl00P1oOgl60?ooo`4000000@3oool00180oooo00<0^k^k028R8P3oool0
1@3oool00`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c
0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01@3Vi^H00`000000oooo
0?ooo`0U0?ooo`030000003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c
0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV
06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI
01TI6@0601TI6BT000001`0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00P0i^KV
00<000000?ooo`3oool0803oool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<0080c<c<
0P0000070;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`030?ooo`4000000@3oool000l0oooo00D04A4A09VIV@3oool0^k^k000000060?ooo`030000
003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c
00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP050>KViP030000003oool0oooo02D0oooo
00<000000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c
00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT06ATI00D06ATI
:@00000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`050;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo
0?ooo`0P0?ooo`030000003Vi^H0i^KV00P0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c
0;>c/`060;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`040?ooo`4000000@3oool000l0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP060?ooo`030000
003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c
00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP050>KViP030000003oool0oooo02D0oooo
00<000000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c
00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI
:000000801TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0506IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c
0;>c/`040;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000oooo
0?ooo`0P0?ooo`030000003Vi^H0i^KV00P0i^KV00@000000<c<c03<c<`0c<c<0P0000080;>c/`03
0000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV0?ooo`050?ooo`40
00000@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00D0i^KV
00<000000?ooo`3oool0903oool00`000000i^KV0>KViP050>KViP030000003<c<`0c<c<00H0c<c<
00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c
00<0000001TI6@0I6AT01P0I6ATX000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI
09VIV@0309VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV
0>KViP070>KViP030000003oool0oooo0240oooo00<000000>KViP3Vi^H01`3Vi^H01@000000c<c<
0<c<c03<c<`0000000T0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`03
0000001VIVH0IVIV00H0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<
00<000000>KViP3Vi^H01@3Vi^H00`000000oooo0?ooo`0T0?ooo`030000003Vi^H0i^KV00D0i^KV
00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI
00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6BL00000200I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<
0<c<c0040<c<c0030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool0803oool00`000000i^KV
0>KViP070>KViP050000003<c<`0c<c<0<c<c00000002@2c/k<00`000000VIVI09VIV@0409VIV@03
0000001oOgl0Ogmo00<0Ogmo00@0000006IVIP1VIVH0IVIV1P3oool100000040oooo000J0?ooo`03
0000003oool0oooo00@0oooo0`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0
/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP030000003oool0oooo0280
oooo00<000000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0
/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00H0
6ATI9`00000901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000
/k>c0;>c/`050;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H0203Vi^H00`000000
oooo0?ooo`0P0?ooo`030000003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`00P3<c<`00`000000
/k>c0;>c/`060;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000
IVIV06IVIP0206IVIPH0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?ooo`<0Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<
00<000000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0R0?ooo`030000003Vi^H0i^KV00H0i^KV
00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI
00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0601TI6BH000002@0I6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<
0<c<c0040<c<c0030000003Vi^H0i^KV00P0i^KV00<000000?ooo`3oool0803oool00`000000i^KV
0>KViP070>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000oooo
0?ooo`030?ooo`4000000@3oool001X0oooo0P0000050?ooo`<0Ogmo00<0000009VIV@2IVIT00`2I
VIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3V
i^H00`000000oooo0?ooo`0R0?ooo`030000003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`0103<
c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101o
Ogl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c
<c<00`0000006ATI01TI6@0701TI6BH00000200I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c0030000003V
i^H0i^KV00P0i^KV00<000000?ooo`3oool0803oool00`000000i^KV0>KViP070>KViP030000003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0309VIV@8000001@1o
Ogl00`000000IVIV06IVIP0306IVIP030000003oool0oooo00<0oooo0P0000010?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`03
0;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0Q
0?ooo`030000003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`04
0;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@07
01TI6BD000002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<00000
0;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00H0i^KV0P00000R
0?ooo`030000003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`05
0;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0oooo00D0oooo0@0000010?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<
00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`000000oooo0?ooo`0Q0?ooo`030000003Vi^H0i^KV
00H0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI
00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<
00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6B@000002@0I6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH00`00
0000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`00
0000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00H0i^KV00<000000?ooo`3oool08@3oool00`00
0000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`00
0000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`00
0000C4a<04a<C0060?ooo`4000000@3oool001X0oooo00<000000?ooo`3oool0103oool307moO`03
0000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c003
0000003Vi^H0i^KV00L0i^KV00<000000?ooo`3oool08@3oool00`000000i^KV0>KViP060>KViP03
0000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C003
0000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6ATT000000X06ATI00<0000003<c<`0c
<c<0100c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<
c<`0103<c<`00`000000i^KV0>KViP060>KViP030000003oool0oooo0240oooo00<000000>KViP3V
i^H01`3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00@0000004a<C01<
C4`0C4a<1P3oool100000040oooo000J0?ooo`030000003oool0oooo00@0oooo0`1oOgl00`000000
VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00`000000
i^KV0>KViP070>KViP030000003oool0oooo0200oooo00<000000>KViP3Vi^H01`3Vi^H00`000000
c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI8`00000:01TI6@030000000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0
Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00@0
c<c<00<000000>KViP3Vi^H01P3Vi^H00`000000oooo0?ooo`0Q0?ooo`030000003Vi^H0i^KV00L0
i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0
VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<0080
C4a<1P3oool100000040oooo000J0?ooo`030000003oool0oooo0?l0ooooBP3oool100000040oooo
000J0?ooo`030000003oool0oooo0?l0ooooBP3oool100000040oooo000J0?ooo`030000003oool0
oooo0?l0ooooBP3oool100000040oooo000J0?ooo`030000003oool0oooo0?l0ooooBP3oool10000
0040oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool04@3oool100000040
oooo000J0?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
0P0000010?ooo`006P3ooooo000004h000000@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0
ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {0, 0, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We have used an option in this plot, ",
  StyleBox["PlotPoints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Rule]\)\(\ \)\)\)\)]],
  StyleBox["25",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", in order to increase the number of points where the function has been \
sampled to a 25-by-25 grid (the default is 15-by-15).  For functions with \
rapid variation, this helps reduce errors in placement of the contours. "
}], "Text"],

Cell[TextData[{
  "\tIn this relatively basic version of a contour plot, the ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-values of each contour are evenly spaced, but the spacing is determined \
automatically (and there's no easy way to find out what the values of the \
contours are!). To set the ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-values by hand, use the ",
  StyleBox["Contours",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, as in ",
  StyleBox["Contours",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rule]\)\(\ \)\)\)]],
  StyleBox["{-0.9,-0.5,0,0.5,0.9}. ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "This list gives the list of ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-values where contours will be drawn. Alternatively, if one just wants to \
increase or decrease the number of contours, one can use ",
  StyleBox["Contours",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Rule]\)\(\ \)\)\)]],
  StyleBox["30",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which will now draw 30 evenly spaced contours."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table  
                9  .13\ \ Two\ Ways\ to\ Plot\ Functions\ of\ Two\ \
Variables\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {GridBox[{
              {
                RowBox[{
                  StyleBox["Plot",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[",",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      StyleBox[\(x, xmin, xmax\),
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["}",
                        FontFamily->"Times"]}], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      StyleBox[\(y, ymin, ymax\),
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["}",
                        FontFamily->"Times"]}]}], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                RowBox[{
                  RowBox[{
                    StyleBox["Create",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["a",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["surface",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["plot",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox[
                      StyleBox[
                        RowBox[{"of", 
                          StyleBox["f",
                            FontSlant->"Italic"]}]],
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["as",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["a",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["function",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["of",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["x",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["and",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["y",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["in",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["the",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["ranges",
                      FontFamily->"Times"]}], "\[IndentingNewLine]", 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["xmin",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["to",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["xmax",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["and",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["ymin",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["to",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["ymax",
                        FontFamily->"Times",
                        FontSlant->"Italic"]}], 
                    StyleBox[",",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox["respectively",
                      FontFamily->"Times"]}], "\[IndentingNewLine]"}]},
              {
                RowBox[{
                  StyleBox["ContourPlot",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    StyleBox[",",
                      FontFamily->"Times",
                      FontSlant->"Italic"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      StyleBox[\(x, xmin, xmax\),
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["}",
                        FontFamily->"Times"]}], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      StyleBox[\(y, ymin, ymax\),
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["}",
                        FontFamily->"Times"]}]}], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                RowBox[{
                  StyleBox["Create",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["a",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["contour",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["plot",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["f",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["as",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["a",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["function",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["and",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["y",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times"]}]}
              },
            ColumnAlignments->{Left},
            AllowScriptLevelChange->True]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.6.7 Animations", "Subsubtitle",
  CellTags->{"i:56", "c:33"}],

Cell[TextData[{
  "\tAn animation can be created from a series of plots. For instance, we can \
create a sequence of plots of ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ k\ x\)]],
  " for different values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " using the ",
  StyleBox["Table ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "command shown in Cell ",
  ButtonBox["9.87",
    ButtonData:>"Cell 9.87",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Sin[k\ x], {x, 0, 10}, PlotRange \[Rule] {\(-1\), 1}], {k,  .2, 
          2,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.87"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .33406 L
.10458 .36118 L
.14415 .38628 L
.18221 .40992 L
.22272 .43437 L
.26171 .45706 L
.30316 .48007 L
.34309 .50103 L
.3815 .51991 L
.42237 .5385 L
.46172 .5548 L
.49955 .56889 L
.53984 .58209 L
.57861 .59295 L
.61984 .60243 L
.65954 .60949 L
.67958 .61226 L
.69774 .6143 L
.71741 .61602 L
.72821 .61674 L
.73838 .61727 L
.74815 .61765 L
.75306 .61779 L
.75589 .61786 L
.75846 .61791 L
.76067 .61795 L
.76307 .61798 L
.76439 .618 L
.76561 .61801 L
.76685 .61802 L
.76801 .61802 L
.769 .61803 L
.77007 .61803 L
.77125 .61803 L
.77234 .61803 L
.77341 .61803 L
.77458 .61803 L
.7758 .61802 L
.77693 .61802 L
.77956 .61799 L
.78198 .61796 L
.78464 .61792 L
.78746 .61787 L
.79219 .61775 L
.79739 .61759 L
.80699 .61719 L
.81598 .61671 L
.83627 .61521 L
.8548 .61335 L
Mistroke
.89456 .60782 L
.93281 .60054 L
.97351 .59073 L
.97619 .59001 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooocgooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0oooooolmooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooolm
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooo
oooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0
003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`3oooooocgooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocgooooo000>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000oooooolm
ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000kooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolmooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooocgooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003o
ooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o
0000ooooooooool0oooooolmooooo`00:Oooool2o`000?oooooo?_ooool002Wooooo00?o0000oooo
ooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`00
0?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool2
o`000?oooooo?_ooool002Wooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool0oooooolmooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo?Oooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo?Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`000?oooooo?Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo?Oooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`3oooooocgooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooocgo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003oooooocko
oooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooo
oolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo
?Oooool002Wooooo00?o0000ooooooooool0>?ooool5o`0003_ooooo0_l000000ol@413ooooooooo
o`0gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0>Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03Ko
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool002Wooooo00?o0000
ooooooooool0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A403cooooo00?o0000ooooooooool0>?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q03Wooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0hooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003o
ooooooooo`0iooooo`03oiRHV?lQ8B7ok^k^03[ooooo1Ol0000iooooo`05o`000?oooooooooooooo
ool00000>Oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`;o0000>oooool00onHV9So8B4Qonk^kP0i
ooooo`04odA4A?oMgMgoooooo`0003[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0iooooo`05oc8b
<_nHV9SooooooiRHV?lb<S80>?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool002Wooooo00?o0000ooooooooool0>oooool00omgMgOoIVIVooooo`0hooooo`04
omgMgOmEEEGoooooo`0003[ooooo00Go0000oeEEEOl0003o410@olc<c00iooooo`05olc<c?l0003o
0000o`000?o<c<`0>?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool002Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0hooooo`03ogMgMoo<
c<co000003[ooooo00?oEEEEohN7Qoooool0>oooool01Ol@413o^[Zjoooooonj^[[o410@03Sooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`00
0?oooooooooo03Sooooo00Go0000okZj^_ooooooV9RHoa0@400jooooo`03onk^k_m4A4Co000003[o
oooo00?ogMgMoa0@4?nHV9P0>oooool01Ol0003o^[Zjoooooonj^[[o000003Sooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo
03Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00kooooo`03ogMgMol0003ooooo03[ooooo00Coc<c<
odA4A?l0003o410@>Oooool01OnYZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o0000oooooolnooooo`00:Ooo
ool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool0
02Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgo
oooo000Qoooooooo0000B?l0000002Wooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo00;o0000>Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo
00;ooooo0_l0003oooooocWooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooolfooooo`00:Oooool2o`0000Kooooo0_l0003oooooocKooooo000Yooooo`03o`000?oo
oooooooo00Oooooo0_l0003oooooocCooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0oooooolaooooo`00:Oooool00ol0003oooooooooo`0:ooooo`;o0000oooooolaoooo
o`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo;_ooool002Wooooo
0_l0000>ooooo`;o0000ooooool^ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0?oooooo:oooool002Wooooo00?o0000ooooooooool04?ooool2o`000?oooooo:oooool0
02Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3oooooobSooooo000Yooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0oooooolWooooo`00:Oooool2o`0001Gooooo
0_l0003oooooobOooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0oooo
oolTooooo`00:Oooool00ol0003oooooooooo`0Gooooo`;o0000oooooolTooooo`00:Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo8Oooool002Wooooo00?o0000oooooooo
ool06_ooool2o`000?oooooo8Oooool002Wooooo0_l0000Mooooo`;o0000oooooolOooooo`00:Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oooooo7?ooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo01oooooo0_l0003ooooooacooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08Oooool2o`000?oooooo6_ooool000Kooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo5oooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0002Cooooo0_l0003ooooooaOooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo5?ooool000Kooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Wooooo`;o0000oooooolDooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:Oooool2o`000?oooooo4_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`3oooooo`oooooo000Yooooo`;o0000;Oooool2o`000?oooooo3oooool0
02Wooooo00?o0000ooooooooool0;_ooool2o`000?oooooo3Oooool002Wooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`3oooooo`[ooooo000Yooooo`03o`000?oooooooooo037ooooo
0_l0003oooooo`[ooooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0oooo
ool7ooooo`00:Oooool2o`0003Gooooo0_l0003oooooo`Oooooo000Yooooo`03o`000?oooooooooo
03Kooooo0_l0003oooooo`Gooooo000Yooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0ooooool2ooooo`00:Oooool00ol0003oooooooooo`0iooooo`;o0000ooooool2ooooo`00:Ooo
ool00ol0003oooooooooo`0kooooo`;o0000ooooool002Wooooo0_l0000nooooo`03o`000?oooooo
oooo0?cooooo000Yooooo`03o`000?oooooooooo03kooooo0_l0003looooo`00:Oooool00ol0003o
ooooooooo`10ooooo`;o0000n_ooool002Wooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`3gooooo`00:Oooool00ol0003oooooooooo`13ooooo`;o0000moooool002Wooooo0_l00016
ooooo`;o0000mOooool002Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`3boooo
o`00:Oooool00ol0003oooooooooo`18ooooo`;o0000l_ooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool0B_ooool2o`000?3ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1<ooooo`;o0000k_ooool000ko
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0ol0001>oooo
o`;o0000k?ooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0D?ooool2o`000>[ooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0D_ooool2
o`000>Sooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo05Cooooo0_l0003Vooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`;o0000i?ooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0005Wooooo0_l0003R
ooooo`00:Oooool00ol0003oooooooooo`1Jooooo`;o0000h?ooool002Wooooo00?o0000oooooooo
ool0G?ooool2o`000=kooooo000Yooooo`03o`000?oooooooooo05kooooo0_l0003Looooo`00:Ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo0=Wooooo000Yooooo`;o0000H_ooool2
o`000=Wooooo000Yooooo`03o`000?oooooooooo06?ooooo0_l0003Gooooo`00:Oooool00ol0003o
ooooooooo`1Uooooo`;o0000eOooool002Wooooo00?o0000ooooooooool0Ioooool2o`000=?ooooo
000Yooooo`03o`000?oooooooooo06Wooooo0_l0003Aooooo`00:Oooool2o`0006cooooo0_l0003?
ooooo`00:Oooool00ol0003oooooooooo`1]ooooo`;o0000cOooool002Wooooo00?o0000oooooooo
ool0Koooool2o`000<_ooooo000Yooooo`03o`000?oooooooooo077ooooo0_l00039ooooo`00:Ooo
ool00ol0003oooooooooo`1cooooo`?o0000a_ooool002Wooooo0_l0001gooooo`;o0000a?ooool0
02Wooooo00?o0000ooooooooool0N?ooool2o`000<;ooooo000Yooooo`03o`000?oooooooooo07[o
oooo0ol0002oooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
07gooooo0_l0002mooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1ooooo
o`;o0000^oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool3o`00087ooooo0_l0002iooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo08?ooooo0_l0002gooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0QOooool2o`000;Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Qoooool2
o`000;?ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`29ooooo`;o0000/Ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
002<ooooo`?o0000[_ooool002Wooooo00?o0000ooooooooool0S_ooool3o`000:_ooooo000Yoooo
o`03o`000?oooooooooo097ooooo0ol0002Xooooo`00:Oooool00ol0003oooooooooo`2Dooooo`?o
0000YOooool002Wooooo00?o0000ooooooooool0Uoooool3o`000:;ooooo000Yooooo`;o0000Vooo
ool3o`0009oooooo000Yooooo`03o`000?oooooooooo09gooooo0ol0002Looooo`00:Oooool00ol0
003oooooooooo`2Pooooo`;o0000V_ooool002Wooooo00?o0000ooooooooool0X_ooool3o`0009Oo
oooo000Yooooo`03o`000?oooooooooo0:Gooooo0ol0002Dooooo`00:Oooool2o`000:Wooooo1?l0
002@ooooo`00:Oooool00ol0003oooooooooo`2/ooooo`Co0000P?ooool4o`0000Sooooo000Yoooo
o`03o`000?oooooooooo0;3ooooo1?l0001iooooo`?o00003?ooool002Wooooo00?o0000oooooooo
ool0]?ooool5o`00077ooooo0ol0000?ooooo`00:Oooool00ol0003oooooooooo`2iooooo`Go0000
JOooool3o`0001;ooooo000Yooooo`;o0000_oooool4o`00063ooooo1Ol0000Eooooo`00:Oooool0
0ol0003oooooooooo`32ooooo`Go0000E?ooool7o`0001[ooooo000Yooooo`03o`000?oooooooooo
0<Oooooo1?l0001:ooooo`Ko00008Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0<_ooooo2ol0000hooooo`Oo00009oooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3Fooooo`Oo00009Oooool<o`0002kooooo000Qooooo`03o`000?oo
oooooooo00Gooooo0ol0003MooooobGo0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00
003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .35894 L
.10458 .41185 L
.14415 .45864 L
.18221 .49977 L
.22272 .53818 L
.26171 .56891 L
.28158 .58194 L
.30316 .59394 L
.32216 .60257 L
.33296 .60664 L
.34309 .60991 L
.35344 .61269 L
.36292 .61472 L
.37305 .61637 L
.37864 .61703 L
.38138 .6173 L
.38395 .61751 L
.38637 .61768 L
.38898 .61782 L
.39013 .61787 L
.39135 .61792 L
.3925 .61796 L
.39354 .61798 L
.39475 .61801 L
.39606 .61803 L
.39727 .61803 L
.39841 .61803 L
.39905 .61803 L
.39974 .61802 L
.40097 .61801 L
.40165 .61799 L
.4023 .61798 L
.40376 .61794 L
.40601 .61785 L
.40837 .61773 L
.41261 .61744 L
.41716 .61701 L
.42214 .61642 L
.43242 .61477 L
.44176 .61279 L
.46271 .60663 L
.48189 .59896 L
.50269 .58854 L
.54361 .56189 L
.58301 .52917 L
.6209 .49203 L
.66124 .44742 L
.70006 .40073 L
.74134 .34846 L
Mistroke
.7811 .29696 L
.81934 .24773 L
.86004 .19711 L
.89922 .15143 L
.94086 .10759 L
.97619 .07515 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000?oooooo?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolmooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000O
ooooo`03oeEEEOmVIVKo000000Oooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`00:Oooool00ol0003oooooooooo`3oooooocgooooo000Yooooo`03o`000?oo
oooooooo0?oooooo?Oooool002Wooooo0_l0003oooooockooooo000Yooooo`03o`000?oooooooooo
0?oooooo?Oooool002Wooooo00?o0000ooooooooool0oooooolmooooo`00:Oooool00ol0003ooooo
ooooo`3oooooocgooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo0_l0003o
ooooockooooo000Yooooo`03o`000?oooooooooo0?oooooo?Oooool002Wooooo00?o0000oooooooo
ool0oooooolmooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
0?oooooo?Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolmoooo
o`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0003ooooooc?ooooo0_l00008ooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo0?oooooo<_ooool00ol0003oooooooooo`08ooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0oooooolaooooo`03o`000?oooooooooo00Wooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0ooooool`ooooo`03o`000?oooooooooo00[ooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooooboooooo00?o0000ooooooooool02ooo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
003oooooobkooooo0_l0000>ooooo`00:Oooool00ol0003oooooooooo`3oooooobcooooo00?o0000
ooooooooool03_ooool002Wooooo00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo
00oooooo000Yooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0@ooooo`00
:Oooool00ol0003oooooooooo`3oooooobWooooo00?o0000ooooooooool04Oooool002Wooooo0_l0
003oooooobWooooo00?o0000ooooooooool04_ooool002Wooooo00?o0000ooooooooool0oooooolX
ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo0?oooooo9oooool00ol0
003oooooooooo`0Cooooo`00:Oooool00ol0003oooooooooo`3oooooobKooooo00?o0000oooooooo
ool05?ooool002Wooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo01Gooooo
000Yooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Fooooo`00:Oooool2
o`000?oooooo9?ooool00ol0003oooooooooo`0Gooooo`00:Oooool00ol0003oooooooooo`3ooooo
ob;ooooo00?o0000ooooooooool06?ooool002Wooooo00?o0000ooooooooool0oooooolQooooo`03
o`000?oooooooooo01Wooooo000Yooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003ooooo
ooooo`0Iooooo`00:Oooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool06_oo
ool002Wooooo0_l0003oooooob3ooooo00?o0000ooooooooool06oooool002Wooooo00?o0000oooo
ooooool0oooooolNooooo`03o`000?oooooooooo01cooooo000>ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo7Oooool00ol0003oooooooooo`0Mooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0oooooolL
ooooo`03o`000?oooooooooo01kooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000
ooooooooool07oooool000kooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00Cooooo0ol0003ooooooa_ooooo00?o0000ooooooooool07oooool000kooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`3ooooooa[ooooo00?o0000ooooooooool08?ooool000kooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolIooooo`03o`000?oo
oooooooo027ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003oooooooooo`0Rooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo5ooo
ool00ol0003oooooooooo`0Sooooo`00:Oooool2o`000?oooooo5oooool00ol0003oooooooooo`0T
ooooo`00:Oooool00ol0003oooooooooo`3ooooooaGooooo00?o0000ooooooooool09Oooool002Wo
oooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`00
0?oooooooooo0?oooooo4oooool00ol0003oooooooooo`0Wooooo`00:Oooool00ol0003ooooooooo
o`3ooooooa;ooooo00?o0000ooooooooool0:?ooool002Wooooo0_l0003ooooooa;ooooo00?o0000
ooooooooool0:Oooool002Wooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
02[ooooo000Yooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0[ooooo`00
:Oooool00ol0003oooooooooo`3oooooo`kooooo00?o0000ooooooooool0;?ooool002Wooooo00?o
0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo02cooooo000Yooooo`;o0000ooooool>
ooooo`03o`000?oooooooooo02gooooo000Yooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0
003oooooooooo`0^ooooo`00:Oooool00ol0003oooooooooo`3oooooo`_ooooo00?o0000oooooooo
ool0;oooool002Wooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo02oooooo
000Yooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0`ooooo`00:Oooool2
o`000?oooooo2_ooool00ol0003oooooooooo`0aooooo`00:Oooool00ol0003oooooooooo`3ooooo
o`Sooooo00?o0000ooooooooool0<_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo0?oooooo1oooool00ol0003oooooooooo`0cooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`0cooooo`001?l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0ooooool6ooooo`03o`000?oooooooooo03Cooooo0006
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0003oooooo`Gooooo00?o0000ooooooooool0=Oooool000Kooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0fooooo`001_oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`0fooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool3ooooo`03o`000?oooooooooo03Oo
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`0hoooo
o`00:Oooool2o`000?oooooo0_ooool00ol0003oooooooooo`0iooooo`00:Oooool00ol0003ooooo
ooooo`3oooooo`7ooooo00?o0000ooooooooool0>Oooool002Wooooo00?o0000ooooooooool0oooo
ool00ol0003oooooooooo`0jooooo`00:Oooool00ol0003oooooooooo`3nooooo`03o`000?oooooo
oooo03_ooooo000Yooooo`03o`000?oooooooooo0?gooooo00?o0000ooooooooool0??ooool002Wo
oooo0_l0003mooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo0?cooooo
00?o0000ooooooooool0?Oooool002Wooooo00?o0000ooooooooool0>?ooool5o`0003_ooooo0_l0
00000ol@413oooooooooo`0gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0>Oooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0;oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h3ooooo`00:Oooool00ol0003oooooooooo`0hooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@0??ooool00ol0003oooooooooo`0hooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
>Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool0>Oooool00onHV9So8B4Qonk^kP0jooooo`Go0000>Oooool01Ol0003ooooooooooooooooo0000
03Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`;o0000>oooool0
0onHV9So8B4Qonk^kP0iooooo`04odA4A?oMgMgoooooo`0003[ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@0iooooo`07oc8b<_nHV9SooooooiRHV?lb<S;oooooo`00000fooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0koooo
o`03ogMgMomVIVKooooo03Sooooo00CogMgMoeEEEOoooooo0000>_ooool01Ol0003oEEEEo`000?l@
413oc<c<03Wooooo00Koc<c<o`000?l0003o0000olc<c?l0000gooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo03Sooooo00?oMgMgolc<c?l00000>_ooool00omEEEGoQhN7ooooo`0kooooo`06
oa0@4?nj^[[ooooookZj^_l@413o0000=oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool002Wooooo00?o0000ooooooooool0>?ooool01Ol0003o^[ZjoooooonH
V9So410@03[ooooo00?ok^k^odA4A?l00000>_ooool00ooMgMgo410@oiRHV00kooooo`05o`000?nj
^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool002Wooooo00?o0000ooooooooool0>?ooool01OnHV9So410@o`000?lQ8B7oc<c<03_o
oooo00?oMgMgo`000?ooool0>_ooool01?o<c<coA4A4o`000?l@410iooooo`05ojVYZOl@413o0000
o`000?nYZJT0=_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool002Wooooo0_l0003eooooo`03o`000?oooooooooo04Gooooo000Yooooo`03o`000?oooooooooo
0??ooooo00?o0000ooooooooool0A_ooool002Wooooo00?o0000ooooooooool0loooool00ol0003o
ooooooooo`16ooooo`00:Oooool00ol0003oooooooooo`3booooo`03o`000?oooooooooo04Oooooo
000Yooooo`03o`000?oooooooooo0?7ooooo00?o0000ooooooooool0B?ooool0027oooooool00018
o`000000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`06ooooo`00:Oooool2o`0003cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`00
0?oooooo00000>kooooo00?o0000ooooooooool0Boooool002Wooooo00Co0000oooooooooooo0000
k?ooool00ol0003oooooooooo`1<ooooo`00:Oooool2o`0000;ooooo00?o0000ooooooooool0j?oo
ool00ol0003oooooooooo`1=ooooo`00:Oooool01Ol0003ooooooooooooooooo00000>[ooooo00?o
0000ooooooooool0COooool002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3V
ooooo`03o`000?oooooooooo04kooooo000Yooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0i?ooool00ol0003oooooooooo`1?ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>;ooooo00?o0000ooooooooool0D?ooool002Wooooo0_l00006ooooo`03o`00
0?oooooooooo0>7ooooo00?o0000ooooooooool0D?ooool002Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3Oooooo`03o`000?oooooooooo057ooooo000Yooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0g_ooool00ol0003oooooooooo`1Booooo`00:Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0=cooooo00?o0000ooooooooool0Doooool002Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Kooooo`03o`000?oooooooooo05?o
oooo000Yooooo`;o00002_ooool00ol0003oooooooooo`3Iooooo`03o`000?oooooooooo05Cooooo
000Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0eoooool00ol0003ooooooooo
o`1Eooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Kooooo00?o0000
ooooooooool0E_ooool002Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Eoooo
o`03o`000?oooooooooo05Kooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0doooool00ol0003oooooooooo`1Gooooo`00:Oooool2o`0000kooooo00?o0000ooooooooool0
dOooool00ol0003oooooooooo`1Hooooo`00:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo0=3ooooo00?o0000ooooooooool0FOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`1Jooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0cOooool00ol0003oooooooooo`1Jooooo`001_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`1Kooooo`001_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o
00004Oooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo05cooooo0006ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<Sooooo00?o0000oooo
ooooool0GOooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0<Oooooo00?o0000ooooooooool0GOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`1Nooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0Gooo
ool002Wooooo0_l0000Eooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0H?ooool0
02Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`31ooooo`03o`000?oooooooooo
063ooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0_oooool00ol0003o
ooooooooo`1Qooooo`00:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0;gooooo
00?o0000ooooooooool0H_ooool002Wooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`2looooo`03o`000?oooooooooo06?ooooo000Yooooo`;o00006Oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo06Cooooo000Yooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0^?ooool00ol0003oooooooooo`1Uooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo0;Kooooo00?o0000ooooooooool0I_ooool002Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo06Oooooo000Yooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`1Wooooo`00:Oooool2
o`0001kooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`1Xooooo`00:Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0JOooool002Wo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo06[o
oooo000Yooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0[?ooool00ol0003ooooo
ooooo`1[ooooo`00:Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:[ooooo00?o
0000ooooooooool0K?ooool002Wooooo0_l0000Rooooo`03o`000?oooooooooo0:Sooooo00?o0000
ooooooooool0KOooool002Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Woooo
o`03o`000?oooooooooo06gooooo000Yooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0YOooool00ol0003oooooooooo`1^ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0Koooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`1`ooooo`003_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000oooo
ooooool0X?ooool00ol0003oooooooooo`1aooooo`003_ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool0L_ooool000kooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo09cooooo00?o0000ooooooooool0Loooool000kooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo07Cooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooooooo`1eooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o0000:oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo07Kooooo000Yoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`1goooo
o`00:Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09;ooooo00?o0000oooooooo
ool0N?ooool002Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo07Wooooo000Yooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0S_oo
ool00ol0003oooooooooo`1jooooo`00:Oooool2o`00033ooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`1kooooo`00:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool0O?ooool002Wooooo00?o0000ooooooooool0<Oooool2o`0008Wo
oooo00?o0000ooooooooool0OOooool002Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo07kooooo000Yooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`1oooooo`00:Oooool2o`0003Kooooo00?o0000
ooooooooool0POooool00ol0003oooooooooo`20ooooo`00:Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0POooool002Wooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo08;ooooo000Yooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`23ooooo`00:Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0Q?oo
ool002Wooooo0_l0000kooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0QOooool0
02Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1dooooo`;o0000R?ooool002Wo
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo08So
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo08Wooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo03kooooo0_l0001_ooooo`03o`000?oooooooooo08[ooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo
00?ooooo0ol00010ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Roooool000Ko
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo06Sooooo0_l0002>oooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooooooo08kooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo08oooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`14ooooo`;o0000Hoooool00ol0003oooooooooo`2@ooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`0004Oooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`2Aooooo`00:Oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0T_ooool002Wooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1Jooooo`;o0000UOooool002Wooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo09Gooooo000Yooooo`03o`00
0?oooooooooo04[ooooo0_l0001Fooooo`;o0000V?ooool002Wooooo0_l0001=ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0V?ooool002Wooooo00?o0000ooooooooool0COooool2
o`00053ooooo0_l0002Kooooo`00:Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool0Voooool002Wooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo09cooooo000Yooooo`03o`000?oooooooooo057ooooo
0_l00018ooooo`;o0000Woooool002Wooooo0_l0001Dooooo`?o0000A?ooool00ol0003ooooooooo
o`2Oooooo`00:Oooool00ol0003oooooooooo`1Fooooo`;o0000@?ooool2o`000:;ooooo000Yoooo
o`03o`000?oooooooooo05Sooooo0_l0000kooooo`?o0000Y?ooool002Wooooo00?o0000oooooooo
ool0F_ooool2o`0003Oooooo0_l0002Wooooo`00:Oooool00ol0003oooooooooo`1Looooo`;o0000
<oooool2o`000:Wooooo000Yooooo`;o0000Goooool2o`0002oooooo0_l0002[ooooo`00:Oooool0
0ol0003oooooooooo`1Pooooo`;o0000:oooool2o`000:gooooo000Yooooo`03o`000?oooooooooo
06;ooooo0ol0000Uooooo`?o0000[oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo06Gooooo0ol0000Oooooo`?o0000/_ooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Xooooo`Ko00004oooool6o`000;Gooooo000Qooooo`03o`000?oo
oooooooo00Gooooo0ol0001^oooooa?o0000^oooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIVo`00
003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .38349 L
.10458 .45956 L
.14415 .52149 L
.18221 .5687 L
.20178 .58733 L
.22272 .60257 L
.23293 .60817 L
.23832 .61063 L
.24402 .61285 L
.24901 .61447 L
.25449 .6159 L
.2569 .61642 L
.25949 .61689 L
.26194 .61726 L
.26416 .61754 L
.2667 .61778 L
.26809 .61788 L
.2694 .61795 L
.27062 .61799 L
.27174 .61802 L
.27297 .61803 L
.27427 .61803 L
.27558 .618 L
.27632 .61797 L
.27699 .61794 L
.27829 .61787 L
.27952 .61778 L
.28229 .61752 L
.2853 .61713 L
.29036 .61622 L
.29573 .61491 L
.30539 .61168 L
.31476 .60747 L
.32486 .60178 L
.34314 .58847 L
.36318 .56964 L
.38428 .54534 L
.42239 .49121 L
.46295 .42221 L
.50199 .34878 L
.54349 .26823 L
.58347 .19317 L
.62194 .12781 L
.66286 .06998 L
.68321 .0469 L
.70226 .02919 L
.72052 .01599 L
.73078 .01027 L
.74015 .00613 L
Mistroke
.74493 .00442 L
.75002 .00291 L
.75442 .00185 L
.75917 .00098 L
.76209 .00058 L
.76337 .00044 L
.76478 .0003 L
.76602 .00021 L
.76734 .00012 L
.76808 9e-05 L
.76875 6e-05 L
.77005 2e-05 L
.77131 0 L
.77248 0 L
.77376 2e-05 L
.77441 4e-05 L
.77512 7e-05 L
.77631 .00012 L
.77759 .0002 L
.77991 .0004 L
.78231 .00068 L
.78488 .00105 L
.7895 .00192 L
.795 .00329 L
.79999 .00486 L
.81085 .0093 L
.8211 .01478 L
.84115 .02902 L
.85962 .04609 L
.89907 .09412 L
.93701 .1528 L
.97619 .22267 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000>kooooo1_l00018ooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0>Wooooo1Ol00006ooooo`Go0000@oooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3Uooooo`Co00004?ooool3o`00043ooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool00ol0003oooooooooo`0Eooooo`?o0000
?Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Rooooo`;o00006ooo
ool00ol0003oooooooooo`0jooooo`007oooool00omEEEGoIVIVo`000007ooooo`;o0000h_ooool0
0ol0003oooooooooo`0Looooo`;o0000>_ooool002Wooooo00?o0000ooooooooool0goooool2o`00
027ooooo00?o0000ooooooooool0=oooool002Wooooo00?o0000ooooooooool0g_ooool00ol0003o
ooooooooo`0Rooooo`;o0000=oooool002Wooooo00?o0000ooooooooool0g?ooool2o`0002Oooooo
00?o0000ooooooooool0=?ooool002Wooooo00?o0000ooooooooool0foooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo03?ooooo000Yooooo`;o0000f_ooool2o`0002cooooo0_l0000c
ooooo`00:Oooool00ol0003oooooooooo`3Hooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0<?ooool002Wooooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02oooooo000Yooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0^ooooo`00:Oooool00ol0003oooooooooo`3Eooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0;Oooool002Wooooo0_l0003Eooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0;?ooool002Wooooo00?o0000ooooooooool0doooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02cooooo000Yooooo`03o`000?oooooooooo0=?o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0[ooooo`00:Oooool00ol0003ooooo
ooooo`3Booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0:_ooool002Wooooo00?o
0000ooooooooool0dOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02Wooooo000Y
ooooo`;o0000dOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Sooooo000Yoooo
o`03o`000?oooooooooo0<oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Xoooo
o`00:Oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool09oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`3=oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool09_ooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0cOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
02Gooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool3o`000<cooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0Tooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Sooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02?ooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`39ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool08Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0003:ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool08?ooool002Wooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo01oooooo000Yooooo`03o`000?oooooooooo0<Oooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Oooooo`00:Oooool00ol0003oooooooooo`36ooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool07_ooool002Wooooo00?o0000ooooooooool0
a_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01gooooo000Yooooo`;o0000a_oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01gooooo000Yooooo`03o`000?oooooo
oooo0<Cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Looooo`00:Oooool00ol0
003oooooooooo`34ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07?ooool002Wo
oooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01_o
oooo000Yooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0Jooooo`00:Oooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool06_ooool002Wooooo0_l00032ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool06Oooool002Wooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo01Sooooo000Yooooo`03o`000?oooooooooo0<3ooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0Hooooo`00:Oooool00ol0003oooooooooo`2oooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool05oooool002Wooooo00?o0000ooooooooool0__oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Kooooo000Yooooo`;o0000_oooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Eooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2mooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05Oooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0D
ooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
oooo01?ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`?o0000^oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01?ooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01;ooooo000>
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0;Wooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Booooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool04Oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`2hooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool04?ooool002Wooooo0_l0002iooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool04?ooool002Wooooo00?o0000ooooooooool0]oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo00oooooo000Yooooo`03o`000?oooooooooo0;Ko
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0?ooooo`00:Oooool00ol0003ooooo
ooooo`2fooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03_ooool002Wooooo00?o
0000ooooooooool0]Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00kooooo000Y
ooooo`;o0000]_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00gooooo000Yoooo
o`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0<oooo
o`00:Oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
ool03?ooool002Wooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo00_ooooo000Yooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0NOoo
ool00ol0003oooooooooo`0;ooooo`00:Oooool2o`000;?ooooo00?o0000ooooooooool0N_ooool0
0ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`1looooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo0;3ooooo
00?o0000ooooooooool0OOooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003ooooooooo
o`2`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool02?ooool002Wooooo0_l0002`
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool01oooool002Wooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00Oooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool01_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`2^ooooo`03o`000?oooooooooo08_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2]ooooo`03o`000?oooooooooo08cooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002/ooooo`03o`000?oo
oooooooo08gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo08gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Zoooool00ol0003ooooo
ooooo`2>ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Zoooool00ol0003o
ooooooooo`2>ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo
08oooooo000Yooooo`;o0000Zoooool00ol0003oooooooooo`2?ooooo`00:Oooool00ol0003ooooo
ooooo`2Yooooo`03o`000?oooooooooo093ooooo000Yooooo`03o`000?oooooooooo0:Wooooo00?o
0000ooooooooool0T?ooool002Wooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`2A
ooooo`00:Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo097ooooo000Yooooo`;o
0000Z?ooool00ol0003oooooooooo`2Booooo`00:Oooool00ol0003oooooooooo`2Wooooo`03o`00
0?oooooooooo09;ooooo000Yooooo`03o`000?oooooooooo03Sooooo1Ol0000kooooo`;o000000?o
410@ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
>Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03Kooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^0oooool002Wooooo00?o0000ooooooooool0>?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A403cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0;ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40>Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q03Sooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo03Wo
oooo00?oV9RHob4Q8Oo^k^h0>_ooool5o`0002[ooooo00?o0000ooooooooool03?ooool01Ol0003o
oooooooooooooooo000003Wooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`0003_ooooo00?oV9RH
ob4Q8Oo^k^h0>Oooool01?m4A4CogMgMooooool0000[ooooo`03o`000?oooooooooo00cooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0iooooo`05oc8b<_nHV9SooooooiRHV?lb<S80>?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000oooooooo
ool0>oooool00omgMgOoIVIVooooo`0hooooo`04omgMgOmEEEGoooooo`0002[ooooo00?o0000oooo
ooooool03Oooool01Ol0003oEEEEo`000?l@413oc<c<03Wooooo00Goc<c<o`000?l0003o0000olc<
c00hooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03Sooooo00?oMgMgolc<c?l00000:_oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOn7QhOooooo03_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400hooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00
:Oooool00ol0003oooooooooo`0hooooo`05o`000?nj^[[ooooooiRHV?l@4100>_ooool00oo^k^ko
A4A4o`00000Yooooo`03o`000?oooooooooo00kooooo00?ogMgMoa0@4?nHV9P0>oooool01Ol0003o
^[Zjoooooonj^[[o000003Sooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo000Yooooo`03o`000?oooooooooo03Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00k
ooooo`03ogMgMol0003ooooo02Sooooo00?o0000ooooooooool03oooool01?o<c<coA4A4o`000?l@
410iooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=_ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool002Wooooo0_l0002Sooooo`03o`000?oooooooooo09Oooooo
000Yooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0Uoooool002Wooooo00?o0000
ooooooooool0XOooool00ol0003oooooooooo`2Hooooo`00:Oooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo09Sooooo000Yooooo`03o`000?oooooooooo0:3ooooo00?o0000oooooooo
ool0VOooool0027oooooool00018o`000000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`00:Oooool2
o`0003cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Kooooo000Yooooo`;o0000Woooool00ol0003oooooooooo`2Kooooo`00:Oooool00ol0003o
ooooo`00002Nooooo`03o`000?oooooooooo09_ooooo000Yooooo`?o0000WOooool00ol0003ooooo
ooooo`2Looooo`00:Oooool01?l0003oooooooooool0002Looooo`03o`000?oooooooooo09cooooo
000Yooooo`05o`000?ooooooooooooooool00000V_ooool00ol0003oooooooooo`2Mooooo`00:Ooo
ool01Ol0003ooooooooooooooooo000009[ooooo00?o0000ooooooooool0WOooool002Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo09kooooo000Y
ooooo`;o00000oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo09kooooo000Yoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`2Ooooo
o`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Cooooo00?o0000oooooooo
ool0Woooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Booooo`03o`00
0?oooooooooo0:3ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T_oo
ool00ol0003oooooooooo`2Pooooo`00:Oooool2o`0000Kooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`2Qooooo`00:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
093ooooo00?o0000ooooooooool0XOooool002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2>ooooo`03o`000?oooooooooo0:;ooooo000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0S_ooool00ol0003oooooooooo`2Rooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Xoooool002Wooooo0_l00009
ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0Y?ooool002Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo0:Cooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool0YOooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0YOooool000Kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0Y_oo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01?ooool3o`0000[ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`2Vooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo0:Oooooo0006ooooo`05oa0@4?ooooooooooooooool@4100
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo0:Oooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0Z?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo0:Sooooo000Yooooo`;o00003_ooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo0:Wooooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`2Yooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool0Z_ooool002Wooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1mooooo`03o`000?oooooooooo0:_ooooo000Yooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`2[ooooo`00:Oooool2o`00013o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`2/ooooo`00:Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0[?ooool002Wooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0:gooooo000Y
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`2]
ooooo`00:Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07Kooooo00?o0000oooo
ooooool0[_ooool002Wooooo0_l0000Cooooo`03o`000?oooooooooo07Kooooo00?o0000oooooooo
ool0[_ooool002Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo0:oooooo000Yooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`2`ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0/?ooool002Wooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo0;7ooooo000Yooooo`;o00005_ooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo0;7ooooo000Yooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`2booooo`00:Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0/oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo0;?ooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
]?ooool000kooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo
0ol0000Gooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0]?ooool000kooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo0;Gooooo000>ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo0;Kooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2fooooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0]oooool000kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00001_ooool2o`0001cooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`2gooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0^?ooool002Wooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo0;Wooooo000Yooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`2iooooo`00:Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool0^_ooool002Wooooo0_l0000Oooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0^_ooool002Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo0;_ooooo000Yooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`2looooo`00:Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0_Oooool0
02Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
0;gooooo000Yooooo`;o00008_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo0;ko
oooo000Yooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`2oooooo`00:Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0_oooool002Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo0<3ooooo000Yooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`31ooooo`00:Oooool2o`0002Gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`32ooooo`00:Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0`_ooool002Wooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0<?ooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo0<Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`34ooooo`001_ooool01Ol@413ooooooooo
oooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000
:Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0<Gooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0<Kooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0aoooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03
ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0aoooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`38oooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`00
02kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`39ooooo`00:Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0b_ooool002Wooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0<_ooooo
000Yooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`3<ooooo`00:Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0cOooool002Wooooo0_l0000cooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0c_ooool002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo0<oooooo000Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`3@ooooo`00:Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0dOooool002Wooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0=;ooooo000Yooooo`;o0000>?ooool2o`00
02gooooo00?o0000ooooooooool0doooool002Wooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0Xooooo`;o0000e_ooool002Wooooo00?o0000ooooooooool0>_ooool2o`0002Oooooo
00?o0000ooooooooool0e_ooool002Wooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Rooooo`;o0000fOooool002Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo0=Wooooo000Yooooo`;o0000?oooool2o`0001kooooo0_l0003Loooo
o`00:Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0g?ooool002Wooooo00?o0000ooooooooool0@Oooool2o`0001Sooooo0_l0003Oooooo`007ooo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0@oooool2o`0001;ooooo1?l0
003Qooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo0ol0000=
ooooo`;o0000iOooool0027ooooo00?o0000ooooooooool01Oooool3o`0004Sooooo3Ol0003Woooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .40755 L
.10458 .50296 L
.12507 .54129 L
.14415 .57085 L
.16254 .59298 L
.17284 .60245 L
.18221 .60916 L
.18704 .6119 L
.19216 .61425 L
.19654 .61582 L
.19901 .61652 L
.20135 .61706 L
.20265 .61731 L
.20405 .61754 L
.20535 .61771 L
.20652 .61783 L
.20719 .61789 L
.20792 .61794 L
.20869 .61798 L
.20941 .61801 L
.21009 .61803 L
.2108 .61803 L
.21209 .61802 L
.21328 .61797 L
.21456 .61788 L
.21577 .61777 L
.21688 .61763 L
.21958 .6172 L
.22214 .61664 L
.22673 .61528 L
.23179 .61325 L
.24205 .60746 L
.25155 .60012 L
.26047 .59154 L
.28065 .56636 L
.29915 .53678 L
.33878 .45604 L
.37689 .36304 L
.41745 .25827 L
.45649 .16278 L
.47641 .1195 L
.49799 .07859 L
.51703 .04874 L
.52785 .0347 L
.53797 .02361 L
.54836 .01437 L
.55785 .00789 L
.56305 .00515 L
.56799 .00308 L
Mistroke
.57321 .00147 L
.57616 .00082 L
.57749 .00058 L
.57889 .00038 L
.58016 .00024 L
.58083 .00017 L
.58155 .00012 L
.58281 4e-05 L
.58398 1e-05 L
.58469 0 L
.58546 0 L
.58619 2e-05 L
.58686 5e-05 L
.58814 .00012 L
.58878 .00017 L
.58949 .00024 L
.59196 .00056 L
.59336 .0008 L
.59463 .00105 L
.59945 .00234 L
.60379 .00392 L
.60853 .00611 L
.61807 .01199 L
.62838 .02046 L
.63772 .03003 L
.65869 .05762 L
.69872 .131 L
.73724 .22054 L
.77821 .32563 L
.81767 .42513 L
.85561 .50901 L
.87673 .54745 L
.896 .57601 L
.90555 .58763 L
.91595 .59823 L
.92571 .60617 L
.93487 .61181 L
.93939 .61393 L
.94426 .61573 L
.94689 .61649 L
.94966 .61712 L
.95203 .61753 L
.95337 .61771 L
.95462 .61784 L
.95593 .61794 L
.95667 .61798 L
.95736 .61801 L
.95861 .61803 L
.95924 .61803 L
.95994 .61802 L
Mistroke
.96114 .61797 L
.96244 .61789 L
.96366 .61778 L
.96477 .61765 L
.96743 .61722 L
.97034 .61659 L
.97562 .61496 L
.97619 .61475 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`000;;ooooo1?l00026ooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0:gooooo1Ol00004ooooo`Co0000P_ooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00_ooooo0ol0001oooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo0_l0000Aooooo`03o`00
0?oooooooooo07cooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ZOoo
ool00ol0003oooooooooo`0Booooo`;o0000O?ooool001oooooo00?oEEEEofIVI_l000001oooool2
o`000:Sooooo0_l0000Gooooo`03o`000?oooooooooo07Wooooo000Yooooo`03o`000?oooooooooo
0:Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1hooooo`00:Oooool00ol0003o
ooooooooo`2Uooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Moooool002Wooooo
00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Kooooo
000Yooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`1eooooo`00:Oooool2o`000:Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1d
ooooo`00:Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0M?ooool002Wooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo07?ooooo000Yooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1booooo`00:Oooool00ol0003oooooooooo`2Oooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0LOooool002Wooooo0_l0002Oooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0L?ooool002Wooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo000Yooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1_ooooo`00:Oooool00ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0K_ooool002Wooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06gooooo000Y
ooooo`;o0000W?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06gooooo000Yoooo
o`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1/oooo
o`00:Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0K?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Joooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
06_ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool3o`0009Sooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`1Zooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo09Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`1Yooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06Wooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo06Sooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0J?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0002Fooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0Ioooool002Wooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo06Oooooo000Yooooo`03o`000?oooooooooo09Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`1Vooooo`00:Oooool00ol0003oooooooooo`2Cooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0I_ooool002Wooooo00?o0000ooooooooool0
Toooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo06Gooooo000Yooooo`;o0000Tooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo06Gooooo000Yooooo`03o`000?oooooo
oooo09;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Tooooo`00:Oooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0I?ooool002Wo
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo06?o
oooo000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`1Rooooo`00:Oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0H_ooool002Wooooo0_l0002@ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0HOooool002Wooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo067ooooo000Yooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1Pooooo`00:Oooool00ol0003oooooooooo`2>ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0H?ooool002Wooooo00?o0000ooooooooool0S_oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo05oooooo000Yooooo`;o0000S_ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo05oooooo000Yooooo`03o`000?oooooooooo
08gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Oooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`2<ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0G_ooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1N
ooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo05gooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`?o0000Roooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05gooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo05cooooo000>
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Looooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2:ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0G?ooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0Foooool002Wooooo0_l0002:ooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool0Foooool002Wooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo05[ooooo000Yooooo`03o`000?oooooooooo08So
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Jooooo`00:Oooool00ol0003ooooo
ooooo`28ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0F_ooool002Wooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Wooooo000Y
ooooo`;o0000R?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Wooooo000Yoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`1Hoooo
o`00:Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool0F?ooool002Wooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo05Sooooo000Yooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`1Gooooo`00:Oooool2o`0008Kooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`1Gooooo`00:Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0E_ooool002Wooooo00?o0000ooooooooool0Q?ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo05Kooooo000Yooooo`03o`000?oooooooooo08?ooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Eooooo`00:Oooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0EOooool002Wooooo0_l00024
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0EOooool002Wooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05Cooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooooooool0E?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Doooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Cooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000POooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo05?ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Booooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool0DOooool002Wooooo0_l0001oooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool0DOooool002Wooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo053ooooo000Yooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`1@ooooo`00:Oooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0D?ooool002Wooooo00?o0000oooo
ooooool0OOooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04oooooo000Yooooo`;o
0000OOooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo04oooooo000Yooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1>ooooo`00:Ooo
ool00ol0003oooooooooo`0hooooo`Go0000>oooool2o`000003oa0@4?oooooo000003Oooooo00Go
k^k^oc8b<_l0003o410@olc<c00booooo`03o`000?oooooooooo00Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c00fooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000Y
ooooo`03o`000?oooooooooo03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`03o`000?oo
oooo000003Sooooo00GoEEEEogMgMoooooooV9RHob4Q8@0booooo`03o`000?oooooooooo00Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@0hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0iooooo`03oiRHV?lQ8B7ok^k^03[o
oooo1_l0000hooooo`05o`000?ooooooooooooooool00000<oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41000oooool002Wooooo0_l0000kooooo`03oiRHV?lQ8B7ok^k^03Wooooo00KoA4A4
omgMgOoooooo0000ooooool0000hooooo`05o`000?nHV9SooooooiRHV?lQ8B40<oooool00ol0003o
ooooooooo`03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80>?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000ooooooooool0>oooool00omg
MgOoIVIVooooo`0hooooo`03omgMgOmEEEGooooo00;o0000>Oooool01Ol0003oEEEEo`000?l@413o
c<c<03?ooooo00?o0000ooooooooool00oooool01Oo<c<co0000o`000?l0003oc<c<03Sooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0>?ooool01?mgMgOoc<c<o`000?l0000iooooo`03oeEE
EOn7QhOooooo03Kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@03So
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03
o`000?oooooooooo03Sooooo00Go0000okZj^_ooooooV9RHoa0@400jooooo`03onk^k_m4A4Co0000
03[ooooo00?ogMgMoa0@4?nHV9P0=_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooo
okZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool002Wooooo00?o0000ooooooooool0>?ooool01OnHV9So410@o`000?lQ8B7oc<c<03_ooooo00?o
MgMgo`000?ooool0>_ooool01?o<c<coA4A4o`000?l@410eooooo`09o`000?oooooooooooooooonY
ZJWo410@o`000?l@413oZJVY03Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`;o0000N_ooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo04_ooooo000Yooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`1;ooooo`00:Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0B_ooool002Wooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo04[ooooo000Yooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`19ooooo`008Oooooooo`0004So0000000Yoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Kooooo000Yooooo`;o0000??ooool00ol0003oooooooooo`0hoooo
o`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooo
oooo000003gooooo00?o0000ooooooooool01_ooool002Wooooo0_l0001gooooo`03o`000?oooooo
oooo07Sooooo00?o0000ooooooooool0B?ooool002Wooooo0_l0001fooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooooooool0B?ooool002Wooooo0ol0001eooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0Aoooool002Wooooo00?o0000ooooool00000M?ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo04Oooooo000Yooooo`04o`000?ooooooooooo`0007?ooooo
00?o0000ooooooooool0O?ooool00ol0003oooooooooo`16ooooo`00:Oooool01?l0003ooooooooo
ool0001cooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0A_ooool002Wooooo00Co
0000oooooooooooo0000L_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo04Kooooo
000Yooooo`;o00000_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool0AOooool002Wooooo00Go0000ooooooooooooooooo`00001`ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0AOooool002Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0A?ooool0
02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0A?ooool002Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0A?ooool002Wooooo
0_l00004ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`13ooooo`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`13ooooo`00:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`12
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`12ooooo`00:Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`12ooooo`00
:Oooool2o`0000Kooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo047ooooo000Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo047ooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`10ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo043ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0@?ooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool01?ooool3o`0000Oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo03oooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0ooooo
o`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo03oooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`0nooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0nooooo`00:Oooool2
o`0000[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2>ooooo`03o`000?oooooo
oooo03gooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0G_ooool00ol0
003oooooooooo`2?ooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03go
oooo000Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`2Aooooo`03o`000?oooooooooo03cooooo000Yooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03cooooo000Y
ooooo`;o00003?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo09;ooooo00?o0000
ooooooooool0>oooool002Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo09?ooooo00?o0000ooooooooool0>oooool002Wooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo09?ooooo00?o0000oooooooo
ool0>oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo09Gooooo00?o0000ooooooooool0>_ooool002Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool0>_oo
ool002Wooooo0_l0000>ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0U_ooool0
0ol0003oooooooooo`0iooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0iooooo`00:Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`0hooooo`00:Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`0hooooo`00:Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0V_ooool00ol0003ooooooooo
o`0gooooo`00:Oooool2o`00013ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`2K
ooooo`03o`000?oooooooooo03Oooooo000Yooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo03Kooooo000Yooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo03Kooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo03Gooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0W_ooool00ol0
003oooooooooo`0eooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool3o`00017ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo03Cooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`2Pooooo`03o`000?oooooooooo03Cooooo000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0<oooool0
00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0:;ooooo00?o0000
ooooooooool0<oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo0:?ooooo00?o0000ooooooooool0<oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001_ooool2o`0001Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2T
ooooo`03o`000?oooooooooo03;ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo03;ooooo000Yooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2Vooooo`03
o`000?oooooooooo037ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo037ooooo000Yooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Xooooo`03o`000?oo
oooooooo033ooooo000Yooooo`;o00005oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo0:Sooooo00?o0000ooooooooool0<?ooool002Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0;oooool002Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0:[o
oooo00?o0000ooooooooool0;oooool002Wooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0;_ooool002Wooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0:cooooo00?o
0000ooooooooool0;_ooool002Wooooo0_l0000Iooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool0[_ooool00ol0003oooooooooo`0]ooooo`00:Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`0]oooo
o`00:Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0/?ooool00ol0003oooooooooo`0/ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0/ooooo`00:Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0/Ooo
ool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001cooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo02_ooooo000Yooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo
02[ooooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo02[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
0;Gooooo00?o0000ooooooooool0:Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0;Kooooo00?o0000oooo
ooooool0:Oooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo
00Sooooo00?o0000ooooooooool00oooool3o`0001kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2gooooo`03o`000?oooooooooo02Sooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0;Sooooo00?o0000oooo
ooooool0:?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo02Oooooo0006oooo
o`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool09oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2looooo`03o`000?oo
oooooooo02Kooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o00008_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0;kooooo00?o
0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool09Oooool002Wooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0<3ooooo00?o0000oooo
ooooool09?ooool002Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo0<;ooooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0
8_ooool002Wooooo0_l0000Uooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0a?oo
ool00ol0003oooooooooo`0Rooooo`00:Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Qooooo`00:Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0b?ooool00ol0
003oooooooooo`0Pooooo`00:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`0Oooooo`00:Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Nooooo`00:Oooool2o`0002Wooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`3=ooooo`03o`000?oooooooooo01gooooo000Yooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo01gooooo000Yoooo
o`03o`000?oooooooooo02[ooooo0_l0000Mooooo`;o0000d_ooool00ol0003oooooooooo`0Loooo
o`00:Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0doooool00ol0003oooooooooo`0Kooooo`00:Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0eOooool2o`0001_ooooo000Yooooo`;o0000;ooo
ool2o`0001Kooooo00?o0000ooooooooool0f?ooool00ol0003oooooooooo`0Hooooo`00:Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0f_ooool2
o`0001Sooooo000Yooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool2o`00
0=oooooo00?o0000ooooooooool05Oooool001oooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo03;ooooo0_l0000>ooooo`03o`000?oooooooooo0>3ooooo0_l0000Eooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2?ooool3o`000>Gooooo00?o0000ooooooooool02?ooool2o`0000Sooooo000Qooooo`03o`000?oo
oooooooo00Gooooo0ol0000eooooo`[o0000jOooool:o`0000[ooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?o
EEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .43097 L
.08255 .48776 L
.10458 .54079 L
.11448 .56074 L
.12507 .57907 L
.13499 .59323 L
.14415 .60357 L
.14901 .60795 L
.15437 .61188 L
.15975 .61486 L
.1627 .61608 L
.16546 .61696 L
.1667 .61727 L
.16805 .61755 L
.16934 .61775 L
.17052 .61789 L
.1717 .61798 L
.17277 .61803 L
.174 .61803 L
.17516 .61798 L
.17643 .61788 L
.17707 .61781 L
.17777 .61771 L
.18017 .61725 L
.18153 .61691 L
.18298 .61648 L
.1856 .61551 L
.19088 .61285 L
.19577 .60956 L
.20684 .59919 L
.21659 .58681 L
.22696 .57046 L
.26471 .48659 L
.30491 .36738 L
.3436 .24273 L
.38474 .12245 L
.40527 .07409 L
.41527 .05433 L
.42436 .03881 L
.4332 .02607 L
.44279 .01502 L
.44806 .01021 L
.45291 .00658 L
.45756 .00385 L
.46247 .00175 L
.465 .00099 L
.46625 .00069 L
.4674 .00046 L
.46853 .00028 L
Mistroke
.46956 .00016 L
.4707 6e-05 L
.47191 1e-05 L
.47322 1e-05 L
.47442 6e-05 L
.47574 .00017 L
.4764 .00025 L
.47713 .00035 L
.47836 .00056 L
.47968 .00085 L
.48205 .00152 L
.48441 .00237 L
.48697 .00351 L
.49163 .00614 L
.50036 .01303 L
.50978 .02324 L
.52017 .03774 L
.54119 .07673 L
.58145 .18077 L
.62019 .30246 L
.66138 .43257 L
.68195 .49039 L
.70106 .53661 L
.71952 .57262 L
.72977 .58842 L
.73922 .60012 L
.74949 .60959 L
.75489 .61317 L
.75765 .61462 L
.7606 .6159 L
.7632 .61677 L
.76557 .61737 L
.76671 .61759 L
.76795 .61778 L
.76913 .61791 L
.77021 .61799 L
.77147 .61803 L
.77264 .61802 L
.77393 .61796 L
.77466 .6179 L
.77533 .61782 L
.77659 .61764 L
.77798 .61739 L
.78077 .61667 L
.7833 .61579 L
.78604 .61459 L
.79103 .61176 L
.80035 .60426 L
.81125 .59192 L
.8213 .57724 L
Mistroke
.84004 .54207 L
.86067 .49301 L
.90097 .37481 L
.93977 .24982 L
.97619 .14091 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`0008gooooo1?l0002[ooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo08_ooooo0ol00003ooooo`Co0000Yoooool0027ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`29ooooo`;o00002_ooool00ol0003oooooooooo`2Tooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2Sooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo08Kooooo0_l0000?ooooo`03o`000?oooooooooo0:;ooooo000Oooooo`03oeEEEOmVIVKo
000000Oooooo0_l00026ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0XOooool0
02Wooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
0:3ooooo000Yooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`2Oooooo`00:Oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0W_ooool002Wooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo09kooooo000Yooooo`;o0000Poooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo09gooooo000Yooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`2Looooo`00:Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0W?ooool002Wooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo09_ooooo000Yooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Kooooo`00:Oooool2
o`0007oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Jooooo`00:Oooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0V_ooool002Wo
oooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo09Wo
oooo000Yooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`2Hooooo`00:Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0V?ooool002Wooooo0_l0001looooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0Uoooool002Wooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo09Oooooo000Yooooo`03o`000?oooooooooo07[ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`2Fooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2Eoooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0UOooool000Co00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000NOooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo09Cooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0N?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Cooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Toooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1gooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0Toooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`0007Sooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`2Booooo`00:Oooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0T_ooool002Wooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09;ooooo000Yooooo`03
o`000?oooooooooo07Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Aooooo`00
:Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
TOooool002Wooooo0_l0001eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0T?oo
ool002Wooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo093ooooo000Yooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`2@ooooo`00:Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0Soooool002Wooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo08oooooo000Yooooo`03o`000?oooooooooo07;ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`2>ooooo`00:Oooool2o`0007?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`2>ooooo`00:Oooool00ol0003oooooooooo`1aoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0S_ooool002Wooooo00?o0000oooooooo
ool0LOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08gooooo000Yooooo`03o`00
0?oooooooooo077ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2=ooooo`00:Ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0SOoo
ool002Wooooo0_l0001aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Poooool0
0ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`06ooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0POooool0
0ol0003oooooooooo`07ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool000Kooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo00Oooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04
ooooo`?o0000K_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool02?ooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`08ooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`08ooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`09ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo00Wooooo000Yooooo`;o0000K_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool02_ooool002Wo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool0K?ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02_ooool002Wooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool02oooool002Wooooo0_l0001/ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0NOooool00ol0003oooooooooo`0;ooooo`00:Oooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0;oooo
o`00:Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`0<ooooo`00:Oooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0<ooooo`00:Ooo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0M_oo
ool00ol0003oooooooooo`0<ooooo`00:Oooool2o`0006[ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo00gooooo000Yooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo
00gooooo000Yooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00gooooo000Yooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00kooooo
000Yooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00kooooo000Yooooo`;o0000JOooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool03oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00oooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool03oooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo013ooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0001Vooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0@ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool04?ooool000Kooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`0Aooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool04Oooool000Kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool04Oooool002Wooooo0_l0001Vooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Joooool00ol0003ooooo
ooooo`0Booooo`00:Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0B
ooooo`00:Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`0Cooooo`00:Oooool2o`0006Cooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo01?ooooo000Yooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Xooooo`03o`00
0?oooooooooo01?ooooo000Yooooo`03o`000?oooooooooo03Sooooo1Ol0000Uooooo`03o`000?oo
oooooooo01?ooooo0_l000000ol@413oooooooooo`0gooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
0_ooool00ol0003oooooooooo`0dooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0;_ooool00ol0003o
ooooooooo`05ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo000Y
ooooo`03o`000?oooooooooo03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Uooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0>?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo
00?o0000ooooooooool0<oooool01OlQ8B7oV9RHoooooonHV9So8B4Q02kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool0>Oooool00onHV9So8B4Qonk^kP0Vooooo`03o`000?oooooooooo017o
oooo1Ol0000iooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0coooo
o`05o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`0003_ooooo00?oV9RH
ob4Q8Oo^k^h09?ooool00ol0003oooooooooo`0Booooo`04odA4A?oMgMgoooooo`0003[ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@03ooooo`03o`000?oooooooooo03?ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo03_ooooo00?oMgMgofIVI_oo
ool08oooool00ol0003oooooooooo`0Booooo`04omgMgOmEEEGoooooo`0003[ooooo00Go0000oeEE
EOl0003o410@olc<c004ooooo`03o`000?oooooooooo03;ooooo00Goc<c<o`000?l0003o0000olc<
c00]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo000Yooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Cooooo`03ogMgMoo<c<co000003[ooooo00?oEEEEohN7Qoooool01_oo
ool00ol0003oooooooooo`0booooo`05oa0@4?nj^[[ooooookZj^_l@4100;Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00
:Oooool00ol0003oooooooooo`0hooooo`05o`000?nj^[[ooooooiRHV?l@41008oooool00ol0003o
ooooooooo`0Dooooo`03onk^k_m4A4Co000003[ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003o
ooooooooo`0booooo`05o`000?nj^[[ooooookZj^_l00000;?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0
003oooooooooo`0hooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08oooool00ol0003oooooooooo`0E
ooooo`03ogMgMol0003ooooo03[ooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003ooooooooo
o`0aooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;?ooool00ol0003oooooooooo`07ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00:Oooool2o`00067ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Kooooo
000Yooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Oooooo000Yoooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Sooooo000Qoooooooo0000
B?l0000002Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooool000003oooool00ol0003oooooooooo`06ooooo`00:Oooool2o`0003cooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`00:Oooool2o`0005kooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Wooooo000Yoooo
o`;o0000G_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool06Oooool002Wooooo0ol0001Mooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003oooooo`00001Looooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`00:Ooo
ool00ol0003oooooo`00001Looooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Jooooo`00:Oooool01?l0003oooooooooool0001Kooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Kooooo`00:Oooool0
1?l0003oooooooooool0001Jooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`0Kooooo`00:Oooool2o`000003ooooool0003ooooo05Wooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01_ooooo000Yoooo
o`05o`000?ooooooooooooooool00000FOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool07?ooool002Wooooo00Go0000ooooooooooooooooo`00001H
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0L
ooooo`00:Oooool01Ol0003ooooooooooooooooo000005Sooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01cooooo000Yooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool07Oooool002Wooooo0_l00003ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01go
oooo000Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07Oooool002Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Nooooo`00:Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool07_ooool002Wooooo0_l00005ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01oooooo000Yooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1/ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool07oooool000Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool07oooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0KOooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo023ooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Pooooo`001_ooool01Ol0003o
oooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04oooo
o`?o00001Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`0Pooooo`001_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Qooooo`001_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool08Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool08Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0Rooooo`00:Oooool2o`0000Sooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool08_oo
ool002Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo07;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Rooooo`00:Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo02?ooooo000Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`0Sooooo`00:Oooool2o`0000[ooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool09?ooool002Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Tooooo`00:Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo02Cooooo000Yooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool09Oooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Uooooo`00:Ooo
ool2o`0000_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1hooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04;ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
02Kooooo000Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool09_ooool002Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`0000gooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool09oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0W
ooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Sooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:?ooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0:?ooool000kooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo0ol0000=ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Wooooo000>oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`20ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0:Oooool000kooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo02Wooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0:_ooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Zooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`;o00004?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Zooooo`00:Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02_ooooo000Yooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0:oooool002Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0[ooooo`00
:Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02cooooo000Yooooo`;o00004_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0/ooooo`00:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02cooooo000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`28ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Oooool002Wo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo08So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`00:Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02kooooo000Yooooo`;o00005?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0^ooooo`00:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0Roooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo000Yoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;oooool002Wooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0_ooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo033ooooo000Yooooo`;o00005_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo08kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`00:Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000Yooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0<Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo0006ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2B
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool000Kooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3
o`0001Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03?ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0U?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03?ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0dooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0dooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co00001_ooool2o`0001_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=Oooool002Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo09Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0eooooo`00:Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03Kooooo000Yooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0=oooool002Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo09_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0gooooo`00
:Oooool2o`0001gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2Looooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0>?ooool002Wooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0hooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03Wooooo000Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`2Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>Oooool002Wo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:7o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0jooooo`00:Oooool2o`00023ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0>oooool002Wooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0kooooo`00:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Y_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03cooooo000Yoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Xoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0??ooool002Wooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0mooooo`00:Oooool2o`0002Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
?_ooool002Wooooo00?o0000ooooooooool09?ooool2o`00017ooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`0?ooooo`;o0000@Oooool002Wooooo00?o0000ooooooooool09_ooool2
o`0000kooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo047ooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Wooooo0_l0002cooooo`;o00002oooool2o`0004Cooooo000Qooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`;o
0000]oooool2o`0000Sooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000ooooooooool0
1Oooool3o`0002[ooooo2?l0002kooooo`So0000Aoooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`007oooool00omEEEGoIVIV
o`00003oooooodOooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .45358 L
.08255 .51742 L
.0932 .54606 L
.10458 .57196 L
.11531 .59144 L
.12507 .60469 L
.12977 .60949 L
.13225 .6116 L
.13488 .61351 L
.13717 .6149 L
.1397 .61615 L
.142 .61701 L
.14313 .61733 L
.14415 .61758 L
.1454 .6178 L
.14608 .61789 L
.14673 .61796 L
.14787 .61803 L
.14911 .61802 L
.14977 .61799 L
.15049 .61793 L
.15124 .61785 L
.15194 .61774 L
.15319 .61749 L
.15453 .61713 L
.15718 .61618 L
.15969 .61495 L
.1644 .61184 L
.16901 .60775 L
.17327 .60307 L
.18292 .58938 L
.19255 .5716 L
.20159 .55138 L
.22219 .49406 L
.26088 .35658 L
.30202 .19905 L
.32254 .12885 L
.34164 .07421 L
.36007 .03429 L
.37038 .01827 L
.37484 .01285 L
.37975 .00797 L
.3846 .00427 L
.38725 .00273 L
.38973 .0016 L
.39092 .00116 L
.39205 .00081 L
.39308 .00055 L
.39417 .00033 L
Mistroke
.39535 .00015 L
.39645 5e-05 L
.39775 0 L
.39893 3e-05 L
.40024 .00015 L
.4009 .00023 L
.40162 .00036 L
.4029 .00063 L
.40409 .00097 L
.40677 .00197 L
.40965 .00343 L
.41493 .00716 L
.41973 .01171 L
.42967 .02457 L
.43886 .04041 L
.45963 .0891 L
.49895 .21875 L
.53675 .3643 L
.55776 .44194 L
.57701 .50502 L
.59589 .55581 L
.6055 .57646 L
.61575 .59417 L
.62108 .60153 L
.62612 .60725 L
.63063 .61137 L
.63297 .61312 L
.63553 .61473 L
.63777 .61588 L
.64018 .61685 L
.64151 .61726 L
.64272 .61755 L
.64394 .61778 L
.6451 .61793 L
.64616 .61801 L
.64729 .61803 L
.64825 .618 L
.64931 .61792 L
.65045 .61777 L
.65168 .61753 L
.65284 .61724 L
.65391 .61691 L
.65638 .61594 L
.65864 .6148 L
.66369 .61134 L
.66838 .60704 L
.67281 .60202 L
.68273 .58748 L
.6935 .5668 L
.71335 .5166 L
Mistroke
.73438 .44939 L
.77224 .30733 L
.81255 .15727 L
.8311 .09904 L
.85134 .04864 L
.86231 .02819 L
.86765 .02016 L
.87249 .014 L
.87716 .0091 L
.88222 .00497 L
.885 .00322 L
.88756 .00195 L
.89 .00103 L
.89123 .00067 L
.89258 .00037 L
.89389 .00016 L
.8951 5e-05 L
.89573 1e-05 L
.89642 0 L
.89715 1e-05 L
.89783 5e-05 L
.89908 .00017 L
.90022 .00034 L
.90148 .00061 L
.9028 .00098 L
.9051 .00182 L
.90725 .00284 L
.91211 .00598 L
.91741 .01069 L
.92222 .01612 L
.93303 .0322 L
.94302 .05164 L
.95223 .07316 L
.97303 .13296 L
.97619 .14321 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`0007Gooooo1?l0002Oooooo`?o00008Oooool0027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1cooooo`?o00000_ooool4o`0009Wooooo0ol00002oooo
o`Co00007_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`08ooooo`;o0000UOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Iooooo`007oooool00omEEEGoIVIVo`000007ooooo`;o0000L?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Iooooo`00:Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Sooooo000Yooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool002Wooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`00:Oooool00ol0003ooooooooo
o`1/ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0R_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Kooooo000Yooooo`;o0000K?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0E
ooooo`00:Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo000Yooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool002Wooooo00?o0000ooooooooool0
JOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Cooooo`00:Oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01?ooooo000Yooooo`;o0000JOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool04Oooool002Wooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Aooooo`00:Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0P?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo000Y
ooooo`;o0000Ioooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`00:Oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00oooooo000Yooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool03oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003o
k^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool03_ooool000Co00000_ooool01Ol@413ooooooooooooooooo410@
00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o0000I?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0>ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool03Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool03Oooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00cooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l0
0006ooooo`;o0000Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`00:Oooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00cooooo000Yooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool02oooool002Wooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo07Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`00
:Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo000Yooooo`;o0000HOoo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00[ooooo000Yooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool002Wo
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool02Oooool002Wooooo0_l0001Oooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Yoooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool002Wooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06oooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`08ooooo`00:Oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00Oooooo000Yooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01ooo
ool002Wooooo0_l0001Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0>_ooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo03[ooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0kooooo`003_ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0005cooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo03_ooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0>oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo06Wooooo00?o0000ooooooooool0>oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0??ooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0looooo`00:Oooool2
o`0005_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo03cooooo000Yooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03go
oooo000Yooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo03gooooo000Y
ooooo`;o0000F_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0?_ooool002Wooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0?_ooool002Wooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0?_ooool002Wooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0?oooool002Wooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0?ooo
ool002Wooooo0_l0001Iooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0oooooo`00:Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0oooooo`00:Oooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`10ooooo`00:Oooool00ol0003ooooooooo
o`1Gooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`10ooooo`00:Oooool2o`0005Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo047ooooo000Yooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo047ooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`11ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo047ooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`12ooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`?o0000EOooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0@_ooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo04;ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0@oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo04?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
04?ooooo000Yooooo`;o0000EOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool0@oooool002Wooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0A?ooool002Wooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool0A?ooool002Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0A?ooool002Wooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool0AOooool002Wooooo0_l0001Cooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`15ooooo`00:Oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`15ooooo`00:Ooo
ool00ol0003oooooooooo`0hooooo`Go00005Oooool00ol0003oooooooooo`0Sooooo`;o000000?o
410@ooooooooool07oooool00ol0003oooooooooo`0Eooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
>Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03Kooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^0oooool002Wooooo00?o0000ooooooooool0>?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A401Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Gooooo00GoEEEEogMgMoooooooV9RHob4Q8@0iooooo`05ob4Q8Ol0003ooooooiRHV?lQ
8B40>?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wo
oooo00?o0000ooooooooool0>Oooool00onHV9So8B4Qonk^kP0Eooooo`03o`000?oooooooooo02;o
oooo1Ol0000Rooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000ioooo
o`;o00000_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`00:Oooool2o`0003_ooooo00?oV9RHob4Q8Oo^k^h05?ooool00ol0
003oooooooooo`0Rooooo`04odA4A?oMgMgoooooo`0002?ooooo00?o0000ooooooooool05?ooool0
1Ol0003oV9RHoooooonHV9So8B4Q03Wooooo00Go<S8bo`000?ooooooV9RHoc8b<P0hooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003ooooo
ooooo`0kooooo`03ogMgMomVIVKooooo01?ooooo00?o0000ooooooooool08_ooool01?oMgMgoEEEE
ooooool0000Sooooo`03o`000?oooooooooo01Cooooo00Go0000oeEEEOl0003o410@olc<c00ioooo
o`Co000000?oc<c<ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool002Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Cooooo00?oMgMgolc<c?l000008oooool00ol0003oooooooooo`0Doooo
o`03oeEEEOn7QhOooooo03_ooooo00Go0000okZj^_oooooo^[Zjoa0@400hooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool00ol0003oooooooooo`0h
ooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool00ol0003oooooooooo`0Tooooo`03onk^k_m4
A4Co000002Cooooo00?o0000ooooooooool04oooool00ooMgMgo410@oiRHV00kooooo`05o`000?nj
^[[ooooookZj^_l00000>?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool002Wooooo00?o0000ooooooooool0>?ooool01OnHV9So410@o`000?lQ8B7oc<c<01?o
oooo00?o0000ooooooooool09Oooool00omgMgOo0000ooooo`0Sooooo`03o`000?oooooooooo01Co
oooo00Coc<c<odA4A?l0003o410@>Oooool01Ol0003o410@o`000?l@413oZJVY03Kooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Yooooo`;o0000DOooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0B?ooool0
02Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0B?ooool002Wooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0B?ooool002Wooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0BOooool002Wooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0BOooool0027oooooool00018
o`000000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool0
02Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Kooooo000Yooooo`;o0000C_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0B_ooool002Wooooo0_l0001>ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1:ooooo`00:Oooool2o`0004kooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04[ooooo000Y
ooooo`03o`000?oooooo000004gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooo000004cooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo04_ooooo000Yooooo`03
o`000?oooooo000004cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo04_ooooo000Yooooo`03o`000?oooooo000004cooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04_ooooo000Yooooo`;o000000?o
ooooo`000?ooool0B_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0C?ooool002Wooooo00Co0000oooooooooooo0000B_ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0C?ooool002Wooooo00Co0000
oooooooooooo0000B_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0C?ooool002Wooooo00Co0000oooooooooooo0000B_ooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0COooool002Wooooo00Go0000
ooooooooooooooooo`000018ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`1=ooooo`00:Oooool2o`0000;ooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0COooool0
02Wooooo00Go0000ooooooooooooooooo`000018ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`1=ooooo`00:Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo04kooooo000Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0C_ooool002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1>ooooo`00:Ooo
ool2o`0000?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0C_ooool002Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`1?ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`1?ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1Jooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0Coooool000Kooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo04oooooo0006ooooo`05o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00004ooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo053ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo053ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1@ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`1@ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo057ooooo000Yooooo`;o00001_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1Aooooo`00:Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo057ooooo000Yooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0DOooool002Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`1Booooo`00:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo05;ooooo000Yoooo
o`;o00002?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`1Booooo`00:Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo05?ooooo000Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
Doooool002Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Cooooo`00:Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo05?ooooo000Yooooo`;o00002Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`1Dooooo`00:Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Co
oooo000Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0E?ooool002Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`1Dooooo`00:Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo05Gooooo000Yooooo`;o00002_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Eoooo
o`00:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Gooooo000Yooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0EOooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06Sooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`1Fooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`1Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool3o`0000_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0E_ooool000kooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`1Gooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Eoooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`1Gooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
05Sooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo0_l0000=oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo05Sooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0F?ooool002Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Iooooo`00:Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Wooooo000Yooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0FOooool002Wooooo0_l0000?ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
05[ooooo000Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0F_ooool002Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Jooooo`00:Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo05_ooooo000Yooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0Foooool002Wooooo0_l0000@ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05_ooooo000Yooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0G?ooool002Wooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`1Looooo`00:Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo05cooooo000Yooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0GOooool0
02Wooooo0_l0000Booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0M_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo05gooooo000Yooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0GOooool002Wooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1Nooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`00
0?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0G_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Nooooo`001_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`?o00004oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`1Oooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0Goooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0Goooool000Kooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
063ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo063ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006
ooooo`;o00005_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Pooooo`00:Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo067ooooo000Yooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0HOooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Qooooo`00:Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06;ooooo000Yooooo`;o00006?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Rooooo`00:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
06?ooooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`24ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0I?ooool002Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08Cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Tooooo`00:Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo06Gooooo000Yooooo`;o00006oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1V
ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Kooooo000Yooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0Ioooool002Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Xooooo`00:Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo06Sooooo000Yooooo`;o00007_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Yooooo`00:Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo06Wooooo000Yooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo00[o
oooo0_l0001/ooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`07ooooo`;o0000U_ooool00ol0003oooooooooo`07ooooo`;o0000
K_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o00001_oo
ool00ol0003oooooooooo`2Gooooo`;o00001_ooool00ol0003oooooooooo`1^ooooo`008Oooool0
0ol0003oooooooooo`05ooooo`?o00008oooool6o`0009cooooo1ol0001`ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000O
ooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .39337 L
.06244 .47524 L
.08255 .54392 L
.09396 .57412 L
.09905 .58526 L
.10458 .59559 L
.11004 .60393 L
.11508 .60995 L
.11989 .61417 L
.12232 .61571 L
.12369 .61641 L
.125 .61696 L
.12615 .61735 L
.12741 .61768 L
.12855 .61789 L
.12962 .618 L
.13088 .61803 L
.13202 .61797 L
.13334 .61779 L
.13459 .61752 L
.13568 .61719 L
.13684 .61676 L
.1389 .61577 L
.14113 .61439 L
.14357 .61249 L
.14881 .6071 L
.15378 .60037 L
.16308 .58361 L
.1731 .55984 L
.184 .52784 L
.22478 .36657 L
.26405 .19157 L
.28374 .11486 L
.3018 .05859 L
.31122 .03599 L
.32114 .01785 L
.3263 .01085 L
.3311 .00587 L
.33386 .00369 L
.33637 .00214 L
.33776 .00146 L
.33927 .00087 L
.33996 .00065 L
.34069 .00045 L
.342 .00019 L
.34321 5e-05 L
.34453 0 L
.34577 6e-05 L
.34693 .00022 L
Mistroke
.34808 .00046 L
.34911 .00075 L
.35144 .00166 L
.35395 .00305 L
.35666 .00502 L
.36157 .00982 L
.36622 .01579 L
.37112 .02356 L
.37989 .04115 L
.39956 .09622 L
.41791 .16361 L
.45687 .33458 L
.47672 .42209 L
.49828 .5061 L
.50835 .53902 L
.51902 .56845 L
.52814 .58855 L
.53818 .60489 L
.54311 .61057 L
.5458 .613 L
.5483 .61484 L
.55044 .61608 L
.55273 .61707 L
.55404 .61748 L
.55527 .61777 L
.55637 .61793 L
.55757 .61802 L
.55887 .61801 L
.56008 .6179 L
.56078 .61779 L
.56142 .61767 L
.56285 .61728 L
.56422 .61678 L
.56572 .6161 L
.56843 .61447 L
.57095 .61253 L
.57363 .61001 L
.57844 .60432 L
.58779 .58905 L
.59788 .56666 L
.61616 .51215 L
.65726 .34386 L
.69686 .16934 L
.7168 .09565 L
.73493 .0443 L
.745 .02368 L
.74962 .01629 L
.75452 .00993 L
.757 .00729 L
.75974 .00485 L
Mistroke
.76226 .00304 L
.76456 .00175 L
.76595 .00114 L
.76727 .00069 L
.76867 .00033 L
.76946 .00018 L
.77019 9e-05 L
.77088 3e-05 L
.77153 0 L
.77274 3e-05 L
.77405 .00017 L
.77478 .0003 L
.77546 .00045 L
.77672 .00081 L
.77792 .00125 L
.78016 .00233 L
.78258 .00387 L
.78521 .00597 L
.78993 .0109 L
.7943 .01674 L
.80432 .03463 L
.81497 .06014 L
.83445 .12203 L
.85274 .19408 L
.89145 .36673 L
.91111 .45087 L
.93261 .52916 L
.94254 .55838 L
.95315 .5837 L
.9583 .59362 L
.96316 .60149 L
.96789 .60771 L
.97225 .61217 L
.97619 .61513 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`0006Cooooo1?l00027ooooo`?o0000B_ooool0027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Sooooo`;o00000_ooool2o`0008Cooooo0ol00002oooo
o`;o0000B?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`;o
00001_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00Gooooo0_l00016ooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
A?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04?ooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0001Pooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo04;ooooo000Yooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@Oooool002Wo
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`11ooooo`00:Oooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Moooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo043ooooo000Yooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0@?ooool002Wooooo0_l0001Mooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0MOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03oooooo000Yoooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?oooool002Wooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0nooooo`00:Oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03kooooo000Yooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?Ooo
ool002Wooooo0_l0001Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03gooooo000Yooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0?Oooool002Wooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0looooo`00:Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03cooooo
000Yooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0??ooool002Wooooo0_l0001H
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0>oooool002Wooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`00
1_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0>_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0E_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0jooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0001Fooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03Wooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0ioooo
o`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0i
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>?ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>?oo
ool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0
001Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo03Sooooo000Yooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0=oooool002Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0goooo
o`00:Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Oooooo000Yooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0=_ooool002Wooooo0_l0001Dooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Kooooo000Yooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=_ooool0
02Wooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0eooooo`00:Oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Yooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0=Oooool002Wooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0dooooo`00:Oooool2o`0005;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=?ooool002Wooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0dooooo`00:Oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03?ooooo000Yooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
<oooool002Wooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`00:Oooool2
o`00057ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0<oooool002Wooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03;ooooo0006oooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo000>ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000C_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0a
ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool000kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0aooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0`ooooo`00:Oooool2o`0004kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<?ooool0
02Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`00:Oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02oooooo000Yooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;oooool002Wooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0_ooooo`00:Oooool2o`0004gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool002Wooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0^ooooo`00:Oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02kooooo000Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
;_ooool002Wooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`00:Oooool2
o`0004_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0;Oooool002Wooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0]ooooo`00:Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02go
oooo000Yooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;Oooool002Wooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0]ooooo`00:Oooool2o`0004[ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0;?ooool002Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0/oooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0/
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0;?ooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0;?ooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3o`0004Sooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
:oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02_ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02_o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00006ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool002Wo
oooo0_l00018ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0Zooooo`00:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02[ooooo000Yoooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:Oooool002Wooooo0_l00017ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo02Wooooo000Yooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
:Oooool002Wooooo00?o0000ooooooooool0>?ooool5o`0000Sooooo00?o0000ooooooooool0<?oo
ool2o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<01Sooooo00?o0000ooooooooool07_ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01Wo
oooo00?o0000ooooooooool06_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h3ooooo`00:Oooool00ol0003oooooooooo`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q01Oooooo00?o0000ooooooooool07oooool01OlQ8B7oV9RH
oooooonHV9So8B4Q01Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0>Oooool00onHV9So
8B4Qonk^kP09ooooo`03o`000?oooooooooo02kooooo1Ol0000:ooooo`03o`000?oooooooooo02co
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo01oooooo00Go0000oooo
ooooooooooooo`00000Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`;o0000>oooool00onHV9So8B4Qonk^kP08
ooooo`03o`000?oooooooooo02kooooo00CoA4A4omgMgOoooooo00003?ooool00ol0003ooooooooo
o`0[ooooo`05o`000?nHV9SooooooiRHV?lQ8B405oooool00ol0003oooooooooo`0Oooooo`05oc8b
<_nHV9SooooooiRHV?lb<S806_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0kooooo`03
ogMgMomVIVKooooo00Kooooo00?o0000ooooooooool0;oooool01?oMgMgoEEEEooooool0000<oooo
o`03o`000?oooooooooo02_ooooo00Go0000oeEEEOl0003o410@olc<c00Gooooo`03o`000?oooooo
oooo01oooooo00Goc<c<o`000?l0003o0000olc<c00Jooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03ogMgMoo<
c<co000000cooooo00?o0000ooooooooool0:oooool00omEEEGoQhN7ooooo`0Hooooo`03o`000?oo
oooooooo023ooooo00Go410@okZj^_oooooo^[Zjoa0@400Jooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000Yooooo`03o`00
0?oooooooooo03Sooooo00Go0000okZj^_ooooooV9RHoa0@4007ooooo`03o`000?oooooooooo033o
oooo00?ok^k^odA4A?l000003?ooool00ol0003oooooooooo`0[ooooo`03omgMgOl@413oV9RH01So
oooo00?o0000ooooooooool08?ooool01Ol0003o^[Zjoooooonj^[[o000001[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
02Wooooo00?o0000ooooooooool0>?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo00?o0000
ooooooooool0<Oooool00omgMgOo0000ooooo`0<ooooo`03o`000?oooooooooo02_ooooo00Coc<c<
odA4A?l0003o410@5_ooool00ol0003oooooooooo`0Pooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
6oooool00ol0003oooooooooo`0Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`00:Oooool2o`0004Gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09oooool002Wooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Wooooo`00:Oooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo02Oooooo000Yooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool09oooool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Vooooo`00
8Oooooooo`0004So0000000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool2o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`00:Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`06ooooo`00:Oooool2o`0004?ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool09Oooool002Wo
oooo0_l00013ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo02Gooooo000Yooooo`;o0000@_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Uooooo`00:Oooool2o`0004;ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool09Oooool002Wooooo0_l00012
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooo0000047ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool09?ooool002Wooooo00?o0000ooooool00000@?ooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Tooooo`00
:Oooool3o`00043ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool09?ooool002Wooooo00?o0000ooooool00000@?oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Tooooo`00:Oooool01?l0003oooooooooool0000oooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo02Cooooo000Yooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool08ooo
ool002Wooooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Sooooo`00:Oooool2
o`000003ooooool0003ooooo03gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool08oooool002Wooooo00Co0000oooo
oooooooo0000?_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Sooooo`00:Oooool01Ol0003ooooooooooooooooo
000003gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool08oooool002Wooooo00Go0000ooooooooooooooooo`00000l
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02;ooooo000Yooooo`05o`000?ooooooooooooooool00000??ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Rooooo`00:Oooool2o`0000;ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0Rooooo`00:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool08_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Qooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0Qooooo`001_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Qooooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o00000_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo027ooooo0006ooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08?oo
ool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool08?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Pooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08?ooool002Wooooo
0_l00005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07oooool002Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo01oooooo000Y
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0O
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool07_ooool002Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo01kooooo000Yooooo`;o00001_ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`0Nooooo`00:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool07Oooool002Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo01gooooo000Yooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Mooooo`00:Oooool2o`0000Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Mooooo`00:Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07?ooool002Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01cooooo000Yoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Loooo
o`00:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool07?ooool002Wooooo0_l00009ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
6oooool002Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo01_ooooo000Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Kooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool06oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0Jooooo`003_ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool3o`0000Wooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`0Jooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool06_ooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool06Oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01Wooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0Iooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`;o0000
2oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo000Yooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Hooooo`00:Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool06?ooool0
02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
01Sooooo000Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0Gooooo`00:Oooool2o`0000gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`0Gooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool05oooool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0Fooooo`00:Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool05_ooool002Wooooo0_l0000>ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool05_ooool002Wooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05Oooool002Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Go
oooo000Yooooo`;o00003oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo01Cooooo
000Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0Dooooo`00:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooooooool05?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool05?ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooooooo01?ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0ol0000@ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06Sooooo00?o
0000ooooooooool04oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo06Sooooo00?o0000ooooooooool04oooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0Booooo`001_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0Booooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo01;ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00004_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo017ooooo000Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0Aooooo`00:Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool04Oooool002Wooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo013ooooo000Yooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0@ooooo`00:Oooool2o`0001Co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0@ooooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool03oooool002Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00oooooo000Y
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0?
ooooo`00:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ooooool03_ooool002Wooooo0_l0000Gooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool03_ooool002Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo07Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo00gooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0M_oo
ool00ol0003oooooooooo`0<ooooo`00:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool03?ooool002Wooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo000Yooooo`;o00006Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1jooooo`03o`000?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Noooool00ol0003oooooooooo`0:ooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo0_l0001nooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0O?ooool00ol0003oooooooooo`09ooooo`007oooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1nooooo`;o00002Oooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0POooool2o`0000Gooooo0_l00023ooooo`03o`000?oooooooooo
00Kooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0000Mooooo`Ko0000QOooool6o`0008ko
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .40504 L
.06244 .4958 L
.07216 .53332 L
.08255 .56684 L
.08852 .5826 L
.09396 .59456 L
.09942 .60418 L
.10208 .60798 L
.10458 .61099 L
.10699 .6134 L
.10919 .61517 L
.11164 .61663 L
.11299 .61722 L
.11428 .61763 L
.11551 .61789 L
.11682 .61802 L
.11806 .61801 L
.11919 .61788 L
.11988 .61775 L
.12052 .61759 L
.12195 .61709 L
.12322 .61651 L
.12455 .61575 L
.12675 .61416 L
.1291 .61199 L
.13334 .60689 L
.13839 .59885 L
.14299 .58971 L
.15291 .5644 L
.16208 .53467 L
.18284 .44894 L
.22211 .25072 L
.2418 .1553 L
.25986 .08224 L
.2691 .05251 L
.2792 .02708 L
.28447 .01701 L
.28936 .00969 L
.29202 .00656 L
.29453 .00416 L
.29592 .00306 L
.29743 .00206 L
.2988 .00132 L
.30006 .00079 L
.30127 .0004 L
.30242 .00016 L
.30363 2e-05 L
.30495 2e-05 L
.3061 .00014 L
Mistroke
.30732 .0004 L
.30848 .00076 L
.30952 .00119 L
.3121 .00265 L
.31489 .00487 L
.31994 .01059 L
.32527 .01897 L
.3309 .03033 L
.34098 .05681 L
.36066 .12842 L
.379 .213 L
.41796 .41166 L
.43781 .50141 L
.44828 .54073 L
.45938 .57462 L
.46924 .59704 L
.47485 .6063 L
.47742 .60966 L
.48011 .61258 L
.48241 .61459 L
.48363 .61547 L
.48493 .61626 L
.48613 .61686 L
.48722 .6173 L
.48831 .61764 L
.48934 .61787 L
.49055 .61801 L
.49182 .61802 L
.49291 .61792 L
.49411 .61769 L
.4954 .61731 L
.49678 .61673 L
.49927 .61527 L
.50183 .61322 L
.50455 .61042 L
.50943 .60382 L
.51468 .59451 L
.52049 .58164 L
.53086 .55229 L
.5406 .51799 L
.57926 .33779 L
.59888 .23663 L
.62037 .13521 L
.63027 .09528 L
.64087 .05914 L
.65087 .03226 L
.65996 .01457 L
.6648 .00793 L
.66724 .00533 L
.66992 .00306 L
Mistroke
.67221 .00162 L
.6735 .00101 L
.67467 .00058 L
.67576 .00028 L
.67695 8e-05 L
.67808 0 L
.67912 3e-05 L
.68042 .0002 L
.68116 .00035 L
.68184 .00054 L
.68308 .00099 L
.6844 .00162 L
.68668 .00305 L
.68918 .00514 L
.69473 .01169 L
.69991 .02012 L
.71037 .04375 L
.72027 .07367 L
.73884 .14646 L
.77718 .33689 L
.79658 .43396 L
.81799 .52542 L
.82774 .55851 L
.83286 .57326 L
.83825 .58666 L
.843 .59658 L
.84818 .60533 L
.85046 .60847 L
.85289 .61134 L
.85498 .61339 L
.85727 .61522 L
.85852 .61603 L
.85987 .61674 L
.86128 .61733 L
.86192 .61753 L
.86261 .61772 L
.86393 .61795 L
.86518 .61803 L
.8664 .61798 L
.86753 .61782 L
.86823 .61766 L
.86898 .61745 L
.87035 .61693 L
.87168 .61626 L
.87291 .61552 L
.8757 .61334 L
.87863 .61032 L
.88361 .60354 L
.88825 .59536 L
.89879 .57042 L
Mistroke
.90928 .53748 L
.9192 .4998 L
.93777 .41597 L
.97617 .22014 L
.97619 .22005 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`0005Oooooo0ol0001gooooo`?o0000J?ooool0027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Fooooo`;o00000_ooool2o`0007?ooooo0ol000001?oo
oooo0000o`000?l0001Vooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05Cooooo0_l00006ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Tooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo06;ooooo000Oooooo`03oeEEEOmVIVKo000000Oooooo0_l0
001Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo06;ooooo000Yooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0HOooool002Wooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Poooo
o`00:Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo063ooooo000Yooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Goooool002Wooooo0_l0001Aooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo05oooooo000Yooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Goooool0
02Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Nooooo`00:Oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05kooooo000Yooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0G_ooool002Wooooo0_l0001?ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05gooooo000Y
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0GOooool002Wooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1Looooo`00:Oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo05cooooo000Yooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
Foooool002Wooooo0_l0001=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05_ooooo000Yooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0Foooool002Wooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0F_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Iooooo`001?l00002ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol0001;
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo05Wooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1Iooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1Hooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0F?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0F?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Kooooo0_l0001:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Sooooo000Yooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Eoooool002Wooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Gooooo`00:Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
05Oooooo000Yooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Eoooool002Wooooo
0_l00019ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo05Kooooo000Yooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0E_ooool002Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1F
ooooo`00:Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Kooooo000Yooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0EOooool002Wooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1Eooooo`00:Oooool2o`0004Sooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0EOoo
ool002Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Eooooo`00:Oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo05Cooooo000Yooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0E?ooool002Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Dooooo`00:Oooool2o`0004Kooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0E?ooool002Wooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1Cooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo05?ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo05?ooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo000>
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000A?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Cooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
D_ooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1Booooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo05;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1Booooo`00:Oooool2o`0004Cooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0D_ooool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1A
ooooo`00:Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo057ooooo000Yooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0DOooool002Wooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1Aooooo`00:Oooool2o`0004?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0DOoo
ool002Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1@ooooo`00:Oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo053ooooo000Yooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0D?ooool002Wooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1@ooooo`00:Oooool2o`0004;ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0D?ooool002Wooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`1?ooooo`00:Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo04oooooo000Yooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0Coooool002Wooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1?ooooo`00:Ooo
ool2o`00047ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0Coooool002Wooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Kooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01_oo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool01_ooool000Co00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`07ooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`?o0000?oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Oooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool01oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07oooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool02?ooool002Wooooo0_l0000oooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool02?ooool002Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo00Sooooo000Yooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`08ooooo`00:Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool02?ooool002Wooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Wooooo000Yooooo`;o0000?_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003ooooo
ooooo`0hooooo`Ko0000=_ooool01?l0003oooooooooooooool2o`000003oa0@4?oooooooooo03Oo
oooo00Gok^k^oc8b<_l0003o410@olc<c00eooooo`09o`000?ooooooooooooooooo<c<co8B4Qo`00
0?lQ8B7oc<c<03Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool0
02Wooooo00?o0000ooooooooool0>?ooool01_nHV9So8B4Qonk^k_ooooooA4A4o`0003Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`05oeEEEOmgMgOo0000oiRHV?lQ8B40
=Oooool02Ol0003ooooooooooooooooo8B4QoiRHV?ooooooV9RHob4Q8@0hooooo`;o00000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo03Wooooo00CoV9RH
ob4Q8Oo^k^ko0000>?ooool6o`0003Wooooo00Go0000ooooool0003oooooo`00000eooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2o`0003_ooooo00?oV9RHob4Q8Ol0
0000>?ooool01Ol0003oA4A4omgMgOoooooo000003[ooooo00Go0000oiRHV?l0003oV9RHob4Q8@0e
ooooo`09o`000?oooooooooooooooolb<S;oV9RHoooooonHV9So<S8b03Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oooooooooo03_o
oooo00?oMgMgo`000?ooool0=oooool01Ol0003ogMgMoeEEEOoooooo000003[ooooo0ol000000ol@
413oc<c<ooooo`0dooooo`05o`000?ooooooooooooooooo<c<`00ol000000oo<c<coooooooooo`0f
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`00:Oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo03Kooooo00Go0000oooooomgMgOoc<c<o`00
000jooooo`03oeEEEOl0003ooooo03Sooooo00So0000oooooooooooo410@okZj^_oooooo^[Zjoa0@
43Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo000Yoooo
o`03o`000?oooooooooo03Sooooo00Go0000okZj^_ooooooV9RHo`00000hooooo`05o`000?oooooo
k^k^odA4A?l00000>_ooool00ooMgMgo0000oiRHV00hooooo`08o`000?ooooooooooo`000?nj^[[o
oooookZj^_l0000hooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`00:Oooool00ol0003oooooooooo`0hooooo`05oiRHV?l@413o0000o`000?o<c<`0>Oooool0
1?l0003oooooogMgMol0000kooooo`04o`000?m4A4Co0000oa0@43Kooooo00So0000oooooooooooo
ZJVYoa0@4?l0003o410@ojVYZCKooooo00?oEEEEo`000?l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo000Yooooo`;o0000??ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00_ooooo000Yooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0;ooooo`00:Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02oooool002Wooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00_ooooo000Yooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`008Oooooooo`0004So0000000Yoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00_ooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
oooooooo00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`0joooo
o`;o0000>oooool00ol0003oooooo`00000iooooo`05o`000?ooooooooooooooool00000>Oooool0
1Ol0003ooooooooooooooooo000003Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`00:Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool03?ooool002Wooooo0_l0000jooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool03Oooool002Wooooo0_l0000jooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03Oooool002Wooooo0_l0000jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
3Oooool002Wooooo0_l0000jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03Ooo
ool002Wooooo0_l0000jooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03Oooool0
02Wooooo00?o0000ooooool00000>?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00kooooo000Yooooo`?o0000>?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00ko
oooo000Yooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0>ooooo`00:Oooool00ol0003oooooo`00000hooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool03_ooool002Wooooo00?o0000ooooool00000>?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00kooooo000Yooooo`04o`000?ooooooooooo`0003Kooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`00:Oooool2o`000003ooooool0003ooooo
03Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0?ooooo`00:Oooool01?l0003o
ooooooooool0000fooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03oooool002Wo
oooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00oooooo000Yooooo`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0?ooooo`00:Oooool01Ol0003ooooooooooooooooo000003Cooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0@ooooo`00:Oooool2o`0000;ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo000Yooooo`05o`00
0?ooooooooooooooool00000=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo013o
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool01Ol0003ooooooooooooooooo000003Cooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0@ooooo`001_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`04ooooo`05o`000?ooooooooooooooool00000=?ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo013ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04Oooool000Kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool3o`0000;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo017ooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo017ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Aooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Booooo`00:Oooool2o`00
00Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01;ooooo000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01;ooooo
000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01?ooooo000Yoooo
o`;o00001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool04oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool002Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
4oooool002Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool05?ooool002Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05?ooool0
02Wooooo0_l00006ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Dooooo`00:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Dooooo`00:Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Dooooo`00:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Eooooo`00:Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0E
ooooo`00:Oooool2o`0000Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01Gooooo000Yooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Gooooo000Yooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01Kooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Fooooo`003_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00oooool3o`0000Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01Kooooo000>ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool000ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool05oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool2o`0000Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo000Yooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01Sooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo000Yooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Sooooo000Yooooo`;o00002oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool06?ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06Oooool002Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06Oooool002Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06Oooool002Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool06Oooool002Wooooo0_l0000<ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`00
:Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Jooooo`00:Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`00:Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Kooooo`00:Oooool2o`0000gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo000Yooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool07?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool000Kooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00So
oooo00?o0000ooooooooool00oooool3o`0000gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01cooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool07?ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01gooooo0006ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool07Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01gooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006
ooooo`;o00004?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07_ooool002Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool002Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool07_ooool002Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool07_ooool002Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07ooo
ool002Wooooo0_l0000Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Oooooo`00:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`00:Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Pooooo`00:Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`00:Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Qooooo`00:Oooool2o`0001?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo027ooooo000Yooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo000Yooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02;ooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo000Yooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02?ooooo000Yooooo`;o00005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool09?ooool002Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool002Wo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`;o0000K_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`007oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
9_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`;o00001Ooo
ool00ol0003oooooooooo`1_ooooo`?o00001?ooool2o`00077ooooo0_l00004ooooo`;o0000:Ooo
ool0027ooooo00?o0000ooooooooool01Oooool3o`0001[ooooo1Ol0001dooooo`Go0000M?ooool6
o`0002[ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000oooooom7ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .41656 L
.06244 .51514 L
.07216 .55371 L
.08255 .58584 L
.08852 .59954 L
.09396 .6088 L
.09658 .61215 L
.09796 .61361 L
.09942 .61493 L
.10069 .6159 L
.1021 .61675 L
.10338 .61734 L
.10458 .61773 L
.10583 .61797 L
.10652 .61803 L
.10715 .61803 L
.10838 .61792 L
.10954 .61765 L
.1102 .61744 L
.1109 .61716 L
.11214 .61653 L
.11349 .61566 L
.11496 .61447 L
.11742 .61197 L
.12006 .60855 L
.12483 .60051 L
.1298 .58958 L
.13452 .57695 L
.14335 .54763 L
.16326 .45878 L
.18168 .35758 L
.20193 .24009 L
.22095 .13855 L
.23911 .06173 L
.24409 .04542 L
.24933 .03077 L
.25415 .0197 L
.2587 .01144 L
.2611 .00797 L
.2637 .00491 L
.26606 .00276 L
.26824 .00132 L
.26946 .00075 L
.2706 .00036 L
.27185 9e-05 L
.27255 2e-05 L
.2732 0 L
.27448 .0001 L
.27521 .00024 L
Mistroke
.27589 .00042 L
.27712 .00087 L
.27844 .00155 L
.28083 .00325 L
.28341 .0058 L
.28808 .01223 L
.29263 .02072 L
.29681 .0304 L
.30657 .05964 L
.31567 .09456 L
.33635 .19548 L
.37531 .41791 L
.39516 .5163 L
.40636 .55985 L
.41171 .57678 L
.41672 .59016 L
.42153 .60064 L
.42593 .60812 L
.42826 .61126 L
.43082 .61401 L
.43338 .61606 L
.43478 .61687 L
.43608 .61744 L
.43737 .61781 L
.43809 .61794 L
.43876 .61801 L
.43999 .61801 L
.44129 .61783 L
.44245 .61751 L
.44354 .61707 L
.44474 .61644 L
.44602 .6156 L
.44886 .61307 L
.45156 .60986 L
.45662 .60175 L
.4612 .5921 L
.46626 .57897 L
.4765 .54498 L
.49492 .4628 L
.53509 .23606 L
.55354 .13783 L
.564 .09063 L
.57374 .0543 L
.58341 .02674 L
.58883 .01536 L
.59376 .00769 L
.59646 .00458 L
.59896 .00242 L
.60026 .00156 L
.6017 .00083 L
Mistroke
.60242 .00055 L
.6032 .00031 L
.60393 .00015 L
.6046 5e-05 L
.60591 1e-05 L
.60712 .00013 L
.60781 .00027 L
.60844 .00045 L
.60986 .00101 L
.61109 .00167 L
.61243 .00258 L
.61485 .00472 L
.61722 .00745 L
.61977 .01104 L
.62436 .01926 L
.62983 .03186 L
.6348 .04593 L
.65587 .12937 L
.69574 .35001 L
.71397 .45108 L
.72435 .50184 L
.73409 .54277 L
.74361 .57519 L
.74852 .58857 L
.75388 .60046 L
.75922 .60933 L
.76213 .61288 L
.76353 .61426 L
.76484 .61536 L
.76606 .61621 L
.76739 .61696 L
.76859 .61746 L
.7697 .61779 L
.7709 .61799 L
.77222 .61802 L
.77289 .61797 L
.7736 .61786 L
.77489 .61751 L
.77558 .61725 L
.77623 .61696 L
.77744 .61629 L
.78015 .6142 L
.7825 .61175 L
.78503 .60844 L
.79079 .59836 L
.79608 .58609 L
.80587 .5562 L
.81619 .51556 L
.85423 .31304 L
.87543 .1922 L
Mistroke
.89473 .09785 L
.90433 .06058 L
.90939 .04417 L
.91476 .0294 L
.91945 .01886 L
.92193 .01419 L
.92461 .00989 L
.92706 .00662 L
.92931 .00419 L
.93156 .00231 L
.93268 .00158 L
.93371 .00103 L
.93495 .00052 L
.9356 .00033 L
.93629 .00017 L
.93745 2e-05 L
.93873 3e-05 L
.93987 .00019 L
.94109 .00052 L
.94224 .00098 L
.94329 .00152 L
.9458 .00333 L
.94853 .00607 L
.9535 .01312 L
.95813 .02204 L
.96305 .03391 L
.97189 .06114 L
.97619 .07695 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`0004gooooo0ol0001Yooooo`?o0000JOooool3o`0001Cooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool2o`000004ooooool0003o0000
o`0006Kooooo0_l00002ooooo`03o`000?oooooooooo06Gooooo0_l00002ooooo`;o00004_ooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06?ooooo0_l00005ooooo`03o`000?oooooooooo00oooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0>ooooo`007oooool00omEEEGoIVIVo`000007ooooo`;o0000B_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03Oooool002Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool002Wooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool002Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03?ooool002Wooooo0_l00017ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`00:Oooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0FOooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`00:Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`00:Oooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`00:Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`00:Oooool2o`0004Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo000Y
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo000Yooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo000Yooooo`;o0000A?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?oo
ool002Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02?ooool002Wooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`07ooooo`001?l00002ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo0ol00012
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`0Oooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo023ooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo023ooooo0006
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool08?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go0000
1?ooool4o`0000Kooooo0_l00012ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
8?ooool002Wooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo027ooooo000Yooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0Qooooo`00:Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool08Oooool002Wooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo027ooooo000Yooooo`;o0000@Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo027ooooo000Yooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Rooooo`00:Oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08_ooool002Wooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02;ooooo000Yooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Rooooo`00
:Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
8_ooool002Wooooo0_l0000oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool08ooo
ool002Wooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo02?ooooo000Yooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Sooooo`00:Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool08oooool002Wooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo02?ooooo000Yooooo`;o0000?_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo02Cooooo000Yooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Tooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool09?ooool000kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Tooooo`001_ooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02Cooooo000>
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Gooooo000>ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Gooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Uooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool09Oooool000kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool09Oooool002Wooooo0_l0000looooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Kooooo000Yooooo`;o0000>ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Oooooo000Yooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Wooooo`00:Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09oooool002Wo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo02Oo
oooo000Yooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0Wooooo`00:Oooool2o`0003[ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0Wooooo`00:Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0:?ooool002Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0:?ooool002Wooooo0_l0000iooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Wooooo0006ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:Ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0:Oooool000Co00000_ooool01Ol@413ooooooooo
oooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Yooooo`001_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`?o0000=oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02Wooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0:Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0:_ooool000Kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Zoooo
o`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co00001_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0:_ooool002Wooooo0_l0000hooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0:_ooool002Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo02[ooooo000Yooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0[ooooo`00:Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0:oooool002Wooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo02_ooooo000Yooooo`;o0000=oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02_ooooo000Yooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0[ooooo`00:Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Go0000:_ooool00ol0003oooooooooo`0>ooooo`;o0000
00?o410@ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`06_ooool00ol0003oooooooooo`0Looooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`05oooool00ol0
003oooooooooo`0Looooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo
000Yooooo`03o`000?oooooooooo03Gooooo00So0000ooooooooooooV9RHob4Q8Oo^k^koooooodA4
A2[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
013ooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Jooooo`03o`000?oooooooooo01cooooo00Go8B4Q
oiRHV?ooooooV9RHob4Q8@0Fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Yooooo`03o`000?oooooooooo03Gooooo00Oo
0000oooooooooooooooooiRHV?lQ8B7ok^k^02_ooooo00?o0000ooooooooool03?ooool5o`0002Ko
oooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000oooo
ooooool06oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool002Wooooo0_l0000f
ooooo`03o`000?oooooooooo00;ooooo00?oV9RHob4Q8Oo^k^h0:_ooool00ol0003oooooooooo`0<
ooooo`04odA4A?oMgMgoooooo`0002Oooooo00?o0000ooooooooool04?ooool01Ol0003oV9RHoooo
oonHV9So8B4Q01_ooooo00?o0000ooooooooool06oooool01Olb<S;oV9RHoooooonHV9So<S8b01Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool002Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03
ogMgMomVIVKooooo02[ooooo00?o0000ooooooooool02oooool01?oMgMgoEEEEooooool0000Voooo
o`03o`000?oooooooooo017ooooo00Go0000oeEEEOl0003o410@olc<c00Kooooo`03o`000?oooooo
oooo01_ooooo00Goc<c<o`000?l0003o0000olc<c00Fooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000Yooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00cooooo00?oMgMgolc<c?l000009_ooool00ol0003oooooooooo`0Aooooo`03oeEEEOn7
QhOooooo01gooooo00?o0000ooooooooool06oooool01Ol@413o^[Zjoooooonj^[[o410@01Kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41000oooool002Wooooo00?o0000ooooooooool0=?ooool02Ol0003ooooooooooooooooo0000okZj
^_ooooooV9RHoa0@400[ooooo`03o`000?oooooooooo00cooooo00?ok^k^odA4A?l000009_ooool0
0ol0003oooooooooo`0Aooooo`03omgMgOl@413oV9RH01gooooo00?o0000ooooooooool06oooool0
1Ol0003o^[Zjoooooonj^[[o000001Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000ooooooooool0=?oo
ool02Ol0003oooooooooooooooooV9RHoa0@4?l0003o8B4Qolc<c00[ooooo`03o`000?oooooooooo
00gooooo00?oMgMgo`000?ooool09Oooool00ol0003oooooooooo`0Booooo`04olc<c?m4A4Co0000
oa0@41_ooooo00?o0000ooooooooool06oooool01OnYZJWo410@o`000?l@413oZJVY01Gooooo00?o
0000ooooooooool07_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool002Wooooo0_l0000eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;Ooo
ool002Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02gooooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0]ooooo`00:Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0;Oooool002Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02kooooo000Qoooooooo0000B?l0000002Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo000Yoooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool002Wooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo000Yooooo`;o0000
<oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo000Yooooo`;o0000<ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Yooooo`;o0000<oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo000Yooooo`;o0000<oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo000Yooooo`;o0000<oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02oooooo000Yooooo`;o0000<_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02oooooo000Yooooo`?o0000<Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo033ooooo000Yooooo`03o`000?oooooo0000037ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`00:Oooool00ol0003oooooo`00000aoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<?ooool002Wooooo00?o0000ooooool0
0000<Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo000Yooooo`03o`00
0?oooooo0000033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`00:Ooo
ool3o`00033ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`00:Oooool0
1?l0003oooooooooool0000_ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Ooo
ool002Wooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo037ooooo000Yooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0aooooo`00:Oooool01?l0003oooooooooool0000_ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0<Oooool002Wooooo0_l000000ooooooo0000ooooo`0]
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool002Wooooo00Go0000oooo
ooooooooooooo`00000]ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool0
00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`05o`000?ooooooooooooooool00000;Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03;ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0<_ooool000Kooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000002gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0booooo`001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`?o000000?ooooo
o`000?ooool0:oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03;ooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0booooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03?ooooo
0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`001_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0cooooo`00:Oooool2o`0000?ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo000Yooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo
000Yooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03Cooooo000Yooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Cooooo000Yoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo03Cooooo000Yooooo`;o00001?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=?ooool002Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=?ooool002Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0=?ooool002Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=Oooool0
02Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0=Oooool002Wooooo0_l00005ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0eooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0eooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0eooooo`00:Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0f
ooooo`00:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0fooooo`00:Oooool2o`0000Kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Kooooo000Yooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03Kooooo000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Kooooo000>ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03Kooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0gooooo`003_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Oooooo000>ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Oooooo
000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0=oooool000kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0=oooool000kooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>?ooool000kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0000Sooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Sooooo000Yooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo03Sooooo000Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03Sooooo000Yooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03Sooooo000Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03Sooooo000Yooooo`;o00002Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0>Oooool002Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0>Oooool002Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool002Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0>Oooool002Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool002Wooooo0_l0000:ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0jooooo`00
:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0jooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`00:Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0jooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`00:Oooool2o`0000co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03_o
oooo000Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03_ooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0??ooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0??ooool000Kooooo00Go410@oooooooooooooooo
oa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool3o`0000cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03cooooo
0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0?Oooool000Kooooo00Go0000oooooooooooooooo
o`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWo
MgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?Oooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo03kooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00003_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool002Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0?_ooool002Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Dooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0?_ooool002Wooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0?ooo
ool002Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0?oooool002Wooooo0_l0000@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0oooooo`00:Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Eoooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`10ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`10ooooo`00:Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`10ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`11ooooo`00:Oooool2o`00017ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo047ooooo000Yooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo047ooooo000Yooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04;ooooo000Yooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04;ooooo000Yooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo04?ooooo000Yooooo`;o00004oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0@oooool002Wo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0A?ooool002Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool001oooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo0_l00004ooooo`03o`000?oooooo
oooo04Kooooo000Qooooo`03o`000?oooooooooo00Gooooo0ol0000Fooooo`Go0000Ioooool5o`00
06Oooooo1Ol00019ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Oooooo`03oeEEEOmVIVKo00000?ooooooAoooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04262 .42792 L
.06244 .53312 L
.06747 .5543 L
.07286 .57393 L
.07751 .58818 L
.08255 .60064 L
.08564 .60664 L
.08848 .61107 L
.0912 .6143 L
.09258 .61556 L
.09409 .61664 L
.09479 .61704 L
.09545 .61735 L
.0967 .61778 L
.09739 .61793 L
.09804 .61801 L
.09875 .61803 L
.0995 .61798 L
.10016 .61787 L
.10088 .61768 L
.10217 .61717 L
.10342 .61646 L
.10458 .61561 L
.10704 .61321 L
.10928 .61031 L
.11432 .60138 L
.11898 .59018 L
.1234 .57708 L
.1333 .53959 L
.14407 .4876 L
.18485 .23549 L
.2051 .1182 L
.21502 .07206 L
.22412 .03872 L
.2287 .02557 L
.23297 .0157 L
.23742 .0079 L
.23977 .00484 L
.24228 .00239 L
.2436 .00145 L
.24482 .00078 L
.24545 .00052 L
.24615 .00029 L
.24688 .00012 L
.24756 3e-05 L
.24882 3e-05 L
.24996 .00021 L
.2506 .00039 L
.25129 .00065 L
Mistroke
.25254 .00128 L
.25377 .00211 L
.25489 .00303 L
.25738 .00571 L
.25969 .00894 L
.26187 .01262 L
.26654 .02261 L
.27166 .03671 L
.28198 .07453 L
.30047 .16815 L
.34095 .42268 L
.35962 .52388 L
.37016 .56741 L
.37519 .58383 L
.37991 .59645 L
.38482 .60661 L
.38743 .61072 L
.38877 .61248 L
.39023 .61413 L
.39158 .61539 L
.39302 .61647 L
.39382 .61695 L
.39454 .61731 L
.39527 .6176 L
.39595 .6178 L
.39724 .61801 L
.39793 .61803 L
.39865 .61799 L
.39986 .61775 L
.40054 .61752 L
.40119 .61726 L
.40244 .61658 L
.40379 .6156 L
.40627 .61317 L
.40867 .61003 L
.4109 .60643 L
.41595 .59588 L
.42132 .58113 L
.43067 .54731 L
.44077 .50059 L
.45904 .39589 L
.47866 .26984 L
.50015 .14011 L
.51005 .0903 L
.52065 .04753 L
.52579 .03131 L
.53065 .01895 L
.53501 .01042 L
.53747 .00671 L
.53974 .004 L
Mistroke
.54099 .00281 L
.54217 .00187 L
.54325 .00118 L
.5444 .00062 L
.54565 .00021 L
.5468 3e-05 L
.54751 0 L
.54817 4e-05 L
.54942 .00027 L
.55052 .00066 L
.55168 .00124 L
.55268 .00189 L
.55377 .00275 L
.55621 .00526 L
.55848 .00831 L
.56369 .01788 L
.56844 .02965 L
.57911 .06598 L
.58903 .11072 L
.59821 .15978 L
.61897 .28804 L
.63924 .41721 L
.64917 .47476 L
.65826 .52125 L
.66695 .55847 L
.67644 .58966 L
.68139 .60156 L
.68599 .60979 L
.68853 .61315 L
.69084 .61545 L
.69212 .61641 L
.6928 .61683 L
.69351 .6172 L
.69482 .61771 L
.69603 .61797 L
.69724 .61803 L
.69856 .61787 L
.69981 .6175 L
.70097 .61697 L
.70211 .61626 L
.70315 .61547 L
.70548 .61316 L
.70799 .60985 L
.7107 .60534 L
.71562 .59473 L
.72517 .56556 L
.73394 .52967 L
.75281 .42903 L
.7735 .29805 L
.7947 .16613 L
Mistroke
.81399 .06969 L
.8236 .03537 L
.82902 .02083 L
.83161 .01521 L
.83403 .01072 L
.83631 .00719 L
.8384 .00457 L
.84073 .00235 L
.84201 .00144 L
.84322 .00078 L
.84439 .00033 L
.84564 6e-05 L
.84682 0 L
.84789 .00011 L
.84914 .00044 L
.84985 .00072 L
.85051 .00103 L
.85171 .00177 L
.85297 .00276 L
.85552 .00539 L
.85793 .00869 L
.86245 .01694 L
.86731 .02875 L
.8726 .04491 L
.89093 .12449 L
.9317 .37531 L
.95195 .49389 L
.96109 .53776 L
.97096 .5756 L
.97619 .59113 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo
@oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000
ooooooooool01Oooool3o`0004Gooooo0ol0001Oooooo`;o0000Goooool2o`0003;ooooo000Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0A?ooool2o`000003ooooool0003o0000
05cooooo0_l000000ooooooo0000o`00001Mooooo`;o000000?oooooo`000?l00000<?ooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0;Oooool001oooooo00?oEEEEofIVI_l000001oooool2o`0004;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02cooooo000Yoooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo02_ooooo000Yooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo000Yooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02_ooooo000Yooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02[ooooo000Yooooo`;o0000@Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:_ooool0
02Wooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:_ooool002Wooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool002Wooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:Oooool002Wooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool002Wooooo0_l0000o
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0X
ooooo`00:Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Xooooo`00
:Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Wooooo`00:Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`00:Oooool2
o`0003gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02Oooooo000Yooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo000Yooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Ko
oooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool000Co00000_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03oooo
o`?o0000>oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool09_ooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`001_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool09Oooool000Kooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0U
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09Oooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000kooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`00:Oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Tooooo`00:Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`00:Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Tooooo`00:Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`00:Oooool2o`0003[ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo000Y
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02?ooooo000Yooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo000Yooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo02?ooooo000Yooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo000Yooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo02;ooooo000Yooooo`;o0000>Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool08_ooool002Wooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool002Wo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool08_ooool002Wooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool002Wooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool08Oooool002Wooooo0_l0000hooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Qooooo`00:Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qoooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`003_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08Oooool0
00Kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo027ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`?o0000=_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool08?ooool000kooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`003_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Pooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Pooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0006ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo023ooooo000Yooooo`;o0000=_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool002Wooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool08?ooool002Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool002Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
7oooool002Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool07oooool002Wooooo0_l0000eooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`00:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Oooooo`00:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`00:Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Nooooo`00:Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Nooooo`00:Oooool2o`0003Cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo000Yoooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo000Yooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01kooooo000Yooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo000Yooooo`;o0000<oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07Oooool0
02Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07Oooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01gooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool07Ooo
ool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01gooooo0006ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Looooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool000Kooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Looooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`01?ooool4o`0000Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool002Wooooo0_l0000aooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`00
:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Kooooo`00:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`00:Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Kooooo`00:Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Kooooo`00:Oooool2o`00037o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01_o
oooo000Yooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01_ooooo000Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool01_ooool5o`0001oooooo00?o0000ooooooooool06Oooool2o`000003oa0@4?oo
oooooooo01Cooooo00?o0000ooooooooool08?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo
00?o0000ooooooooool0<Oooool01Oo<c<co0000o`000?lQ8B7oc<c<02Oooooo00?o0000oooooooo
ool03?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`00:Oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00Oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Pooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`0aooooo`05o`00
0?nHV9SooooooiRHV?lQ8B40:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h08?ooool00ol0003oooooooooo`0Gooooo`Go
00005_ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`0aooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`00:Oooool2
o`00033ooooo00?o0000ooooooooool02?ooool00onHV9So8B4Qonk^kP0Pooooo`03o`000?oooooo
oooo01Kooooo00CoA4A4omgMgOoooooo00005oooool00ol0003oooooooooo`0Pooooo`05o`000?nH
V9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`0aooooo`05o`000?nHV9SooooooiRHV?lb
<S80:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`00:Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo00?oMgMgofIVI_ooool07oooool00ol0003oooooooooo`0Fooooo`04omgMgOmEEEGoooooo`00
01Kooooo00?o0000ooooooooool08Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0<?ooool4o`000003olc<c?oooooooooo02Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool002Wooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool05oooool00omgMgOoc<c<o`00000Fooooo`03o`000?oooooooooo027ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`0`ooooo`05o`000?nj^[[ooooookZj^_l@4100:?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`00:Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oooooo00Go
0000okZj^_ooooooV9RHoa0@400Pooooo`03o`000?oooooooooo01Oooooo00?ok^k^odA4A?l00000
5_ooool00ol0003oooooooooo`0Qooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
<?ooool01Ol0003o^[Zjoooooonj^[[o000002Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool002Wooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`07ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08?ooool00ol0
003oooooooooo`0Hooooo`03ogMgMol0003ooooo01Gooooo00?o0000ooooooooool08_ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo02oooooo00Ko0000ojVYZOl@413o0000oa0@
4?nYZJTYooooo`03o`000?oooooooooo00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo000Yooooo`;o0000;oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool06Oooool002Wooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06Ooo
ool002Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool06Oooool002Wooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06Oooool002Wo
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool06Oooool0027oooooool00018o`000000:Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool2o`0000gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Kooooo000Yooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`00:Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Hooooo`00:Oooool2o`0002kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo000Yooooo`;o0000;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool06?ooool002Wooooo
0_l0000]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Gooooo`00:Oooool2o`0002gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Oooooo000Yooooo`;o0000;Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool002Wooooo0_l0000]oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Goooo
o`00:Oooool3o`0002cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01Oooooo000Yooooo`03o`000?oooooo000002cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Oooooo000Yooooo`03o`000?oo
oooo000002_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Oooooo000Yooooo`03o`000?oooooo000002_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Kooooo000Yooooo`03o`000?oooooo0000
02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
01Kooooo000Yooooo`?o0000:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool05_ooool002Wooooo00?o0000ooooool00000:oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool002Wooooo00Co
0000oooooooooooo0000:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool05_ooool002Wooooo00Co0000oooooooooooo0000:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05_ooool002Wooooo00Co
0000oooooooooooo0000:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool05Oooool002Wooooo0_l000000ooooooo0000ooooo`0Xooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eooooo`00:Oooool0
1?l0003oooooooooool0000Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Eooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooo
0000:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool05Oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003ooooooooooooooooo
000002Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01Gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eooooo`001_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8boooo
o`04ooooo`?o000000?oooooo`000?ooool09_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05?ooool000Kooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`05o`00
0?ooooooooooooooool000009oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool05?ooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Cooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000002Oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo0006
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool002Wooooo0_l0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo01?ooooo000Yooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool04oooool002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Coooo
o`00:Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01?ooooo000Yooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool04oooool002Wooooo0_l00003ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo01?ooooo000Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04_ooool0
02Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Booooo`00:Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo01;ooooo000Yooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool04_ooool002Wooooo0_l00004ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01;ooooo000Y
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04Oooool002Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Aooooo`00:Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo017ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
4Oooool002Wooooo0_l00005ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo017ooooo000Yooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool04Oooool002Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0@ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo013ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo013ooooo000>oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`?o00001Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0@ooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo013ooooo000>oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0@ooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo00oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03oooool000kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0000Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03ooo
ool002Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0?ooooo`00:Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo00oooooo000Yooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool03_ooool002Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0>ooooo`00:Oooool2o`0000Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03_ooool002Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0>ooooo`00:Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo00kooooo000Yooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool03Oooool002Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0=ooooo`00:Ooo
ool2o`0000Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool03Oooool002Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0=ooooo`00:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
00gooooo000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool002Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<ooooo`00:Oooool2o`0000[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool03?ooool002Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<
ooooo`00:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00cooooo0006ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0;
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWo
oooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo00_ooooo0006ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo0ol0000:ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_ooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`001_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0:ooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool000Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool000Kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000<ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00[ooooo000Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool02Ooo
ool002Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool02Oooool002Wooooo0_l0000>ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo
000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02?ooool002Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`00:Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00Oooooo000Yooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool01oooool002Wooooo0_l0000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Oooooo000Yooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool01_ooool002Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`06ooooo`00:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Kooooo`00:Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Kooooo`00:Oooool2o`00017ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05cooooo000Yooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo000Y
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05gooooo000Oooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool2o`00
00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo05Wooooo0_l00003ooooo`03o`000?oooooooooo05Wo
oooo0_l00003ooooo`;o0000H?ooool0027ooooo00?o0000ooooooooool01Oooool3o`0001Cooooo
1?l0001Mooooo`Go0000G?ooool5o`00067ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l00000
oooooom7ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To animate the plots, select all of the plots by clicking on the blue cell \
marker to the right that contains the plots (the one with the arrow on the \
bottom) . Then go to the main menu under ",
  StyleBox["Cell",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and select the command ",
  StyleBox["Animate Selected Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". (Or type  \[ControlKey]-",
  StyleBox["y",
    FontWeight->"Bold"],
  " under the Windows operating system , or ",
  StyleBox["\:fdff",
    FontFamily->"Chicago"],
  "-",
  StyleBox["y",
    FontWeight->"Bold"],
  " under the Macintosh operating system)."
}], "Text"],

Cell[TextData[{
  "\tNote that it is useful to specify the vertical range of the plots using \
the ",
  StyleBox["PlotRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, so that the axes of the graphs remain fixed during the \
animation."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.6.8 Add-On Packages", "Subsubtitle",
  CellTags->{"i:57", "c:34"}],

Cell[TextData[{
  "\tIn addition to the basic plotting functions that are intrinsic to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", there are many other types of plots that are only available if one loads \
in the appropriate ",
  StyleBox["add-on package ",
    FontSlant->"Italic"],
  "into memory. These add-on packages are ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks that have within them the definitions of various functions. To \
extend the capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", there are a whole series of  add-on packages. All graphics add-on \
packages can be loaded at once by simply typing ",
  StyleBox["<<Graphics`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". (",
  StyleBox["<<",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  is the notation used for loading external files. ",
  StyleBox["Graphics`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["context",
    FontSlant->"Italic"],
  ". Recall from Sec. ",
  ButtonBox["9.4.2",
    ButtonData:>"c:14",
    ButtonStyle->"Hyperlink"],
  " that a context is a \"surname\"  for a set of variables or functions.  In \
this case, the context refers to a collection of graphics functions and \
variables. All of the functions and variables in this context are loaded into \
memory when this command is evaluated. )"
}], "Text",
  CellTags->"i:113"],

Cell[TextData[{
  "\tTo load any particular one of these external notebooks, you can give the \
(full) name of that specific notebook. For instance, typing ",
  StyleBox["<<Graphics`Graphics3D` ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "loads only one notebook containing a set of functions having to do with 3D \
plots. You can see here that contexts can have sub-contexts: ",
  StyleBox["Graphics3D`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a subcontext (like a middle name) of ",
  StyleBox["Graphics`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\tIf we wish to plot the function ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(1/2\)\)]],
  " using logarithmic axes, we first load the graphics packages:"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.88"],

Cell[TextData[{
  "and then we can use the plot in Cell ",
  ButtonBox["9.89",
    ButtonData:>"Cell 9.89",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLogPlot[x\^\(1/2\), {x,  .1, 10\^3}, 
      PlotStyle \[Rule] Apricot]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.89"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.585358 0.520516 -0.361771 0.643393 [
[.09185 -0.0125 -8 -12 ]
[.09185 -0.0125 8 0 ]
[.29898 -0.0125 -8 -12 ]
[.29898 -0.0125 8 0 ]
[.45567 -0.0125 -11 -12 ]
[.45567 -0.0125 11 0 ]
[.61237 -0.0125 -11 -12 ]
[.61237 -0.0125 11 0 ]
[.8195 -0.0125 -11 -12 ]
[.8195 -0.0125 11 0 ]
[.97619 -0.0125 -14 -12 ]
[.97619 -0.0125 14 0 ]
[-0.0125 .28162 -16 -6 ]
[-0.0125 .28162 0 6 ]
[-0.0125 .39492 -16 -6 ]
[-0.0125 .39492 0 6 ]
[-0.0125 .4753 -16 -6 ]
[-0.0125 .4753 0 6 ]
[-0.0125 .5886 -16 -6 ]
[-0.0125 .5886 0 6 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09185 0 m
.09185 .00625 L
s
gsave
.09185 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.29898 0 m
.29898 .00625 L
s
gsave
.29898 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.45567 0 m
.45567 .00625 L
s
gsave
.45567 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.61237 0 m
.61237 .00625 L
s
gsave
.61237 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8195 0 m
.8195 .00625 L
s
gsave
.8195 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.18351 0 m
.18351 .00375 L
s
.24854 0 m
.24854 .00375 L
s
.3402 0 m
.3402 .00375 L
s
.37505 0 m
.37505 .00375 L
s
.40523 0 m
.40523 .00375 L
s
.43186 0 m
.43186 .00375 L
s
.70402 0 m
.70402 .00375 L
s
.76906 0 m
.76906 .00375 L
s
.86071 0 m
.86071 .00375 L
s
.89556 0 m
.89556 .00375 L
s
.92575 0 m
.92575 .00375 L
s
.95237 0 m
.95237 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .28162 m
.00625 .28162 L
s
gsave
-0.0125 .28162 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .39492 m
.00625 .39492 L
s
gsave
-0.0125 .39492 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4753 m
.00625 .4753 L
s
gsave
-0.0125 .4753 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .5886 m
.00625 .5886 L
s
gsave
-0.0125 .5886 -77 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .30825 m
.00375 .30825 L
s
0 .33257 m
.00375 .33257 L
s
0 .35493 m
.00375 .35493 L
s
0 .37564 m
.00375 .37564 L
s
0 .41295 m
.00375 .41295 L
s
0 .42989 m
.00375 .42989 L
s
0 .44586 m
.00375 .44586 L
s
0 .46097 m
.00375 .46097 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .34 .13 r
.5 Mabswid
0 0 m
.25226 .1559 L
.41867 .25875 L
.50872 .31441 L
.57079 .35277 L
.62224 .38457 L
.66269 .40957 L
.69898 .43199 L
.72917 .45065 L
.75485 .46652 L
.7793 .48163 L
.80058 .49479 L
.81931 .50636 L
.83768 .51772 L
.85406 .52784 L
.87026 .53785 L
.88483 .54686 L
.89802 .55501 L
.91126 .56319 L
.92331 .57063 L
.93544 .57814 L
.94655 .585 L
.95675 .59131 L
.96712 .59771 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00;oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0gooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01kooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^033o
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^01_ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`00;oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0jooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg02Gooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Nooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0cooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo000`ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@400kooooo`04o`000?oooooooooooa0@40?ooooo00?o410@oooooooo
ool08oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@
413ooooooooooooooooo410@01oooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@400dooooo`04o`000?oooooooooooa0@40?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo01_ooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001?ooool0037ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000003[ooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Pooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000<oooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool003;ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000003Oooooo00Go0000ob4Q8Ol0003o
<S8bolc<c002ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000027ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00000`ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Cooooo000cooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400U
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41008_ooool01Ol0003ooooooooooooooooo410@00?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo02kooooo00?o0000ooooooooool01?ooool01Ol@
413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@400Mooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Cooooo000_ooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Oooooo00?o0000ooooooooool01?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg02Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`05o`000?nj^[[ooooooiRH
V?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0`ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL07Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`04ooooo`00;oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0gooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02?ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0N
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0`ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Kooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo000Hooooo`;ooeLQool00015o`0000[ooooo000H
ooooo`03o`000?oooooooeLQ01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00;ooeLQ6?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04?ooool001So
oooo00?o0000ooooooooool00_ooool2oomG8OooooooB_ooool001Sooooo00?o0000ooooooooool0
1?ooool00oooEb7oooooooooo`3oooooodOooooo000Hooooo`03o`000?oooooooooo00Gooooo0_oo
Eb7oooooodOooooo000Hooooo`03o`000?oooooooooo00Oooooo00?ooeLQooooooooool0oooooom4
ooooo`006?ooool00ol0003oooooooooo`08ooooo`;ooeLQoooooom4ooooo`006?ooool00ol0003o
ooooooooo`0:ooooo`;ooeLQoooooom2ooooo`006?ooool00ol0003oooooooooo`0<ooooo`03oomG
8Ooooooooooo0?oooooo?oooool001Sooooo00?o0000ooooooooool03Oooool2oomG8Ooooooo?ooo
ool001Sooooo00?o0000ooooooooool03oooool00oooEb7oooooooooo`3ooooooccooooo000Hoooo
o`03o`000?oooooooooo013ooooo0_ooEb7ooooooccooooo000Hooooo`03o`000?oooooooooo01;o
oooo0_ooEb7ooooooc[ooooo000Hooooo`03o`000?oooooooooo01Cooooo00?ooeLQooooooooool0
oooooolgooooo`006?ooool00ol0003oooooooooo`0Eooooo`;ooeLQoooooolgooooo`006?ooool0
0ol0003oooooooooo`0Gooooo`;ooeLQooooooleooooo`006?ooool00ol0003oooooooooo`0Ioooo
o`03oomG8Ooooooooooo0?oooooo<_ooool001Sooooo00?o0000ooooooooool06_ooool2oomG8Ooo
oooo<_ooool001Sooooo00?o0000ooooooooool07?ooool00oooEb7oooooooooo`3ooooooboooooo
000Hooooo`03o`000?oooooooooo01gooooo0_ooEb7ooooooboooooo000Hooooo`03o`000?oooooo
oooo01oooooo0_ooEb7oooooobgooooo000Hooooo`03o`000?oooooooooo027ooooo00?ooeLQoooo
ooooool0oooooolZooooo`006?ooool00ol0003oooooooooo`0Rooooo`;ooeLQoooooolZooooo`00
6?ooool00ol0003oooooooooo`0Tooooo`03oomG8Ooooooooooo0?oooooo9oooool001Sooooo00?o
0000ooooooooool09Oooool2oomG8Ooooooo9oooool001Sooooo00?o0000ooooooooool09oooool2
oomG8Ooooooo9Oooool001Sooooo00?o0000ooooooooool0:Oooool00oooEb7oooooooooo`3ooooo
ob;ooooo000Hooooo`03o`000?oooooooooo02[ooooo0_ooEb7oooooob;ooooo000Hooooo`03o`00
0?oooooooooo02cooooo00?ooeLQooooooooool0oooooolOooooo`006?ooool00ol0003ooooooooo
o`0]ooooo`;ooeLQoooooolOooooo`006?ooool00ol0003oooooooooo`0_ooooo`;ooeLQoooooolM
ooooo`006?ooool00ol0003oooooooooo`0aooooo`03oomG8Ooooooooooo0?oooooo6_ooool001So
oooo00?o0000ooooooooool0<_ooool2oomG8Ooooooo6_ooool001Sooooo00?o0000ooooooooool0
=?ooool00oooEb7oooooooooo`3ooooooaOooooo000Hooooo`03o`000?oooooooooo03Gooooo0_oo
Eb7ooooooaOooooo000Hooooo`03o`000?oooooooooo03Oooooo0_ooEb7ooooooaGooooo000Hoooo
o`03o`000?oooooooooo03Wooooo00?ooeLQooooooooool0oooooolBooooo`006?ooool00ol0003o
ooooooooo`0jooooo`;ooeLQoooooolBooooo`006?ooool00ol0003oooooooooo`0looooo`;ooeLQ
ooooool@ooooo`006?ooool00ol0003oooooooooo`0nooooo`03oomG8Ooooooooooo0?oooooo3Ooo
ool001Sooooo00?o0000ooooooooool0?oooool2oomG8Ooooooo3Oooool001Sooooo00?o0000oooo
ooooool0@Oooool00oooEb7oooooooooo`3oooooo`[ooooo000Hooooo`03o`000?oooooooooo04;o
oooo0_ooEb7oooooo`[ooooo000Hooooo`03o`000?oooooooooo04Cooooo0_ooEb7oooooo`Sooooo
000Hooooo`03o`000?oooooooooo04Kooooo00?ooeLQooooooooool0ooooool5ooooo`006?ooool0
0ol0003oooooooooo`17ooooo`;ooeLQooooool5ooooo`006?ooool00ol0003oooooooooo`19oooo
o`03oomG8Ooooooooooo0?oooooo0_ooool001Sooooo00?o0000ooooooooool0B_ooool2oomG8Ooo
oooo0_ooool001Sooooo00?o0000ooooooooool0C?ooool2oomG8Ooooooo000Hooooo`03o`000?oo
oooooooo04kooooo00?ooeLQooooooooool0o?ooool001Sooooo00?o0000ooooooooool0Coooool2
oomG8Ocooooo000Hooooo`03o`000?oooooooooo057ooooo00?ooeLQooooooooool0nOooool001So
oooo00?o0000ooooooooool0D_ooool2oomG8OWooooo000Hooooo`03o`000?oooooooooo05Cooooo
0_ooEb7gooooo`006?ooool00ol0003oooooooooo`1Fooooo`03oomG8Ooooooooooo0?Cooooo000H
ooooo`03o`000?oooooooooo05Oooooo0_ooEb7dooooo`006?ooool00ol0003oooooooooo`1Ioooo
o`;ooeLQl_ooool001Sooooo00?o0000ooooooooool0Foooool00oooEb7oooooooooo`3_ooooo`00
6?ooool00ol0003oooooooooo`1Looooo`;ooeLQkoooool001Sooooo00?o0000ooooooooool0G_oo
ool2oomG8Ngooooo000Hooooo`03o`000?oooooooooo063ooooo00?ooeLQooooooooool0j_ooool0
01Sooooo00?o0000ooooooooool0HOooool2oomG8N[ooooo000Hooooo`03o`000?oooooooooo06?o
oooo00?ooeLQooooooooool0ioooool001Sooooo00?o0000ooooooooool0I?ooool2oomG8NOooooo
000Hooooo`03o`000?oooooooooo06Kooooo0_ooEb7Uooooo`006?ooool00ol0003oooooooooo`1X
ooooo`03oomG8Ooooooooooo0>;ooooo000Hooooo`03o`000?oooooooooo06Wooooo0_ooEb7Roooo
o`006?ooool00ol0003oooooooooo`1[ooooo`;ooeLQh?ooool001Sooooo00?o0000ooooooooool0
KOooool00oooEb7oooooooooo`3Mooooo`006?ooool00ol0003oooooooooo`1^ooooo`;ooeLQgOoo
ool001Sooooo00?o0000ooooooooool0L?ooool2oomG8M_ooooo000Hooooo`03o`000?oooooooooo
07;ooooo00?ooeLQooooooooool0f?ooool001Sooooo00?o0000ooooooooool0Loooool2oomG8MSo
oooo000Hooooo`03o`000?oooooooooo07Gooooo00?ooeLQooooooooool0eOooool001Sooooo00?o
0000ooooooooool0M_ooool2oomG8MGooooo000Hooooo`03o`000?oooooooooo07Sooooo0_ooEb7C
ooooo`006?ooool00ol0003oooooooooo`1jooooo`03oomG8Ooooooooooo0=3ooooo000Hooooo`03
o`000?oooooooooo07_ooooo0_ooEb7@ooooo`006?ooool00ol0003oooooooooo`1mooooo`;ooeLQ
c_ooool001Sooooo00?o0000ooooooooool0Ooooool00oooEb7oooooooooo`3;ooooo`006?ooool0
0ol0003oooooooooo`20ooooo`;ooeLQboooool001Sooooo00?o0000ooooooooool0P_ooool2oomG
8LWooooo000Hooooo`03o`000?oooooooooo08Cooooo00?ooeLQooooooooool0a_ooool001Sooooo
00?o0000ooooooooool0QOooool2oomG8LKooooo000Hooooo`03o`000?oooooooooo08Oooooo00?o
oeLQooooooooool0`oooool001Sooooo00?o0000ooooooooool0R?ooool2oomG8L?ooooo000Hoooo
o`03o`000?oooooooooo08[ooooo0_ooEb71ooooo`006?ooool00ol0003oooooooooo`2<ooooo`03
oomG8Ooooooooooo0;kooooo0004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPSooooo00?o0000ooooooooool0SOooool2oomG8Kkooooo0006ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo08oooooo00?ooeLQ
ooooooooool0^oooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Sooooo0ol0002@ooooo`;ooeLQ^oooool000Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0T_ooool2oomG8KWooooo0006oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo09Cooooo00?ooeLQooooooooool0]_ooool000Kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0UOooool2oomG8KKooooo0006oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo09Oooooo0_ooEb6dooooo`001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`2Iooooo`03oomG8Ooooooooooo0;7ooooo000Hoooo
o`03o`000?oooooooooo09[ooooo0_ooEb6aooooo`006?ooool00ol0003oooooooooo`2Looooo`03
oomG8Ooooooooooo0:kooooo000Hooooo`03o`000?oooooooooo09gooooo0_ooEb6^ooooo`006?oo
ool2o`000:3ooooo0_ooEb6/ooooo`006?ooool00ol0003oooooooooo`2Qooooo`03oomG8Ooooooo
oooo0:Wooooo000Hooooo`03o`000?oooooooooo0:;ooooo0_ooEb6Yooooo`006?ooool00ol0003o
ooooooooo`2Tooooo`03oomG8Ooooooooooo0:Kooooo000Hooooo`03o`000?oooooooooo0:Gooooo
0_ooEb6Vooooo`006?ooool00ol0003oooooooooo`2Wooooo`03oomG8Ooooooooooo0:?ooooo000H
ooooo`03o`000?oooooooooo0:Sooooo0_ooEb6Sooooo`006?ooool00ol0003oooooooooo`2Zoooo
o`03oomG8Ooooooooooo0:3ooooo000Hooooo`;o0000[?ooool2oomG8J3ooooo000Hooooo`03o`00
0?oooooooooo0:gooooo0_ooEb6Nooooo`006?ooool00ol0003oooooooooo`2_ooooo`03oomG8Ooo
oooooooo09_ooooo000Hooooo`03o`000?oooooooooo0;3ooooo0_ooEb6Kooooo`006?ooool00ol0
003oooooooooo`2booooo`03oomG8Ooooooooooo09Sooooo000Hooooo`03o`000?oooooooooo0;?o
oooo0_ooEb6Hooooo`006?ooool00ol0003oooooooooo`2eooooo`03oomG8Ooooooooooo09Gooooo
000Hooooo`;o0000]oooool2oomG8IGooooo000Hooooo`03o`000?oooooooooo0;Sooooo0_ooEb6C
ooooo`006?ooool00ol0003oooooooooo`2jooooo`03oomG8Ooooooooooo093ooooo000Hooooo`03
o`000?oooooooooo0;_ooooo0_ooEb6@ooooo`006?ooool00ol0003oooooooooo`2mooooo`;ooeLQ
S_ooool001Sooooo00?o0000ooooooooool0_oooool00oooEb7oooooooooo`2;ooooo`006?ooool0
0ol0003oooooooooo`30ooooo`;ooeLQRoooool001Sooooo0_l00033ooooo`;ooeLQROooool001So
oooo00?o0000ooooooooool0a?ooool00oooEb7oooooooooo`26ooooo`006?ooool00ol0003ooooo
ooooo`35ooooo`;ooeLQQ_ooool001Sooooo00?o0000ooooooooool0aoooool2oomG8HCooooo0004
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Kooooo00?o
0000ooooooooool0bOooool00oooEb7oooooooooo`21ooooo`001_ooool00ol0003oooooooooo`06
ooooo`03ogMgMolb<S;ooooo00Kooooo00?o0000ooooooooool0b_ooool2oomG8H7ooooo0006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool3o`000<cooooo0_ooEb5ooooo
o`001_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Kooooo00?o0000oooooooo
ool0c_ooool00oooEb7oooooooooo`1looooo`001_ooool00ol0003oooooooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01oooool00ol0003oooooooooo`3?ooooo`;ooeLQO?ooool000Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=7ooooo
0_ooEb5jooooo`001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0doooool00oooEb7oooooooooo`1gooooo`001?ooool00omEEEGoIVIVo`000005
ooooo`Co00002?ooool00ol0003oooooooooo`3Dooooo`;ooeLQMoooool001Sooooo0_l0003Goooo
o`;ooeLQMOooool001Sooooo00?o0000ooooooooool0f?ooool00oooEb7oooooooooo`1booooo`00
6?ooool00ol0003oooooooooo`3Iooooo`;ooeLQL_ooool001Sooooo00?o0000ooooooooool0fooo
ool2oomG8G3ooooo000Hooooo`03o`000?oooooooooo0=gooooo00?ooeLQooooooooool0KOooool0
01Sooooo00?o0000ooooooooool0g_ooool2oomG8Fgooooo000Hooooo`;o0000hOooool2oomG8F_o
oooo000Hooooo`03o`000?oooooooooo0>;ooooo0_ooEb5Yooooo`006?ooool00ol0003ooooooooo
o`3Tooooo`03oomG8Ooooooooooo06Kooooo000Hooooo`03o`000?oooooooooo0>Gooooo0_ooEb5V
ooooo`006?ooool00ol0003oooooooooo`3Wooooo`;ooeLQI?ooool001Sooooo0_l0003Zooooo`03
oomG8Ooooooooooo067ooooo000Hooooo`03o`000?oooooooooo0>[ooooo0_ooEb5Qooooo`006?oo
ool00ol0003oooooooooo`3/ooooo`03oomG8Ooooooooooo05kooooo000Hooooo`03o`000?oooooo
oooo0>gooooo00?ooeLQooooooooool0GOooool001Sooooo00?o0000ooooooooool0k_ooool2oomG
8Egooooo000Hooooo`;o0000lOooool00oooEb7oooooooooo`1Jooooo`006?ooool00ol0003ooooo
ooooo`3aooooo`03oomG8Ooooooooooo05Wooooo0003ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0l_ooool2oomG8EWooooo0003ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000oooooooo
ool0m?ooool2oomG8EOooooo0004ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4008ooooo`?o0000m_ooool2oomG8EGooooo0005ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?Sooooo0_ooEb5Cooooo`00
1_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3jooooo`;ooeLQDOooool000Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Kooooo00?o0000ooooooooool0o?ooool00oooEb7oooooooooo`1>ooooo`00
0oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?gooooo0_ooEb5>ooooo`000oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?oooooo00?ooeLQ
ooooooooool0Boooool001Sooooo00?o0000ooooooooool0ooooool1ooooo`03oomG8Ooooooooooo
04[ooooo000Hooooo`03o`000?oooooooooo0?oooooo0_ooool2oomG8D[ooooo000Hooooo`03o`00
0?oooooooooo0?oooooo1?ooool00oooEb7oooooooooo`17ooooo`006?ooool00ol0003ooooooooo
o`3oooooo`Gooooo0_ooEb57ooooo`006?ooool00ol0003oooooooooo`3oooooo`Oooooo00?ooeLQ
ooooooooool0A?ooool001Sooooo00?o0000ooooooooool0ooooool8ooooo`;ooeLQA?ooool001So
oooo00?o0000ooooooooool0ooooool:ooooo`;ooeLQ@_ooool001Sooooo00?o0000ooooooooool0
ooooool<ooooo`;ooeLQ@?ooool001Sooooo00?o0000ooooooooool0ooooool>ooooo`;ooeLQ?_oo
ool001Sooooo00?o0000ooooooooool0ooooool@ooooo`;ooeLQ??ooool001Sooooo00?o0000oooo
ooooool0oooooolBooooo`03oomG8Ooooooooooo03Wooooo000Hooooo`03o`000?oooooooooo0?oo
oooo4oooool2oomG8CWooooo000Hooooo`03o`000?oooooooooo0?oooooo5Oooool00oooEb7ooooo
ooooo`0fooooo`006?ooool00ol0003oooooooooo`3ooooooaKooooo0_ooEb4fooooo`006?ooool0
0ol0003oooooooooo`3ooooooaSooooo00?ooeLQooooooooool0<oooool001Sooooo00?o0000oooo
ooooool0oooooolIooooo`;ooeLQ<oooool001Sooooo00?o0000ooooooooool0oooooolKooooo`03
oomG8Ooooooooooo033ooooo000Hooooo`03o`000?oooooooooo0?oooooo7?ooool00oooEb7ooooo
ooooo`0_ooooo`006?ooool00ol0003oooooooooo`3ooooooagooooo0_ooEb4_ooooo`006?ooool0
0ol0003oooooooooo`3ooooooaoooooo0oooEb4/ooooo`006?ooool00ol0003oooooooooo`3ooooo
ob;ooooo0_ooEb4Zooooo`006?ooool00ol0003oooooooooo`3oooooobCooooo00?ooeLQoooooooo
ool09oooool001Sooooo00?o0000ooooooooool0oooooolUooooo`03oomG8Ooooooooooo02Kooooo
000Hooooo`03o`000?oooooooooo0?oooooo9_ooool2oomG8BKooooo000Hooooo`03o`000?oooooo
oooo0?oooooo:?ooool2oomG8BCooooo000Hooooo`03o`000?oooooooooo0?oooooo:_ooool2oomG
8B;ooooo000Hooooo`03o`000?oooooooooo0?oooooo;?ooool00oooEb7oooooooooo`0Oooooo`00
6?ooool00ol0003oooooooooo`3oooooobgooooo00?ooeLQooooooooool07_ooool001Sooooo00?o
0000ooooooooool0ooooool^ooooo`;ooeLQ7_ooool000?ooooo00GoV9RHoa0@4?l0003o<S8bolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3ooooooc3ooooo
00?ooeLQooooooooool06oooool000?ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`3ooooooc7ooooo0_ooEb4Kooooo`00
1oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01_ooool3o`000?oo
oooo<oooool2oomG8AWooooo0006ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?oooooo=Oooool2oomG8AOooooo0005ooooo`03oa0@
4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
oooo=oooool00oooEb7oooooooooo`0Dooooo`001_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`3oooooocSooooo0_ooEb4Dooooo`00
0oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?oooooo>_ooool00oooEb7oooooooooo`0Aooooo`000oooool01OnYZJWo
410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooo
oooo0?oooooo>oooool00oooEb7oooooooooo`0@ooooo`006?ooool00ol0003oooooooooo`3ooooo
odkooooo000Hooooo`03o`000?oooooooooo0?ooooooC_ooool001Sooooo00?o0000ooooooooool0
oooooom>ooooo`006?ooool00ol0003oooooooooo`3oooooodkooooo000Hooooo`03o`000?oooooo
oooo0?ooooooC_ooool00001\
\>"],
  ImageRangeCache->{{{76, 363}, {380.875, 203.938}} -> {0.420586, 1.68742, \
0.0073909, 0.00597936}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We also added an option to color the line, with an argument ",
  StyleBox["Apricot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "that was defined in the graphics add-on packages. The add-on package \
allows us to define colors simply as ",
  StyleBox["Red",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Green",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Blue",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc. A full list of defined colors can be found in the add-on file ",
  Cell[BoxData[
      \(TraditionalForm\`Graphics`Colors`\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "\tHowever, a problem call ",
  StyleBox["shadowing",
    FontSlant->"Italic"],
  " can develop if one tries to use a function or variable before it has been \
defined by loading the appropriate add-on package. For example, if we quit \
the kernel, and try to recreate the previous plot, we are thwarted because \
the function ",
  StyleBox["LogLogPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is no-longer defined:"
}], "Text",
  CellTags->"i:120"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLogPlot[x\^\(1/2\), {x,  .1, 10\^3}, 
      PlotStyle \[Rule] Apricot]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.90"],

Cell[BoxData[
    \(LogLogPlot[\@x, {x, 0.1`, 1000}, PlotStyle \[Rule] Apricot]\)], "Output"]
}, Open  ]],

Cell["\<\
Now if we load the graphics packages and repeat the evaluation, we \
would expect to the plot to work. But it does not:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(LogLogPlot[x\^\(1/2\), {x,  .1, 10\^3}, 
      PlotStyle \[Rule] Apricot]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.91"],

Cell[BoxData[
    \(LogLogPlot[\@x, {x, 0.1`, 1000}, PlotStyle \[Rule] Apricot]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is a common problem, responsible for much confusion and gnashing of \
teeth among beginning users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The reason that this does not work is that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remembers that we previously used a function named ",
  StyleBox["LogLogPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " , and thinks we mean this function, whose full name is ",
  StyleBox["Global`LogLogPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  However, we really mean \n",
  StyleBox["Graphics`Graphics`LogLogPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The former name ",
  StyleBox["shadows ",
    FontSlant->"Italic"],
  " the latter: ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by default assumes that the short form ",
  Cell[BoxData[
      FormBox[
        StyleBox["LogLogPlot",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " means the user-defined function, not the add-on function.  In fact, if we \
use the latter's full name in Cell ",
  ButtonBox["9.91",
    ButtonData:>"Cell 9.91",
    ButtonStyle->"Hyperlink"],
  ", the plot works (try it!). Question: how could we get the variable ",
  StyleBox["Apricot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to work again? (Hint: What is its full name?)\n\t Rather than typing the \
full name, we can use a different method to restore this graphics function:  \
delete memory of ",
  StyleBox["Global`LogLogPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " using ",
  StyleBox["Remove[LogLogPlot]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that  ",
  StyleBox["Clear[LogLogPlot]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "does not work: this command only clears the definition (if any) of the \
function, but does not remove it from the list of user-defined variables.  \
Once ",
  StyleBox["Remove",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is applied, evaluation of Cell ",
  ButtonBox["9.91",
    ButtonData:>"Cell 9.91",
    ButtonStyle->"Hyperlink"],
  " will produce the desired plot. "
}], "Text"],

Cell[TextData[{
  "\tIn addition to the add-on packages that come with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", various add-on packages written by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users can be found on the world wide web. One particularly useful website \
in this regard is ",
  ButtonBox["http://library.wolfram.com/database/MathSource/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/database/MathSource/"], None},
    ButtonStyle->"Hyperlink"],
  ". There, one can find a large collection of notebooks that extend the \
capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". For example, the ExtendGraphics packages written by Tom Wickham-Jones \
contain functions that allow one to add labels to contours in contour plots, \
or perform contour plots of discrete data distributed on an irregular grid. \
An updated version of the contour labelling routine is also available as a \
stand-alone add-on package named ",
  StyleBox["LabelContour.m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".. Once this file has been downloaded from the above website and placed in \
any directory where ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " searches for files (such as a users home directory, or the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " folder), it can be loaded via the command"
}], "Text",
  CellTags->"i:114"],

Cell[BoxData[
    \(<< LabelContour`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.92"],

Cell[TextData[{
  "(For more on loading external files, see the discussion of the ",
  StyleBox["Directory",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SetDirectory",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands in Sec. ",
  ButtonBox["9.11.4",
    ButtonData:>"c:82",
    ButtonStyle->"Hyperlink"],
  ".) This add-on package defines the graphics functions ",
  StyleBox["LabelContourLines",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["LabelContourLegend",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", examples of which are shown in Cell ",
  ButtonBox["9.93",
    ButtonData:>{"", "Cell 9.93"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(c = 
          ContourPlot[
            x^2\  - \ y^2 - 2  y - Sin[x\ y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
            ContourShading \[Rule] True, 
            Contours \[Rule] Table[i, {i, \(-5\), 3, 2}], 
            DisplayFunction \[Rule] Identity, PlotPoints \[Rule] 20];\), 
      "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(LabelContourLines[c, LabelSize \[Rule] 14, 
          LabelColor \[Rule] RGBColor[1, 0, 0], LabelFont -> "\<Courier\>", 
          LabelWeight -> "\<Bold\>", LabelSlant -> "\<Italic\>"];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"LabelContourLegend", "[", 
        RowBox[{
        "c", ",", \(LabelSize \[Rule] 12\), ",", \(LabelFont -> "\<Times\>"\),
           ",", 
          RowBox[{"HeightName", "->", "\"\<\[CapitalPhi](\!\(\*
StyleBox[\"x\",\nFontSlant->\"Italic\"]\),\!\(\*
StyleBox[\"y\",\nFontSlant->\"Italic\"]\))\>\""}]}], "]"}], ";"}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.93"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.5 0.238095 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .2619 -12 -4.5 ]
[-0.0125 .2619 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .7381 -6 -4.5 ]
[-0.0125 .7381 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-2)] -0.0125 .02381 1 0 Mshowa
0 .2619 m
.00625 .2619 L
s
[(-1)] -0.0125 .2619 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .7381 m
.00625 .7381 L
s
[(1)] -0.0125 .7381 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(2)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .21429 m
.00375 .21429 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .40476 m
.00375 .40476 L
s
0 .45238 m
.00375 .45238 L
s
0 .54762 m
.00375 .54762 L
s
0 .59524 m
.00375 .59524 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .78571 m
.00375 .78571 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.2619 .99375 m
.2619 1 L
s
.5 .99375 m
.5 1 L
s
.7381 .99375 m
.7381 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.21429 .99625 m
.21429 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.40476 .99625 m
.40476 1 L
s
.45238 .99625 m
.45238 1 L
s
.54762 .99625 m
.54762 1 L
s
.59524 .99625 m
.59524 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.78571 .99625 m
.78571 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .2619 m
1 .2619 L
s
.99375 .5 m
1 .5 L
s
.99375 .7381 m
1 .7381 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.02381 .97619 m
.97619 .97619 L
.97619 .02381 L
.02381 .02381 L
F
.428 g
.02381 .85347 m
.07393 .83476 L
.09607 .82581 L
.12406 .81356 L
.17419 .78736 L
.19326 .77569 L
.22431 .75493 L
.26372 .72556 L
.27444 .71736 L
.32456 .67903 L
.32941 .67544 L
.37469 .64534 L
.41166 .62531 L
.42481 .6197 L
.47494 .60343 L
.52506 .59602 L
.57519 .59633 L
.62531 .60296 L
.67544 .61471 L
.71079 .62531 L
.72556 .63079 L
.77569 .65102 L
.82481 .67544 L
.82581 .67601 L
.87594 .70807 L
.89795 .72556 L
.92607 .75318 L
.94442 .77569 L
.97619 .82555 L
.97619 .97619 L
.02381 .97619 L
F
0 g
.001 w
.02381 .85347 m
.07393 .83476 L
.09607 .82581 L
.12406 .81356 L
.17419 .78736 L
.19326 .77569 L
.22431 .75493 L
.26372 .72556 L
.27444 .71736 L
.32456 .67903 L
.32941 .67544 L
.37469 .64534 L
.41166 .62531 L
.42481 .6197 L
.47494 .60343 L
.52506 .59602 L
.57519 .59633 L
.62531 .60296 L
.67544 .61471 L
.71079 .62531 L
.72556 .63079 L
.77569 .65102 L
.82481 .67544 L
.82581 .67601 L
.87594 .70807 L
.89795 .72556 L
.92607 .75318 L
.94442 .77569 L
.97619 .82555 L
s
.256 g
.02381 .91948 m
.07393 .90518 L
.12406 .89223 L
.17419 .87806 L
.1809 .87594 L
.22431 .86069 L
.27444 .83893 L
.30091 .82581 L
.32456 .81357 L
.37469 .78737 L
.39824 .77569 L
.42481 .76376 L
.47494 .74516 L
.52506 .73262 L
.57519 .72629 L
.62531 .72592 L
.67544 .73131 L
.72556 .74257 L
.77569 .76057 L
.80657 .77569 L
.82581 .78766 L
.87277 .82581 L
.87594 .82907 L
.91471 .87594 L
.92607 .89227 L
.94863 .92607 L
.97619 .96371 L
.97619 .97619 L
.02381 .97619 L
F
0 g
.02381 .91948 m
.07393 .90518 L
.12406 .89223 L
.17419 .87806 L
.1809 .87594 L
.22431 .86069 L
.27444 .83893 L
.30091 .82581 L
.32456 .81357 L
.37469 .78737 L
.39824 .77569 L
.42481 .76376 L
.47494 .74516 L
.52506 .73262 L
.57519 .72629 L
.62531 .72592 L
.67544 .73131 L
.72556 .74257 L
.77569 .76057 L
.80657 .77569 L
.82581 .78766 L
.87277 .82581 L
.87594 .82907 L
.91471 .87594 L
.92607 .89227 L
.94863 .92607 L
.97619 .96371 L
s
.772 g
.02381 .779 m
.02965 .77569 L
.07393 .74779 L
.10213 .72556 L
.12406 .70586 L
.15199 .67544 L
.17419 .64783 L
.18984 .62531 L
.2213 .57519 L
.22431 .57032 L
.24892 .52506 L
.27409 .47494 L
.27444 .47449 L
.29521 .42481 L
.31026 .37469 L
.31196 .32456 L
.29359 .27444 L
.27444 .22909 L
.27125 .22431 L
.24551 .17419 L
.22731 .12406 L
.22431 .11359 L
.21247 .07393 L
.19993 .02381 L
.02381 .02381 L
F
0 g
.02381 .779 m
.02965 .77569 L
.07393 .74779 L
.10213 .72556 L
.12406 .70586 L
.15199 .67544 L
.17419 .64783 L
.18984 .62531 L
.2213 .57519 L
.22431 .57032 L
.24892 .52506 L
.27409 .47494 L
.27444 .47449 L
.29521 .42481 L
.31026 .37469 L
.31196 .32456 L
.29359 .27444 L
.27444 .22909 L
.27125 .22431 L
.24551 .17419 L
.22731 .12406 L
.22431 .11359 L
.21247 .07393 L
.19993 .02381 L
s
1 g
.02381 .67409 m
.0548 .62531 L
.07393 .57675 L
.07433 .57519 L
.0849 .52506 L
.08886 .47494 L
.08844 .42481 L
.08644 .37469 L
.08564 .32456 L
.0875 .27444 L
.09163 .22431 L
.09657 .17419 L
.10078 .12406 L
.10292 .07393 L
.10171 .02381 L
.02381 .02381 L
F
0 g
.02381 .67409 m
.0548 .62531 L
.07393 .57675 L
.07433 .57519 L
.0849 .52506 L
.08886 .47494 L
.08844 .42481 L
.08644 .37469 L
.08564 .32456 L
.0875 .27444 L
.09163 .22431 L
.09657 .17419 L
.10078 .12406 L
.10292 .07393 L
.10171 .02381 L
s
.89829 .97619 m
.87594 .94913 L
.8559 .92607 L
.82581 .89699 L
.79875 .87594 L
.77569 .86231 L
.72556 .84123 L
.67544 .82987 L
.62531 .82619 L
.57519 .8292 L
.52506 .83838 L
.47494 .85317 L
.42481 .87237 L
.41622 .87594 L
.37469 .89372 L
.32456 .91403 L
.28955 .92607 L
.27444 .93057 L
.22431 .94267 L
.17419 .95157 L
.12406 .95953 L
.07393 .96923 L
.04785 .97619 L
F
.89829 .97619 m
.87594 .94913 L
.8559 .92607 L
.82581 .89699 L
.79875 .87594 L
.77569 .86231 L
.72556 .84123 L
.67544 .82987 L
.62531 .82619 L
.57519 .8292 L
.52506 .83838 L
.47494 .85317 L
.42481 .87237 L
.41622 .87594 L
.37469 .89372 L
.32456 .91403 L
.28955 .92607 L
.27444 .93057 L
.22431 .94267 L
.17419 .95157 L
.12406 .95953 L
.07393 .96923 L
.04785 .97619 L
s
.772 g
.97619 .67467 m
.92607 .62903 L
.9214 .62531 L
.87594 .5919 L
.85169 .57519 L
.82581 .55796 L
.77596 .52506 L
.77569 .52489 L
.72556 .49169 L
.70113 .47494 L
.67544 .45755 L
.62984 .42481 L
.62531 .42163 L
.57519 .38242 L
.56765 .37469 L
.52506 .33275 L
.52222 .32456 L
.5031 .27444 L
.50641 .22431 L
.52238 .17419 L
.52506 .16619 L
.54589 .12406 L
.57387 .07393 L
.57519 .07201 L
.60865 .02381 L
.97619 .02381 L
F
0 g
.97619 .67467 m
.92607 .62903 L
.9214 .62531 L
.87594 .5919 L
.85169 .57519 L
.82581 .55796 L
.77596 .52506 L
.77569 .52489 L
.72556 .49169 L
.70113 .47494 L
.67544 .45755 L
.62984 .42481 L
.62531 .42163 L
.57519 .38242 L
.56765 .37469 L
.52506 .33275 L
.52222 .32456 L
.5031 .27444 L
.50641 .22431 L
.52238 .17419 L
.52506 .16619 L
.54589 .12406 L
.57387 .07393 L
.57519 .07201 L
.60865 .02381 L
s
1 g
.97619 .55721 m
.93994 .52506 L
.92607 .51263 L
.88619 .47494 L
.87594 .46484 L
.83951 .42481 L
.82581 .40856 L
.80176 .37469 L
.77569 .32944 L
.77358 .32456 L
.75561 .27444 L
.74857 .22431 L
.75442 .17419 L
.77569 .12576 L
.77912 .12406 L
.82581 .08385 L
.8453 .07393 L
.87594 .06078 L
.92607 .03885 L
.95215 .02381 L
.97619 .02381 L
F
0 g
.97619 .55721 m
.93994 .52506 L
.92607 .51263 L
.88619 .47494 L
.87594 .46484 L
.83951 .42481 L
.82581 .40856 L
.80176 .37469 L
.77569 .32944 L
.77358 .32456 L
.75561 .27444 L
.74857 .22431 L
.75442 .17419 L
.77569 .12576 L
.77912 .12406 L
.82581 .08385 L
.8453 .07393 L
.87594 .06078 L
.92607 .03885 L
.95215 .02381 L
s
gsave
.47494 .60343 -75.5625 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
71.375 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1.) show
88.125 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52506 .73262 -75.5625 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
71.375 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(3.) show
88.125 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27409 .47494 -71.375 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1.) show
79.750 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.08644 .37469 -71.375 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(3.) show
79.750 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47494 .85317 -75.5625 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
71.375 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(5.) show
88.125 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62531 .42163 -71.375 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1.) show
79.750 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.77358 .32456 -71.375 -12 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24 translate 1 -1 scale
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(3.) show
79.750 16.000 moveto
%%IncludeResource: font Courier-BoldItalic
%%IncludeFont: Courier-BoldItalic
/Courier-BoldItalic findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007?ooool5
o`0004gooooo1?l000000ol@413oooooooooo`15ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0C?oo
ool4o`000003oa0@4?oooooooooo04Wooooo1Ol00008ooooo`007?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A404oooooo00?o0000ooooooooool0Aoooool01OmgMgOoV9RHoooooonHV9SoMgMg04kooooo
00?o0000ooooooooool0Boooool01OnHV9So8B4Qonk^k_ooooooA4A400Sooooo000Dooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP15ooooo`Ko00001Oooool00ol0003oooooooooo`17ooooo`05oa0@
4?ooooooooooooooool@4100C_ooool00ol0003oooooooooo`1<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo000Nooooo`03oiRHV?lQ8B7ok^k^04oooooo00?o0000ooooooooool0Aoooool01Ol0003ooooo
oooooooooooo000004kooooo00?o0000ooooooooool0COooool00onHV9So8B4Qonk^kP08ooooo`00
7oooool00omgMgOoIVIVooooo`1>ooooo`03o`000?oooooooooo04Oooooo00Go0000oooooooooooo
ooooo`00001>ooooo`03o`000?oooooooooo04kooooo00?oMgMgofIVI_ooool01oooool0023ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`17ooooo`05oa0@4?ooooooooooooooool@
4100C_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Kooooo000Looooo`05o`00
0?nj^[[ooooooiRHV?l@4100Coooool00ol0003oooooooooo`17ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0C_ooool00ol0003oooooooooo`1;ooooo`05o`000?nj^[[ooooooiRHV?l@41002?ooool0
01cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01=ooooo`03oeEEEOmVIVKo000004Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP1<ooooo`03oeEEEOmVIVKo000004gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c008ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`004oooooooo`0005Go00000Oooool001?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`05ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool0oooooomAooooo`7o00000Oooool000Sooooo1Ol00006ooooo`03o`000?oooooo
oooo0?ooooooDOooool1o`00007ooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool0
0ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`001_l00003ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo0ol0000Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Qoooool00ol0
003oooooooooo`1aooooo`;o00003Oooool3o`00007ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo00?o0000ooooooooool07oooool00ol0003oaLG5olG5a@0OolG5a@03o`000?nIVIWoVIVI08Oo
VIVI00?o0000olG5aOo5aLD0Koo5aLD2o`00017ooooo0Ol00001ooooo`002oooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000olG5aOo5aLD07oo5aLD00ol0003oVIVI
oiVIV@26oiVIV@03o`000?o5aLGoaLG506koaLG50_l0000Cooooo`7o00000Oooool000cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG5023oaLG500?o
0000oiVIVOnIVIT0Q?nIVIT00ol0003oaLG5olG5a@1^olG5a@03o`000?oooooooooo01?ooooo0Ol0
0001ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool07ooo
ool00ol0003oaLG5olG5a@0PolG5a@03o`000?nIVIWoVIVI08CoVIVI00?o0000olG5aOo5aLD0K?o5
aLD2o`0001Kooooo0Ol00001ooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o
0000ooooooooool07oooool00ol0003oaLG5olG5a@0PolG5a@03o`000?nIVIWoVIVI08?oVIVI00?o
0000olG5aOo5aLD0Joo5aLD2o`0001Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0O
ooooo`03o`000?o5aLGoaLG5023oaLG500?o0000oiVIVOnIVIT0P_nIVIT00ol0003oaLG5olG5a@1Z
olG5a@;o00006_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01oooooo00?o0000olG5
aOo5aLD08Oo5aLD00ol0003oVIVIoiVIV@21oiVIV@03o`000?o5aLGoaLG506SoaLG50_l0000Loooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool07oooool00ol0003oaLG5olG5a@0QolG5a@03
o`000?nIVIWoVIVI083oVIVI00?o0000olG5aOo5aLD0Ioo5aLD2o`0001kooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`0Pooooo`03o`000?o5aLGoaLG5023oaLG500?o0000oiVIVOnIVIT0
OonIVIT00ol0003oaLG5olG5a@1UolG5a@?o00008?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo023ooooo00?o0000olG5aOo5aLD08?o5aLD00ol0003oVIVIoiVIV@1noiVIV@03o`000?o5
aLGoaLG506CoaLG50_l0000Sooooo`7o00000Oooool001?ooooo00?o0000ooooooooool08?ooool0
0ol0003oaLG5olG5a@0PolG5a@03o`000?nIVIWoVIVI07koVIVI00?o0000olG5aOo5aLD0H_o5aLD2
o`0002Gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Pooooo`03o`000?o5aLGoaLG5
027oaLG500?o0000oiVIVOnIVIT0O?nIVIT00ol0003oaLG5olG5a@1QolG5a@;o00009oooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD08Oo5aLD00ol0003o
VIVIoiVIV@1koiVIV@03o`000?o5aLGoaLG5063oaLG50_l0000Yooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool08?ooool00ol0003oaLG5olG5a@0QolG5a@03o`000?nIVIWoVIVI07_oVIVI
00?o0000olG5aOo5aLD0GOo5aLD3o`0002_ooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0Pooooo`03o`000?o5aLGoaLG5027oaLG500?o0000oiVIVOnIVIT0N_nIVIT00ol0003oaLG5olG5
a@1LolG5a@;o0000;_ooool1o`00007ooooo000Cooooo`;o00008Oooool00ol0003oaLG5olG5a@0R
olG5a@03o`000?nIVIWoVIVI07SoVIVI00?o0000olG5aOo5aLD0F_o5aLD3o`0002oooooo0_l00001
ooooo`004oooool00ol0003oooooooooo`0Pooooo`03o`000?o5aLGoaLG502;oaLG500?o0000oiVI
VOnIVIT0N?nIVIT00ol0003oaLG5olG5a@1HolG5a@;o0000<oooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD08_o5aLD00ol0003oVIVIoiVIV@1hoiVIV@03
o`000?o5aLGoaLG505GoaLG50ol0000eooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
8?ooool00ol0003oaLG5olG5a@0RolG5a@03o`000?nIVIWoVIVI07OoVIVI00?o0000olG5aOo5aLD0
E?o5aLD2o`0003Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Pooooo`03o`000?o5
aLGoaLG502?oaLG500?o0000oiVIVOnIVIT0M_nIVIT00ol0003oaLG5olG5a@1BolG5a@;o0000>_oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD08oo5aLD0
0ol0003oVIVIoiVIV@1eoiVIV@03o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0>_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD08oo5aLD00ol0
003oVIVIoiVIV@1doiVIV@03o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0>oooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD09?o5aLD00ol0003o
VIVIoiVIV@1coiVIV@03o`000?o5aLGoaLG5057oaLG500?o0000ooooooooool0??ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD09?o5aLD00ol0003oVIVI
oiVIV@1boiVIV@03o`000?o5aLGoaLG5057oaLG500?o0000ooooooooool0?Oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo023ooooo00?o0000olG5aOo5aLD09?o5aLD00ol0003oVIVIoiVI
V@1boiVIV@03o`000?o5aLGoaLG5053oaLG500?o0000ooooooooool0?_ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo01oooooo00?o0000olG5aOo5aLD09Oo5aLD00ol0003oVIVIoiVIV@1a
oiVIV@03o`000?o5aLGoaLG5053oaLG500?o0000ooooooooool0?oooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo01oooooo00?o0000olG5aOo5aLD09_o5aLD00ol0003oVIVIoiVIV@1_oiVI
V@03o`000?o5aLGoaLG504ooaLG50_l00012ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool07oooool00ol0003oaLG5olG5a@0VolG5a@03o`000?nIVIWoVIVI06ooVIVI00?o0000olG5aOo5
aLD0C_o5aLD00ol0003oooooooooo`12ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
7oooool00ol0003oaLG5olG5a@0VolG5a@03o`000?nIVIWoVIVI06koVIVI00?o0000olG5aOo5aLD0
C_o5aLD00ol0003oooooooooo`13ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool07ooo
ool00ol0003oaLG5olG5a@0WolG5a@03o`000?nIVIWoVIVI06goVIVI00?o0000olG5aOo5aLD0COo5
aLD00ol0003oooooooooo`14ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool07oooool0
0ol0003oaLG5olG5a@0WolG5a@03o`000?nIVIWoVIVI06coVIVI00?o0000olG5aOo5aLD0COo5aLD0
0ol0003oooooooooo`15ooooo`7o00000Oooool001?ooooo0_l0000Pooooo`03o`000?o5aLGoaLG5
02OoaLG500?o0000oiVIVOnIVIT0JonIVIT00ol0003oaLG5olG5a@1=olG5a@03o`000?oooooooooo
04Gooooo0_l00001ooooo`004oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502So
aLG500?o0000oiVIVOnIVIT0J_nIVIT00ol0003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04Oo
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502SoaLG5
00?o0000oiVIVOnIVIT0JOnIVIT00ol0003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04Sooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502SoaLG500?o
0000oiVIVOnIVIT0JOnIVIT00ol0003oaLG5olG5a@1;olG5a@03o`000?oooooooooo04Wooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502WoaLG500?o0000
oiVIVOnIVIT0IonIVIT00ol0003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04Wooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502WoaLG500?o0000oiVI
VOnIVIT0IonIVIT00ol0003oaLG5olG5a@1;olG5a@03o`000?oooooooooo04[ooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502WoaLG500?o0000oiVIVOnI
VIT0I_nIVIT00ol0003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04[ooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502[oaLG500?o0000oiVIVOnIVIT0
IOnIVIT00ol0003oaLG5olG5a@1;olG5a@03o`000?oooooooooo04_ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502[oaLG500?o0000oiVIVOnIVIT0I?nI
VIT00ol0003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04_ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502[oaLG500?o0000oiVIVOnIVIT0I?nIVIT0
0ol0003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04_ooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`0Oooooo`03o`000?o5aLGoaLG502_oaLG500?o0000oiVIVOnIVIT0H_nIVIT00ol0
003oaLG5olG5a@1<olG5a@03o`000?oooooooooo04cooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0Nooooo`03o`000?o5aLGoaLG502coaLG500?o0000oiVIVOnIVIT0H_nIVIT00ol0003o
aLG5olG5a@1<olG5a@03o`000?oooooooooo04cooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?o5aLGoaLG502coaLG500?o0000oiVIVOnIVIT0HOnIVIT00ol0003oaLG5
olG5a@1<olG5a@03o`000?oooooooooo04gooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0Nooooo`03o`000?o5aLGoaLG502goaLG500?o0000oiVIVOnIVIT0H?nIVIT00ol0003oaLG5olG5
a@1<olG5a@03o`000?oooooooooo04gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0N
ooooo`03o`000?o5aLGoaLG502goaLG500?o0000oiVIVOnIVIT0GonIVIT00ol0003oaLG5olG5a@1<
olG5a@03o`000?oooooooooo04kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Noooo
o`03o`000?o5aLGoaLG502goaLG500?o0000oiVIVOnIVIT0GonIVIT00ol0003oaLG5olG5a@1<olG5
a@03o`000?oooooooooo04kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Nooooo`03
o`000?o5aLGoaLG502koaLG500?o0000oiVIVOnIVIT0GOnIVIT00ol0003oaLG5olG5a@1=olG5a@03
o`000?oooooooooo04kooooo0Ol00001ooooo`004oooool2o`0001oooooo00?o0000olG5aOo5aLD0
;_o5aLD00ol0003oVIVIoiVIV@1MoiVIV@03o`000?o5aLGoaLG504coaLG500?o0000ooooooooool0
C_ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo01kooooo00?o0000olG5aOo5aLD0;_o5
aLD00ol0003oVIVIoiVIV@1LoiVIV@03o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0Cooo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo01kooooo00?o0000olG5aOo5aLD0;oo5aLD0
0ol0003oVIVIoiVIV@1KoiVIV@03o`000?o5aLGoaLG504coaLG500?o0000ooooooooool0D?ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo01kooooo00?o0000olG5aOo5aLD0;oo5aLD00ol0
003oVIVIoiVIV@1KoiVIV@03o`000?o5aLGoaLG504coaLG500?o0000ooooooooool0D?ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo01kooooo00?o0000olG5aOo5aLD0<?o5aLD00ol0003o
VIVIoiVIV@1JoiVIV@03o`000?o5aLGoaLG504coaLG500?o0000ooooooooool0D?ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo01kooooo00?o0000olG5aOo5aLD0<?o5aLD00ol0003oVIVI
oiVIV@1IoiVIV@03o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0D?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo01kooooo00?o0000olG5aOo5aLD0<Oo5aLD00ol0003oVIVIoiVI
V@1HoiVIV@03o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0D?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo01gooooo00?o0000olG5aOo5aLD0<_o5aLD00ol0003oVIVIoiVIV@1H
oiVIV@03o`000?o5aLGoaLG504coaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo01gooooo00?o0000olG5aOo5aLD0<oo5aLD00ol0003oVIVIoiVIV@1FoiVI
V@03o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo01gooooo00?o0000olG5aOo5aLD0<oo5aLD00ol0003oVIVIoiVIV@1FoiVIV@03
o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo01gooooo00?o0000olG5aOo5aLD0=?o5aLD00ol0003oVIVIoiVIV@1EoiVIV@03o`00
0?o5aLGoaLG504goaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo01gooooo00?o0000olG5aOo5aLD0=Oo5aLD00ol0003oVIVIoiVIV@1CoiVIV@03o`000?o5
aLGoaLG504koaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo01gooooo00?o0000olG5aOo5aLD0=Oo5aLD00ol0003oVIVIoiVIV@1CoiVIV@03o`000?o5aLGo
aLG504koaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01gooooo00?o0000olG5aOo5aLD0=_o5aLD00ol0003oVIVIoiVIV@1BoiVIV@03o`000?o5aLGoaLG5
04koaLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01go
oooo00?o0000olG5aOo5aLD0=_o5aLD00ol0003oVIVIoiVIV@1BoiVIV@03o`000?o5aLGoaLG504ko
aLG500?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01gooooo
00?o0000olG5aOo5aLD0=oo5aLD00ol0003oVIVIoiVIV@1@oiVIV@03o`000?o5aLGoaLG504ooaLG5
00?o0000ooooooooool0DOooool1o`00007ooooo000Cooooo`;o00007Oooool00ol0003oaLG5olG5
a@0holG5a@03o`000?nIVIWoVIVI053oVIVI00?o0000olG5aOo5aLD0C_o5aLD00ol0003ooooooooo
o`1Aooooo`;o00000Oooool001?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0i
olG5a@03o`000?nIVIWoVIVI04ooVIVI00?o0000olG5aOo5aLD0C_o5aLD00ol0003oooooooooo`1B
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0iolG5
a@03o`000?nIVIWoVIVI04koVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`1Boooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0jolG5a@03
o`000?nIVIWoVIVI04goVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`1Booooo`7o
00000Oooool001?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0jolG5a@03o`00
0?nIVIWoVIVI04goVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`1Booooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0kolG5a@03o`000?nI
VIWoVIVI04coVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`1Booooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0kolG5a@03o`000?nIVIWo
VIVI04coVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`1Booooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool07?ooool00ol0003oaLG5olG5a@0lolG5a@03o`000?nIVIWoVIVI
04_oVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`1Booooo`7o00000Oooool001?o
oooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0molG5a@03o`000?nIVIWoVIVI04_o
VIVI00?o0000olG5aOo5aLD0D?o5aLD00ol0003oooooooooo`1Aooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0molG5a@03o`000?nIVIWoVIVI04_oVIVI
00?o0000olG5aOo5aLD0D?o5aLD00ol0003oooooooooo`1Aooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool06oooool00ol0003oaLG5olG5a@0nolG5a@03o`000?nIVIWoVIVI04[oVIVI00?o
0000olG5aOo5aLD0D?o5aLD00ol0003oooooooooo`1Aooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool06oooool00ol0003oaLG5olG5a@0nolG5a@03o`000?nIVIWoVIVI04[oVIVI00?o0000
olG5aOo5aLD0D?o5aLD00ol0003oooooooooo`1Aooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool06oooool00ol0003oaLG5olG5a@0oolG5a@03o`000?nIVIWoVIVI04SoVIVI00?o0000olG5
aOo5aLD0DOo5aLD00ol0003oooooooooo`1Aooooo`7o00000Oooool000Wooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000olG5aOo5aLD0?oo5aLD00ol0003o
VIVIoiVIV@18oiVIV@03o`000?o5aLGoaLG5057oaLG500?o0000ooooooooool0DOooool1o`00007o
oooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oaLG5
olG5a@0oolG5a@03o`000?nIVIWoVIVI04SoVIVI00?o0000olG5aOo5aLD0DOo5aLD00ol0003ooooo
ooooo`1Aooooo`7o00000Oooool000Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01_ooooo00?o0000olG5aOo5aLD0@?o5aLD00ol0003oVIVIoiVIV@17oiVIV@03o`000?o5
aLGoaLG5057oaLG500?o0000ooooooooool0DOooool1o`00007ooooo000;ooooo`03o`000?oooooo
oooo00Gooooo0ol0000Kooooo`03o`000?o5aLGoaLG5043oaLG500?o0000oiVIVOnIVIT0AonIVIT0
0ol0003oaLG5olG5a@1AolG5a@03o`000?oooooooooo04oooooo0ol00001ooooo`002oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0@_o5aLD00ol0
003oVIVIoiVIV@16oiVIV@03o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0D?ooool1o`00
007ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003o
aLG5olG5a@12olG5a@03o`000?nIVIWoVIVI04KoVIVI00?o0000olG5aOo5aLD0D_o5aLD00ol0003o
ooooooooo`1@ooooo`7o00000Oooool000_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?o5aLGoaLG504;oaLG500?o0000oiVIVOnIVIT0A_nIVIT00ol0003oaLG5
olG5a@1BolG5a@03o`000?oooooooooo053ooooo0Ol00001ooooo`002Oooool00omEEEGoIVIVo`00
0007ooooo`03o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0@oo5aLD00ol0003oVIVIoiVI
V@15oiVIV@03o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0D?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0@oo5aLD00ol0003oVIVIoiVIV@15
oiVIV@03o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0D?ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0A?o5aLD00ol0003oVIVIoiVIV@15oiVI
V@03o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0Coooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0A?o5aLD00ol0003oVIVIoiVIV@15oiVIV@03
o`000?o5aLGoaLG505;oaLG500?o0000ooooooooool0Coooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo01[ooooo00?o0000olG5aOo5aLD0A?o5aLD00ol0003oVIVIoiVIV@15oiVIV@03o`00
0?o5aLGoaLG505;oaLG500?o0000ooooooooool0Coooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo01[ooooo00?o0000olG5aOo5aLD0AOo5aLD00ol0003oVIVIoiVIV@15oiVIV@03o`000?o5
aLGoaLG505;oaLG500?o0000ooooooooool0C_ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo01[ooooo00?o0000olG5aOo5aLD0AOo5aLD00ol0003oVIVIoiVIV@15oiVIV@03o`000?o5aLGo
aLG505;oaLG500?o0000ooooooooool0C_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01[ooooo00?o0000olG5aOo5aLD0A_o5aLD00ol0003oVIVIoiVIV@14oiVIV@03o`000?o5aLGoaLG5
05;oaLG500?o0000ooooooooool0C_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01[o
oooo00?o0000olG5aOo5aLD0A_o5aLD00ol0003oVIVIoiVIV@15oiVIV@03o`000?o5aLGoaLG505;o
aLG500?o0000ooooooooool0COooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01[ooooo
00?o0000olG5aOo5aLD0Aoo5aLD00ol0003oVIVIoiVIV@14oiVIV@03o`000?o5aLGoaLG505;oaLG5
00?o0000ooooooooool0COooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01[ooooo00?o
0000olG5aOo5aLD0Aoo5aLD00ol0003oVIVIoiVIV@14oiVIV@03o`000?o5aLGoaLG505;oaLG500?o
0000ooooooooool0COooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01[ooooo00?o0000
olG5aOo5aLD0Aoo5aLD00ol0003oVIVIoiVIV@15oiVIV@03o`000?o5aLGoaLG505;oaLG500?o0000
ooooooooool0C?ooool1o`00007ooooo000Cooooo`;o00006oooool00ol0003oaLG5olG5a@18olG5
a@03o`000?nIVIWoVIVI04CoVIVI00?o0000olG5aOo5aLD0D_o5aLD00ol0003oooooooooo`1;oooo
o`;o00000Oooool001?ooooo00?o0000ooooooooool06_ooool00ol0003oaLG5olG5a@18olG5a@03
o`000?nIVIWoVIVI04CoVIVI00?o0000olG5aOo5aLD0C?o5aLD5ool00003olG5aOl0003ooooo00Ko
oooo0ooo0014ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool06_ooool00ol0003oaLG5
olG5a@19olG5a@03o`000?nIVIWoVIVI04CoVIVI00?o0000olG5aOo5aLD0B_o5aLD8ool00003o`00
0?oooooooooo00?ooooo1?oo0014ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool06_oo
ool00ol0003oaLG5olG5a@19olG5a@03o`000?nIVIWoVIVI04CoVIVI00?o0000olG5aOo5aLD0Boo5
aLD2ool000?oaLG50_oo00000ol0003oooooooooo`04ooooo`?oo`00A?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0BOo5aLD00ol0003oVIVIoiVIV@14
oiVIV@03o`000?o5aLGoaLG5057oaLG50_oo001=ooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool06_ooool00ol0003oaLG5olG5a@1:olG5a@03o`000?nIVIWoVIVI04CoVIVI00?o0000olG5
aOo5aLD0D?o5aLD2ool00003o`000?oooooooooo04[ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0Jooooo`03o`000?o5aLGoaLG504[oaLG500?o0000oiVIVOnIVIT0A?nIVIT00ol0003o
aLG5olG5a@1=olG5a@Goo`0000?o0000ooooooooool0B_ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo01[ooooo00?o0000olG5aOo5aLD0B_o5aLD00ol0003oVIVIoiVIV@15oiVIV@03o`00
0?o5aLGoaLG504goaLG51?oo00000oo5aLGo0000ooooo`1:ooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool06_ooool00ol0003oaLG5olG5a@1:olG5a@03o`000?nIVIWoVIVI04GoVIVI0_l0
001AolG5a@;oo`0000?o0000ooooooooool0BOooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo01[ooooo00?o0000olG5aOo5aLD0B_o5aLD00ol0003oVIVIoiVIV@17oiVIV@03o`000?o5aLGo
aLG504WoaLG50_oo0003olG5a@;oo`0000?oaLG5o`000?ooool0BOooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo01[ooooo00?o0000olG5aOo5aLD0B_o5aLD00ol0003oVIVIoiVIV@18oiVI
V@03o`000?o5aLGoaLG504WoaLG51_oo0002olG5a@03o`000?oooooooooo04Oooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0Jooooo`03o`000?o5aLGoaLG504[oaLG500?o0000oiVIVOnI
VIT0BOnIVIT00ol0003oaLG5olG5a@19olG5a@Coo`000oo5aLD00ol0003oooooooooo`17ooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool06_ooool00ol0003oaLG5olG5a@1:olG5a@03o`00
0?nIVIWoVIVI04[oVIVI00?o0000olG5aOo5aLD0D?o5aLD00ol0003oooooooooo`16ooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool06_ooool00ol0003oaLG5olG5a@1:olG5a@03o`000?nI
VIWoVIVI04_oVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`16ooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool06_ooool00ol0003oaLG5olG5a@19olG5a@03o`000?nIVIWo
VIVI04goVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`15ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool06_ooool00ol0003oaLG5olG5a@19olG5a@03o`000?nIVIWoVIVI
04koVIVI00?o0000olG5aOo5aLD0Coo5aLD00ol0003oooooooooo`14ooooo`7o00000Oooool001?o
oooo0_l0000Kooooo`03o`000?o5aLGoaLG504WoaLG500?o0000oiVIVOnIVIT0ConIVIT00ol0003o
aLG5olG5a@1>olG5a@03o`000?oooooooooo04?ooooo0_l00001ooooo`004oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?o5aLGoaLG504WoaLG500?o0000oiVIVOnIVIT0D?nIVIT00ol0003oaLG5
olG5a@1>olG5a@03o`000?oooooooooo04?ooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0Booooo`Goo`000oooool00ol0003oaLG5olG5a@03olG5a@?oo`00@oo5aLD00ol0003oVIVIoiVI
V@1AoiVIV@03o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0@oooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo017ooooo2?oo00000ooooooo0000olG5a@03olG5a@Coo`00@oo5aLD0
0ol0003oVIVIoiVIV@1BoiVIV@03o`000?o5aLGoaLG504goaLG500?o0000ooooooooool0@_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo01;ooooo0_oo0003ooooo`;oo`0000?oooooo`00
0?o5aLD01?o5aLD3ool004?oaLG500?o0000oiVIVOnIVIT0DonIVIT00ol0003oaLG5olG5a@1=olG5
a@03o`000?oooooooooo047ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Hooooo`;o
o`0000?o0000olG5aOo5aLD0BOo5aLD00ol0003oVIVIoiVIV@1DoiVIV@03o`000?o5aLGoaLG504co
aLG500?o0000ooooooooool0@Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Sooooo
0_oo00000ol0003oaLG5olG5a@19olG5a@03o`000?nIVIWoVIVI05GoVIVI00?o0000olG5aOo5aLD0
C?o5aLD00ol0003oooooooooo`10ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool05Ooo
ool5ool00003o`000?o5aLGoaLG504WoaLG500?o0000oiVIVOnIVIT0EOnIVIT00ol0003oaLG5olG5
a@1<olG5a@03o`000?oooooooooo043ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0F
ooooo`Coo`0000?o0000olG5aOo5aLD0BOo5aLD00ol0003oVIVIoiVIV@1FoiVIV@03o`000?o5aLGo
aLG504coaLG500?o0000ooooooooool0?oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01Wooooo0_oo001:olG5a@03o`000?nIVIWoVIVI05SoVIVI0_l0001=olG5a@03o`000?oooooooooo
03kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Dooooo`;oo`000oooool2ool004[o
aLG500?o0000oiVIVOnIVIT0F_nIVIT00ol0003oaLG5olG5a@1:olG5a@03o`000?oooooooooo03ko
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Eooooo`Koo`00B_o5aLD00ol0003oVIVI
oiVIV@1KoiVIV@03o`000?o5aLGoaLG504[oaLG500?o0000ooooooooool0?Oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo01Kooooo1?oo00000ol0003oaLG5olG5a@17olG5a@03o`000?nI
VIWoVIVI05goVIVI0_l0001;olG5a@03o`000?oooooooooo03cooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0Jooooo`03o`000?o5aLGoaLG504OoaLG500?o0000oiVIVOnIVIT0GonIVIT0
0ol0003oaLG5olG5a@18olG5a@03o`000?oooooooooo03cooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`0Jooooo`03o`000?o5aLGoaLG504OoaLG500?o0000oiVIVOnIVIT0H?nIVIT00ol0
003oaLG5olG5a@18olG5a@03o`000?oooooooooo03_ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0Kooooo`03o`000?o5aLGoaLG504GoaLG500?o0000oiVIVOnIVIT0H_nIVIT2o`0004Wo
aLG500?o0000ooooooooool0>_ooool1o`00007ooooo000Cooooo`;o00007?ooool00ol0003oaLG5
olG5a@15olG5a@03o`000?nIVIWoVIVI06CoVIVI00?o0000olG5aOo5aLD0A_o5aLD00ol0003ooooo
ooooo`0iooooo`;o00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5
a@15olG5a@03o`000?nIVIWoVIVI06GoVIVI00?o0000olG5aOo5aLD0A_o5aLD00ol0003ooooooooo
o`0iooooo`7o00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@15
olG5a@03o`000?nIVIWoVIVI06?oVIVI1ooo0007olG5a@?oo`00>oo5aLD00ol0003oooooooooo`0h
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@14olG5
a@03o`000?nIVIWoVIVI06CoVIVI1ooo0006olG5a@Coo`00??o5aLD00ol0003oooooooooo`0goooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@14olG5a@03
o`000?nIVIWoVIVI06SoVIVI0_oo00000ol0003oaLG5olG5a@05olG5a@?oo`00?Oo5aLD00ol0003o
ooooooooo`0fooooo`7o00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5
olG5a@14olG5a@03o`000?nIVIWoVIVI06SoVIVI0_oo00000onIVIWo0000olG5a@16olG5a@03o`00
0?oooooooooo03Gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Kooooo`03o`000?o5
aLGoaLG504?oaLG500?o0000oiVIVOnIVIT0JOnIVIT2ool000;oVIVI0_l00016olG5a@03o`000?oo
oooooooo03Cooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Kooooo`03o`000?o5aLGo
aLG504?oaLG500?o0000oiVIVOnIVIT0JOnIVIT2ool000CoVIVI0_l00015olG5a@03o`000?oooooo
oooo03?ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Kooooo`03o`000?o5aLGoaLG5
04?oaLG500?o0000oiVIVOnIVIT0J_nIVIT2ool000GoVIVI00?o0000olG5aOo5aLD0@_o5aLD00ol0
003oooooooooo`0cooooo`7o00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003o
aLG5olG5a@12olG5a@03o`000?nIVIWoVIVI06_oVIVI0_oo0006oiVIV@03o`000?o5aLGoaLG504;o
aLG500?o0000ooooooooool0<_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01_ooooo
00?o0000olG5aOo5aLD0@_o5aLD00ol0003oVIVIoiVIV@1[oiVIV@;oo`001onIVIT2o`0004?oaLG5
00?o0000ooooooooool0<Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01_ooooo00?o
0000olG5aOo5aLD0@_o5aLD00ol0003oVIVIoiVIV@1XoiVIV@Goo`002OnIVIT00ol0003oaLG5olG5
a@11olG5a@03o`000?oooooooooo033ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0K
ooooo`03o`000?o5aLGoaLG5047oaLG500?o0000oiVIVOnIVIT0JonIVIT4ool000WoVIVI0_l00012
olG5a@03o`000?oooooooooo02oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Koooo
o`03o`000?o5aLGoaLG5047oaLG500?o0000oiVIVOnIVIT0N_nIVIT00ol0003oaLG5olG5a@10olG5
a@03o`000?oooooooooo02kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Kooooo`03
o`000?o5aLGoaLG5043oaLG500?o0000oiVIVOnIVIT0O?nIVIT00ol0003oaLG5olG5a@10olG5a@03
o`000?oooooooooo02gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Kooooo`03o`00
0?o5aLGoaLG5043oaLG500?o0000oiVIVOnIVIT0OOnIVIT2o`00043oaLG500?o0000ooooooooool0
;Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01_ooooo00?o0000olG5aOo5aLD0?oo5
aLD00ol0003oVIVIoiVIV@20oiVIV@03o`000?o5aLGoaLG503koaLG500?o0000ooooooooool0;?oo
ool1o`00007ooooo000Cooooo`;o00007?ooool00ol0003oaLG5olG5a@0oolG5a@03o`000?nIVIWo
VIVI087oVIVI00?o0000olG5aOo5aLD0?_o5aLD00ol0003oooooooooo`0Zooooo`;o00000Oooool0
01?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0oolG5a@03o`000?nIVIWoVIVI
08;oVIVI0_l0000oolG5a@03o`000?oooooooooo02[ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0Kooooo`03o`000?o5aLGoaLG503koaLG500?o0000oiVIVOnIVIT0QOnIVIT00ol0003o
aLG5olG5a@0molG5a@03o`000?oooooooooo02Wooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?o5aLGoaLG503?oaLG51ooo0004olG5a@03o`000?nIVIWoVIVI00?oo`00
PonIVIT2o`0003koaLG500?o0000ooooooooool0:?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo01_ooooo00?o0000olG5aOo5aLD0<oo5aLD7ool000?oaLG500?o0000oiVIVOnIVIT01?oo
0025oiVIV@03o`000?o5aLGoaLG503coaLG50_l0000Xooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool06oooool00ol0003oaLG5olG5a@0golG5a@;oo`001?o5aLD01?l0003oVIVIoiVIVOnI
VIT3ool008KoVIVI0_l0000nolG5a@03o`000?oooooooooo02Gooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0Kooooo`03o`000?o5aLGoaLG503OoaLG50_oo0004olG5a@03o`000?nIVIWo
VIVI08coVIVI00?o0000olG5aOo5aLD0??o5aLD00ol0003oooooooooo`0Tooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0golG5a@;oo`000oo5aLD00ol0
003oVIVIoiVIV@2>oiVIV@;o0000?Oo5aLD00ol0003oooooooooo`0Sooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0golG5a@;oo`000oo5aLD00ol0003o
VIVIoiVIV@2@oiVIV@03o`000?o5aLGoaLG503_oaLG500?o0000ooooooooool08_ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo01_ooooo00?o0000olG5aOo5aLD0>?o5aLD2ool00003olG5
aOl0003oVIVI09?oVIVI00?o0000olG5aOo5aLD0>oo5aLD00ol0003oooooooooo`0Qooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0holG5a@;oo`0000?o
aLG5o`000?nIVIT0U?nIVIT2o`0003coaLG500?o0000ooooooooool08?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo01_ooooo00?o0000olG5aOo5aLD0>?o5aLD2ool00003o`000?nIVIWo
VIVI09KoVIVI00?o0000olG5aOo5aLD0>_o5aLD00ol0003oooooooooo`0Oooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0eolG5a@Goo`0000?o0000oiVI
VOnIVIT0UonIVIT00ol0003oaLG5olG5a@0jolG5a@03o`000?oooooooooo01kooooo0Ol00001oooo
o`002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool06oooool00ol0
003oaLG5olG5a@0golG5a@Coo`00V_nIVIT2o`0003_oaLG500?o0000ooooooooool07Oooool1o`00
007ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Koooo
o`03o`000?o5aLGoaLG503WoaLG500?o0000oiVIVOnIVIT0VonIVIT00ol0003oaLG5olG5a@0iolG5
a@03o`000?oooooooooo01cooooo0Ol00001ooooo`002?ooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool06oooool00ol0003oaLG5olG5a@0holG5a@03o`000?nIVIWoVIVI
09goVIVI0_l0000jolG5a@03o`000?oooooooooo01_ooooo0Ol00001ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0000Jooooo`03o`000?o5aLGoaLG503SoaLG500?o0000oiVI
VOnIVIT0X?nIVIT00ol0003oaLG5olG5a@0holG5a@03o`000?oooooooooo01Sooooo0ol00001oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06_ooool00ol0
003oaLG5olG5a@0holG5a@03o`000?nIVIWoVIVI0:7oVIVI0_l0000iolG5a@03o`000?oooooooooo
01Wooooo0Ol00001ooooo`002?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool06_ooool00ol0003oaLG5olG5a@0golG5a@03o`000?nIVIWoVIVI0:CoVIVI0_l0000holG5
a@03o`000?oooooooooo01Sooooo0Ol00001ooooo`002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool06_ooool00ol0003oaLG5olG5a@0golG5a@03o`000?nIVIWoVIVI
0:KoVIVI00?o0000olG5aOo5aLD0=_o5aLD00ol0003oooooooooo`0Gooooo`7o00000Oooool000So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo01[ooooo00?o0000olG5
aOo5aLD0=_o5aLD00ol0003oVIVIoiVIV@2XoiVIV@;o0000=oo5aLD2o`0001Oooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0Jooooo`03o`000?o5aLGoaLG503KoaLG500?o0000oiVIVOnI
VIT0Z_nIVIT00ol0003oaLG5olG5a@0folG5a@03o`000?oooooooooo01Cooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`0Jooooo`03o`000?o5aLGoaLG503GoaLG500?o0000oiVIVOnIVIT0
[?nIVIT2o`0003OoaLG500?o0000ooooooooool04oooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo01[ooooo00?o0000olG5aOo5aLD0=Oo5aLD00ol0003oVIVIoiVIV@2^oiVIV@03o`000?o5
aLGoaLG503GoaLG500?o0000ooooooooool04_ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo01[ooooo00?o0000olG5aOo5aLD0=?o5aLD00ol0003oVIVIoiVIV@2`oiVIV@;o0000=_o5aLD2
o`0001;ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Jooooo`03o`000?o5aLGoaLG5
03CoaLG500?o0000oiVIVOnIVIT0/_nIVIT00ol0003oaLG5olG5a@0eolG5a@03o`000?oooooooooo
00oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Jooooo`03o`000?o5aLGoaLG503?o
aLG500?o0000oiVIVOnIVIT0]?nIVIT2o`0003KoaLG500?o0000ooooooooool03_ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo01Wooooo00?o0000olG5aOo5aLD0=?o5aLD00ol0003oVIVI
oiVIV@2foiVIV@03o`000?o5aLGoaLG503CoaLG500?o0000ooooooooool03Oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo01Wooooo00?o0000olG5aOo5aLD0<oo5aLD00ol0003oVIVIoiVI
V@2hoiVIV@;o0000=Oo5aLD00ol0003oooooooooo`0<ooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool06Oooool00ol0003oaLG5olG5a@0colG5a@03o`000?nIVIWoVIVI0;[oVIVI0_l0000d
olG5a@03o`000?oooooooooo00_ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Ioooo
o`03o`000?o5aLGoaLG503;oaLG500?o0000oiVIVOnIVIT0_OnIVIT00ol0003oaLG5olG5a@0bolG5
a@03o`000?oooooooooo00[ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Hooooo`03
o`000?o5aLGoaLG503?oaLG500?o0000oiVIVOnIVIT0__nIVIT2o`0003?oaLG500?o0000oooooooo
ool02Oooool1o`00007ooooo000Cooooo`;o00006Oooool00ol0003oaLG5olG5a@0bolG5a@03o`00
0?nIVIWoVIVI0<7oVIVI00?o0000olG5aOo5aLD0<Oo5aLD00ol0003oooooooooo`07ooooo`;o0000
0Oooool001?ooooo00?o0000ooooooooool06?ooool00ol0003oaLG5olG5a@0bolG5a@03o`000?nI
VIWoVIVI0<;oVIVI0_l0000bolG5a@03o`000?oooooooooo00Oooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0Hooooo`03o`000?o5aLGoaLG5037oaLG500?o0000oiVIVOnIVIT0aOnIVIT0
0ol0003oaLG5olG5a@0`olG5a@03o`000?oooooooooo00Kooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`0Hooooo`03o`000?o5aLGoaLG5037oaLG500?o0000oiVIVOnIVIT0a_nIVIT2o`00
037oaLG500?o0000ooooooooool01Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Oo
oooo00?o0000olG5aOo5aLD0<Oo5aLD00ol0003oVIVIoiVIV@39oiVIV@03o`000?o5aLGoaLG502ko
aLG52?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Oooooo00?o0000olG5aOo5aLD0
<Oo5aLD00ol0003oVIVIoiVIV@3:oiVIV@;o0000;_o5aLD8ooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool05oooool00ol0003oaLG5olG5a@0`olG5a@03o`000?nIVIWoVIVI0<goVIVI00?o
0000olG5aOo5aLD0:oo5aLD8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool05oooool0
0ol0003oaLG5olG5a@0`olG5a@03o`000?nIVIWoVIVI0<koVIVI0_l0000[olG5a@Sooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0Fooooo`03o`000?o5aLGoaLG5033oaLG500?o0000oiVI
VOnIVIT0dOnIVIT00ol0003oaLG5olG5a@0XolG5a@Sooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0Fooooo`03o`000?o5aLGoaLG502ooaLG500?o0000oiVIVOnIVIT0donIVIT2o`0002So
aLG52?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Kooooo00?o0000olG5aOo5aLD0
;oo5aLD00ol0003oVIVIoiVIV@3EoiVIV@03o`000?o5aLGoaLG502GoaLG52?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo01Kooooo00?o0000olG5aOo5aLD0;_o5aLD00ol0003oVIVIoiVI
V@3GoiVIV@03o`000?o5aLGoaLG502CoaLG52?ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo01Gooooo00?o0000olG5aOo5aLD0;_o5aLD00ol0003oVIVIoiVIV@3IoiVIV@;o00009?o5aLD8
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool05Oooool00ol0003oaLG5olG5a@0^olG5
a@03o`000?nIVIWoVIVI0=_oVIVI00?o0000olG5aOo5aLD08Oo5aLD8ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool05?ooool00ol0003oaLG5olG5a@0^olG5a@03o`000?nIVIWoVIVI0=go
VIVI00?o0000olG5aOo5aLD08?o5aLD8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
5?ooool00ol0003oaLG5olG5a@0]olG5a@03o`000?nIVIWoVIVI05CoVIVI1ooo0007oiVIV@?oo`00
N_nIVIT2o`00023oaLG52?ooool1o`00007ooooo000Cooooo`;o00005Oooool00ol0003oaLG5olG5
a@0]olG5a@03o`000?nIVIWoVIVI05CoVIVI1ooo0006oiVIV@Coo`006?l0001ToiVIV@03o`000?o5
aLGoaLG501goaLG51oooool2o`00007ooooo000Cooooo`03o`000?oooooooooo01?ooooo00?o0000
olG5aOo5aLD0;Oo5aLD00ol0003oVIVIoiVIV@1IoiVIV@;oo`001OnIVIT3o`0000?oo`006?m]KFd6
o`0005ooVIVI0_l0000MolG5a@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Coooo
o`03o`000?o5aLGoaLG502coaLG500?o0000oiVIVOnIVIT0BonIVIT7ool000SoVIVI0_oo0005o`00
02CoKFe]1Ol0001LoiVIV@03o`000?o5aLGoaLG501[oaLG52?ooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo01;ooooo00?o0000olG5aOo5aLD0;Oo5aLD00ol0003oVIVIoiVIV@1;oiVIV@Oo
o`001OnIVIT3o`0000;oo`00;_m]KFd5o`0005SoVIVI0_l0000JolG5a@Sooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`0Booooo`03o`000?o5aLGoaLG502coaLG500?o0000oiVIVOnIVIT0
EOnIVIT3o`0000?oKFe]0_oo000cofe]K@Co0000E_nIVIT00ol0003oaLG5olG5a@0GolG5a@Sooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0Aooooo`03o`000?o5aLGoaLG502goaLG500?o
0000oiVIVOnIVIT0DOnIVIT4o`0000OoKFe]0_oo000fofe]K@Go0000D_nIVIT00ol0003oaLG5olG5
a@0FolG5a@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Aooooo`03o`000?o5aLGo
aLG502coaLG500?o0000oiVIVOnIVIT0ConIVIT3o`0000_oKFe]0_oo000kofe]K@Co0000ConIVIT2
o`0001KoaLG52?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo017ooooo00?o0000olG5
aOo5aLD0:oo5aLD00ol0003oVIVIoiVIV@1=oiVIV@?o00003_m]KFd2ool003ooKFe]1?l0001=oiVI
V@03o`000?o5aLGoaLG501?oaLG52?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo013o
oooo00?o0000olG5aOo5aLD0;?o5aLD00ol0003oVIVIoiVIV@1:oiVIV@?o00003_m]KFd5ool004?o
KFe]1?l0001:oiVIV@;o00004oo5aLD8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
4?ooool00ol0003oaLG5olG5a@0[olG5a@03o`000?nIVIWoVIVI04WoVIVI0_l0000Cofe]K@Coo`00
A_m]KFd4o`0004SoVIVI00?o0000olG5aOo5aLD04?o5aLD8ooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool03oooool00ol0003oaLG5olG5a@0[olG5a@03o`000?nIVIWoVIVI04SoVIVI0_l0
001Sofe]K@?o0000A_nIVIT00ol0003oaLG5olG5a@0?olG5a@Sooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0?ooooo`03o`000?o5aLGoaLG502_oaLG500?o0000oiVIVOnIVIT0A_nIVIT2
o`0006SoKFe]0ol00013oiVIV@03o`000?o5aLGoaLG500ooaLG52?ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00kooooo00?o0000olG5aOo5aLD0:oo5aLD00ol0003oVIVIoiVIV@15oiVI
V@;o0000KOm]KFd2o`0004;oVIVI0_l0000?olG5a@Sooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0>ooooo`03o`000?o5aLGoaLG502[oaLG500?o0000oiVIVOnIVIT0A?nIVIT2o`00077o
KFe]0ol00011oiVIV@03o`000?o5aLGoaLG500coaLG52?ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo00gooooo00?o0000olG5aOo5aLD0:oo5aLD00ol0003oVIVIoiVIV@13oiVIV@03o`00
0?m]KFgoKFe]07CoKFe]0_l00010oiVIV@03o`000?o5aLGoaLG500_oaLG52?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo00cooooo00?o0000olG5aOo5aLD0:oo5aLD00ol0003oVIVIoiVI
V@12oiVIV@;o0000NOm]KFd3o`0003koVIVI00?o0000olG5aOo5aLD02_o5aLD8ooooo`7o00000Ooo
ool001?ooooo0_l0000=ooooo`03o`000?o5aLGoaLG502_oaLG500?o0000oiVIVOnIVIT0@?nIVIT2
o`0007koKFe]0_l0000moiVIV@03o`000?o5aLGoaLG500WoaLG51oooool2o`00007ooooo000Coooo
o`03o`000?oooooooooo00_ooooo00?o0000olG5aOo5aLD0:oo5aLD00ol0003oVIVIoiVIV@0ooiVI
V@;o0000P_m]KFd2o`0003coVIVI00?o0000olG5aOo5aLD02?o5aLD8ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool02oooool00ol0003oaLG5olG5a@0ZolG5a@03o`000?nIVIWoVIVI03oo
VIVI00?o0000ofe]KOm]KFd0Q?m]KFd3o`0003[oVIVI00?o0000olG5aOo5aLD01oo5aLD8ooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool02_ooool00ol0003oaLG5olG5a@0[olG5a@03o`00
0?nIVIWoVIVI03goVIVI0_l0002:ofe]K@;o0000>OnIVIT2o`0000OoaLG52?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo00Wooooo00?o0000olG5aOo5aLD0:oo5aLD00ol0003oVIVIoiVI
V@0moiVIV@03o`000?m]KFgoKFe]08coKFe]0_l0000ioiVIV@03o`000?o5aLGoaLG500CoaLG52?oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Wooooo00?o0000olG5aOo5aLD0:_o5aLD0
0ol0003oVIVIoiVIV@0loiVIV@;o0000TOm]KFd2o`0003SoVIVI00?o0000olG5aOo5aLD00oo5aLD8
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool02?ooool00ol0003oaLG5olG5a@0ZolG5
a@03o`000?nIVIWoVIVI03coVIVI00?o0000ofe]KOm]KFd0Tom]KFd2o`0003OoVIVI00?o0000olG5
aOo5aLD00_o5aLD8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool02?ooool00ol0003o
aLG5olG5a@0YolG5a@03o`000?nIVIWoVIVI03_oVIVI0_l0002Hofe]K@?o0000=OnIVIT01?l0003o
aLG5olG5aOo5aLD8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01oooool00ol0003o
aLG5olG5a@0YolG5a@03o`000?nIVIWoVIVI03_oVIVI00?o0000ofe]KOm]KFd0Vom]KFd2o`0003Co
VIVI00?o0000olG5aOo5aLD02?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Kooooo
00?o0000olG5aOo5aLD0:Oo5aLD00ol0003oVIVIoiVIV@0joiVIV@;o0000X?m]KFd2o`0003?oVIVI
00?o0000olG5aOooool01oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o
0000olG5aOo5aLD0:?o5aLD00ol0003oVIVIoiVIV@0joiVIV@03o`000?m]KFgoKFe]0:;oKFe]0_l0
000boiVIV@03o`000?oooooooooo00Kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05
ooooo`03o`000?o5aLGoaLG502SoaLG500?o0000oiVIVOnIVIT0>_nIVIT00ol0003oKFe]ofe]K@2U
ofe]K@03o`000?nIVIWoVIVI033oVIVI00?o0000ooooooooool01Oooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00Gooooo:oo5aLD00ol0003oVIVIoiVIV@0ioiVIV@03o`000?m]KFgoKFe]
0:KoKFe]0_l0000aoiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05ooooob[o
aLG500?o0000oiVIVOnIVIT0>?nIVIT2o`000:_oKFe]0_l0000_oiVIV@Sooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`05ooooobWoaLG500?o0000oiVIVOnIVIT0>?nIVIT00ol0003oKFe]
ofe]K@2]ofe]K@03o`000?nIVIWoVIVI02coVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo:?o5aLD00ol0003oVIVIoiVIV@0hoiVIV@03o`000?m]KFgoKFe]0:ooKFe]0_l0
000/oiVIV@Sooooo0Ol00001ooooo`004oooool2o`0000Kooooo9oo5aLD00ol0003oVIVIoiVIV@0g
oiVIV@;o0000]?m]KFd2o`0002[oVIVI1oooool2o`00007ooooo000Cooooo`03o`000?oooooooooo
00Gooooo9_o5aLD00ol0003oVIVIoiVIV@0goiVIV@03o`000?m]KFgoKFe]0;KoKFe]00?o0000oiVI
VOnIVIT09onIVIT8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01OoooolVolG5a@03
o`000?nIVIWoVIVI03KoVIVI00?o0000ofe]KOm]KFd0^?m]KFd2o`0002OoVIVI2?ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo00Gooooo9Oo5aLD00ol0003oVIVIoiVIV@0eoiVIV@;o0000
_Om]KFd2o`0002GoVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo9?o5
aLD00ol0003oVIVIoiVIV@0eoiVIV@03o`000?m]KFgoKFe]0;ooKFe]00?o0000oiVIVOnIVIT08_nI
VIT8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01OoooolSolG5a@03o`000?nIVIWo
VIVI03GoVIVI00?o0000ofe]KOm]KFd0`Om]KFd2o`0002;oVIVI2?ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00Gooooo8Oo5aLD2o`0003OoVIVI00?o0000ofe]KOm]KFd0a?m]KFd2o`00
023oVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo8?o5aLD00ol0003o
VIVIoiVIV@0eoiVIV@;o0000bOm]KFd00ol0003oVIVIoiVIV@0MoiVIV@Sooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`05oooooaooaLG500?o0000oiVIVOnIVIT0=OnIVIT00ol0003oKFe]
ofe]K@3:ofe]K@03o`000?nIVIWoVIVI01coVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo7Oo5aLD2o`0003OoVIVI00?o0000ofe]KOm]KFd0c?m]KFd2o`0001coVIVI2?oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo7?o5aLD00ol0003oVIVIoiVIV@0e
oiVIV@;o0000dOm]KFd00ol0003oVIVIoiVIV@0IoiVIV@Sooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`05oooooa_oaLG500?o0000oiVIVOnIVIT0=?nIVIT2o`0005?oKFe]1Ooo0009ofe]
K@?oo`00L?m]KFd00ol0003oVIVIoiVIV@0HoiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`05oooooaWoaLG50_l0000eoiVIV@;o0000E?m]KFd8ool000KoKFe]1?oo000<ofe]K@go
0000F?m]KFd00ol0003oVIVIoiVIV@0GoiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`05oooooaSoaLG500?o0000oiVIVOnIVIT0=?nIVIT00ol0003oKFe]ofe]K@1Eofe]K@;oo`00
0om]KFd2ool000OoKFe]0ooo000<o`0000go@D512Ol0001?ofe]K@03o`000?nIVIWoVIVI01OoVIVI
2?ooool1o`00007ooooo0009ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`05oooooaOoaLG500?o0000oiVIVOnIVIT0=?nIVIT00ol0003oKFe]ofe]K@1;ofe]K@Ooo`002_m]
KFd2ool000So00008om1@D46o`0004[oKFe]00?o0000oiVIVOnIVIT05_nIVIT8ooooo`7o00000Ooo
ool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooooaKoaLG500?o0000
oiVIVOnIVIT0<onIVIT2o`0004koKFe]1ooo0005ofe]K@Go00000_oo000aod51@@Co0000Aom]KFd0
0ol0003oVIVIoiVIV@0EoiVIV@Sooooo0Ol00001ooooo`002oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo5Oo5aLD00ol0003oVIVIoiVIV@0coiVIV@03o`000?m]KFgoKFe]
05KoKFe]1?l00002od51@@Goo`00=Om1@D45o`0004?oKFe]00?o0000oiVIVOnIVIT05?nIVIT8oooo
o`7o00000Oooool000_ooooo00?o0000ooooooooool01Oooool3o`0000Gooooo5?o5aLD00ol0003o
VIVIoiVIV@0coiVIV@03o`000?m]KFgoKFe]05;oKFe]1Ol00007od51@@Coo`00>_m1@D44o`00043o
KFe]00?o0000oiVIVOnIVIT04onIVIT6ooooo`?o00000Oooool000_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05oooooa?oaLG500?o0000oiVIVOnIVIT0<onIVIT00ol0003oKFe]
ofe]K@1?ofe]K@Co00003om1@D42ool003go@D510ol0000nofe]K@03o`000?nIVIWoVIVI01;oVIVI
2?ooool1o`00007ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
oolBolG5a@03o`000?nIVIWoVIVI03;oVIVI0_l0001?ofe]K@?o00003_m1@D42ool000?o@D510_oo
0010od51@@?o0000??m]KFd00ol0003oVIVIoiVIV@0AoiVIV@Sooooo0Ol00001ooooo`002oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo4?o5aLD2o`0003CoVIVI00?o0000
ofe]KOm]KFd0C?m]KFd3o`0001;o@D511_oo0013od51@@?o0000>_m]KFd00ol0003oVIVIoiVIV@0@
oiVIV@Sooooo0Ol00001ooooo`002Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo
00Gooooo3_o5aLD2o`0003GoVIVI00?o0000ofe]KOm]KFd0B_m]KFd3o`0001Ko@D511?oo0017od51
@@?o0000>?m]KFd00ol0003oVIVIoiVIV@0?oiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`05ooooo`goaLG500?o0000oiVIVOnIVIT0<onIVIT2o`0004[oKFe]0ol0001Wod51@@?o
0000=_m]KFd00ol0003oVIVIoiVIV@0>oiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`05ooooo`_oaLG50_l0000eoiVIV@03o`000?m]KFgoKFe]04OoKFe]0ol0001]od51@@?o0000
<om]KFd00ol0003oVIVIoiVIV@0>oiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`05ooooo`WoaLG50_l0000eoiVIV@;o0000Aom]KFd3o`0007?o@D510_l0000bofe]K@03o`000?nI
VIWoVIVI00goVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo2?o5aLD0
0ol0003oVIVIoiVIV@0coiVIV@;o0000Aom]KFd2o`0007So@D510_l0000aofe]K@03o`000?nIVIWo
VIVI00coVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo1_o5aLD2o`00
03GoVIVI00?o0000ofe]KOm]KFd0AOm]KFd2o`0007co@D510ol0000_ofe]K@03o`000?nIVIWoVIVI
00_oVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo1?o5aLD2o`0003Go
VIVI0_l00015ofe]K@?o0000POm1@D42o`0002koKFe]00?o0000oiVIVOnIVIT02_nIVIT8ooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool01Oooool3olG5a@03o`000?nIVIWoVIVI03CoVIVI
00?o0000ofe]KOm]KFd0@om]KFd2o`0008Ko@D510_l0000]ofe]K@03o`000?nIVIWoVIVI00WoVIVI
2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?oaLG5o`000?l00000=OnI
VIT2o`0004CoKFe]0_l0002:od51@@;o0000;?m]KFd00ol0003oVIVIoiVIV@08oiVIV@Sooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?nIVIWoVIVI03CoVIVI00?o0000
ofe]KOm]KFd0@_m]KFd2o`0008ko@D5100?o0000ofe]KOm]KFd0:Om]KFd00ol0003oVIVIoiVIV@08
oiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05ooooocGoVIVI0_l00013ofe]
K@;o0000TOm1@D42o`0002[oKFe]00?o0000oiVIVOnIVIT01onIVIT8ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool01OooooldoiVIV@03o`000?m]KFgoKFe]047oKFe]0_l0002Eod51@@03
o`000?m]KFgoKFe]02SoKFe]00?o0000oiVIVOnIVIT01_nIVIT8ooooo`7o00000Oooool001?ooooo
0_l00006oooooc;oVIVI0_l00012ofe]K@;o0000V?m1@D42o`0002SoKFe]00?o0000oiVIVOnIVIT0
1_nIVIT7ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool01Oooool`oiVIV@;o0000@_m]
KFd2o`0009co@D5100?o0000ofe]KOm]KFd09_m]KFd00ol0003oVIVIoiVIV@05oiVIV@Sooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`05ooooobkoVIVI0_l00012ofe]K@;o0000Wom1@D40
0ol0003oKFe]ofe]K@0Vofe]K@03o`000?nIVIWoVIVI00CoVIVI2?ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00Gooooo;?nIVIT2o`0004;oKFe]0_l0002Rod51@@03o`000?m]KFgoKFe]
02GoKFe]00?o0000oiVIVOnIVIT01?nIVIT8ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool01OoooolZoiVIV@;o0000@_m]KFd2o`000:Go@D510_l0000Vofe]K@03o`000?nIVIWoVIVI00?o
VIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo:OnIVIT00ol0003oKFe]
ofe]K@11ofe]K@03o`000?m1@D7o@D510:Oo@D5100?o0000ofe]KOm]KFd09?m]KFd00ol0003oVIVI
oiVIV@02oiVIV@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05ooooobOoVIVI0_l0
0012ofe]K@;o0000Zom1@D400ol0003oKFe]ofe]K@0Sofe]K@03o`000?nIVIWoVIVI00;oVIVI2?oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo9OnIVIT2o`0004;oKFe]0_l0002^
od51@@03o`000?m]KFgoKFe]02?oKFe]00Co0000oiVIVOnIVIWoVIVI2?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo00Gooooo8onIVIT2o`0004;oKFe]0_l0002aod51@@03o`000?m]KFgo
KFe]02;oKFe]00Co0000oiVIVOnIVIWoVIVI2?ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00Gooooo8OnIVIT2o`0004;oKFe]0_l0002dod51@@;o00008om]KFd00ol0003oVIVIoiVIV@08
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01OoooolNoiVIV@?o0000@_m]KFd2o`00
0;So@D5100?o0000ofe]KOm]KFd08Om]KFd00ol0003oVIVIooooo`07ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool01OoooolLoiVIV@;o0000@om]KFd2o`000;_o@D5100?o0000ofe]KOm]
KFd08?m]KFd00ol0003oVIVIooooo`07ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
1OoooolIoiVIV@?o0000@om]KFd2o`000;ko@D5100?o0000ofe]KOm]KFd08?m]KFd00ol0003ooooo
ooooo`06ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01OoooolGoiVIV@;o0000A?m]
KFd2o`000<7o@D5100?o0000ofe]KOm]KFd08?m]KFd00ol0003oooooooooo`05ooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool01OoooolDoiVIV@?o0000A?m]KFd2o`0006Oo@D514_l0001;
od51@@03o`000?m]KFgoKFe]01ooKFe]2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
00Gooooo4_nIVIT2o`0004GoKFe]0_l0001Mod51@BSo0000@Om1@D400ol0003oKFe]ofe]K@0Oofe]
K@Sooooo0Ol00001ooooo`004oooool2o`0000Kooooo4?nIVIT2o`0004KoKFe]00?o0000od51@Om1
@D40Eom1@D4bo`0003ko@D5100?o0000ofe]KOm]KFd07_m]KFd7ooooo`;o00000Oooool001?ooooo
00?o0000ooooooooool01Oooool=oiVIV@?o0000A_m]KFd2o`0005Go@D51??l0000jod51@@03o`00
0?m]KFgoKFe]01goKFe]2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo2onI
VIT2o`0004OoKFe]0_l0001Bod51@DGo0000=om1@D400ol0003oKFe]ofe]K@0Lofe]K@Sooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`05ooooo`SoVIVI0ol00016ofe]K@?o0000@om1@D45
ool000So@D510ooo0019o`0003Go@D5100?o0000ofe]KOm]KFd06om]KFd8ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool01Oooool6oiVIV@;o0000Aom]KFd2o`0004Go@D512?oo0003od51
@@;o00001?oo001<o`0003;o@D5100?o0000ofe]KOm]KFd06om]KFd8ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool01Oooool4oiVIV@;o0000A_m]KFd3o`0004go@D510_oo0006o`0000?o
o`00C_l0000aod51@@03o`000?m]KFgoKFe]01[oKFe]2?ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00CoVIVIo`000?l0003o0000A_m]KFd2o`0003oo@D511ooo0009od51@@;o
00000_oo001Io`0002oo@D5100?o0000ofe]KOm]KFd06Om]KFd8ooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool01Oooool00ol0003oKFe]ofe]K@15ofe]K@;o0000@Om1@D47ool000Go@D51
0_oo0004o`0000;oo`00Fol0000^od51@@03o`000?m]KFgoKFe]01SoKFe]2?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo00GoooooAOm]KFd3o`0004go@D510_l00008ool005go0000;Om1
@D400ol0003oKFe]ofe]K@0Gofe]K@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05
oooood?oKFe]0_l0001=od51@@Ko00001_oo001Qo`0002_o@D5100?o0000ofe]KOm]KFd05_m]KFd8
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Ooooom0ofe]K@?o0000C?m1@D49o`00
00;oo`00Iol0000Yod51@@03o`000?m]KFgoKFe]01KoKFe]2?ooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo00Gooooo?Om]KFd3o`0004co@D513?l00002ool006Wo0000:?m1@D400ol0003o
KFe]ofe]K@0Eofe]K@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05oooooc[oKFe]
0ol0001<od51@@oo00002?oo001Uo`0002Oo@D5100?o0000ofe]KOm]KFd05?m]KFd8ooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool01Ooooolgofe]K@?o0000COm1@D4Bo`0000Soo`00I_l0
000Vod51@@03o`000?m]KFgoKFe]01?oKFe]2?ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00Gooooo=?m]KFd3o`0004go@D51QOl0000Uod51@@03o`000?m]KFgoKFe]01;oKFe]2?ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo<Om]KFd3o`0004go@D51ROl0000Tod51
@@03o`000?m]KFgoKFe]01;oKFe]2?ooool1o`00007ooooo000Cooooo`;o00001_ooool^ofe]K@?o
0000C_m1@D6<o`0002Co@D5100?o0000ofe]KOm]KFd04Om]KFd7ooooo`;o00000Oooool001?ooooo
00?o0000ooooooooool01OoooolZofe]K@Co0000Com1@D6?o`0002Co@D5100?o0000ofe]KOm]KFd0
4?m]KFd8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01OoooolWofe]K@?o0000D?m1
@D6Co`0002?o@D5100?o0000ofe]KOm]KFd04?m]KFd8ooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool01OoooolTofe]K@?o0000DOm1@D6Fo`0002?o@D5100?o0000ofe]KOm]KFd03om]KFd8
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01OoooolPofe]K@Co0000D_m1@D6Io`00
02?o@D5100?o0000ofe]KOm]KFd03_m]KFd8ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool01OoooolLofe]K@Co0000Dom1@D6Mo`0002;o@D5100?o0000ofe]KOm]KFd03_m]KFd8ooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool01OoooolGofe]K@Go0000EOm1@D6Qo`00027o@D51
00?o0000ofe]KOm]KFd03Om]KFd8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Ooo
oolCofe]K@Co0000Eom1@D6Uo`00027o@D5100?o0000ofe]KOm]KFd03?m]KFd8ooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool01Oooool?ofe]K@Co0000FOm1@D6Xo`00027o@D5100?o0000
ofe]KOm]KFd02om]KFd8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Oooool<ofe]
K@?o0000Fom1@D6[o`00023o@D5100?o0000ofe]KOm]KFd02om]KFd8ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool01Oooool8ofe]K@Co0000Fom1@D6_o`00023o@D5100?o0000ofe]KOm]
KFd02_m]KFd8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Oooool5ofe]K@?o0000
GOm1@D6bo`00023o@D5100?o0000ofe]KOm]KFd02Om]KFd8ooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool01Oooool2ofe]K@?o0000GOm1@D6fo`0001oo@D5100?o0000ofe]KOm]KFd02Om]
KFd8ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Oooool2o`0005go@D51^_l0000O
od51@@03o`000?m]KFgoKFe]00SoKFe]2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
00GoooooG?m1@D6no`0001oo@D5100?o0000ofe]KOm]KFd01om]KFd8ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool01OoooomIod51@L;o00007om1@D400ol0003oKFe]ofe]K@06ofe]K@So
oooo0Ol00001ooooo`004oooool2o`0000KoooooE_m1@D75o`0001oo@D5100?o0000ofe]KOm]KFd0
1_m]KFd7ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool01OoooomCod51@LWo00007om1
@D400ol0003oKFe]ofe]K@05ofe]K@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05
ooooodoo@D51c_l0000Ood51@@03o`000?m]KFgoKFe]00CoKFe]2?ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00GoooooB_m1@D7Do`0001ko@D5100?o0000ofe]KOm]KFd01?m]KFd8oooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool01Ooooom6od51@MWo00007_m1@D400ol0003o
KFe]ofe]K@03ofe]K@Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05oooood7o@D51
gol0000Nod51@@03o`000?m]KFgoKFe]00;oKFe]2?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo>om1@D7Vo`0001ko@D5100Co0000ofe]KOm]KFgoKFe]2?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo00Gooooo=_m1@D7/o`0001go@D5100Co0000ofe]KOm]KFgoKFe]
2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo<?m1@D7bo`0001ko@D5100?o
0000ofe]KOm]KFd02?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo:_m1@D7i
o`0001ko@D5100?o0000ofe]KOooool01oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
00Gooooo9Om1@D7oo`0001go@D5100?o0000ofe]KOooool01oooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo00Gooooo7om1@D7oo`0000Oo00007Om1@D400ol0003oooooooooo`06ooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool01OoooolIod51@Ooo00003_l0000Mod51@@03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05oooooaCo@D51ool0
000Do`0001co@D512?ooool1o`00007ooooo0008ooooo`Go00001_ooool00ol0003oooooooooo`05
ooooo`oo@D51ool0000Jo`0001_o@D512?ooool1o`00007ooooo0008ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01_ooool00ol0003oooooooooo`05ooooo`[o@D51ool0000Po`0001[o@D512?ooool1
o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00005ooooo`So@D51ool0000So`00
01Wo@D511_ooool3o`00007ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooooooo
ool0oooooomAooooo`7o00000Oooool000_ooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`3ooooooe7ooooo0Ol00001ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooDOooool1o`00007ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`05ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo000Coooooooo0000EOl00001ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-2.33804, -2.31582, 0.0154596, \
0.0154596}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70922 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.361533 0.337724 0.35461 0.337724 [
[ 0 0 0 0 ]
[ 1 .70922 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0168862 0.699257 0.692334 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.240385 0.5 0.240385 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -6 -9 ]
[.25962 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -3 -9 ]
[.74038 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -12 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-1)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(1)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(2)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-2)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-1)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(1)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(2)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.428 g
.01923 .85687 m
.06984 .83798 L
.09218 .82895 L
.12045 .81658 L
.17105 .79012 L
.19031 .77834 L
.22166 .75739 L
.26145 .72773 L
.27227 .71945 L
.32287 .68075 L
.32777 .67713 L
.37348 .64674 L
.41081 .62652 L
.42409 .62085 L
.4747 .60443 L
.5253 .59695 L
.57591 .59726 L
.62652 .60395 L
.67713 .61581 L
.71281 .62652 L
.72773 .63205 L
.77834 .65247 L
.82794 .67713 L
.82895 .6777 L
.87955 .71007 L
.90178 .72773 L
.93016 .75561 L
.94869 .77834 L
.98077 .82868 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .85687 m
.06984 .83798 L
.09218 .82895 L
.12045 .81658 L
.17105 .79012 L
.19031 .77834 L
.22166 .75739 L
.26145 .72773 L
.27227 .71945 L
.32287 .68075 L
.32777 .67713 L
.37348 .64674 L
.41081 .62652 L
.42409 .62085 L
.4747 .60443 L
.5253 .59695 L
.57591 .59726 L
.62652 .60395 L
.67713 .61581 L
.71281 .62652 L
.72773 .63205 L
.77834 .65247 L
.82794 .67713 L
.82895 .6777 L
.87955 .71007 L
.90178 .72773 L
.93016 .75561 L
.94869 .77834 L
.98077 .82868 L
s
.256 g
.01923 .92351 m
.06984 .90907 L
.12045 .896 L
.17105 .88169 L
.17784 .87955 L
.22166 .86416 L
.27227 .84219 L
.29899 .82895 L
.32287 .81658 L
.37348 .79013 L
.39726 .77834 L
.42409 .76629 L
.4747 .74752 L
.5253 .73486 L
.57591 .72846 L
.62652 .72809 L
.67713 .73353 L
.72773 .7449 L
.77834 .76308 L
.80952 .77834 L
.82895 .79043 L
.87636 .82895 L
.87955 .83223 L
.9187 .87955 L
.93016 .89604 L
.95295 .93016 L
.98077 .96817 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .92351 m
.06984 .90907 L
.12045 .896 L
.17105 .88169 L
.17784 .87955 L
.22166 .86416 L
.27227 .84219 L
.29899 .82895 L
.32287 .81658 L
.37348 .79013 L
.39726 .77834 L
.42409 .76629 L
.4747 .74752 L
.5253 .73486 L
.57591 .72846 L
.62652 .72809 L
.67713 .73353 L
.72773 .7449 L
.77834 .76308 L
.80952 .77834 L
.82895 .79043 L
.87636 .82895 L
.87955 .83223 L
.9187 .87955 L
.93016 .89604 L
.95295 .93016 L
.98077 .96817 L
s
.772 g
.01923 .78168 m
.02513 .77834 L
.06984 .75017 L
.0983 .72773 L
.12045 .70784 L
.14865 .67713 L
.17105 .64925 L
.18686 .62652 L
.21862 .57591 L
.22166 .571 L
.24651 .5253 L
.27191 .4747 L
.27227 .47425 L
.29324 .42409 L
.30844 .37348 L
.31015 .32287 L
.2916 .27227 L
.27227 .22648 L
.26905 .22166 L
.24307 .17105 L
.22469 .12045 L
.22166 .10988 L
.20971 .06984 L
.19705 .01923 L
.01923 .01923 L
F
0 g
.01923 .78168 m
.02513 .77834 L
.06984 .75017 L
.0983 .72773 L
.12045 .70784 L
.14865 .67713 L
.17105 .64925 L
.18686 .62652 L
.21862 .57591 L
.22166 .571 L
.24651 .5253 L
.27191 .4747 L
.27227 .47425 L
.29324 .42409 L
.30844 .37348 L
.31015 .32287 L
.2916 .27227 L
.27227 .22648 L
.26905 .22166 L
.24307 .17105 L
.22469 .12045 L
.22166 .10988 L
.20971 .06984 L
.19705 .01923 L
s
1 g
.01923 .67576 m
.05052 .62652 L
.06984 .57749 L
.07024 .57591 L
.08091 .5253 L
.08491 .4747 L
.08449 .42409 L
.08246 .37348 L
.08165 .32287 L
.08354 .27227 L
.08771 .22166 L
.0927 .17105 L
.09694 .12045 L
.0991 .06984 L
.09788 .01923 L
.01923 .01923 L
F
0 g
.01923 .67576 m
.05052 .62652 L
.06984 .57749 L
.07024 .57591 L
.08091 .5253 L
.08491 .4747 L
.08449 .42409 L
.08246 .37348 L
.08165 .32287 L
.08354 .27227 L
.08771 .22166 L
.0927 .17105 L
.09694 .12045 L
.0991 .06984 L
.09788 .01923 L
s
.90212 .98077 m
.87955 .95345 L
.85932 .93016 L
.82895 .90081 L
.80162 .87955 L
.77834 .86579 L
.72773 .84451 L
.67713 .83304 L
.62652 .82932 L
.57591 .83236 L
.5253 .84163 L
.4747 .85656 L
.42409 .87595 L
.41541 .87955 L
.37348 .89751 L
.32287 .91801 L
.28752 .93016 L
.27227 .93471 L
.22166 .94692 L
.17105 .95591 L
.12045 .96395 L
.06984 .97374 L
.0435 .98077 L
F
.90212 .98077 m
.87955 .95345 L
.85932 .93016 L
.82895 .90081 L
.80162 .87955 L
.77834 .86579 L
.72773 .84451 L
.67713 .83304 L
.62652 .82932 L
.57591 .83236 L
.5253 .84163 L
.4747 .85656 L
.42409 .87595 L
.41541 .87955 L
.37348 .89751 L
.32287 .91801 L
.28752 .93016 L
.27227 .93471 L
.22166 .94692 L
.17105 .95591 L
.12045 .96395 L
.06984 .97374 L
.0435 .98077 L
s
.772 g
.98077 .67635 m
.93016 .63027 L
.92545 .62652 L
.87955 .59279 L
.85508 .57591 L
.82895 .55852 L
.77861 .5253 L
.77834 .52513 L
.72773 .49161 L
.70306 .4747 L
.67713 .45715 L
.63109 .42409 L
.62652 .42088 L
.57591 .38129 L
.5683 .37348 L
.5253 .33114 L
.52243 .32287 L
.50313 .27227 L
.50647 .22166 L
.52259 .17105 L
.5253 .16298 L
.54633 .12045 L
.57458 .06984 L
.57591 .06789 L
.6097 .01923 L
.98077 .01923 L
F
0 g
.98077 .67635 m
.93016 .63027 L
.92545 .62652 L
.87955 .59279 L
.85508 .57591 L
.82895 .55852 L
.77861 .5253 L
.77834 .52513 L
.72773 .49161 L
.70306 .4747 L
.67713 .45715 L
.63109 .42409 L
.62652 .42088 L
.57591 .38129 L
.5683 .37348 L
.5253 .33114 L
.52243 .32287 L
.50313 .27227 L
.50647 .22166 L
.52259 .17105 L
.5253 .16298 L
.54633 .12045 L
.57458 .06984 L
.57591 .06789 L
.6097 .01923 L
s
1 g
.98077 .55776 m
.94417 .5253 L
.93016 .51275 L
.88991 .4747 L
.87955 .4645 L
.84277 .42409 L
.82895 .40768 L
.80466 .37348 L
.77834 .3278 L
.77621 .32287 L
.75807 .27227 L
.75096 .22166 L
.75686 .17105 L
.77834 .12216 L
.7818 .12045 L
.82895 .07985 L
.84862 .06984 L
.87955 .05655 L
.93016 .03441 L
.9565 .01923 L
.98077 .01923 L
F
0 g
.98077 .55776 m
.94417 .5253 L
.93016 .51275 L
.88991 .4747 L
.87955 .4645 L
.84277 .42409 L
.82895 .40768 L
.80466 .37348 L
.77834 .3278 L
.77621 .32287 L
.75807 .27227 L
.75096 .22166 L
.75686 .17105 L
.77834 .12216 L
.7818 .12045 L
.82895 .07985 L
.84862 .06984 L
.87955 .05655 L
.93016 .03441 L
.9565 .01923 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.73303 .11145 m
.73303 .59777 L
.97619 .59777 L
.97619 .11145 L
F
1 g
.73303 .11145 m
.73303 .59777 L
.97619 .59777 L
.97619 .11145 L
F
0 g
.0001 w
[ ] 0 setdash
.73303 .11145 m
.97619 .11145 L
.97619 .59777 L
.73303 .59777 L
.73303 .11145 L
s
% Start of sub-graphic
p
0.733029 0.111449 0.97619 0.597771 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0245098 0.245098 [
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0441176 0.35119 0.289216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
.02381 .01472 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .16667 -61 -10.1562 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.3125 translate 1 -1 scale
63.000 13.312 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.312 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
79.688 13.312 moveto
(-) show
87.375 13.312 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
96.375 13.312 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.328431 0.35119 0.573529 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.256 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
.02381 .01472 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .45098 -61 -10.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.0625 translate 1 -1 scale
63.000 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.062 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
79.688 13.062 moveto
(-) show
87.375 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
96.375 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.612745 0.35119 0.857843 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.428 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
.02381 .01472 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .73529 -61 -10.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.0625 translate 1 -1 scale
63.000 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.062 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
79.688 13.062 moveto
(-) show
87.375 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
96.375 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.897059 0.35119 1.14216 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.6 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
.02381 .01472 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.01961 -61 -10.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.0625 translate 1 -1 scale
63.000 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.062 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
79.688 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
88.688 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.18137 0.35119 1.42647 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.772 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
.02381 .01472 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.30392 -61 -10.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.0625 translate 1 -1 scale
63.000 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.062 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
79.688 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
88.688 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 1.46569 0.35119 1.71078 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .60332 L
.97619 .60332 L
.97619 .01472 L
.02381 .01472 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 1.58824 -61 -10.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.0625 translate 1 -1 scale
63.000 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.062 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(>) show
79.688 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
88.688 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 1.85294 -77.7812 -10.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.062 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.062 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
70.625 13.062 moveto
(H) show
74.750 13.062 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
%%BeginResource: font Times-Italic-MISO
%%BeginFont: Times-Italic-MISO
/Times-Italic /Times-Italic-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
80.125 13.062 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
83.438 13.062 moveto
%%IncludeResource: font Times-Italic-MISO
%%IncludeFont: Times-Italic-MISO
/Times-Italic-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.750 13.062 moveto
(L) show
92.562 13.062 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .70922 L
0 .70922 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 204.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000ob000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007oooool5
o`0003;ooooo1?l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0<_oo
ool4o`000003oa0@4?oooooooooo02kooooo1Ol0001`ooooo`007oooool01OnHV9So8B4Qonk^k_oo
ooooA4A403Cooooo00?o0000ooooooooool0;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Cooooo
00?o0000ooooooooool0<?ooool01OnHV9So8B4Qonk^k_ooooooA4A4073ooooo000Gooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP0Zooooo`Ko00001Oooool00ol0003oooooooooo`0/ooooo`05oa0@
4?ooooooooooooooool@4100=?ooool00ol0003oooooooooo`0aooooo`03oiRHV?lQ8B7ok^k^077o
oooo000Qooooo`03oiRHV?lQ8B7ok^k^03Cooooo00?o0000ooooooooool0;?ooool01Ol0003ooooo
oooooooooooo000003Cooooo00?o0000ooooooooool0<_ooool00onHV9So8B4Qonk^kP1`ooooo`00
8_ooool00omgMgOoIVIVooooo`0cooooo`03o`000?oooooooooo02cooooo00Go0000oooooooooooo
ooooo`00000dooooo`03o`000?oooooooooo03?ooooo00?oMgMgofIVI_ooool0Koooool002?ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`05oa0@4?ooooooooooooooool@
4100=?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06kooooo000Oooooo`05o`00
0?nj^[[ooooooiRHV?l@4100=?ooool00ol0003oooooooooo`0/ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0=?ooool00ol0003oooooooooo`0`ooooo`05o`000?nj^[[ooooooiRHV?l@4100L?ooool0
01oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00booooo`03oeEEEOmVIVKo000002kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0booooo`03oeEEEOmVIVKo000003;ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c01`ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
6_oooooQo`0006gooooo000@ooooo`Go00001Oooool01Ol0003ooooooooooooooooo000003Gooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo
00Go0000ooooooooooooooooo`00001]ooooo`004?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool0gOooool00ol0003oooooooooo`1[ooooo`002?ooool6o`0000?ooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`3Mooooo`03o`000?oooooooooo06_ooooo
000Booooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000Dooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`1:ooooo`;o00001oooool2o`0006gooooo000C
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oaLG5olG5a@0C
olG5a@03o`000?nIVIWoVIVI05[oVIVI00?o0000olG5aOo5aLD0B?o5aLD2o`0000[ooooo00?o0000
ooooooooool0Joooool001Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Coooo
o`03o`000?o5aLGoaLG501?oaLG500?o0000oiVIVOnIVIT0FOnIVIT00ol0003oaLG5olG5a@17olG5
a@;o00003?ooool00ol0003oooooooooo`1[ooooo`004?ooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo00?o0000ooooooooool04oooool00ol0003oaLG5olG5a@0DolG5a@03o`000?nIVIWoVIVI
05OoVIVI00?o0000olG5aOo5aLD0A_o5aLD2o`0000kooooo00?o0000ooooooooool0Joooool0013o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo01?ooooo00?o0000olG5
aOo5aLD05?o5aLD00ol0003oVIVIoiVIV@1FoiVIV@03o`000?o5aLGoaLG504CoaLG50ol0000@oooo
o`03o`000?oooooooooo06_ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5
aLD05?o5aLD00ol0003oVIVIoiVIV@1FoiVIV@03o`000?o5aLGoaLG504;oaLG50_l0000Cooooo`03
o`000?oooooooooo06_ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD0
5Oo5aLD00ol0003oVIVIoiVIV@1DoiVIV@03o`000?o5aLGoaLG5047oaLG50_l0000Eooooo`03o`00
0?oooooooooo06_ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD05Oo5
aLD00ol0003oVIVIoiVIV@1CoiVIV@03o`000?o5aLGoaLG503ooaLG50ol0000Gooooo`03o`000?oo
oooooooo06_ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD05Oo5aLD0
0ol0003oVIVIoiVIV@1CoiVIV@03o`000?o5aLGoaLG503goaLG50_l0000Jooooo`03o`000?oooooo
oooo06_ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD05Oo5aLD00ol0
003oVIVIoiVIV@1BoiVIV@03o`000?o5aLGoaLG503_oaLG50ol0000Looooo`03o`000?oooooooooo
06_ooooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD05_o5aLD00ol0003o
VIVIoiVIV@1@oiVIV@03o`000?o5aLGoaLG503[oaLG50_l0000Oooooo`03o`000?oooooooooo06_o
oooo000Jooooo`;o00005?ooool00ol0003oaLG5olG5a@0FolG5a@03o`000?nIVIWoVIVI04ooVIVI
00?o0000olG5aOo5aLD0>Oo5aLD2o`00023ooooo0_l0001]ooooo`006_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?o5aLGoaLG501KoaLG500?o0000oiVIVOnIVIT0ConIVIT00ol0003oaLG5olG5
a@0holG5a@03o`000?oooooooooo027ooooo00?o0000ooooooooool0Joooool001[ooooo00?o0000
ooooooooool04oooool00ol0003oaLG5olG5a@0GolG5a@03o`000?nIVIWoVIVI04goVIVI00?o0000
olG5aOo5aLD0>?o5aLD00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06_ooooo000Joooo
o`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD05oo5aLD00ol0003oVIVIoiVIV@1=oiVI
V@03o`000?o5aLGoaLG503KoaLG50_l0000Uooooo`03o`000?oooooooooo00[oooooF?l00009oooo
o`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGoaLG501OoaLG500?o0000oiVIVOnI
VIT0C?nIVIT00ol0003oaLG5olG5a@0folG5a@03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`00
0?oooooooooo01?ooooo00?o0000olG5aOo5aLD06?o5aLD00ol0003oVIVIoiVIV@1;oiVIV@03o`00
0?o5aLGoaLG503GoaLG500?o0000ooooooooool09_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04ooo
ool00ol0003oaLG5olG5a@0HolG5a@03o`000?nIVIWoVIVI04[oVIVI00?o0000olG5aOo5aLD0=Oo5
aLD00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGo
aLG501SoaLG500?o0000oiVIVOnIVIT0B_nIVIT00ol0003oaLG5olG5a@0colG5a@;o0000:_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool0
01[ooooo00?o0000ooooooooool04oooool00ol0003oaLG5olG5a@0IolG5a@03o`000?nIVIWoVIVI
04SoVIVI00?o0000olG5aOo5aLD0<oo5aLD00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?o5aLGoaLG501WoaLG500?o0000oiVIVOnIVIT0B?nIVIT00ol0003o
aLG5olG5a@0bolG5a@03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`;o00005?ooool00ol0003oaLG5
olG5a@0IolG5a@03o`000?nIVIWoVIVI04OoVIVI00?o0000olG5aOo5aLD0<_o5aLD00ol0003ooooo
ooooo`0[ooooo`;o00003?ooool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003ooooo
ooooo`07ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGoaLG501WoaLG500?o
0000oiVIVOnIVIT0AonIVIT00ol0003oaLG5olG5a@0aolG5a@03o`000?oooooooooo02gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGoaLG501WoaLG500?o0000
oiVIVOnIVIT0A_nIVIT00ol0003oaLG5olG5a@0aolG5a@03o`000?oooooooooo02kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003oooooooooo`07
ooooo`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGoaLG501WoaLG500?o0000oiVI
VOnIVIT0A_nIVIT00ol0003oaLG5olG5a@0aolG5a@03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGoaLG501[oaLG500?o0000oiVIVOnI
VIT0A?nIVIT00ol0003oaLG5olG5a@0aolG5a@03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003oooooooooo`07ooooo`00
6_ooool00ol0003oooooooooo`0Cooooo`03o`000?o5aLGoaLG501[oaLG500?o0000oiVIVOnIVIT0
A?nIVIT00ol0003oaLG5olG5a@0aolG5a@03o`000?oooooooooo02oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02oooooa[o00005?ooool00onHV9So<S8booooo`0<ooooo`03odA4
A?l0003o000000;o000000GoV9RHoooooooooooooooooc8b<P0;ooooo`03o`000?oooooooooo00Oo
oooo000Jooooo`03o`000?oooooooooo01?ooooo00?o0000olG5aOo5aLD06oo5aLD00ol0003oVIVI
oiVIV@12oiVIV@03o`000?o5aLGoaLG5037oaLG500?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo6_l0000Aooooo`05omgMgOmgMgOo8B4QoiRHV?o^
k^h04Oooool00onHV9So0000oiRHV00>ooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`00
0?oooooooooo01?ooooo00?o0000olG5aOo5aLD06oo5aLD00ol0003oVIVIoiVIV@11oiVIV@03o`00
0?o5aLGoaLG503;oaLG500?o0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;ooooo6_l0000?ooooo`04okZj^_m4A4CoEEEEokZj^QGooooo00?oV9RHo`000?oo
ool03Oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`00
0?o5aLGoaLG501goaLG500?o0000oiVIVOnIVIT0@?nIVIT00ol0003oaLG5olG5a@0aolG5a@03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooooa[o0000
3_ooool00olb<S;o410@okZj^P0:ooooo`So00001_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000olG5aOo5aLD07Oo5
aLD00ol0003oVIVIoiVIV@0ooiVIV@03o`000?o5aLGoaLG503;oaLG500?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo6_l0000?ooooo`04ojVYZOm4
A4CoEEEEokZj^QGooooo00?oV9RHo`000?ooool03Oooool00ol0003oooooooooo`07ooooo`006_oo
ool00ol0003oooooooooo`0Booooo`03o`000?o5aLGoaLG501goaLG500?o0000oiVIVOnIVIT0?onI
VIT00ol0003oaLG5olG5a@0bolG5a@03o`000?oooooooooo037ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02oooooa[o00004Oooool01OoMgMgoIVIVoc8b<_nHV9Sok^k^017ooooo
00?oV9RHo`000?nHV9P03_ooool00ol0003oooooooooo`07ooooo`006_ooool2o`0001?ooooo00?o
0000olG5aOo5aLD07_o5aLD00ol0003oVIVIoiVIV@0moiVIV@03o`000?o5aLGoaLG503;oaLG500?o
0000ooooooooool0<Oooool2o`0000cooooo00?o0000ooooooooool00_oooolJo`0001Cooooo00?o
V9RHoc8b<_ooool03?ooool00oo<c<co0000o`000002o`000003oiRHV?oooooooooo00gooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04_ooool00ol0003oaLG5olG5a@0N
olG5a@03o`000?nIVIWoVIVI03goVIVI00?o0000olG5aOo5aLD0<_o5aLD00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oooolJo`0002Cooooo00?o410@
omgMgOooool04Oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Boooo
o`03o`000?o5aLGoaLG501ooaLG500?o0000oiVIVOnIVIT0>onIVIT00ol0003oaLG5olG5a@0bolG5
a@03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
oa[o00009?ooool00on7QhOoIVIVooooo`0Aooooo`03o`000?oooooooooo00Oooooo000Jooooo`03
o`000?oooooooooo01;ooooo00?o0000olG5aOo5aLD07oo5aLD00ol0003oVIVIoiVIV@0koiVIV@03
o`000?o5aLGoaLG503;oaLG500?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo6_l0000Tooooo`03omgMgOl0003o000000;o000000?o<S8boooooooo
ool03?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`00
0?o5aLGoaLG5023oaLG500?o0000oiVIVOnIVIT0>_nIVIT00ol0003oaLG5olG5a@0bolG5a@03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooooa[o0000
>?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`000?o5
aLGoaLG5023oaLG500?o0000oiVIVOnIVIT0>OnIVIT00ol0003oaLG5olG5a@0colG5a@03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00Oooooo000Jooooo`03o`000?oooooooooo01;ooooo00?o0000olG5aOo5aLD08Oo5aLD0
0ol0003oVIVIoiVIV@0hoiVIV@03o`000?o5aLGoaLG503;oaLG500?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool0
01[ooooo00?o0000ooooooooool04_ooool00ol0003oaLG5olG5a@0QolG5a@03o`000?nIVIWoVIVI
03SoVIVI00?o0000olG5aOo5aLD0<_o5aLD00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?o5aLGoaLG502?oaLG500?o0000oiVIVOnIVIT0=_nIVIT00ol0003o
aLG5olG5a@0colG5a@03o`000?oooooooooo03Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo017ooooo
00?o0000olG5aOo5aLD08oo5aLD00ol0003oVIVIoiVIV@0foiVIV@03o`000?o5aLGoaLG503?oaLG5
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oaLG5olG5
a@0SolG5a@03o`000?nIVIWoVIVI03KoVIVI00?o0000olG5aOo5aLD0<oo5aLD00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`07ooooo`006_ooool2o`0001;ooooo00?o0000olG5aOo5aLD09?o5aLD00ol0003oVIVIoiVIV@0e
oiVIV@03o`000?o5aLGoaLG503;oaLG500?o0000ooooooooool0=?ooool2o`0000cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?o5aLGoaLG502CoaLG500?o0000oiVIVOnIVIT0=?nIVIT00ol0003oaLG5olG5a@0colG5
a@03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo017ooooo00?o0000olG5aOo5
aLD09Oo5aLD00ol0003oVIVIoiVIV@0coiVIV@03o`000?o5aLGoaLG503?oaLG500?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool01oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oaLG5olG5a@0VolG5a@03o`00
0?nIVIWoVIVI03;oVIVI00?o0000olG5aOo5aLD0<oo5aLD00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_oooolJo`0003Sooooo00?o0000ooooooooool0
1oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oaLG5olG5a@0VolG5a@03o`000?nI
VIWoVIVI03;oVIVI00?o0000olG5aOo5aLD0<oo5aLD00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o@D51od51@@0Fod51@@03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04Oooool0
0ol0003oaLG5olG5a@0WolG5a@03o`000?nIVIWoVIVI037oVIVI00?o0000olG5aOo5aLD0<oo5aLD0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
0ol0003o@D51od51@@0Fod51@@03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool0
01[ooooo00?o0000ooooooooool04Oooool00ol0003oaLG5olG5a@0WolG5a@03o`000?nIVIWoVIVI
037oVIVI00?o0000olG5aOo5aLD0=?o5aLD00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003o@D51od51@@0Fod51@@03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003o
aLG5olG5a@0WolG5a@03o`000?nIVIWoVIVI037oVIVI00?o0000olG5aOo5aLD0=?o5aLD00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o
@D51od51@@0Fod51@@03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool0017ooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000olG5aOo5aLD0
:?o5aLD00ol0003oVIVIoiVIV@0`oiVIV@03o`000?o5aLGoaLG503CoaLG500?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000od51@Om1@D40
5_m1@D400ol0003oooooooooo`0Booooo`03oiRHV?lb<S;ooooo00cooooo00Go8B4Qo`000?l0003o
A4A4okZj^P04ooooo`03oc8b<_oooooooooo00Wooooo00?o0000ooooooooool01oooool001?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG502WoaLG5
00?o0000oiVIVOnIVIT0;onIVIT00ol0003oaLG5olG5a@0eolG5a@03o`000?oooooooooo03Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?m1@D7o@D5101Ko@D51
00?o0000ooooooooool03oooool01OoMgMgoMgMgob4Q8OnHV9Sok^k^013ooooo00?ok^k^oeEEEOnY
ZJT03oooool00ol0003oooooooooo`07ooooo`002?ooool6o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG502WoaLG500?o0000oiVIVOnIVIT0
;onIVIT00ol0003oaLG5olG5a@0eolG5a@03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?m1@D7o@D5101Ko@D5100?o0000ooooooooool0
3Oooool01?nj^[[oA4A4oeEEEOnj^[XDooooo`03onk^k_l@413ooooo00kooooo00?o0000oooooooo
ool01oooool001?ooooo00?o0000ooooooooool01?ooool2o`00017ooooo00?o0000olG5aOo5aLD0
:_o5aLD00ol0003oVIVIoiVIV@0^oiVIV@03o`000?o5aLGoaLG503GoaLG500?o0000ooooooooool0
<oooool2o`0000cooooo00?o0000ooooooooool00_ooool00ol0003o@D51od51@@0Fod51@@03o`00
0?oooooooooo00cooooo00?o<S8boa0@4?nj^[X02_ooool8o`0000Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo013ooooo00?o0000olG5aOo5aLD0:_o5aLD00ol0003oVIVIoiVIV@0^oiVIV@03o`000?o5
aLGoaLG503KoaLG500?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000od51@Om1@D405_m1@D400ol0003oooooooooo`0=ooooo`04ojVYZOm4
A4CoEEEEokZj^Q?ooooo00?ok^k^ogMgMolb<S803oooool00ol0003oooooooooo`07ooooo`004ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000olG5aOo5aLD0:_o5
aLD00ol0003oVIVIoiVIV@0^oiVIV@03o`000?o5aLGoaLG503KoaLG500?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000od51@Om1@D405_m1
@D400ol0003oooooooooo`0?ooooo`05omgMgOmVIVKo<S8boiRHV?o^k^h03oooool01?lb<S;o0000
oc8b<_o^k^h?ooooo`03o`000?oooooooooo00Oooooo000Cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0[olG5a@03o`000?nIVIWoVIVI02goVIVI
00?o0000olG5aOo5aLD0=_o5aLD00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_ooool00ol0003o@D51od51@@0Fod51@@03o`000?oooooooooo01;ooooo
00?oV9RHoc8b<_ooool03oooool00on7QhOoV9RHooooo`0?ooooo`03o`000?oooooooooo00Oooooo
000Aooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5
a@0[olG5a@03o`000?nIVIWoVIVI02goVIVI00?o0000olG5aOo5aLD0=_o5aLD00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o@D51od51
@@0Fod51@@03o`000?oooooooooo027ooooo00Go^[Zjooooooooooooooooo`00000@ooooo`03o`00
0?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo013ooooo00?o0000olG5aOo5aLD0;?o5
aLD00ol0003oVIVIoiVIV@0]oiVIV@03o`000?o5aLGoaLG503KoaLG500?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000od51@Om1@D405_m1
@D400ol0003oooooooooo`0Qooooo`05ofIVI_nHV9SoooooohN7Qol000004?ooool00ol0003ooooo
ooooo`07ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG502coaLG500?o
0000oiVIVOnIVIT0;OnIVIT00ol0003oaLG5olG5a@0folG5a@03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?m1@D7o@D5101Ko@D5100?o
0000ooooooooool08Oooool01Oo^k^koEEEEo`000?l0003oV9RH013ooooo00?o0000ooooooooool0
1oooool001[ooooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0]olG5a@03o`000?nI
VIWoVIVI02coVIVI00?o0000olG5aOo5aLD0=_o5aLD00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_oooolJo`0003Sooooo00?o0000ooooooooool01ooo
ool001[ooooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0]olG5a@03o`000?nIVIWo
VIVI02goVIVI00?o0000olG5aOo5aLD0=_o5aLD00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0
003oooooooooo`0?ooooo`03o`000?o5aLGoaLG502ooaLG500?o0000oiVIVOnIVIT0;?nIVIT00ol0
003oaLG5olG5a@0folG5a@03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oo
oooo00?o0000olG5aOo5aLD0;oo5aLD00ol0003oVIVIoiVIV@0/oiVIV@03o`000?o5aLGoaLG503Ko
aLG500?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool01oooool001[ooooo0_l0000@ooooo`03o`000?o5aLGoaLG502ooaLG5
00?o0000oiVIVOnIVIT0;OnIVIT00ol0003oaLG5olG5a@0folG5a@03o`000?oooooooooo02oooooo
0_l0000<ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool001[ooooo00?o
0000ooooooooool03oooool00ol0003oaLG5olG5a@0`olG5a@03o`000?nIVIWoVIVI02coVIVI00?o
0000olG5aOo5aLD0=_o5aLD00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0?
ooooo`03o`000?o5aLGoaLG5033oaLG500?o0000oiVIVOnIVIT0;?nIVIT00ol0003oaLG5olG5a@0f
olG5a@03o`000?oooooooooo033ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000olG5
aOo5aLD0<Oo5aLD00ol0003oVIVIoiVIV@0/oiVIV@03o`000?o5aLGoaLG503KoaLG500?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool01oooool001[ooooo00?o0000ooooooooool03oooool00ol0003oaLG5olG5a@0aolG5a@03
o`000?nIVIWoVIVI02coVIVI00?o0000olG5aOo5aLD0=oo5aLD00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`00
6_ooool00ol0003oooooooooo`0?ooooo`03o`000?o5aLGoaLG5037oaLG500?o0000oiVIVOnIVIT0
;OnIVIT00ol0003oaLG5olG5a@0folG5a@03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oo
oooooooo00oooooo00?o0000olG5aOo5aLD0<Oo5aLD00ol0003oVIVIoiVIV@0^oiVIV@03o`000?o5
aLGoaLG503KoaLG500?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo6_l0000hooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooo
oooo00oooooo00?o0000olG5aOo5aLD0<Oo5aLD00ol0003oVIVIoiVIV@0_oiVIV@03o`000?o5aLGo
aLG503GoaLG500?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ofe]KOm]KFd05_m]KFd00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000olG5aOo5aLD0<Oo5aLD00ol0
003oVIVIoiVIV@0`oiVIV@03o`000?o5aLGoaLG503GoaLG500?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ofe]KOm]KFd05_m]KFd00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oo
oooo00?o0000olG5aOo5aLD0<?o5aLD00ol0003oVIVIoiVIV@0boiVIV@03o`000?o5aLGoaLG503Co
aLG500?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ofe]KOm]KFd05_m]KFd00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oo
oooo000Jooooo`;o00004?ooool00ol0003oaLG5olG5a@0`olG5a@03o`000?nIVIWoVIVI03?oVIVI
00?o0000olG5aOo5aLD0=?o5aLD00ol0003oooooooooo`0Zooooo`;o00003?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?m]KFgoKFe]01KoKFe]00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`07ooooo`006_ooool00ol0003oooooooooo`0?ooooo`03o`000?o5aLGoaLG5033oaLG500?o
0000oiVIVOnIVIT0=?nIVIT00ol0003oaLG5olG5a@0colG5a@03o`000?oooooooooo02_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?m]KFgoKFe]01KoKFe]00?o
0000ooooooooool04_ooool00onHV9So<S8booooo`0>ooooo`?o00000oooool00olb<S;ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000
olG5aOo5aLD0<?o5aLD00ol0003oVIVIoiVIV@0eoiVIV@03o`000?o5aLGoaLG503?oaLG500?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ofe]KOm]KFd05_m]KFd00ol0003oooooooooo`0?ooooo`05omgMgOmgMgOo8B4QoiRHV?o^k^h04?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooo
oooo00oooooo00?o0000olG5aOo5aLD0<?o5aLD00ol0003oVIVIoiVIV@0foiVIV@03o`000?o5aLGo
aLG503;oaLG500?o0000ooooooooool0:_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ofe]KOm]KFd05_m]KFd00ol0003oooooooooo`0=ooooo`04okZj^_m4A4Co
EEEEokZj^Q?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`006_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?o5aLGoaLG5033oaLG500?o0000oiVIVOnIVIT0=onIVIT0
0ol0003oaLG5olG5a@0bolG5a@03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?m]KFgoKFe]01KoKFe]00?o0000ooooooooool03?ooool0
0olb<S;o410@okZj^P0:ooooo`So00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000olG5aOo5aLD0<?o5aLD00ol0
003oVIVIoiVIV@0hoiVIV@03o`000?o5aLGoaLG5037oaLG500?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ofe]KOm]KFd05_m]KFd00ol0
003oooooooooo`0=ooooo`04ojVYZOm4A4CoEEEEokZj^Q?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0?ooooo`03o`000?o5aLGoaLG5
033oaLG500?o0000oiVIVOnIVIT0>OnIVIT2o`0003;oaLG500?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ofe]KOm]KFd05_m]KFd00ol0
003oooooooooo`0?ooooo`05omgMgOmVIVKo<S8boiRHV?o^k^h04?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000olG5
aOo5aLD0;oo5aLD00ol0003oVIVIoiVIV@0loiVIV@03o`000?o5aLGoaLG5033oaLG500?o0000oooo
ooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ofe]
KOm]KFd05_m]KFd00ol0003oooooooooo`0Booooo`03oiRHV?lb<S;ooooo00oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0?ooooo`03
o`000?o5aLGoaLG502ooaLG500?o0000oiVIVOnIVIT0?OnIVIT00ol0003oaLG5olG5a@0`olG5a@03
o`000?oooooooooo02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?m]KFgoKFe]01KoKFe]00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000olG5aOo5aLD0
;oo5aLD00ol0003oVIVIoiVIV@0noiVIV@;o0000<?o5aLD00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oKFe]ofe]K@0Fofe]K@03o`00
0?oooooooooo02?ooooo00?o8B4Qo`000?ooool04?ooool00ol0003oooooooooo`07ooooo`006_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?o5aLGoaLG502ooaLG500?o0000oiVIVOnIVIT0@?nI
VIT00ol0003oaLG5olG5a@0^olG5a@03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?m]KFgoKFe]01KoKFe]00?o0000ooooooooool08ooo
ool00onj^[[o<S8booooo`0@ooooo`03o`000?oooooooooo00Oooooo000Jooooo`;o00004Oooool0
0ol0003oaLG5olG5a@0]olG5a@03o`000?nIVIWoVIVI04;oVIVI00?o0000olG5aOo5aLD0;_o5aLD0
0ol0003oooooooooo`0Sooooo`;o00003?ooool00ol0003oooooooooo`02oooooa[o0000>?ooool0
0ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG5
02goaLG500?o0000oiVIVOnIVIT0@onIVIT2o`0002ooaLG500?o0000ooooooooool08oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool001[o
oooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0]olG5a@03o`000?nIVIWoVIVI04Go
VIVI00?o0000olG5aOo5aLD0;?o5aLD00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?o5aLGoaLG502goaLG500?o0000oiVIVOnIVIT0A_nIVIT00ol0003oaLG5
olG5a@0/olG5a@03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo013ooooo00?o
0000olG5aOo5aLD0;?o5aLD00ol0003oVIVIoiVIV@18oiVIV@03o`000?o5aLGoaLG502coaLG500?o
0000ooooooooool08Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0/
olG5a@03o`000?nIVIWoVIVI04WoVIVI0_l0000]olG5a@03o`000?oooooooooo023ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Joooo
o`03o`000?oooooooooo013ooooo00?o0000olG5aOo5aLD0;?o5aLD00ol0003oVIVIoiVIV@1;oiVI
V@03o`000?o5aLGoaLG502[oaLG500?o0000ooooooooool08?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool001[ooooo00?o0000oooooooo
ool04?ooool00ol0003oaLG5olG5a@0[olG5a@03o`000?nIVIWoVIVI04goVIVI0_l0000[olG5a@03
o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo013ooooo00?o0000olG5aOo5aLD0
:oo5aLD00ol0003oVIVIoiVIV@1?oiVIV@03o`000?o5aLGoaLG502WoaLG500?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
1oooool001[ooooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0ZolG5a@03o`000?nI
VIWoVIVI057oVIVI00?o0000olG5aOo5aLD0:Oo5aLD00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_oooolJo`0003Sooooo00?o0000ooooooooool01ooo
ool001[ooooo00?o0000ooooooooool04?ooool00ol0003oaLG5olG5a@0ZolG5a@03o`000?nIVIWo
VIVI05;oVIVI0_l0000ZolG5a@03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?nIVIWoVIVI01KoVIVI00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`07ooooo`006_ooool2o`00017ooooo00?o0000olG5aOo5aLD0:Oo5aLD00ol0
003oVIVIoiVIV@1EoiVIV@03o`000?o5aLGoaLG502SoaLG500?o0000ooooooooool06_ooool2o`00
00cooooo00?o0000ooooooooool00_ooool00ol0003oVIVIoiVIV@0FoiVIV@03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04?ooool00ol0003o
aLG5olG5a@0YolG5a@03o`000?nIVIWoVIVI05KoVIVI0_l0000YolG5a@03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?nIVIWoVIVI01Ko
VIVI00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?o5aLGoaLG502WoaLG500?o0000oiVIVOnIVIT0F?nIVIT00ol0003oaLG5
olG5a@0WolG5a@03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?nIVIWoVIVI01KoVIVI00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`07ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG502SoaLG500?o
0000oiVIVOnIVIT0F_nIVIT2o`0002SoaLG50_l0000Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oVIVIoiVIV@0FoiVIV@03o`000?oooooooooo01;ooooo00?o
V9RHoc8b<_ooool01Oooool3o`0000?ooooo00?o<S8booooooooool04oooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG502SoaLG500?o0000
oiVIVOnIVIT0G?nIVIT00ol0003oaLG5olG5a@0WolG5a@03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?nIVIWoVIVI01KoVIVI00?o0000
ooooooooool03oooool01OoMgMgoMgMgob4Q8OnHV9Sok^k^00Oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGo
aLG502OoaLG500?o0000oiVIVOnIVIT0G_nIVIT2o`0002SoaLG500?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oiVIVOnIVIT05_nIVIT0
0ol0003oooooooooo`0=ooooo`04okZj^_m4A4CoEEEEokZj^P[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGo
aLG502OoaLG500?o0000oiVIVOnIVIT0H?nIVIT00ol0003oaLG5olG5a@0VolG5a@03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?nIVIWo
VIVI01KoVIVI00?o0000ooooooooool03?ooool00olb<S;o410@okZj^P0<ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool04?ooool00ol0
003oaLG5olG5a@0VolG5a@03o`000?nIVIWoVIVI06;oVIVI00?o0000olG5aOo5aLD09_o5aLD00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oVIVIoiVIV@0FoiVIV@03o`000?oooooooooo00gooooo00CoZJVYodA4A?mEEEGo^[Zj2_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo000@ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`0@ooooo`03o`000?o5aLGoaLG502KoaLG500?o0000
oiVIVOnIVIT0HonIVIT00ol0003oaLG5olG5a@0VolG5a@03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?nIVIWoVIVI01KoVIVI00?o0000
ooooooooool03oooool01OoMgMgoIVIVoc8b<_nHV9Sok^k^00Oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`07ooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool04?ooool00ol0003oaLG5olG5a@0UolG5a@03o`000?nIVIWoVIVI06GoVIVI0_l0
000WolG5a@03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?nIVIWoVIVI01KoVIVI00?o0000ooooooooool04_ooool00onHV9So<S8boooo
o`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0013ooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo013ooooo00?o0000olG5aOo5aLD09Oo5
aLD00ol0003oVIVIoiVIV@1WoiVIV@;o00009_o5aLD00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oVIVIoiVIV@0FoiVIV@03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`004?ooool0
1Ol0003ooooooooooooooooo000000Gooooo0_l0000@ooooo`03o`000?o5aLGoaLG502GoaLG500?o
0000oiVIVOnIVIT0J_nIVIT00ol0003oaLG5olG5a@0TolG5a@03o`000?oooooooooo00kooooo0_l0
000<ooooo`03o`000?oooooooooo00;ooooo00?o0000oiVIVOnIVIT05_nIVIT00ol0003ooooooooo
o`0Jooooo`03ob4Q8Ol0003ooooo01Wooooo00?o0000ooooooooool01oooool0013ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00oooooo00?o0000olG5aOo5aLD09?o5
aLD00ol0003oVIVIoiVIV@1/oiVIV@;o00009Oo5aLD00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oVIVIoiVIV@0FoiVIV@03o`000?oo
oooooooo01[ooooo00?o^[Zjoc8b<_ooool06Oooool00ol0003oooooooooo`07ooooo`004?ooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool03oooool00ol0003oaLG5olG5
a@0TolG5a@03o`000?nIVIWoVIVI06koVIVI0_l0000TolG5a@03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?nIVIWoVIVI01KoVIVI00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`004?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool03oooool00ol0003oaLG5olG5a@0SolG5a@03o`000?nI
VIWoVIVI077oVIVI00?o0000olG5aOo5aLD08_o5aLD2o`0000gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003oooooooooo`07ooooo`004?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool03oooool00ol0003oaLG5olG5
a@0SolG5a@03o`000?nIVIWoVIVI07;oVIVI0_l0000TolG5a@03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000J
ooooo`03o`000?oooooooooo00oooooo00?o0000olG5aOo5aLD08_o5aLD00ol0003oVIVIoiVIV@1e
oiVIV@;o00008oo5aLD00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`0?oooo
o`03o`000?o5aLGoaLG502;oaLG500?o0000oiVIVOnIVIT0MonIVIT00ol0003oaLG5olG5a@0QolG5
a@03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00oooooo00?o0000olG5aOo5
aLD08Oo5aLD00ol0003oVIVIoiVIV@1ioiVIV@03o`000?o5aLGoaLG5027oaLG500?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool01oooool001[ooooo00?o0000ooooooooool03oooool00ol0003oaLG5olG5a@0QolG5a@03o`00
0?nIVIWoVIVI07[oVIVI0_l0000RolG5a@03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oo
oooooooo00kooooo00?o0000olG5aOo5aLD08Oo5aLD00ol0003oVIVIoiVIV@1moiVIV@03o`000?o5
aLGoaLG5023oaLG500?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool03_ooool0
0ol0003oaLG5olG5a@0QolG5a@03o`000?nIVIWoVIVI07koVIVI0_l0000QolG5a@03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo00Oooooo000Jooooo`;o00003oooool00ol0003oaLG5olG5a@0PolG5a@03o`000?nIVIWoVIVI
087oVIVI00?o0000olG5aOo5aLD07oo5aLD00ol0003oooooooooo`02ooooo`;o00003?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00ko
oooo00?o0000olG5aOo5aLD08?o5aLD00ol0003oVIVIoiVIV@22oiVIV@03o`000?o5aLGoaLG501oo
aLG500?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo6_l0000hooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00kooooo
00?o0000olG5aOo5aLD08?o5aLD00ol0003oVIVIoiVIV@23oiVIV@;o00008?o5aLD01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003oaLG5olG5a@0FolG5a@03
o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool001[ooooo00?o0000ooooooooool0
3_ooool00ol0003oaLG5olG5a@0OolG5a@03o`000?nIVIWoVIVI08KoVIVI00?o0000olG5aOo5aLD0
7Oo5aLD4ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oaLG5
olG5a@0FolG5a@03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool001[ooooo00?o
0000ooooooooool03Oooool00ol0003oaLG5olG5a@0PolG5a@03o`000?nIVIWoVIVI08OoVIVI0_l0
000MolG5a@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?o5
aLGoaLG501KoaLG500?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`006_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?o5aLGoaLG501ooaLG500?o0000oiVIVOnIVIT0R_nIVIT0
0ol0003oaLG5olG5a@0JolG5a@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?o5aLGoaLG501KoaLG500?o0000ooooooooool0=_ooool00ol0003oooooooooo`07
ooooo`006_ooool00ol0003oooooooooo`0=ooooo`03o`000?o5aLGoaLG501koaLG500?o0000oiVI
VOnIVIT0S?nIVIT2o`0001[oaLG51?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo00?o0000olG5aOo5aLD05_o5aLD00ol0003oooooooooo`0Booooo`03oiRHV?lb<S;ooooo
00?ooooo00Go8B4Qo`000?l0003oA4A4okZj^P04ooooo`03oc8b<_oooooooooo01;ooooo00?o0000
ooooooooool01oooool001[ooooo00?o0000ooooooooool03Oooool00ol0003oaLG5olG5a@0NolG5
a@03o`000?nIVIWoVIVI08koVIVI00?o0000olG5aOo5aLD05oo5aLD4ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oaLG5olG5a@0FolG5a@03o`000?oooooooooo
00oooooo00GogMgMogMgMolQ8B7oV9RHonk^kP07ooooo`03onk^k_mEEEGoZJVY01Sooooo00?o0000
ooooooooool01oooool001[ooooo00?o0000ooooooooool03?ooool00ol0003oaLG5olG5a@0NolG5
a@03o`000?nIVIWoVIVI093oVIVI00?o0000olG5aOo5aLD05_o5aLD4ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oaLG5olG5a@0FolG5a@03o`000?oooooooooo
00gooooo00Co^[ZjodA4A?mEEEGo^[Zj2oooool00oo^k^ko410@ooooo`0Gooooo`03o`000?oooooo
oooo00Oooooo000Jooooo`03o`000?oooooooooo00cooooo00?o0000olG5aOo5aLD07Oo5aLD00ol0
003oVIVIoiVIV@2BoiVIV@03o`000?o5aLGoaLG501GoaLG51?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00?o0000olG5aOo5aLD05_o5aLD00ol0003oooooooooo`0<oooo
o`03oc8b<_l@413o^[Zj00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07oooo
o`006_ooool2o`0000cooooo00?o0000olG5aOo5aLD07_o5aLD00ol0003oVIVIoiVIV@11oiVIV@[o
0000B?nIVIT2o`0001GoaLG50oooool2o`0000cooooo00?o0000ooooooooool00_ooool00ol0003o
aLG5olG5a@0FolG5a@03o`000?oooooooooo00gooooo00CoZJVYodA4A?mEEEGo^[Zj2_ooool00oo^
k^koMgMgoc8b<P0Hooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00_o
oooo00?o0000olG5aOo5aLD07Oo5aLD00ol0003oVIVIoiVIV@0loiVIV@Ko00002_m]KFd;o`0003oo
VIVI00?o0000olG5aOo5aLD04_o5aLD4ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool00ol0003oaLG5olG5a@0FolG5a@03o`000?oooooooooo00oooooo00GogMgMofIVI_lb
<S;oV9RHonk^kP06ooooo`04oc8b<_l0003o<S8bonk^kQSooooo00?o0000ooooooooool01oooool0
01[ooooo00?o0000ooooooooool02_ooool00ol0003oaLG5olG5a@0MolG5a@03o`000?nIVIWoVIVI
03WoVIVI1?l0000Kofe]K@So0000>?nIVIT2o`0001;oaLG51?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00?o0000olG5aOo5aLD05_o5aLD00ol0003oooooooooo`0Boooo
o`03oiRHV?lb<S;ooooo00Kooooo00?oQhN7oiRHV?ooool06?ooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?o5aLGoaLG501goaLG500?o0000oiVIVOnI
VIT0=_nIVIT3o`0002OoKFe]1?l0000foiVIV@;o00004?o5aLD4ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oaLG5olG5a@0FolG5a@03o`000?oooooooooo01So
oooo00Go^[Zjooooooooooooooooo`00000Iooooo`03o`000?oooooooooo00Oooooo000Jooooo`03
o`000?oooooooooo00[ooooo00?o0000olG5aOo5aLD07?o5aLD00ol0003oVIVIoiVIV@0doiVIV@?o
0000;_m]KFd3o`0003GoVIVI00?o0000olG5aOo5aLD03Oo5aLD4ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oaLG5olG5a@0FolG5a@03o`000?oooooooooo01So
oooo00GoIVIVoiRHV?ooooooQhN7o`00000Iooooo`03o`000?oooooooooo00Oooooo000Jooooo`03
o`000?oooooooooo00Wooooo00?o0000olG5aOo5aLD07Oo5aLD00ol0003oVIVIoiVIV@0aoiVIV@?o
0000=?m]KFd4o`0003;oVIVI0_l0000=olG5a@Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?o5aLGoaLG501KoaLG500?o0000ooooooooool06?ooool01Oo^k^ko
EEEEo`000?l0003oV9RH01Wooooo00?o0000ooooooooool01oooool001[ooooo00?o0000oooooooo
ool02Oooool00ol0003oaLG5olG5a@0LolG5a@03o`000?nIVIWoVIVI033oVIVI0_l0000kofe]K@Co
0000<?nIVIT00ol0003oaLG5olG5a@0:olG5a@Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?o5aLGoaLG501KoaLG500?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`07ooooo`006_ooool00ol0003oooooooooo`08ooooo`03o`000?o5aLGoaLG501coaLG5
00?o0000oiVIVOnIVIT0;_nIVIT3o`00047oKFe]1?l0000]oiVIV@03o`000?o5aLGoaLG500WoaLG5
1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo6_l0000hooooo`03o`00
0?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o0000olG5aOo5aLD07?o5
aLD00ol0003oVIVIoiVIV@0]oiVIV@03o`000?m]KFgoKFe]04KoKFe]0_l0000/oiVIV@;o00002Oo5
aLD4ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`07ooooo`006_ooool00ol0003oooooooooo`07ooooo`03o`000?o5aLGoaLG501coaLG500?o0000
oiVIVOnIVIT0;?nIVIT2o`0004_oKFe]0ol0000[oiVIV@03o`000?o5aLGoaLG500KoaLG51?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool0
01[ooooo00?o0000ooooooooool01_ooool00ol0003oaLG5olG5a@0LolG5a@03o`000?nIVIWoVIVI
02_oVIVI0_l0001@ofe]K@;o0000:_nIVIT00ol0003oaLG5olG5a@05olG5a@Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`;o
00001oooool00ol0003oaLG5olG5a@0KolG5a@03o`000?nIVIWoVIVI02_oVIVI00?o0000ofe]KOm]
KFd0D_m]KFd2o`0002WoVIVI00?o0000olG5aOo5aLD01?o5aLD3ooooo`;o00003?ooool00ol0003o
ooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`03o`000?oooooooooo00Gooooo
00?o0000olG5aOo5aLD06oo5aLD00ol0003oVIVIoiVIV@0ZoiVIV@;o0000Eom]KFd3o`0002OoVIVI
00?o0000olG5aOo5aLD00oo5aLD4ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`07ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?o5
aLGoaLG501coaLG500?o0000oiVIVOnIVIT0:?nIVIT2o`0005coKFe]0_l0000VoiVIV@03o`000?o5
aLGoaLG500;oaLG51?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oaLG5olG5a@0K
olG5a@03o`000?nIVIWoVIVI02SoVIVI00?o0000ofe]KOm]KFd0G_m]KFd2o`0002GoVIVI00Co0000
olG5aOo5aLGoaLG51?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool01oooool001[ooooo00?o0000ooooooooool00oooool00ol0003oaLG5olG5a@0K
olG5a@03o`000?nIVIWoVIVI02OoVIVI0_l0001Sofe]K@?o00008onIVIT00ol0003oaLG5olG5a@04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07
ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?o5aLGoaLG501[oaLG500?o0000oiVI
VOnIVIT09_nIVIT2o`0006SoKFe]0_l0000RoiVIV@03o`000?o5aLGooooo00?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02oooooa[o0000>?ooool00ol0003oooooooooo`07oooo
o`006_ooool00ol0003oooooooooo`02ooooo`03o`000?o5aLGoaLG501[oaLG500?o0000oiVIVOnI
VIT09_nIVIT00ol0003oKFe]ofe]K@1Zofe]K@;o00008OnIVIT00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool001[ooooo00Go0000oooooooooooo
ooooo`00000LolG5a@03o`000?nIVIWoVIVI02GoVIVI0_l0001_ofe]K@03o`000?nIVIWoVIVI01oo
VIVI00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo000Jooooo`04
o`000?oooooooooooooooagoaLG500?o0000oiVIVOnIVIT08onIVIT2o`00077oKFe]0_l0000PoiVI
V@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`006_ooool01?l0003o
oooooooooooooolLolG5a@03o`000?nIVIWoVIVI02?oVIVI00?o0000ofe]KOm]KFd0Lom]KFd00ol0
003oVIVIoiVIV@0MoiVIV@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`07oooo
o`006_ooool01?l0003ooooooooooooooolKolG5a@03o`000?nIVIWoVIVI02?oVIVI00?o0000ofe]
KOm]KFd0MOm]KFd2o`0001goVIVI1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03oc8b<_nHV9Sooooo
00Wooooo00Go8B4Qo`000?l0003oA4A4okZj^P04ooooo`03oc8b<_oooooooooo01;ooooo00?o0000
ooooooooool01oooool001[ooooo0_l00002oooooa[oaLG500?o0000oiVIVOnIVIT08onIVIT00ol0
003oKFe]ofe]K@1hofe]K@;o00006onIVIT3ooooo`;o00003?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool01Oo^k^koV9RHob4Q8OmgMgOo
gMgM00[ooooo00?ok^k^oeEEEOnYZJT06?ooool00ol0003oooooooooo`07ooooo`006_ooool01?l0
003ooooooooooooooolIolG5a@03o`000?nIVIWoVIVI02;oVIVI0_l0001mofe]K@03o`000?nIVIWo
VIVI01SoVIVI1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`04okZj^_mEEEGoA4A4okZj^PWooooo00?o
k^k^oa0@4?ooool05oooool00ol0003oooooooooo`07ooooo`006_ooool01?l0003ooooooooooooo
oolHolG5a@03o`000?nIVIWoVIVI02;oVIVI00?o0000ofe]KOm]KFd0O_m]KFd2o`0001SoVIVI1?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Aooooo`03okZj^_l@413o<S8b00Wooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`07ooooo`006_ooool01?l0003ooooooooooooooolGolG5a@03o`000?nI
VIWoVIVI02;oVIVI00?o0000ofe]KOm]KFd0POm]KFd00ol0003oVIVIoiVIV@0EoiVIV@Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool03oooool01?nj^[[oEEEEodA4A?nYZJT8ooooo`03onk^k_mgMgOo<S8b01Sooooo
00?o0000ooooooooool01oooool001[ooooo00Co0000oooooooooooooooo5_o5aLD00ol0003oVIVI
oiVIV@0RoiVIV@03o`000?m]KFgoKFe]08?oKFe]0_l0000EoiVIV@Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
3?ooool01Oo^k^koV9RHoc8b<_mVIVKogMgM00Wooooo00Co<S8bo`000?lb<S;ok^k^6?ooool00ol0
003oooooooooo`07ooooo`006_ooool01?l0003ooooooooooooooolEolG5a@03o`000?nIVIWoVIVI
02;oVIVI00?o0000ofe]KOm]KFd0Q_m]KFd00ol0003oVIVIoiVIV@0BoiVIV@Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03?ooool00olb<S;oV9RHooooo`0<ooooo`03ohN7QonHV9Sooooo01Sooooo00?o0000oooo
ooooool01oooool001[ooooo00Co0000oooooooooooooooo5?o5aLD00ol0003oVIVIoiVIV@0RoiVI
V@03o`000?m]KFgoKFe]08SoKFe]00?o0000oiVIVOnIVIT04OnIVIT4ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Sooooo00Go^[Zjooooooooooooooooo`00000Iooooo`03o`000?oooooooooo00Oooooo000Joooo
o`04o`000?oooooooooooooooa?oaLG500?o0000oiVIVOnIVIT08_nIVIT00ol0003oKFe]ofe]K@2:
ofe]K@03o`000?nIVIWoVIVI013oVIVI1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`05ofIVI_nHV9So
ooooohN7Qol000006Oooool00ol0003oooooooooo`07ooooo`004Oooool4o`000003oa0@4?oooooo
oooo00;ooooo00Co0000oooooooooooooooo4Oo5aLD2o`0002?oVIVI0_l00010ofe]KASo0000=_m]
KFd2o`00013oVIVI1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`05onk^k_mEEEGo0000o`000?nHV9P0
6Oooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`04ooooo`04o`000?oo
oooooooooooooa3oaLG500?o0000oiVIVOnIVIT08_nIVIT00ol0003oKFe]ofe]K@0hofe]K@So0000
6?m1@D47o`00037oKFe]00?o0000oiVIVOnIVIT03OnIVIT4ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_oooolJo`0003Sooooo00?o0000ooooooooool01oooool001?ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooooooool?olG5a@03o`000?nIVIWoVIVI027oVIVI
0_l0000gofe]K@Co00009om1@D44o`0002koKFe]00?o0000oiVIVOnIVIT03?nIVIT4ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`004ooo
ool00ol0003oooooooooo`04ooooo`;o00000_ooool>olG5a@03o`000?nIVIWoVIVI027oVIVI00?o
0000ofe]KOm]KFd0<om]KFd4o`0002oo@D510ol0000/ofe]K@03o`000?nIVIWoVIVI00_oVIVI0ooo
ool2o`0000cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`004oooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`goaLG500?o0000oiVIVOnIVIT08?nI
VIT2o`0003?oKFe]0ol0000fod51@@Co0000:Om]KFd00ol0003oVIVIoiVIV@0:oiVIV@Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000C
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo2oo5aLD2o`0002;oVIVI00?o
0000ofe]KOm]KFd0<?m]KFd3o`0003go@D510ol0000Wofe]K@03o`000?nIVIWoVIVI00WoVIVI1?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01ooo
ool001?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool9olG5a@;o00008_nI
VIT2o`00033oKFe]0ol00013od51@@?o00009Om]KFd00ol0003oVIVIoiVIV@08oiVIV@Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000A
ooooo`03oeEEEOmVIVKo000000Kooooo00Co0000oooooooooooooooo2?o5aLD00ol0003oVIVIoiVI
V@0QoiVIV@03o`000?m]KFgoKFe]02goKFe]0ol00019od51@@?o00008_m]KFd00ol0003oVIVIoiVI
V@08oiVIV@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00Oooooo000Jooooo`04o`000?ooooooooooooooo`KoaLG50_l0000RoiVIV@;o0000;_m]
KFd2o`0004oo@D510_l0000Qofe]K@03o`000?nIVIWoVIVI00OoVIVI1?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool001[ooooo00Co0000
oooooooooooooooo1?o5aLD2o`0002?oVIVI00?o0000ofe]KOm]KFd0;?m]KFd2o`0005?o@D510ol0
000Oofe]K@03o`000?nIVIWoVIVI00KoVIVI1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool01oooool001[ooooo00Co0000oooooooooooooooo0oo5
aLD00ol0003oVIVIoiVIV@0RoiVIV@03o`000?m]KFgoKFe]02_oKFe]0_l0001Hod51@@;o00007_m]
KFd00ol0003oVIVIoiVIV@05oiVIV@Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo00Oooooo000Jooooo`05o`000?ooooooooooooooooo5aLD00_l0
000SoiVIV@;o0000;?m]KFd2o`0005co@D510_l0000Mofe]K@03o`000?nIVIWoVIVI00CoVIVI1?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo00?o410@oc8b<_o^k^h08_oo
ool00ol0003oooooooooo`07ooooo`006_ooool01Ol0003ooooooooooooooooo000002?oVIVI0_l0
000/ofe]K@;o0000H?m1@D400ol0003oKFe]ofe]K@0Jofe]K@03o`000?nIVIWoVIVI00CoVIVI1?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?oc<c<ohN7Qoooool01ooo
ool01omgMgOoooooooooooooooook^k^oeEEEOo^k^h00oooool00onYZJWo^[Zjooooo`0Kooooo`03
o`000?oooooooooo00Oooooo000Jooooo`;o00000_oooolSoiVIV@03o`000?m]KFgoKFe]02_oKFe]
00?o0000od51@Om1@D40HOm1@D400ol0003oKFe]ofe]K@0Jofe]K@03o`000?nIVIWoVIVI00?oVIVI
0oooool2o`0000cooooo00?o0000ooooooooool08Oooool2oiRHV0Wooooo00?o0000ooooooooool0
0_ooool00oo<c<coEEEEooooo`03ooooo`03okZj^_nHV9Sooooo01[ooooo00?o0000ooooooooool0
1oooool001[ooooo00Co0000oooooooooooooooo8OnIVIT2o`0002coKFe]0_l0001Uod51@@;o0000
6om]KFd00ol0003oVIVIoiVIV@02oiVIV@Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Iooooo`?o00001?ooool01_oMgMgoA4A4oooooooooooo410@ogMgM`;ooooo00Go8B4Qoc8b
<_o^k^koooooob4Q8@05ooooo`03oa0@4?nYZJWooooo00?ooooo00?oEEEEokZj^_ooool06Oooool0
0ol0003oooooooooo`07ooooo`006_ooool01?l0003ooooooooooooooolOoiVIV@;o0000;?m]KFd2
o`0006Wo@D5100?o0000ofe]KOm]KFd06?m]KFd00ol0003oVIVIoiVIV@02oiVIV@Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l0003ok^k^00Cooooo00?oEEEE
ojVYZOooool00_ooool01_o^k^ko^[Zjolc<c?l@413oc<c<oeEEE@Kooooo00Cok^k^oa0@4?n7QhOo
k^k^0oooool00oo<c<coA4A4ooooo`0Iooooo`03o`000?oooooooooo00Oooooo000Jooooo`04o`00
0?oooooooooooooooagoVIVI0_l0000/ofe]K@;o0000K?m1@D400ol0003oKFe]ofe]K@0Hofe]K@04
o`000?nIVIWoVIVIoiVIV@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Goooo
o`03okZj^_m4A4Co000000;o000000KoA4A4okZj^_oooooooooooa0@4?oMgMd4ooooo`05ojVYZOmV
IVKoIVIVoooooooMgMd01_ooool01?nYZJWoA4A4oooooomgMgL4ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool001[ooooo00Co0000oooooooooooooooo7?nIVIT00ol0003o
KFe]ofe]K@0Zofe]K@;o0000Kom1@D400ol0003oKFe]ofe]K@0Hofe]K@03o`000?nIVIWoVIVI00Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`0;oiRHV?l@413oV9RHonk^
k_l0003ok^k^oiRHV?l@413oV9RHooooool000001_ooool00olQ8B7oZJVYooooo`07ooooo`05oeEE
EOnHV9SoooooomgMgOnj^[X00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oo
oooo000Jooooo`04o`000?oooooooooooooooa[oVIVI0_l0000[ofe]K@;o0000L_m1@D42o`0001So
KFe]00?o0000oiVIVOnIVIT01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Ko
oooo00Go0000omgMgOooooooooooo`000002ooooo`04onk^k_l0003oooooo`0000Kooooo00?o0000
okZj^_ooool01oooool01Ol0003ogMgMoooooooooooo^[Zj00?ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`07ooooo`006_ooool01?l0003ooooooooooooooolHoiVIV@;o0000:om]
KFd2o`0007Ko@D5100?o0000ofe]KOm]KFd05_m]KFd00ol0003oVIVIooooo`03ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05_ooool01Ol0003ogMgMoooooooooooo000000;ooooo
00GogMgMo`000?oooooo410@olc<c004ooooo`04olc<c?lQ8B7oQhN7onk^kPKooooo00?oQhN7ob4Q
8Oooool00_ooool01OmgMgOooooooooooooooooo000001[ooooo00?o0000ooooooooool01oooool0
01[ooooo00Co0000oooooooooooooooo5_nIVIT2o`0002_oKFe]0_l0001iod51@@03o`000?m]KFgo
KFe]01GoKFe]00?o0000oiVIVOooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Kooooo00coV9RHob4Q8OnYZJWoooooo`000?o^k^koZJVYob4Q8OnHV9SooooooeEEEOn7QhL3
ooooo`06ohN7Qom4A4CoIVIVonk^k_mVIVKo410@1?ooool2o`000005ogMgMoooooooooooooooool@
41000_ooool00oo<c<coA4A4ooooo`0Iooooo`03o`000?oooooooooo00Oooooo000Jooooo`04o`00
0?oooooooooooooooaCoVIVI0_l0000[ofe]K@;o0000O?m1@D400ol0003oKFe]ofe]K@0Eofe]K@03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03
okZj^_m4A4Co000000;o000000KoA4A4okZj^_ooooooooooomgMgOlQ8B4Fooooo`03oeEEEOnj^[[o
oooo01Wooooo00?o0000ooooooooool01oooool001[ooooo00Co0000oooooooooooooooo4_nIVIT2
o`0002coKFe]00?o0000od51@Om1@D40OOm1@D400ol0003oKFe]ofe]K@0Eofe]K@05o`000?oooooo
ooooooooool000003?ooool00ol0003oooooooooo`0Iooooo`03onk^k_l0003ok^k^00Gooooo00?o
ZJVYofIVI_ooool04oooool2oiRHV1_ooooo00?o0000ooooooooool01oooool001[ooooo00Co0000
oooooooooooooooo4?nIVIT2o`0002coKFe]0_l0000jod51@Ago0000:_m1@D400ol0003oKFe]ofe]
K@0Dofe]K@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`?o00001_oo
ool00oo<c<coQhN7ooooo`0Aooooo`03ojVYZOnj^[[ooooo01_ooooo00?o0000ooooooooool01ooo
ool001[ooooo0_l00002ooooo`goVIVI0ol0000[ofe]K@?o0000=om1@D4Vo`0002Ko@D5100?o0000
ofe]KOm]KFd05?m]KFd3ooooo`;o00003?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo00Oooooo000Jooooo`04o`000?ooooooooooooooo`_oVIVI0_l0000[ofe]K@?o0000=_m1@D4]
o`0002Co@D5100?o0000ofe]KOm]KFd04om]KFd4ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool01?l0003oooooooooooooool8
oiVIV@?o0000:om]KFd2o`0003Ko@D51<ol0000Rod51@@03o`000?m]KFgoKFe]01;oKFe]1?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01oooool0
01[ooooo00Co0000oooooooooooooooo1OnIVIT3o`0002_oKFe]0ol0000eod51@CWo00008?m1@D40
0ol0003oKFe]ofe]K@0Aofe]K@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00Oooooo000Jooooo`04o`000?ooooooooooooooo`;oVIVI0ol0000/
ofe]K@;o0000=Om1@D4no`0001oo@D5100?o0000ofe]KOm]KFd04?m]KFd4ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`07ooooo`006_ooool01?l0
003oooooooooooooool2o`0002goKFe]0_l0000dod51@D?o00007_m1@D400ol0003oKFe]ofe]K@0?
ofe]K@Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo00Oooooo000Jooooo`04o`000?ooooooooooooooobgoKFe]0_l0000cod51@DWo00006om1@D40
0ol0003oKFe]ofe]K@0?ofe]K@Cooooo00?o0000ooooooooool02_oooomHo`0000Wooooo000Joooo
o`04o`000?ooooooooooooooob[oKFe]0ol0000bod51@Dko00006_m1@D400ol0003oKFe]ofe]K@0>
ofe]K@Cooooo00?o0000ooooooooool0Joooool001[ooooo00Co0000oooooooooooooooo:?m]KFd2
o`0003;o@D51Dol0000Iod51@@03o`000?m]KFgoKFe]00goKFe]1?ooool00ol0003oooooooooo`1[
ooooo`006_ooool01?l0003ooooooooooooooolUofe]K@?o0000<_m1@D5Fo`0001Wo@D5100?o0000
ofe]KOm]KFd03?m]KFd4ooooo`03o`000?oooooooooo06_ooooo000Jooooo`04o`000?oooooooooo
ooooob7oKFe]1?l0000cod51@E[o00006?m1@D400ol0003oKFe]ofe]K@0;ofe]K@Cooooo00?o0000
ooooooooool0Joooool001[ooooo0_l00002oooooakoKFe]0ol0000eod51@Ego00005om1@D400ol0
003oKFe]ofe]K@0;ofe]K@?ooooo0_l0001]ooooo`006_ooool01?l0003ooooooooooooooolKofe]
K@?o0000=Om1@D5Qo`0001Oo@D5100?o0000ofe]KOm]KFd02_m]KFd4ooooo`03o`000?oooooooooo
06_ooooo000Jooooo`04o`000?oooooooooooooooaSoKFe]0ol0000fod51@FCo00005om1@D400ol0
003oKFe]ofe]K@09ofe]K@Cooooo00?o0000ooooooooool0Joooool001[ooooo00Co0000oooooooo
oooooooo5?m]KFd4o`0003Oo@D51Iol0000God51@@03o`000?m]KFgoKFe]00SoKFe]1?ooool00ol0
003oooooooooo`1[ooooo`006_ooool01?l0003oooooooooooooool?ofe]K@Go0000>?m1@D5/o`00
01Go@D5100?o0000ofe]KOm]KFd02?m]KFd4ooooo`03o`000?oooooooooo06_ooooo000Jooooo`04
o`000?ooooooooooooooo`_oKFe]1?l0000jod51@G3o00005Om1@D400ol0003oKFe]ofe]K@07ofe]
K@Cooooo00?o0000ooooooooool0Joooool001[ooooo00Co0000oooooooooooooooo2?m]KFd3o`00
03_o@D51M?l0000Eod51@@03o`000?m]KFgoKFe]00KoKFe]1?ooool00ol0003oooooooooo`1[oooo
o`006_ooool01?l0003oooooooooooooool5ofe]K@?o0000>om1@D5ho`0001Go@D5100?o0000ofe]
KOm]KFd01Om]KFd4ooooo`03o`000?oooooooooo06_ooooo000Jooooo`04o`000?oooooooooooooo
o`;oKFe]0ol0000kod51@Gco00005?m1@D400ol0003oKFe]ofe]K@05ofe]K@Cooooo00?o0000oooo
ooooool0Joooool001[ooooo00Co0000oooooooooooooooo0_l0000kod51@H3o00005?m1@D400ol0
003oKFe]ofe]K@04ofe]K@Cooooo00?o0000ooooooooool0Joooool001[ooooo00Co0000oooooooo
oooooooo>om1@D63o`0001Co@D5100?o0000ofe]KOm]KFd00om]KFd4ooooo`03o`000?oooooooooo
06_ooooo000Jooooo`;o00000_oooolgod51@HOo00005?m1@D400ol0003oKFe]ofe]K@03ofe]K@?o
oooo0_l0001]ooooo`006_ooool01?l0003ooooooooooooooolcod51@Hco00005?m1@D400ol0003o
KFe]ofe]K@02ofe]K@Cooooo00?o0000ooooooooool0Joooool001[ooooo00Co0000oooooooooooo
oooo<?m1@D6@o`0001Co@D5100Co0000ofe]KOm]KFgoKFe]1?ooool00ol0003oooooooooo`1[oooo
o`006_ooool01?l0003oooooooooooooool[od51@IKo00004om1@D401?l0003oKFe]ofe]KOm]KFd4
ooooo`03o`000?oooooooooo06_ooooo000Jooooo`04o`000?ooooooooooooooobGo@D51WOl0000C
od51@@03o`000?m]KFgoKFe]00Cooooo00?o0000ooooooooool0Joooool001[ooooo00Co0000oooo
oooooooooooo7om1@D6So`0001Co@D5100?o0000ofe]KOooool00oooool00ol0003oooooooooo`1[
ooooo`006_ooool01?l0003ooooooooooooooolJod51@JWo00004om1@D400ol0003oKFe]ooooo`03
ooooo`03o`000?oooooooooo06_ooooo000Jooooo`04o`000?oooooooooooooooaCo@D51/?l0000C
od51@@03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Joooool0013ooooo1Ol00005oooo
o`04o`000?ooooooooooooooo`oo@D51]_l0000Cod51@@05o`000?ooooooooooooooool00000KOoo
ool0013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`04o`000?ooooooooooooooo`_o@D51
^_l0000Cod51@@Cooooo00?o0000ooooooooool0Joooool0017ooooo00?oV9RHob4Q8Oo^k^h01_oo
ool01?l0003oooooooooooooool8od51@Kko00004_m1@D44ooooo`03o`000?oooooooooo06_ooooo
000Booooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l00002ooooo`Ko@D51`Ol0000Aod51@@?ooooo0_l0
001]ooooo`004oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0=gooooo00?o0000
ooooooooool0Joooool001Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000003Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo03?ooooo00Go0000ooooooooooooooooo`00001]ooooo`004?ooool01Ol0003o^[ZjoooooonH
V9So410@00Gooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00001]ooooo`004?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Go
oooohOl0001]ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {254.312, 0}} -> {-1.07223, -1.05, 0.0103219, \
0.0103219}, {{8.6875, 250.938}, {248.25, 6}} -> {-2.57136, -2.47718, \
0.0231845, 0.0231845}, {{263, 350.25}, {214.312, 39.9375}} -> {-10.2367, \
-1.97189, 0.0481725, 0.0584952}, {{267.688, 293.625}, {210.438, 189.062}} -> \
{-10.8616, -3.07394, 0.0506029, 0.0818772}, {{267.688, 293.625}, {185.625, \
164.25}} -> {-10.8616, -4.69921, 0.0506029, 0.0818772}, {{267.688, 293.625}, \
{160.875, 139.5}} -> {-10.8616, -6.32037, 0.0506029, 0.0818772}, {{267.688, \
293.625}, {136.062, 114.688}} -> {-10.8616, -7.94564, 0.0506029, 0.0818772}, \
{{267.688, 293.625}, {111.312, 89.9375}} -> {-10.8616, -9.56681, 0.0506029, \
0.0818772}, {{267.688, 293.625}, {86.5, 65.125}} -> {-10.8616, -11.1921, \
0.0506029, 0.0818772}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.6", "Subsubtitle",
  CellTags->{"Ex. 9.6", "c:35"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Using a plot, determine whether the equation ",
  Cell[BoxData[
      \(TraditionalForm\`3  x\^8 - 2  x + 1 = 0\)]],
  "  has any real solutions. (Hint: Plot the left-hand side as a function of \
",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and see whether it can equal zero for any real ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".)"
}], "Text",
  CellTags->"Ex. 9.6"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A train pulls out of a station, with position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " following the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ 0.1\ t\^2\)]],
  " as a function of time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". A second train coming into the station at high speed, sees the first \
train and applies its brakes, following the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ \(-20\)\ \  + \ 5\ t\  - \ t\^2\ \  - \ 
          t\^3\)]],
  " until it comes to a stop.  Use a plot to determine if the two trains \
collide."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " The solution of Newton's equations for the orbit of a mass point around a \
stationary mass (such as the sun) is defined in cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`1\/r = \(1\/r\_o\) \((e\ sin\[Theta] + 1)\)\)]],
  "  where the orbit parameters ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " being the orbit's ",
  StyleBox["eccentricity",
    FontSlant->"Italic"],
  ") are both greater than or equal to zero. Taking ",
  Cell[BoxData[
      \(TraditionalForm\`e\  = 0, 1/2, 1, \)]],
  " and 2, for each case"
}], "Text",
  CellTags->"i:59"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Plot ",
  Cell[BoxData[
      \(TraditionalForm\`r/r\_o\)]],
  " as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " using a polar plot. Classify each orbit as an ellipse, a parabola, or a \
hyperbola."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In each case find the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(r/r\_o\)\)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  "  for  perihelion (closest approach to the sun)."
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " The power density ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "(energy released per unit volume per unit time) in an industrial process \
is found empirically to depend on the mean density ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  " of fuel in the reactor , and the temperature ",
  StyleBox["T ",
    FontSlant->"Italic"],
  "according to  ",
  Cell[BoxData[
      \(TraditionalForm\`S = 
        0.04 \((n\^3.2 + 
                0.2 \( n\^0.7\) \(T\^1.3\) \
\[ExponentialE]\^\(t\^2/100\))\)/\((10 + T\^2)\)\)]],
  " ",
  StyleBox[" ",
    FontSlant->"Italic"],
  " kW/",
  Cell[BoxData[
      \(TraditionalForm\`cm\^3\)]],
  ", (where ",
  StyleBox["T ",
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " are measured in units of 100 K and 1 g/",
  Cell[BoxData[
      \(TraditionalForm\`cm\^3\)]],
  " respectively) .  Furthermore, if the power density exceeds ",
  Cell[BoxData[
      \(TraditionalForm\`S\  = \ 1\ kW/cm\^3\)]],
  ", the power release will exceed cooling capacity , the temperature will \
increase, and the reactor will melt down. Use a contour plot to find the \
regime  of safe operation in  ",
  StyleBox["n ",
    FontSlant->"Italic"],
  "and ",
  StyleBox["T",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Create an animation of the function defined by ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta], t) = \ \[Theta] + t\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " are polar coordinates. This curve is related to ",
  ButtonBox["Fermat's spiral",
    ButtonData:>{
      URL[ "http://www-groups.dcs.st-and.ac.uk/~history/Curves/Fermats.html"],
       None},
    ButtonStyle->"Hyperlink"],
  ". Plot the function in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane with ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5, \(-5\) < y < 5\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-t\) < \[Theta] < 10  \[Pi]\)]],
  ",  and animate it at a sequence of times from ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 1.8  \[Pi]\)]],
  ", in units of ",
  Cell[BoxData[
      \(TraditionalForm\`0.2\ \[Pi]\)]],
  "."
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " Read about the plotting function ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " documentation. Use this function to create a surface plot of a ",
  ButtonBox["M\[ODoubleDot]bius",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mobius.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " strip (a surface with only a single side),  defined by the parametric \
equations ",
  Cell[BoxData[
      \(TraditionalForm\`r(s, \[Theta]) = \ \ 1\  + \ 
          s\ \(cos(\[Theta]/2)\), \ 
      z(s, \[Theta]) = s\ \(sin(\[Theta]/2)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)/2 < s < 1/2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] < 2\ \[Pi]\)]],
  ", in cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], z)\)\)]],
  ". Use ",
  StyleBox["RealTime3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  to view the surface from different angles. (You can put more twists in \
the strip by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]/2\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`n\ \[Theta]/2\)]],
  ".)"
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Read about the plotting function ",
  StyleBox["ContourPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  available in the graphics add-on packages. Use this function to plot \
the surface defined by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y, z)\  = \ 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y, z)\  = 
        x\ y\^2 - \ y\ z\^2\  + \ \(\(z\)\(\ \)\(x\^2\)\(\ \)\)\)]],
  " , over the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`3\)]],
  " in each dimension. (Hint: Take ",
  StyleBox["PlotPoints-> 5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["6",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "). Use ",
  StyleBox["RealTime3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics to view the surface from all sides, and determine where there is \
a singularity. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.7 Help for ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "Users"
}], "Subtitle",
  CellTags->{"Sec. 9.7", "c:36"}],

Cell[TextData[{
  "By now you can see that there's a lot to remember--and we are just getting \
started! Fortunately, ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " comes with an excellent online help facility. It is available on the main \
menu under ",
  StyleBox["Help",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If you go to it now, and  type into the search window  the name of an \
intrinsic function that you wish to learn about, the help browser will \
automatically display information about the function, including options, \
examples, and information about other related functions. Also, the ",
  StyleBox["Master Index",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the help browser has an alphabetical list of every function. Plus, the \
entire 1400-page ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Book",
    FontSlant->"Italic"],
  " is available online by clicking the ",
  StyleBox["Mathematica Book",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "button. Information is also available for the add-on packages."
}], "Text"],

Cell["\<\
\tThe examples displayed in the help browser window can be modified \
and evaluated, just like the examples in the electronic version of this \
textbook,  allowing you to easily explore variations in the examples. \
\>", \
"Text"],

Cell[TextData[{
  "\tYou can also find information about ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions directly within a ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "session. In order to see the definition of a function, type ",
  StyleBox["?Function",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example,"
}], "Text",
  CellTags->"i:122"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Eigenvalues\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.94"],

Cell[BoxData[
    RowBox[{"\<\"Eigenvalues[m] gives a list of the eigenvalues of the square \
matrix m.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Eigenvalues",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print"]
}, Open  ]],

Cell["\<\
This also works for user-defined variables and functions. For \
instance, if you define a function as\
\>", "Text"],

Cell[BoxData[
    \(\(f[x_]\  = \ x\ Sin[x];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.95"],

Cell["you can check its definition using", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.96"],

Cell["Global`f", "Print"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(f[x_] = x\ Sin[x]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"Info3244700897-7405223"]
}, Open  ]],

Cell["\<\
The first line is the full name of the variable, including its \
context. You can also obtain a list of all user-defined variables that have \
been employed in the current session:\
\>", "Text",
  CellTags->"i:121"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Global`*\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.97"],

Cell[BoxData[GridBox[{
        {
          StyleBox["Global`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["f",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3244700899-8581337", "Global`f"},
                  ButtonFrame->"None",
                  ButtonNote->"Global`"], 
                ButtonBox[
                  StyleBox["x",
                    FontColor->RGBColor[0, 0, 1],
                    FontVariations->{"Underline"->True}],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3244700899-8581337", "Global`x"},
                  ButtonFrame->"None",
                  ButtonNote->"Global`"], "", "", "", "", "", "", "", "", "", 
                "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", 
                "", "", "", "", "", "", "", "", "", "", "", ""}
              },
            RowMinHeight->1.05]}
        },
      RowSpacings->{2, 3},
      ColumnAlignments->{Left},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}]
}, Open  ]],

Cell[TextData[{
  "By clicking on the symbols, you will obtain their definitions and/or \
values.  ",
  StyleBox["Eigenvalues",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not listed, because it is not a user-defined variable; and ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is listed because it was used, even though it has not yet been given a \
definition."
}], "Text"],

Cell[TextData[{
  "\tIf you can't remember the name of the function, sometimes you can make a \
guess, and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will correct you:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalue[m]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.98"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(Eigenvalue\)\" is \
similar to existing symbol \"\!\(Eigenvalues\)\"."\)], "Message"],

Cell[BoxData[
    \(Eigenvalue[m]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tTo see all of the options to any ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function,  you can  type ",
  StyleBox["??Function ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "or ",
  StyleBox["Options[Function]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, ",
  StyleBox["??Plot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "gives a long list of options for the plot command, as well as the values \
they take by default:"
}], "Text",
  CellTags->"i:61"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? Plot\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.99"],

Cell[BoxData[
    RowBox[{"\<\"Plot[f, {x, xmin, xmax}] generates a plot of f as a function \
of x from xmin to xmax. Plot[{f1, f2, ... }, {x, xmin, xmax}] plots several \
functions fi.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Plot",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(Attributes[Plot] = {HoldAll, Protected}\)},
          {" "},
          {GridBox[{
                {\(Options[Plot] = {AspectRatio \[Rule] 1\/GoldenRatio, 
                      Axes \[Rule] Automatic, AxesLabel \[Rule] None, 
                      AxesOrigin \[Rule] Automatic, 
                      AxesStyle \[Rule] Automatic, 
                      Background \[Rule] Automatic, 
                      ColorOutput \[Rule] Automatic, Compiled \[Rule] True, 
                      DefaultColor \[Rule] Automatic, Epilog \[Rule] {}, 
                      Frame \[Rule] False, FrameLabel \[Rule] None, 
                      FrameStyle \[Rule] Automatic, 
                      FrameTicks \[Rule] Automatic, GridLines \[Rule] None, 
                      ImageSize \[Rule] Automatic, MaxBend \[Rule] 10.`, 
                      PlotDivision \[Rule] 30.`, PlotLabel \[Rule] None, 
                      PlotPoints \[Rule] 25, PlotRange \[Rule] Automatic, 
                      PlotRegion \[Rule] Automatic, 
                      PlotStyle \[Rule] Automatic, Prolog \[Rule] {}, 
                      RotateLabel \[Rule] True, Ticks \[Rule] Automatic, 
                      DefaultFont \[RuleDelayed] $DefaultFont, 
                      DisplayFunction \[RuleDelayed] $DisplayFunction, 
                      FormatType \[RuleDelayed] $FormatType, 
                      TextStyle \[RuleDelayed] $TextStyle}\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "Plot"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.8 Computer Algebra", "Subtitle",
  CellTags->{"Sec. 9.8", "c:37"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["9.8.1 Manipulating Expressions", "Subsubtitle",
  CellTags->"c:38"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do symbolic as well as numerical mathematics.  The program will \
perform basic algebraic simplifications automatically, as in"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(4  x + 5 - 3  x + 15\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.100"],

Cell[BoxData[
    \(20 + x\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will not expand out expressions in brackets unless you ask it to do so \
using the ",
  StyleBox["Expand",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function",
  ":"
}], "Text",
  CellTags->"i:62"],

Cell[CellGroupData[{

Cell[BoxData[
    \(5 \((x + 2  y)\)\  + 10 \((x\  - 4  y^2\ x - y)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.101"],

Cell[BoxData[
    \(5\ \((x + 2\ y)\) + 10\ \((x - y - 4\ x\ y\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.102"],

Cell[BoxData[
    \(15\ x - 40\ x\ y\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " \tAnother way to simplify an expression is to apply the ",
  StyleBox["Factor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, which tries to factor out all common elements in an expression. \
For example, when applied to the above result, ",
  StyleBox["Factor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " yields"
}], "Text",
  CellTags->"i:63"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.103"],

Cell[BoxData[
    \(\(-5\)\ x\ \((\(-3\) + 8\ y\^2)\)\)], "Output"]
}, Open  ]],

Cell["\<\
\tThere are also several command that are useful when  dealing with \
 complex expressions that include terms with numerators and denominators. For \
instance,  the expression\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x/\((x^2\  + \ 2)\)\  + \ 3/\((x - 1)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.104"],

Cell[BoxData[
    \(3\/\(\(-1\) + x\) + x\/\(2 + x\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "can be put over a common denominator, using the function ",
  StyleBox["Together",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Together[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.105"],

Cell[BoxData[
    \(\(6 - x + 4\ x\^2\)\/\(\((\(-1\) + x)\)\ \((2 + x\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The numerator and denominator of the expression can then be extracted \
using the functions",
  StyleBox[" Numerator ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "and ",
  StyleBox["Denominator",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Numerator[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.106"],

Cell[BoxData[
    \(6 - x + 4\ x\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Denominator[%%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.107"],

Cell[BoxData[
    \(\((\(-1\) + x)\)\ \((2 + x\^2)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If you really want ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " to do all of the work (and after all, isn't that what computers are \
for?), the function ",
  StyleBox["Simplify",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will try various tricks to simplify a given expression . The function ",
  StyleBox["FullSimplify",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has an even larger bag of simplification tricks,  but for this reason \
takes somewhat longer  to run. For example, ",
  StyleBox["Simplify",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " knows all the trigonometric identities:"
}], "Text",
  CellTags->"i:64"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\ Sin[x]^2\ Cos[x] + \ Cos[x]^3]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.108"],

Cell[BoxData[
    \(Cos[x]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One of the palettes, called AlgebraicManipulation, contains a  suite of \
functions that are useful in simplifying or otherwise manipulating algebraic \
expressions. A list of these commands is also provided in Table ",
  ButtonBox["9.14",
    ButtonData:>"Table 9.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          
          StyleBox[\(Table  9  .14  
              Some\ Useful\ Functions\ for\ Doing\ Computer\ Algebra\),
            FontSize->9]},
        {
          StyleBox[GridBox[{
                {
                  StyleBox[\(Expand[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Multiply\ out\ products\ and\ powers\)},
                {
                  StyleBox[\(Factor[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Reduce\ to\ a\ product\ of\ factors\)},
                {
                  StyleBox[\(Together[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Put\ all\ terms\ over\ a\ common\ \
denominator\)},
                {
                  StyleBox[\(Apart[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Separate\ out\ into\ terms\ with\ simple\ \
denominators\)},
                {
                  StyleBox[\(Simplify[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Try\ to\ simplify\ an\ expression\)},
                {
                  StyleBox[\(FullSimplify[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Try\ a\ larger\ collection\ of\ tricks\ to\ \
simplify\ an\ expression\)},
                {
                  StyleBox[\(Numerator[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Pick\ out\ the\ numerator\ of\ an\ \
expression\)},
                {
                  StyleBox[\(Denominator[expr]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(Pick\ out\ the\ denominator\ of\ an\ \
expression\)}
                },
              ColumnSpacings->2.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.14"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.8.2 Replacement", "Subsubtitle",
  CellTags->"c:39"],

Cell[TextData[{
  " In order to evaluate an expression at specific values of the variables \
that appear in the expression, one can perform a ",
  StyleBox["replacement",
    FontSlant->"Italic"],
  ". For example, to evaluate the expression ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 2\)]],
  ", we can replace the variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "  by ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " using the notation"
}], "Text",
  CellTags->"i:65"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x^2\  /. x \[Rule] 2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.109"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The symbol  ",
  StyleBox["/.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  can be thought of as the verb \"replace\", and the expression ",
  StyleBox["/.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule]",
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  means replace ",
  StyleBox["x",
    FontSlant->"Italic"],
  " with 2. The right arrow ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  "  can be obtained from the BasicInput palette, or by typing ->   \
(\"minus-greater than-space\"). One can perform more than one substitution at \
the same time by using a list after the symbol ",
  StyleBox["/.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(y\ Cos[x]\  /. {x \[Rule] 45\ Degree, \ y \[Rule] 2}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.110"],

Cell[BoxData[
    \(\@2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe use of this command is summarized in Table ",
  ButtonBox["9.15",
    ButtonData:>"Table 9.15",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          
          StyleBox[\(Table  
              9  .15\ Performing\ \ Substitutions\ in\ an\ Expression\),
            FontSize->9]},
        {GridBox[{
              {
                RowBox[{
                  StyleBox["expr",
                    FontWeight->"Bold"], " ", 
                  StyleBox["/.",
                    FontWeight->"Bold"], 
                  StyleBox[\(x\ \  \[Rule] value\),
                    FontWeight->"Bold"]}], 
                RowBox[{
                  StyleBox["Replace",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["with",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["value",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontWeight->"Bold"], 
                  StyleBox["everywhere",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["in",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["the",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["expression",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["expr",
                    FontWeight->"Bold"]}]},
              {
                RowBox[{
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  RowBox[{
                    StyleBox["expr",
                      FontWeight->"Bold"], 
                    StyleBox["/.",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["{",
                        FontWeight->"Bold"], 
                      RowBox[{
                        StyleBox[\(x\ \  \[Rule] xval\),
                          FontWeight->"Bold"], 
                        StyleBox[",",
                          FontFamily->"Times",
                          FontWeight->"Bold"], 
                        StyleBox[\(y\ \  \[Rule] yval\),
                          FontWeight->"Bold"], 
                        StyleBox[" ",
                          FontFamily->"Times",
                          FontWeight->"Bold",
                          FontSlant->"Italic"], 
                        StyleBox[",",
                          FontFamily->"Times",
                          FontWeight->"Bold"], 
                        StyleBox["\[Ellipsis]",
                          FontFamily->"Times",
                          FontWeight->"Bold"]}], 
                      StyleBox["}",
                        FontWeight->"Bold"]}]}]}], 
                StyleBox[\(Perform\ several\ replacements\ at\ once\),
                  FontFamily->"Times"]}
              },
            ColumnSpacings->2.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.15"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.8.3 Defining Functions", "Subsubtitle",
  CellTags->{"i:19", "c:40"}],

Cell[CellGroupData[{

Cell["Functions of One Variable", "Section",
  CellTags->"c:41"],

Cell[TextData[{
  "If you need to evaluate an expression like ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + 2  x + 3\)]],
  " many times at different values of the variable, you can save typing in \
all those ",
  StyleBox["/.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  symbols by creating your own function, ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ x\^2 + 2  x + 3\)]],
  ". Then to evaluate the function at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(2\)\(\ \)\)\)]],
  "you need only type ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["2",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ".  To define this function type"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x_]\  = \ x^2 + 2  x + 3\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.111"],

Cell[BoxData[
    \(3 + 2\ x + x\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can now evaluate this function for any value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.112"],

Cell[BoxData[
    \(11\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The underscore in the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is very important. The notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{
              StyleBox["x",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["_",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  "means the following: treat ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " as a stand-in for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " number, variable, or expression. To understand what this implies, let's \
see what happens if we leave out the underscore, defining a new function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " as"
}], "Text",
  CellTags->"i:66"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[x]\  = \ x^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.113"],

Cell[BoxData[
    \(x\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then if we ask for the value of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " at some point, we obtain the following:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.114"],

Cell[BoxData[
    \(g[2]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Typing  ",
  StyleBox["g[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " just returns ",
  StyleBox["g[2]",
    FontFamily->"Courier"],
  " rather than 4, because ",
  StyleBox["g[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has not been defined. We have not defined ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " ",
  StyleBox["for any x",
    FontSlant->"Italic"],
  ". Rather, ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " is defined only when the argument is ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " itself, and no other quantity.  The underscore in ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{
              StyleBox["x",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["_",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  " tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", \"when I type ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " here, I don't literally mean just ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", I mean ",
  StyleBox[" any variable, number, or expression",
    FontSlant->"Italic"],
  "\". "
}], "Text"],

Cell[TextData[{
  "This distinction between ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["g",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["g",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["x_",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " seems like splitting hairs, but it can actually be useful. For example, \
say you want to define a function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " that equals ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " everywhere except at a specific point ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  ", where you want the function to be",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0\)\)\)]],
  ".  Then  type"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[a]\  = \ 0\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.115"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[x_]\  = \ x^2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.116"],

Cell[BoxData[
    \(x\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Evaluating the function at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(3\)\(\ \)\)\)]],
  " yields the correct result: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[3]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.117"],

Cell[BoxData[
    \(9\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Also, evaluating the function at the special point ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " yields"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[a]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.118"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Checking the Definition of a Function", "Section",
  CellTags->"c:42"],

Cell[TextData[{
  "\tIf you want to check the definition of a user-defined function, type ",
  StyleBox["?",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["functionname",
    FontSlant->"Italic"],
  ", just as you would for an intrinsinc function.",
  StyleBox[" ",
    FontSlant->"Italic"],
  "For example, to check the definition of our function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  ", type"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?h\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.119"],

Cell[BoxData[
    \("Global`h"\)], "Print"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(h[a] = 0\)},
                {" "},
                {\(h[x_] = x\^2\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ h],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "Function definitions valid only at specific points like ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " always supersede the more general definitions created by placeholders \
like ",
  StyleBox["x_",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".This is why the general definition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["h",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["x_",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["x",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["^",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["2",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " does not apply to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["h",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["a",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions of Several Variables", "Section",
  CellTags->{"i:67", "c:43"}],

Cell[TextData[{
  "\tCreating  a function with more than one argument is a straightforward \
generalization of the previous syntax. For instance, to define a function ",
  Cell[BoxData[
      \(TraditionalForm\`p(x, y)\  = \ y\ sin\ x\)]],
  ",  type"
}], "Text"],

Cell[BoxData[
    \(\(p[x_, y_]\  = \ y\ Sin[x];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.120"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p[60\ Degree, 2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.121"],

Cell[BoxData[
    \(\@3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[GridBox[{
          {
            StyleBox[\(Table  9  .16\ Defining\ Functions\),
              FontSize->9]},
          {
            StyleBox[GridBox[{
                  {
                    StyleBox[\(f[x] = expr\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"Define", " ", "the", " ", "function", " ", 
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "at", " ", "the", " ", "value", 
                      " ", 
                      StyleBox["x",
                        FontSlant->"Italic"], 
                      RowBox[{"(", 
                        RowBox[{"and", " ", 
                          StyleBox["only",
                            FontSlant->"Italic"], 
                          StyleBox[" ",
                            FontSlant->"Italic"], "at", " ", 
                          StyleBox["x",
                            FontSlant->"Italic"]}], ")"}]}]},
                  {
                    StyleBox[\(f[x_] = expr\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"Define", " ", "the", " ", "function", " ", 
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "for", " ", 
                      StyleBox["any",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "value", " ", "of", " ", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]},
                  {
                    StyleBox[\(?f\),
                      FontFamily->"Courier",
                      FontWeight->
                        "Bold"], \(Ask\ for\ the\ definition\ of\ a\ function\
\)}
                  },
                ColumnSpacings->2.8,
                ColumnAlignments->{Left}],
              FontFamily->"Times"]}
          }]]],
  StyleBox["               ",
    FontSlant->"Italic"]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.8.4 Applying Functions", "Subsubtitle",
  CellTags->"c:44"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows one to apply functions to their argument(s) in several ways. For \
example, to evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", one can type"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[GridBox[{
          {
            StyleBox[\(f[x]\),
              FontFamily->"Courier",
              FontWeight->"Bold"]},
          {
            StyleBox[\(x // f\),
              FontFamily->"Courier",
              FontWeight->"Bold"]},
          {
            StyleBox[\(f@x\),
              FontFamily->"Courier",
              FontWeight->"Bold"]}
          }]],
    FontFamily->"Times"],
  "\t\t"
}], "Text"],

Cell[TextData[{
  "All three forms have their uses. For example, recall that we applied the \
second form of notation to numerical evaluations in ",
  ButtonBox["Sec. 9.1",
    ButtonData:>"Sec. 9.1",
    ButtonStyle->"Hyperlink"],
  " when we used ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["//",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["N",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " rather than ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["N",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ".  This \"afterthought\" form is useful when you have typed out a long \
expression and then decide to apply a function to it.  The \"forethought\" \
form ",
  StyleBox["f@x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will not be used much in this book, but does correspond to the \
theoretical picture of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " \"acting on\" a variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor functions of two arguments, such as ",
  Cell[BoxData[
      \(TraditionalForm\`p(x, y)\)]],
  " above, one can use the notation ",
  StyleBox["x~p~y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". An example of notation of this type is the + symbol. ",
  StyleBox["x+y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " actually stands for ",
  StyleBox["x ~Plus~ y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["Plus[x,y]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the addition function. In fact, one of the basic ideas behind ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is that ",
  StyleBox["any",
    FontSlant->"Italic"],
  " mathematical operation can be thought of  as a function acting on \
arguments. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.8.5 Delayed Evaluation of Functions", "Subsubtitle",
  CellTags->{"i:68", "c:45"}],

Cell[TextData[{
  "Sometimes a function can't be evaluated by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " until a specific value of the argument is given. For instance, this \
happens when you deal with functions that require specific numerical inputs. \
Say, for example, that we wish to define a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " that plots the function ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ y\)]],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(-x\) < y < x\)]],
  ". We would like to type"
}], "Text"],

Cell[CellGroupData[{

Cell["f[x_] = Plot[Sin[y], {y, -x, x}]", "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.122"],

Cell[BoxData[
    \(Plot::"plln" \(\(:\)\(\ \)\) 
      "Limiting value \!\(-x\) in \!\({y, \(\(-x\)\), x}\) is not a \
machine-size real number."\)], "Message"],

Cell[BoxData[
    \(Plot[Sin[y], {y, \(-x\), x}]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, as you can see, that won\[CloseCurlyQuote]t work. Remember from \
",
  ButtonBox["Sec. 9.1",
    ButtonData:>"Sec. 9.1",
    ButtonStyle->"Hyperlink"],
  " what the ",
  StyleBox["=",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sign means: it means, evaluate the right-hand side and assign the result \
to the symbol on the ",
  "left-hand",
  " side. Here, however, the right-hand side cannot be evaluated, because no \
particular numerical value for ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " has been specified."
}], "Text"],

Cell[TextData[{
  "\tTo get around this problem, we use a different type of equal sign,",
  StyleBox[" :=",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " , which means \"delayed equal\". With this delayed equal sign, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remembers that a function has been defined, but does not evaluate the ",
  "right-hand",
  " side until the function is actually called."
}], "Text"],

Cell[TextData[{
  "\tIn our example, we define ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " as"
}], "Text"],

Cell[BoxData[
    \(f[x_]\  := \ Plot[Sin[y], {y, \(-x\), x}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.123"],

Cell[TextData[{
  "There is no ",
  StyleBox["Out",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " line, because there has been no evaluation of the ",
  "right-hand",
  " side yet.  However, if we now ask for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " at a particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " recalls the definition and performs the evaluation, as shown in Cell ",
  ButtonBox["9.124",
    ButtonData:>"Cell 9.124",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[5]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.124"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.294302 [
[.11905 .29652 -6 -9 ]
[.11905 .29652 6 0 ]
[.30952 .29652 -6 -9 ]
[.30952 .29652 6 0 ]
[.69048 .29652 -3 -9 ]
[.69048 .29652 3 0 ]
[.88095 .29652 -3 -9 ]
[.88095 .29652 3 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .59123 m
.02846 .59497 L
.03279 .59783 L
.03754 .6003 L
.0402 .60136 L
.04262 .60212 L
.04385 .60244 L
.04516 .60273 L
.04629 .60293 L
.0475 .6031 L
.04881 .60323 L
.05003 .6033 L
.05077 .60332 L
.05148 .60332 L
.05212 .60331 L
.05281 .60328 L
.05408 .60319 L
.05523 .60306 L
.05656 .60285 L
.05781 .60261 L
.06003 .60205 L
.06244 .60127 L
.06753 .599 L
.07312 .59556 L
.07895 .59092 L
.08439 .58563 L
.10458 .55829 L
.12493 .51944 L
.14349 .47562 L
.18333 .36269 L
.22166 .24506 L
.26245 .13155 L
.2827 .086 L
.30171 .05234 L
.31056 .04009 L
.31988 .0297 L
.32476 .02532 L
.33009 .02138 L
.33495 .01858 L
.33946 .01665 L
.34209 .01583 L
.34451 .01528 L
.34578 .01506 L
.34717 .01488 L
.34787 .01482 L
.34862 .01477 L
.34934 .01473 L
.34999 .01472 L
.35125 .01473 L
.35242 .01478 L
Mistroke
.35371 .01489 L
.35443 .01498 L
.35508 .01507 L
.35757 .01555 L
.35992 .01618 L
.36458 .01797 L
.36885 .02022 L
.37851 .02744 L
.38827 .03767 L
.39737 .04979 L
.41805 .08589 L
.45701 .18063 L
.49842 .30414 L
.53832 .42426 L
.5767 .52123 L
.59651 .55877 L
.60651 .57371 L
.61753 .5868 L
.62247 .59146 L
.62765 .59554 L
.63214 .59839 L
.63692 .60072 L
.63963 .60171 L
.64209 .60241 L
.64328 .60267 L
.64456 .60291 L
.64578 .60308 L
.64689 .6032 L
.6482 .60329 L
.64942 .60332 L
.65012 .60332 L
.65076 .6033 L
.65149 .60326 L
.65219 .60321 L
.65287 .60315 L
.65358 .60306 L
.65487 .60287 L
.65626 .6026 L
.65779 .60223 L
.66013 .60152 L
.6627 .60054 L
.66787 .59792 L
.67266 .59474 L
.67711 .59112 L
.68719 .58069 L
.69796 .56618 L
.71928 .528 L
.73943 .48184 L
.77786 .37441 L
.81875 .24903 L
Mistroke
.85812 .13834 L
.87789 .09259 L
.89597 .05884 L
.90526 .04493 L
.9154 .03263 L
.92095 .02721 L
.92611 .02303 L
.93103 .01982 L
.93358 .01846 L
.93628 .01725 L
.93873 .01636 L
.94143 .0156 L
.94261 .01534 L
.94387 .01511 L
.94507 .01494 L
.94616 .01483 L
.94682 .01478 L
.94752 .01474 L
.94879 .01472 L
.94949 .01472 L
.95014 .01474 L
.95086 .01478 L
.95164 .01485 L
.95296 .015 L
.95435 .01522 L
.95684 .01576 L
.95915 .01645 L
.96163 .01738 L
.96608 .01955 L
.97138 .02295 L
.97619 .0268 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
Z@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0/P3oool00:/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00X03oool6000000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00N`3oool8000002P0oooo00<000000?oo
o`3oool01@3oool3000009X0oooo2000000@0?ooo`00M`3oool4000000P0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo09P0oooo0P0000080?ooo`03
0000003oool0oooo00d0oooo001f0?ooo`030000003oool0oooo00/0oooo0P00000U0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0UP3oool2000000/0oooo0P00000=0?ooo`00M@3o
ool00`000000oooo0?ooo`0>0?ooo`8000008`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo09@0oooo0P00000?0?ooo`8000002`3oool007@0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0N0?ooo`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool007<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool07@3oool00780oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool07P3oool00740oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
7P3oool00700oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool07`3oool006l0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0803oool0
06l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0T0?ooo`800000T03oool00`00
0000oooo0?ooo`0P0?ooo`00KP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0Q0?ooo`00K03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`00K03oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S
0?ooo`00J`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00J`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`00
JP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0U0?ooo`00J@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0V0?ooo`00J@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`0V0?ooo`00J03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`00J03oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo01d0oooo0P0000290?ooo`030000003oool0oooo02L0
oooo001W0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo02P0oooo001V0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo001V
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo02T0oooo001U0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo001U0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo001T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo02X0oooo001T0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo02/0oooo001T0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo02/0oooo001S0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
02`0oooo001S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0603oool2000008@0
oooo00<000000?ooo`3oool0;03oool00680oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0;@3oool00680oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0;@3oool00640oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0;@3oool00640oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool00640oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool0;P3oool00600oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
;`3oool00600oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0;`3oool005l0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0<03oool0
05l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool0<03oool005l0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0<03oool005h0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C0?ooo`800000O`3oool00`000000oooo
0?ooo`0a0?ooo`00GP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`0a0?ooo`00G@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0b
0?ooo`00G@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0b0?ooo`00G@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c0?ooo`00
G03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`0c0?ooo`00G03oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c0?ooo`00G03oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`0d0?ooo`00F`3oool00`000000oooo0?ooo`0j0?ooo`050>k^kP0c<c<00000
03<c<`3^k^h00`3oool010000000oooo028R8P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0
1@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo03@0oooo001K0?ooo`030000003o
ool0oooo03X0oooo00D0MgMg09VIV@3oool0VIVI07MgM`040?ooo`030000000R8R808R8R00P0oooo
00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo03@0oooo
001K0?ooo`030000003oool0oooo0380oooo1P0000020?ooo`05014A4@3oool0oooo0?ooo`0A4A40
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0`00001j0?ooo`030000
003oool0oooo03D0oooo001J0?ooo`030000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00P0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo03D0oooo001J0?ooo`030000003oool0oooo03/0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00@0oooo00D00000028R8P000000
<c<c0<c<c0050?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0=@3oool005X0oooo
00<000000?ooo`3oool0>`3oool01@0A4A40oooo0?ooo`3oool04A4A00D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0=P3oool005T0oooo00<000000?ooo`3oool0?03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0=P3oool005T0oooo00<000000?ooo`3oool0?03oool01@3^k^h0<c<c
0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool00`3oool4000000H0oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`0f0?ooo`00F@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0g0?ooo`00F03o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`0g0?ooo`00F03oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0h0?ooo`00F03oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0h0?ooo`00E`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0h0?ooo`00E`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00/0oooo0P00001g0?ooo`030000003oool0oooo03T0oooo
001F0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo03T0oooo001F0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo001F0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo03X0oooo001E0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03X0oooo001E0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo03X0oooo001E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo03/0oooo001D0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0
oooo03/0oooo001D0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo03`0oooo001D0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo03`0
oooo001C0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0203oool2000007@0oooo
00<000000?ooo`3oool0?03oool005<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0?@3oool005<0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0?@3oool00580oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0?@3oool00580oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool0?P3oool00580oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool00540oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3o
ool00540oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0?`3oool00540oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0?`3oool00500
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0?`3oool00500oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0@03oool004l0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`040?ooo`800000L03oool00`000000oooo0?oo
o`100?ooo`00C`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0KP3oool00`000000oooo0?ooo`110?ooo`00C`3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`110?oo
o`00CP3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`110?ooo`00CP3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`120?ooo`00CP3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`120?ooo`00C@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`120?ooo`00;P3oool20000
0003014A4@3oool0oooo01X0oooo00<000000?ooo`3oool0803oool5000003T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0n0?ooo`D00000:@3oool00`000000oooo0?ooo`0E0?oo
o`80000000<04A4A0?ooo`3oool0:@3oool002l0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0P0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0>@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03h0oooo00D0VIVI028R8P3^k^h0oooo04A4A00Y0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0:P3oool002@0oooo1P0000020?ooo`D000006`3oool00`00
0000oooo0?ooo`0I0?ooo`H000000`3oool00`2IVIT08R8R0>k^kP0k0?ooo`050000003oool0oooo
0?ooo`000000@@3oool00`2IVIT08R8R0>k^kP0Z0?ooo`030000003oool0oooo01<0oooo1@00000[
0?ooo`00;03oool01014A4@0gMgM0?ooo`00000L0?ooo`030000003oool0oooo02<0oooo00<0VIVI
028R8P3^k^h0>P3oool010000000oooo0?ooo`3oool200000440oooo00<0VIVI028R8P3^k^h0:03o
ool00`000000oooo0?ooo`0D0?ooo`0404A4A03MgMd0oooo000002`0oooo000/0?ooo`040=gMg@1E
EED0oooo000001`0oooo00<000000?ooo`3oool0903oool00`1gMgL0IVIV0?ooo`0i0?ooo`050000
003oool0oooo0?ooo`000000@`3oool00`1gMgL0IVIV0?ooo`0W0?ooo`030000003oool0oooo01@0
oooo00@0gMgM05EEE@3oool00000;03oool002d0oooo00<0MgMg0<c<c00000006`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000A03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo00<0MgMg0<c<c0000000;03oool002d0
oooo00<0k^k^04A4A00000006`3oool00`000000oooo0?ooo`0R0?ooo`050000002k^k/0oooo09VI
V@0A4A40>`3oool010000000oooo0?ooo`0000100?ooo`050000002k^k/0oooo09VIV@0A4A409`3o
ool00`000000oooo0?ooo`0F0?ooo`030>k^kP14A4@0000002`0oooo000^0?ooo`0307MgM`000000
oooo01X0oooo00<000000?ooo`3oool08P3oool01@2IVIT04A4A0000000R8R80c<c<03/0oooo00@0
00000?ooo`3oool00000@03oool01@2IVIT04A4A0000000R8R80c<c<02L0oooo00<000000?ooo`3o
ool05`3oool00`1gMgL000000?ooo`0[0?ooo`00BP3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0000006`0oooo00<000000?ooo`3oool0A@3oool004X0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0000001[0?ooo`030000003oool0oooo04H0oooo001:0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`000000J`3oool00`000000oooo0?ooo`160?ooo`00B@3oool00`00
0000oooo0?ooo`1V0?ooo`800000J`3oool00`000000oooo0?ooo`160?ooo`00B@3oool00`000000
oooo0?ooo`1V0?ooo`800000JP3oool00`000000oooo0?ooo`170?ooo`00B@3oool00`000000oooo
0?ooo`1V0?ooo`800000JP3oool00`000000oooo0?ooo`170?ooo`0000<0oooo000000000000o`00
001T00000080oooo00090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool002/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0:P3oool004L0oooo00<000000?ooo`3oool0J@3oool2000006P0oooo00<000000?oo
o`3oool0B03oool004L0oooo00<000000?ooo`3oool0J@3oool2000006L0oooo00<000000?ooo`3o
ool0B@3oool004L0oooo00<000000?ooo`3oool0J@3oool2000006L0oooo00<000000?ooo`3oool0
B@3oool004H0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0000001V0?ooo`030000003o
ool0oooo04T0oooo00160?ooo`030000003oool0oooo06X0oooo00<000000?ooo`000000I@3oool0
0`000000oooo0?ooo`1:0?ooo`00AP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool00000
06D0oooo00<000000?ooo`3oool0BP3oool004D0oooo00<000000?ooo`3oool0J`3oool010000000
oooo0?ooo`00001T0?ooo`030000003oool0oooo04X0oooo00150?ooo`030000003oool0oooo06/0
oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo04/0oooo00150?ooo`030000
003oool0oooo06/0oooo00@000000?ooo`3oool00000H`3oool00`000000oooo0?ooo`1;0?ooo`00
A03oool00`000000oooo0?ooo`1/0?ooo`050000003oool0oooo0?ooo`000000HP3oool00`000000
oooo0?ooo`1;0?ooo`00A03oool00`000000oooo0?ooo`1/0?ooo`050000003oool0oooo0?ooo`00
0000H@3oool00`000000oooo0?ooo`1<0?ooo`00A03oool00`000000oooo0?ooo`1/0?ooo`050000
003oool0oooo0?ooo`000000H@3oool00`000000oooo0?ooo`1<0?ooo`00@`3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`1<0?ooo`00@`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`1=0?ooo`00@`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1=
0?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`1=0?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1>0?ooo`00
@P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1>0?ooo`00@@3oool00`000000oooo0?ooo`1_0?ooo`8000001@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo04h0oooo00110?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo04l0oooo00110?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo04l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo04l0
oooo00100?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0500oooo00100?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0500oooo000o
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0500oooo000o0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0540oooo000o0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0540oooo000n0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0540oooo000n0?ooo`030000003o
ool0oooo0780oooo0P0000080?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0DP3o
ool003h0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0DP3oool003d0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0DP3oool003d0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool0D`3oool003d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0D`3oool003`0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0D`3oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0E03oool003`0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0E03oool003/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0E@3oool003/0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
E@3oool003X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0E@3oool003X0oooo00<000000?ooo`3oool0MP3oool2
000000`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1F0?ooo`00>P3oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`1F0?ooo`00>@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1F0?ooo`00>@3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`1G0?ooo`00>@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`1G0?ooo`00>03oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1G
0?ooo`00>03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`1H0?ooo`00>03oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1H0?ooo`00
=`3oool00`000000oooo0?ooo`1N0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0
oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`1I0?ooo`00=`3oool00`000000oooo0?ooo`1N0?ooo`05
07MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0F@3oool003L0
oooo00<000000?ooo`3oool0GP3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?oo
o`3oool00`3oool3000000l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1I0?oo
o`00=P3oool00`000000oooo0?ooo`1O0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1g
MgL0<c<c0?ooo`040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`1J0?ooo`00=P3oool00`000000oooo0?ooo`1O0?ooo`050000003oool0oooo0?oo
o`000000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo05X0oooo000f0?ooo`030000003oool0oooo
05l0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo05X0oooo000e0?oo
o`030000003oool0oooo0600oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo05/0oooo000e0?ooo`030000003oool0oooo0600oooo00D0k^k^03<c<`000000<c<c0>k^kP0<
0?ooo`@000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0F`3oool003D0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0F`3oool003@0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0G03oool003@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0G03oool003<0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0G03o
ool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0G@3oool00380oooo00<000000?ooo`3oool0OP3oool20000
01@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1M0?ooo`00<P3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`1N0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1N0?ooo`00<@3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`1O0?ooo`00<@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`1O0?ooo`00<03oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1O0?oo
o`00<03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`1P0?ooo`00;`3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1P0?ooo`00;`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`1Q0?ooo`00;`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1Q0?ooo`00;P3oool00`00
0000oooo0?ooo`220?ooo`800000603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
0680oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo0680oooo000]0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0680oooo
000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo06<0oooo000/0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo06<0oooo000/0?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo06@0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06@0oooo000[0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo06D0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo06D0oooo000Z0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo06H0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo06H0oooo000Y0?ooo`030000003oool0oooo08L0
oooo0P00000M0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0I`3oool002P0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0I`3oool002P0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0J03oool002L0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0J03oool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0J@3oool002H0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0J@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0JP3oool002D0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0JP3o
ool002@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0J`3oool002@0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0J`3oool002<0
oooo00<000000?ooo`3oool0S@3oool2000002@0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1/0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1]0?ooo`008@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1^0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1_0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1`0?oo
o`007P3oool2000009<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0740oooo000M0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0780oooo00090?ooo`8000004@3o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo02T0oooo0P00000A0?ooo`030000003o
ool0oooo07<0oooo000;0?ooo`030000003oool0oooo00`0oooo0P00002=0?ooo`@0000000<04A4A
0?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00`0oooo0P00001f
0?ooo`00303oool2000000X0oooo0P00002A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0;03oool2000000X0oooo0P00001h0?ooo`003P3oool3000000D0oooo0P00002C0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool2000000D0oooo0`00001j0?ooo`00
403oool6000009D0oooo00<000000?ooo`3oool01@3oool300000300oooo1P00001l0?ooo`00Z`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002[0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0/P3oool00:/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2b0?ooo`00Z@3oool205EEE@030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-5, -1, 0, 0}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The distinction between these two forms of equality is summarized in Table \
",
  ButtonBox["9.17",
    ButtonData:>"Table 9.17",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[GridBox[{
          {
            RowBox[{
              StyleBox[\(Table  9  .17\ The\ Difference\ Between\),
                FontSize->9], 
              StyleBox["  ",
                FontSize->9], 
              StyleBox["=",
                FontFamily->"Courier",
                FontSize->9,
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontSize->9], 
              RowBox[{
                StyleBox["and",
                  FontSize->9], 
                StyleBox[" ",
                  FontSize->9], 
                StyleBox[":=",
                  FontFamily->"Courier",
                  FontSize->9,
                  FontWeight->"Bold"]}]}]},
          {GridBox[{
                {
                  StyleBox[\(f[x_] = expr\),
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["immediately",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["evaluate",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["expr",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox["and",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox["define",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    StyleBox[\(f[x]\),
                      FontWeight->"Bold"]}]},
                {
                  StyleBox[\(f[x_] := \ expr\),
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["remember",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["this",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["definition",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["of",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["f",
                        FontWeight->"Bold"]}], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    StyleBox[" ",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["but",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["do",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["not",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["evaluate",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["expr",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["until",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox[\(f[x]\),
                        FontWeight->"Bold"], 
                      StyleBox["  ",
                        FontFamily->"Times"], 
                      StyleBox["is",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["used",
                        FontFamily->"Times"]}]}]}
                },
              ColumnSpacings->2.8,
              ColumnAlignments->{Left}]}
          }]]],
  StyleBox["\t\t",
    FontSlant->"Italic"]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.17"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.8.6 Putting Conditions on Function Definitions", "Subsubtitle",
  CellTags->{"i:69", "c:46"}],

Cell[TextData[{
  "Special procedures are necessary when defining discontinuous functions. \
For example, consider the ",
  ButtonBox["Heaviside",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Heaviside.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " step  function"
}], "Text",
  CellTags->"i:123"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(h(x)\), "=", 
          TagBox[
            StyleBox[
              RowBox[{"{", 
                StyleBox[GridBox[{
                      {"0"},
                      {"1"}
                      }],
                  ShowAutoStyles->True]}],
              ShowAutoStyles->False],
            (#&)]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(,\)\(\ \)\(x < 0\)\)},
            {\(\(,\)\(\ \)\(x > \ 0\)\)}
            }], TraditionalForm]]]
}], "NE2",
  CellTags->{"(9.8.1)", "i:106"}],

Cell[TextData[{
  "In order to create a user-defined version of this function in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the use of condition statements is necessary:"
}], "Text"],

Cell[BoxData[
    \(h[x_]\  := \ 1\  /; \ x > 0\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.125"],

Cell[BoxData[
    \(h[x_]\  := \ 0\  /; \ x < 0\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.126"],

Cell[TextData[{
  "The symbol ",
  StyleBox["/;",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " means \"on condition that\" and is followed by logical statements \
limiting the range of validity of the definition. Note that we have used  \
delayed equal signs ",
  StyleBox[":=",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  in the definitions, because the conditions cannot be evaluated until \
specific values of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " are chosen."
}], "Text"],

Cell[TextData[{
  "\tAlso, note that we have not defined ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " at ",
  StyleBox["x",
    FontSlant->"Italic"],
  "=0. Normally that doesn't matter, but in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " we will not get a numerical result if we try to evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`h(0)\)]],
  ". So it is probably best to define ",
  Cell[BoxData[
      \(TraditionalForm\`h(0)\)]],
  ", taking, say, ",
  Cell[BoxData[
      \(TraditionalForm\`h(0)\  = \ 1/2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h[0]\  = \ 1/2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.127"],

Cell[BoxData[
    \(1\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " We can now evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " anywhere on the real line. (What do you think would happen if we \
evaluated",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(h(x)\)\)\)]],
  " at a complex number?) in Cell ",
  ButtonBox["9.128",
    ButtonData:>"Cell 9.128",
    ButtonStyle->"Hyperlink"],
  " we plot the function (with a slightly thickened line for ease of \
viewing)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[h[x], {x, \(-2\), 2}, 
        PlotStyle \[Rule] Thickness[0.015]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.128"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-1)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.48147 .01472 L
.49012 .01472 L
.49468 .01472 L
.49719 .01472 L
.49842 .01472 L
.49955 .01472 L
.50085 .60332 L
.50154 .60332 L
.50226 .60332 L
.50471 .60332 L
.5095 .60332 L
.51896 .60332 L
.53984 .60332 L
.57781 .60332 L
.61824 .60332 L
.65714 .60332 L
.6985 .60332 L
.73835 .60332 L
.77668 .60332 L
.81746 .60332 L
.85673 .60332 L
.89448 .60332 L
.93468 .60332 L
.97337 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`004_ooool5o`0004gooooo1?l000000ol@413oooooooooo`2Gooooo`Co
000000?o410@ooooooooool0BOooool5o`00017ooooo000Booooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0Coooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo04_ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Aooooo`002_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0AOooool6o`0000Go
oooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`1<ooooo`03oiRHV?lQ8B7ok^k^01;o
oooo000Dooooo`03oiRHV?lQ8B7ok^k^04oooooo00?o0000ooooooooool0Voooool00ol0003ooooo
ooooo`1=ooooo`03oiRHV?lQ8B7ok^k^017ooooo000Eooooo`03ogMgMomVIVKooooo04kooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`1>ooooo`03ogMgMomVIVKooooo013ooooo000F
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo00oooooo000Booooo`05o`000?nj^[[ooooooiRHV?l@4100Coooool0
0ol0003oooooooooo`2Kooooo`03o`000?oooooooooo04_ooooo00Go0000okZj^_ooooooV9RHoa0@
400Aooooo`004_ooool01OnHV9So410@o`000?lQ8B7oc<c<04gooooo00?oEEEEofIVI_l00000Vooo
ool00omEEEGoIVIVo`00001=ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool00?ooooooJOoo
ool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?o
oooo00?o0000ooooooooool0/_ooool000ooooooYol0002booooo`003ooooonWo`000;;ooooo0009
oooooooo0000E_l0000:ooooo`003ooooonWo`0000gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool000oo
ooooYol0001>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04?ooool00;7ooooo
1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002boooo
o`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5
o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo
002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go
0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool0
0;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0
002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00
/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`00
0;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002a
ooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool5o`000;;ooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A004ooooo`Go0000/_ooool0
09Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo1Ol0002b
ooooo`00V?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01?ooool5
o`000;;ooooo002Hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03
ooooo`Go0000/_ooool009Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo1Ol0002booooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`Go0000/_ooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool5o`000;;ooooo002aooooo`Go0000/_oo
ool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo
1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002boooo
o`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5
o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo
002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go
0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool0
0;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0
002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00
/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00V?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00_ooool5
o`000;;ooooo002Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool00oooool5o`000;;ooooo002Hooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000Cooooo1Ol0002booooo`00V?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001Oooool5o`000;;ooooo002Hooooo`05o`000?ooooooooooooooool000002ooo
ool01?oMgMgoEEEEooooool00005ooooo`Go0000/_ooool009Sooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Gooooo1Ol0002booooo`00V?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001Oooool5o`000;;ooooo002Hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`Go0000/_ooool00;7ooooo1Ol0
002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00
/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`00
0;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002a
ooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000
/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7o
oooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002b
ooooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Ooo
ool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;o
oooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<
c004ooooo`Go0000/_ooool009Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Cooooo1Ol0002booooo`00V?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000004ooooo`Go0000/_ooool009Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401?ooool5o`00
0;;ooooo002Hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413o
c<c<00Cooooo1Ol0002booooo`00V?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool01_ooool5o`000;;ooooo002Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ooMgMgo410@oiRHV006ooooo`Go0000/_ooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40Cooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aoooo
o`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_oo
ool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo
1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002boooo
o`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5
o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo
002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go
0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool0
0;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0
002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool009Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Cooooo1Ol0002b
ooooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401?ooool5o`000;;ooooo002Hooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Cooooo1Ol0002booooo`00V?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P04ooooo`Go0000/_ooool009Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01?ooool5o`00
0;;ooooo002Hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o
410@00Cooooo1Ol0002booooo`00V?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_oooooo^[Zjo`000004ooooo`Go0000/_ooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01?ooool5o`000;;ooooo002aooooo`Go0000/_oo
ool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo
1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002boooo
o`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5
o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo
002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go
0000/_ooool00;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool0
0;7ooooo1Ol0002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0
002booooo`00/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00
/Oooool5o`000;;ooooo002aooooo`Go0000/_ooool00;7ooooo1Ol0002booooo`00ZOooool4o`00
0004oa0@4?ooooooooooooooo`Go0000/_ooool00:_ooooo00?o0000ooooooooool00ooooonWo`00
013ooooo002[ooooo`03o`000?oooooooooo00?oooooYol0000@ooooo`00Zoooool00ol0003ooooo
ooooo`03ooooojOo00004?ooool00:_ooooo00?o0000ooooooooool00ooooonWo`00013ooooo002[
ooooo`03o`000?oooooooooo00?oooooYol0000@ooooo`00Zoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;;ooooo002Yooooo`03oeEEEOmVIVKo000000Oooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00001\
\>"],
  ImageRangeCache->{{{0, 358.938}, {221.312, 0}} -> {-2, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Table ",
  ButtonBox["9.18",
    ButtonData:>"Table 9.18",
    ButtonStyle->"Hyperlink"],
  " summarized some of the conditions one can add to function definitions. "
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{"                  ", 
            RowBox[{
              
              StyleBox[\(Table  
                  9  .18\ Adding\ Conditions\ to\ Function\ Definitions\),
                FontSize->9], "\[IndentingNewLine]"}]}]},
        {
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox[\(f[x_]\),
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[":=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["expr",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["/;",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["conditions",
                        
                        FontSlant->
                          "Italic"]}]}], \(Adding\ conditions\ to\ the\ \
definition\ of\ a\ function\)}
                },
              ColumnSpacings->1.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]},
        {
          RowBox[{"\[IndentingNewLine]", 
            StyleBox[\(some\ possible\ \(\(conditions\)\(:\)\)\),
              FontFamily->"Times"]}]},
        {
          StyleBox[GridBox[{
                {
                  StyleBox[\(x == y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Test", " ", "whether", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "equals", " ", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(x\  \[NotEqual] y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Test", " ", "whether", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "is", " ", "unequal", " ", "to", 
                    " ", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(x\  > y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Test", " ", "whether", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "is", " ", "greater", " ", "than",
                     " ", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(x\  \[GreaterEqual] y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Test", " ", "whether", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "is", " ", "greater", " ", "than",
                     " ", "or", " ", "equal", " ", "to", " ", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]},
                {
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["<",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["y",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["  ",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Italic"]}], 
                  RowBox[{"Test", " ", "whether", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "is", " ", "less", " ", "than", 
                    " ", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]},
                {
                  StyleBox[\(x\  \[LessEqual] y\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"Test", " ", "whether", " ", 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], "is", " ", "less", " ", "than", 
                    " ", "or", " ", "equal", " ", "to", " ", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]},
                {
                  RowBox[{
                    StyleBox[\(condition\_\(\(\ \)\(1\)\)\),
                      FontSlant->"Italic"], 
                    StyleBox["&&",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[\(condition\_2\),
                      FontSlant->"Italic"]}], 
                  RowBox[{"Test", " ", "whether", " ", "both", " ", 
                    StyleBox[\(condition\_\(\(\ \)\(1\)\)\),
                      FontSlant->"Italic"], " ", "and", 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[\(condition\_\(\(\ \)\(2\)\)\),
                      FontSlant->"Italic"], " ", "are", " ", "true"}]},
                {
                  RowBox[{
                    StyleBox[\(condition\_\(\(\ \)\(1\)\)\),
                      FontSlant->"Italic"], 
                    StyleBox["||",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[\(condition\_\(\(\ \)\(2\)\)\),
                      FontSlant->"Italic"]}], 
                  RowBox[{"Test", " ", "whether", " ", "either", " ", 
                    StyleBox[\(condition\_\(\(\ \)\(1\)\)\),
                      FontSlant->"Italic"], " ", "or", 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[\(condition\_\(\(\ \)\(2\)\)\),
                      FontSlant->"Italic"], " ", "is", " ", "true"}]}
                },
              ColumnSpacings->1.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        },
      ColumnAlignments->{Left}]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->{"i:111", "Table 9.18"}],

Cell[TextData[{
  "The conditions in Table ",
  ButtonBox["9.18",
    ButtonData:>"Table 9.18",
    ButtonStyle->"Hyperlink"],
  " are also referred to as ",
  StyleBox["logical statements",
    FontSlant->"Italic"],
  ". Logical statements are either true or false. For instance, if ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ", the statement ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["\[Equal]",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["y",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " returns ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:80"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x = 1; \ y = 0;\), "\n", 
    \(x \[Equal] y\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.129"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell["\<\
Logical expressions are also used in other contexts such as in the \
control of computer programs, as we will see in later chapters.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.8", "Subsubtitle",
  CellTags->{"Ex. 9.8", "c:47"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to help",
  StyleBox[" ",
    FontSlant->"Italic"],
  "prove the following trigonometric identities:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \(\(cos\^4\)(x)\) + 
          2\ \(\(sin\^4\)(x)\) + \(sin\^2\)(2\ x) = 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(sec(x) - csc(x)\)\/\(cot(x) + tan(x)\) = \(\(\(tan(
                  x) - cot(x)\)\/\(csc(x) + sec(x)\)\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\(2\ \(sin(2\ x)\) - sin(4\ x)\)\/\(cos(x)\) = 
        8\ \(\(sin\^3\)(x)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Factor the following polynomials:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3 + 3\ x\^2 - 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5 + 5\ x\^4 + 10\ x\^3 + 10\ x\^2 + 5\ x + 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^6 + 3\ x\^5 - 21\ x\^4 - 59\ x\^3 + 96\ x\^2 + 
        276\ x + 144\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Simplify the following equation using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and use the result to find all real and complex solutions by hand:"
}], "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      \(TraditionalForm\`1\/30 + 4\/\(21\ \((3\ z - 1)\)\) - 
          3\/\(26\ \((2\ z + 1)\)\) - 41\/\(455\ \((5\ z - 4)\)\) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Use a substitution command to evaluate the following functions at the \
specified values of the variables:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ x\  + \ sin(2  x) + \ 
        sin(3  x) + \(sin(4  x)\) \[Ellipsis] + sin(10\ x)\)]],
  " at",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x = 20\ \[Degree]\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\  + \ 2\ x\ y\  + \ y\^2\)]],
  "  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1, \ y = \(-1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\ \  - \ y\^2\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = cosh\[Theta]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y = sinh\[Theta]\)]],
  ". (Simplify the result.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Define the following functions and, if asked,  plot them over the given \
range of values:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = x\/\(x\^2 + 1\)\)]],
  ". Plot over",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(-3\) < x < 3\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y) = tanh(x\/y)\)]],
  " .  Plot with a surface plot over ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < x < 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < y < 1\)]],
  ". What is happening along the line ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  "?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"f", "(", 
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], 
          StyleBox["=",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "  dimension of the vector ",
  StyleBox["x",
    FontWeight->"Bold"],
  ".  Evaluate for",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], "  ", "=", " ", \((2, 4, 3, 2)\)}]}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((1, \(-1\))\)}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x)\), " ", "=", " ", 
          TagBox[
            StyleBox[
              RowBox[{"{", GridBox[{
                    {\(\(x\)\(,\)\), \(x < 0\)},
                    {GridBox[{
                          {\(\(x\^2\)\(,\)\)},
                          {\(\(1/x\^2\)\(,\)\)}
                          }], GridBox[{
                          {\(0 \[LessEqual] \ x \[LessEqual] \ 1\)},
                          {\(x > 1\)}
                          }]}
                    }]}],
              ShowAutoStyles->False],
            (#&)]}], TraditionalForm]]],
  "      Plot for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < x < 3\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.9 Calculus", "Subtitle",
  CellTags->{"Sec. 9.9", "c:48"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["9.9.1 Derivatives", "Subsubtitle",
  CellTags->{"i:70", "c:49"}],

Cell[TextData[{
  "\tYou can take the derivative of an expression using the intrinsic \
function ",
  StyleBox["D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This function takes two arguments: ",
  StyleBox["D[expr, var]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the derivative of the expression ",
  StyleBox["expr",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with respect to the variable ",
  StyleBox["var",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, ",
  StyleBox["D[f[x],x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " means ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f/\[DifferentialD]x\)]],
  "."
}], "Text"],

Cell["\tFor instance,  if we define  a function", "Text"],

Cell[BoxData[
    \(\(f[x_]\  = \ Tan[x^2];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.130"],

Cell[TextData[{
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "will evaluate the derivative with respect to ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", using the chain rule:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x], x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.131"],

Cell[BoxData[
    \(2\ x\ Sec[x\^2]\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Another way to evaluate the derivative is to use a prime ', as in",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            RowBox[{
              StyleBox["f",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["'",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["x",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(f'\)[x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.132"],

Cell[BoxData[
    \(2\ x\ Sec[x\^2]\^2\)], "Output"]
}, Open  ]],

Cell["Multiple derivatives can be taken by adding more primes:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(f''\)[x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.133"],

Cell[BoxData[
    \(2\ Sec[x\^2]\^2 + 8\ x\^2\ Sec[x\^2]\^2\ Tan[x\^2]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "or by using the notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["D",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontSlant->"Plain"], "[", 
                StyleBox["x",
                  FontSlant->"Plain"], "]"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["x",
                    FontSlant->"Plain"], ",", 
                  StyleBox["n",
                    FontSlant->"Plain"]}], "}"}]}],
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox["n",
          FontFamily->"Courier",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is the order of the derivative:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f[x], {x, 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.134"],

Cell[BoxData[
    \(2\ Sec[x\^2]\^2 + 8\ x\^2\ Sec[x\^2]\^2\ Tan[x\^2]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t The derivative of a function is the function's slope. One oftenneeds to \
find extrema of functions, which are places where the slope is zero ( ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]f\ /\[DifferentialD]x\  = \ 0\)]],
  "). We can do this in ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " by taking the derivative, and then manipulating the resulting expression \
to simplify it. For example, to find the extrema of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/\((1 - x + x\^2)\)\)]],
  ",  type the following: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2/\((1 - x + x^2)\), x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.135"],

Cell[BoxData[
    \(\(-\(\(x\^2\ \((\(-1\) + 
                  2\ x)\)\)\/\((1 - x + x\^2)\)\^2\)\) + \(2\ x\)\/\(1 - x + \
x\^2\)\)], "Output"]
}, Open  ]],

Cell["\<\
To see where the zeros of this function lie, one can simplify it \
via\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.136"],

Cell[BoxData[
    \(\(-\(\(\((\(-2\) + x)\)\ x\)\/\((1 - x + x\^2)\)\^2\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One can now see that the extrema are at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  " When evaluating the derivative of  a  function of several variables,  the \
derivative should be interpreted as a ",
  StyleBox["partial derivative. ",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "For example, "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["D[g[x,y],x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " means  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]g/\[PartialD]x\)\( | \_y\)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", holding ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " fixed."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.9.2 Power Series", "Subsubtitle",
  CellTags->{"i:71", "c:50"}],

Cell[TextData[{
  "The power series of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", taken with respect to a point ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  ", is a polynomial approximation to the function that  matches the value of \
the function and its derivatives at the given  point ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f(x) \[TildeEqual] 
              f(a) + \((x - a)\) \(\(f\^\[Prime]\)(
                    a)\) + \(1\/2\) \(\((x - 
                          a)\)\^2\) \(\(f\^\[DoublePrime]\)(
                    a)\) +  ... \) + \(1\/\(n!\)\) \(\((x - 
                    a)\)\^n\) \[DifferentialD]\^n f\/\[DifferentialD]x\^n\( | \
\_\(x = a\)\)\(+ ... \)\)]],
  " ."
}], "NE3",
  CellTags->"(9.9.1)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(9.9.1)",
    ButtonData:>"(9.9.1)",
    ButtonStyle->"Hyperlink"],
  " is also called a ",
  ButtonBox["Taylor",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Taylor.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " series for the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " about the point ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". The \"approximately equal to\" sign ",
  Cell[BoxData[
      \(TraditionalForm\` \[TildeEqual] \)]],
  " is used here because in general the expression works well only for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " near ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ".  Even if one keeps an infinite number of terms, the series from for ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " may not work for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", or may not even be defined. "
}], "Text",
  CellTags->"i:116"],

Cell[TextData[{
  "\tFor example,  taking the series of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(3/2\)\)]],
  " around ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(=\)\(0\)\(\ \)\)\)]],
  "produces a series that has undefined terms beyond the first. Using Eq. ",
  ButtonBox["(9.9.1)",
    ButtonData:>"(9.9.1)",
    ButtonStyle->"Hyperlink"],
  ", we have"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(3/2\)\  \[TildeEqual] 
          0 + x\[CenterDot]0\  + \ \(1\/2\) 
              x\^2\[CenterDot]\[Infinity] +  ... \)]]
}], "Text"],

Cell[TextData[{
  "This series is practically useless, because the function ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(3/2\)\)]],
  " has a singular second derivative at the point ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " where we are performing the expansion."
}], "Text"],

Cell[TextData[{
  "\tNevertheless, for smooth functions power series can be very useful \
approximations . To create a power series with ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " terms about the point ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " of an expression ",
  StyleBox["expr",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  ", the syntax is\n\t",
  StyleBox["Series[expr,{x,a,M}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\nFor instance, a four-term power series for ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x + 1\)\)]],
  "  about ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " is given by"
}], "Text",
  CellTags->"i:76"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s = Series[Sqrt[x + 1], {x, 0, 4}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.137"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(x\/2\), "-", \(x\^2\/8\), "+", \(x\^3\/16\), 
        "-", \(\(5\ x\^4\)\/128\), "+", 
        InterpretationBox[\(O[x]\^5\),
          SeriesData[ x, 0, {}, 0, 5, 1]]}],
      SeriesData[ x, 0, {1, 
        Rational[ 1, 2], 
        Rational[ -1, 8], 
        Rational[ 1, 16], 
        Rational[ -5, 128]}, 0, 5, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The resulting approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x + 1\)\)]],
  "  is a special ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " object, a ",
  StyleBox["Series",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which can be seen by the ",
  Cell[BoxData[
      StyleBox[\(O[x]\^5\),
        FontWeight->"Bold"]]],
  " at the end of the expression. This indicates the order of the \
approximation: there is an error between the series and  ",
  Cell[BoxData[
      \(TraditionalForm\`\@x\)]],
  " of the order of magnitude ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5\)]],
  ". In other words, if we reduce the value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ", the error in the above series approximation is reduced by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^5\)]],
  " (for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " sufficiently close to ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tAny  function that  is added to a series expression will ",
  StyleBox["automatically",
    FontSlant->"Italic"],
  " be expanded in a series to the same order of approximation. For example,  \
adding ",
  Cell[BoxData[
      \(TraditionalForm\`1/\((x + 4)\)\)]],
  " to this series results in a new series which is an approximation to  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\@\(x + 1\)\),
            "TraditionalForm"], "+", " ", \(1/\((x + 4)\)\)}], 
        TraditionalForm]]],
  StyleBox[" ",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1/\((x + 4)\)\  + \ s\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.138"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(5\/4\), "+", \(\(7\ x\)\/16\), "-", \(\(7\ x\^2\)\/64\), 
        "+", \(\(15\ x\^3\)\/256\), "-", \(\(39\ x\^4\)\/1024\), "+", 
        InterpretationBox[\(O[x]\^5\),
          SeriesData[ x, 0, {}, 0, 5, 1]]}],
      SeriesData[ x, 0, {
        Rational[ 5, 4], 
        Rational[ 7, 16], 
        Rational[ -7, 64], 
        Rational[ 15, 256], 
        Rational[ -39, 1024]}, 0, 5, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  StyleBox["Series",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are special objects, they cannot be directly evaluated at particular \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". If you try, you will get an error:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s /. x \[Rule] 2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.139"],

Cell[BoxData[
    \(SeriesData::"ssdn" \(\(:\)\(\ \)\) 
      "Attempt to evaluate a series at the number \!\(2\); returning \
Indeterminate."\)], "Message"],

Cell[BoxData[
    \(Indeterminate\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In order to evaluate the series at a particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", it must first be transformed from a ",
  "series expression",
  " back to a normal expression with the command ",
  StyleBox["Normal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->"i:77"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[s]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.140"],

Cell[BoxData[
    \(1 + x\/2 - x\^2\/8 + x\^3\/16 - \(5\ x\^4\)\/128\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x + 1\)\)]],
  "  can now be evaluated. For example, in Cell ",
  ButtonBox["9.141",
    ButtonData:>"Cell 9.141",
    ButtonStyle->"Hyperlink"],
  " we plot it and compare it to the original function ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x + 1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{Sqrt[x + 1], %}, {x, \(-1\), 2}, PlotRange \[Rule] {0, 2}, 
        PlotStyle \[Rule] {RGBColor[0, 0, 0], {RGBColor[1, 0, 0], 
              Dashing[{0.05, 0.05}]}}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.141"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0 0.309017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -12 -9 ]
[.18254 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[.32877 .07725 -24 -4.5 ]
[.32877 .07725 0 4.5 ]
[.32877 .15451 -18 -4.5 ]
[.32877 .15451 0 4.5 ]
[.32877 .23176 -24 -4.5 ]
[.32877 .23176 0 4.5 ]
[.32877 .30902 -6 -4.5 ]
[.32877 .30902 0 4.5 ]
[.32877 .38627 -24 -4.5 ]
[.32877 .38627 0 4.5 ]
[.32877 .46353 -18 -4.5 ]
[.32877 .46353 0 4.5 ]
[.32877 .54078 -24 -4.5 ]
[.32877 .54078 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-0.5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(1)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(1.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.34127 .07725 m
.34752 .07725 L
s
[(0.25)] .32877 .07725 1 0 Mshowa
.34127 .15451 m
.34752 .15451 L
s
[(0.5)] .32877 .15451 1 0 Mshowa
.34127 .23176 m
.34752 .23176 L
s
[(0.75)] .32877 .23176 1 0 Mshowa
.34127 .30902 m
.34752 .30902 L
s
[(1)] .32877 .30902 1 0 Mshowa
.34127 .38627 m
.34752 .38627 L
s
[(1.25)] .32877 .38627 1 0 Mshowa
.34127 .46353 m
.34752 .46353 L
s
[(1.5)] .32877 .46353 1 0 Mshowa
.34127 .54078 m
.34752 .54078 L
s
[(1.75)] .32877 .54078 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(2)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .01545 m
.34502 .01545 L
s
.34127 .0309 m
.34502 .0309 L
s
.34127 .04635 m
.34502 .04635 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .09271 m
.34502 .09271 L
s
.34127 .10816 m
.34502 .10816 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .13906 m
.34502 .13906 L
s
.34127 .16996 m
.34502 .16996 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .20086 m
.34502 .20086 L
s
.34127 .21631 m
.34502 .21631 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26266 m
.34502 .26266 L
s
.34127 .27812 m
.34502 .27812 L
s
.34127 .29357 m
.34502 .29357 L
s
.34127 .32447 m
.34502 .32447 L
s
.34127 .33992 m
.34502 .33992 L
s
.34127 .35537 m
.34502 .35537 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .40172 m
.34502 .40172 L
s
.34127 .41717 m
.34502 .41717 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .44807 m
.34502 .44807 L
s
.34127 .47898 m
.34502 .47898 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .50988 m
.34502 .50988 L
s
.34127 .52533 m
.34502 .52533 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57168 m
.34502 .57168 L
s
.34127 .58713 m
.34502 .58713 L
s
.34127 .60258 m
.34502 .60258 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
.02381 .00011 m
.02499 .01881 L
.02605 .02599 L
.02846 .03739 L
.03279 .05196 L
.03784 .06496 L
.04262 .07522 L
.06244 .1078 L
.08265 .13304 L
.10458 .15587 L
.14545 .19128 L
.1848 .22006 L
.22263 .24455 L
.26292 .26819 L
.30169 .28911 L
.34292 .30982 L
.38262 .32853 L
.42082 .34557 L
.46146 .36283 L
.50059 .3787 L
.54217 .39487 L
.58224 .40985 L
.62079 .42376 L
.6618 .43807 L
.70128 .45142 L
.73925 .4639 L
.77968 .47683 L
.81859 .48895 L
.85995 .50151 L
.89979 .51332 L
.93812 .52443 L
.97619 .53523 L
s
1 0 0 r
[ .05 .05 ] 0 setdash
.02381 .0845 m
.06244 .12325 L
.10458 .16061 L
.14415 .19177 L
.18221 .21871 L
.22272 .24469 L
.26171 .26752 L
.30316 .28987 L
.34309 .3099 L
.3815 .32801 L
.42237 .34624 L
.46172 .36288 L
.49955 .3781 L
.53984 .39343 L
.57861 .40724 L
.61984 .42075 L
.65954 .43236 L
.69774 .44196 L
.71905 .44652 L
.73838 .4501 L
.75876 .45323 L
.77751 .45547 L
.78687 .45634 L
.79676 .45708 L
.80155 .45736 L
.80668 .45761 L
.80963 .45772 L
.81232 .45782 L
.81482 .45788 L
.81758 .45794 L
.81877 .45797 L
.82006 .45798 L
.82117 .458 L
.82239 .45801 L
.82368 .45802 L
.82439 .45802 L
.82505 .45802 L
.82623 .45802 L
.82749 .45802 L
.82868 .45801 L
.82996 .458 L
.83118 .45799 L
.8323 .45797 L
.83442 .45793 L
.83666 .45788 L
.84177 .45771 L
.84655 .45749 L
.85179 .45719 L
.85742 .45678 L
.86755 .45582 L
Mistroke
.8786 .45446 L
.8987 .45104 L
.91841 .44643 L
.9394 .44007 L
.97619 .4249 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`006oooool4o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM04gooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo
1?l000000ol@413oooooooooo`0Uooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@0Uooooo`Go00006Oooool001gooooo00?o0000ooooooooool0
9Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo04co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Woooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool09?ooool01OnHV9So8B4Qonk^k_ooooooA4A401Wooooo000Booooo`Ko00001Oooool00ol0
003oooooooooo`0Mooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool0Boooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00onHV9So8B4Qonk^kP0Jooooo`007Oooool00ol0003oooooooooo`0Uooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`1<ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`0Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
3_ooool00omgMgOo<S8booooo`0Vooooo`03oiRHV?lQ8B7ok^k^01Wooooo000Mooooo`03o`000?oo
oooooooo02Gooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0COooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<02Sooooo00?oMgMgofIVI_ooool06?ooool001gooooo00?o0000ooooooooool09Oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0Coooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Gooooo`007Ooo
ool00ol0003oooooooooo`0Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`1?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`05
o`000?nj^[[ooooooiRHV?l@41006Oooool001_ooooo00?oEEEEofIVI_l000009oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0001>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0002Oooooo00?oEEEEofIVI_l00000:Oooool00omEEEGoIVIVo`00000=ooooo`Co00009_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<01Wooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo000Aoooooooo0000A_l0000Booooo`006Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Hooooo`006Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`006Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo0>Gooooo000Iooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0iOooool001Wooooo00?o0000ooooooooool0I?ooool2o`000>Kooooo000Ioooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0iOooool001Wooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`3Uooooo`006Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo0>Gooooo000Iooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0iOoo
ool001Wooooo00?o0000ooooooooool0I?ooool2o`000>Kooooo000Iooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0iOooool001[ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`3Uooooo`006_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo0>Gooooo
000Jooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0iOooool001[ooooo00?o0000
ooooooooool0Hoooool2o`000>Kooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0iOooool001_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`3Uooooo`00
6oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0>Gooooo000Looooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0iOooool001cooooo00?o0000ooooooooool0HOooool2
o`000>Kooooo000Mooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0iOooool001go
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`3Uooooo`007_ooool00ol0003ooooo
ooooo`0kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01_ooool00ol0003oooooooooo`3Uooooo`007_ooool00ol0003o
ooooooooo`0kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Gooooo00?o0000ooooooooool0iOooool0
01oooooo00?o0000ooooooooool0>_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool00ol0003oooooooooo`04ooooo`?o0000iOooool001oooooo00?o0000oooo
ooooool0>_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`05ooooo`03o`000?oooooooooo0>Gooooo000Pooooo`03o`000?oooooooooo
03Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c006ooooo`03o`000?oooooooooo0>Gooooo000Iooooo`03ool00?oooooo
oooo00Gooooo00?o0000ooooooooool0>?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>Gooooo000J
ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0iOooool002;ooooo00?o0000ooooooooool0=oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001oooool2o`000>Ko
oooo000Rooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0iOooool002?ooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`3Uooooo`009?ooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo0>Gooooo000Tooooo`03o`000?oooooooooo05Wooooo00?o0000oooo
ooooool0iOooool002Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`3Uooooo`00
9Oooool00ol0003oooooooooo`1Hooooo`;o0000i_ooool002Kooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`3Uooooo`009oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo0>Gooooo000Xooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0iOooool002Wo
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`3Uooooo`009Oooool2ool000;ooooo
00?o0000ooooooooool0E?ooool2o`000>Kooooo000Wooooo`04ool00?ooooooooooo`0005Gooooo
00?o0000ooooooooool0iOooool002Sooooo00Coo`00oooooooooooo0000E?ooool00ol0003ooooo
ooooo`3Uooooo`00:Oooool01?oo003oooooooooool0001Cooooo`03o`000?oooooooooo0>Gooooo
000Zooooo`04ool00?ooooooooooo`0005;ooooo00?o0000ooooooooool0iOooool002_ooooo0_oo
00000ooooooo0000ooooo`1@ooooo`;o0000i_ooool002gooooo00?oo`00ooooool00000D?ooool0
0ol0003oooooooooo`3Uooooo`00;_ooool00ooo003oooooo`00000cooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`03o`000?oo
oooooooo0>Gooooo000_ooooo`03ool00?oooooo000003;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`05ooooo`03o`000?oooooooooo0>Gooooo000`
ooooo`03ool00?oooooo0000037ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0iOooool0037ooooo00Coo`00ooooool0003o0000;ooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01Oooool3o`000>Gooooo
000booooo`04ool00?ooooooooooo`0002kooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3Uooooo`00=_ooool00ol0003o
ooooooooo`0[ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0>Gooooo000gooooo`03o`000?oooooooooo02[ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0iOooool003So
oooo00?o0000ooooooooool0:Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00007oooo
o`03o`000?oooooooooo0>Gooooo000iooooo`;o0000AOooool2o`000>Kooooo000kooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool0iOooool003cooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`3Uooooo`00?Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo0>Gooooo000nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0iOooool003oo
oooo00?o0000ooooooooool0?_ooool2o`000>Kooooo000nooooo`;oo`000_l0000nooooo`03o`00
0?oooooooooo0>Gooooo0010ooooo`;oo`0000?o0000ooooooooool0>oooool00ol0003ooooooooo
o`3Uooooo`00@_ooool00ooo003o0000ooooo`0kooooo`03o`000?oooooooooo0>Gooooo0013oooo
o`03ool00?l0003o000003[ooooo00?o0000ooooooooool0iOooool004Cooooo0_oo00000ol0003o
ooooooooo`0gooooo`;o0000i_ooool004Kooooo00?oo`00o`000?ooool0=oooool00ol0003ooooo
ooooo`3Uooooo`00Aoooool2ool003Oooooo00?o0000ooooooooool0iOooool004Wooooo00?oo`00
o`000?ooool0=?ooool00ol0003oooooooooo`3Uooooo`00B_ooool00ooo003o0000ooooo`0coooo
o`03o`000?oooooooooo0>Gooooo001;ooooo`03ool00?l0003ooooo03;ooooo0_l0003Vooooo`00
COooool2o`00037ooooo00?o0000ooooooooool0iOooool004oooooo00?o0000ooooooooool02_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`03o`000?oooooooooo0>Gooooo001@ooooo`;o0000
2_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oo
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`3Uooooo`00D_ooool00ol0003ooooo
ooooo`07ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0iOooool005?ooooo0_l00007ooooo`05o`00
0?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Go
oooo0ol0003Uooooo`00EOooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool00ol0
003oooooooooo`3Uooooo`00E_ooool2o`0000Cooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Uoooo
o`00F?ooool02Ol0003oooooooooooooooooMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0>Gooooo
001Iooooo`;oo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`Go00001?ooool4o`0000Oo
oooo00?o0000ooooooooool0iOooool005_ooooo0_oo000Sooooo`;o0000i_ooool005gooooo0_oo
000Qooooo`03o`000?oooooooooo0>Gooooo001Oooooo`;oo`007oooool00ol0003oooooooooo`3U
ooooo`00HOooool00ooo003oooooooooo`0Looooo`03o`000?oooooooooo0>Gooooo001Rooooo`;o
o`007?ooool00ol0003oooooooooo`3Uooooo`00I?ooool2ool001[ooooo0_l0003Vooooo`00I_oo
ool00ooo003o0000ooooo`0Gooooo`03o`000?oooooooooo0>Gooooo001Wooooo`03ool00?l0003o
000001Kooooo00?o0000ooooooooool0iOooool006[ooooo0_l0000Dooooo`03o`000?oooooooooo
0>Gooooo001/ooooo`;o00004_ooool00ol0003oooooooooo`3Uooooo`00K_ooool00ol0003ooooo
ooooo`0?ooooo`;o0000i_ooool006oooooo0_l0000?ooooo`03o`000?oooooooooo0>Gooooo001a
ooooo`;o00003Oooool00ol0003oooooooooo`3Uooooo`00Loooool2o`0000_ooooo00?o0000oooo
ooooool0iOooool007Gooooo0_l00009ooooo`03o`000?oooooooooo0>Gooooo001eooooo`;oo`00
0_l00007ooooo`;o0000i_ooool007Oooooo0_oo0002o`0000Gooooo00?o0000ooooooooool0iOoo
ool007Gooooo1?l00003ool000Cooooo00?o0000ooooooooool0iOooool007Oooooo00?o0000oooo
ooooool00_ooool2ool000;ooooo00?o0000ooooooooool0iOooool007Oooooo00?o0000oooooooo
ool01?ooool2ool00003o`000?oooooooooo0>Gooooo001gooooo`03o`000?oooooooooo00Kooooo
0_oo00000ol0003oooooooooo`3Sooooo`00Moooool00ol0003oooooooooo`06ooooo`04o`000?oo
ooooo`00ool00>Cooooo001gooooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooooooo
ool00?l0003Rooooo`00Moooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
0ol0003Oooooo`00MOooool00omEEEGoIVIVo`000008ooooo`03o`000?oooooooooo00Kooooo0_l0
003Mooooo`00P?ooool2o`0000Wooooo0_l0003Kooooo`00P?ooool00ol0003oooooooooo`0:oooo
o`;o0000fOooool0083ooooo00?o0000ooooooooool03?ooool2o`000=Oooooo0020ooooo`03o`00
0?oooooooooo00kooooo0_l0003Eooooo`00P?ooool00ol0003oooooooooo`0@ooooo`;oo`00dooo
ool0083ooooo0_l0000Cooooo`?oo`00d?ooool0083ooooo00?o0000ooooooooool05?ooool00ol0
003oo`00ool0003>ooooo`00P?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo003oo`000<co
oooo0020ooooo`03o`000?oooooooooo01Sooooo00Co0000ool00?oo003oo`00bOooool0083ooooo
00?o0000ooooooooool06oooool01?l0003oo`00ool00?oo0036ooooo`00P?ooool2o`0001oooooo
00?o0000ool00?l00000a?ooool0083ooooo00?o0000ooooooooool08Oooool3o`000<7ooooo0020
ooooo`03o`000?oooooooooo02Cooooo0_l0002oooooo`00P?ooool00ol0003oooooooooo`0Voooo
o`?o0000_?ooool0083ooooo00?o0000ooooooooool0:Oooool2o`000;[ooooo0020ooooo`;o0000
;?ooool2o`000;Sooooo0020ooooo`03o`000?oooooooooo02gooooo00?o0000ool00?oo0000]Ooo
ool005gooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@06ooooo`03o`000?oooooooooo033ooooo0_oo002cooooo`00Goooool0
0ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0booooo`?oo`00/?ooool005oooooo00?o0000
ooooooooool02oooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0=Oooool3ool00:gooooo001Oooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`05ooooo`?o0000>?ooool2ool00003o`000?oooooooooo
0:Sooooo001Oooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0>_ooool3ool00003o`000?oooooooooo
0:Gooooo001Oooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03gooooo00?oo`00o`000?l00000YOooool005oooooo
00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`10ooooo`?o0000X_ooool005gooooo00?oEEEEofIVI_l00000
3?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00007ooooo`03o`000?oooooooooo04?o
oooo0ol0002Oooooo`00P?ooool2o`0004Oooooo0_l0002Mooooo`00P?ooool00ol0003ooooooooo
o`18ooooo`?o0000V_ooool0083ooooo00?o0000ooooooooool0Boooool00ol0003oo`00ool0002G
ooooo`00P?ooool00ol0003oooooooooo`1=ooooo`04o`000?oo003oo`00ool009Cooooo0020oooo
o`03o`000?oooooooooo053ooooo00Co0000ool00?oo003oo`00TOooool0083ooooo0_l0001Coooo
o`;o00000ooo002>ooooo`00P?ooool00ol0003oooooooooo`1Dooooo`?o00001?oo002:ooooo`00
P?ooool00ol0003oooooooooo`1Gooooo`;o00000_ooool2ool008Sooooo0020ooooo`03o`000?oo
oooooooo05Wooooo0ol0001[ooooo`;oo`007?ooool0083ooooo00?o0000ooooooooool0G?ooool3
o`0006Kooooo0_oo000Nooooo`00P?ooool2o`00063ooooo0_l0001Qooooo`?oo`008?ooool0083o
oooo00?o0000ooooooooool0HOooool3o`0005cooooo0_oo000Sooooo`00P?ooool00ol0003ooooo
ooooo`1Tooooo`?o00001?ooool4ool004oooooo0_oo000Uooooo`00P?ooool00ol0003ooooooooo
o`1Wooooo`?o00001Oooool6ool004Kooooo0ooo000Wooooo`00P?ooool00ol0003oooooooooo`1Z
ooooo`?o00002?ooool5ool003oooooo0_oo000Zooooo`00P?ooool2o`0006kooooo0ol0000:oooo
o`;oo`00JOooool0083ooooo00?o0000ooooooooool0L?ooool4o`00077ooooo001Uooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`03
o`000?oooooooooo07Cooooo0ol0000Dooooo`Goo`005oooool3ool003_ooooo001Wooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Gooooo00?o0000ooooooooool0
Moooool3o`0001Kooooo3?oo0019ooooo`00Ioooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0N_ooool3o`0006Sooooo001Wooooo`03o`000?oooooo
oooo00kooooo00?oMgMgoc8b<_ooool01Oooool3o`0007gooooo1?l0001Tooooo`00Ioooool00ol0
003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`21
ooooo`?o0000HOooool006Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo08Cooooo0ol0001Nooooo`00Ioooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0Qoooool3o`0005_ooooo001Uooooo`03oeEE
EOmVIVKo000000gooooo1?l00007ooooo`03o`000?oooooooooo08[ooooo1?l0001Gooooo`00P?oo
ool2o`0008oooooo0ol0001Dooooo`00P?ooool00ol0003oooooooooo`2Aooooo`?o0000DOooool0
083ooooo00?o0000ooooooooool0U?ooool3o`0004kooooo0020ooooo`03o`000?oooooooooo09Oo
oooo0ol0001;ooooo`00P?ooool00ol0003oooooooooo`2Jooooo`?o0000B?ooool0083ooooo0_l0
002Nooooo`Co0000A?ooool0083ooooo00?o0000ooooooooool0XOooool3o`00047ooooo0020oooo
o`03o`000?oooooooooo0:Cooooo1?l0000mooooo`00P?ooool00ol0003oooooooooo`2Xooooo`?o
0000>_ooool0083ooooo00?o0000ooooooooool0Zoooool3o`0003Oooooo0020ooooo`;o0000[ooo
ool3o`0003Cooooo0020ooooo`03o`000?oooooooooo0;7ooooo1?l0000`ooooo`00P?ooool00ol0
003oooooooooo`2eooooo`?o0000;Oooool0083ooooo00?o0000ooooooooool0^?ooool3o`0002[o
oooo0020ooooo`03o`000?oooooooooo0;_ooooo0ol0000Wooooo`00P?ooool2o`000;oooooo0ol0
000Tooooo`00P?ooool00ol0003oooooooooo`31ooooo`Co00008?ooool005gooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01_ooool00ol0003oooooooooo`35ooooo`Co00007?ooool005oooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`05oooo
o`03o`000?oooooooooo0<Wooooo0_l0000Jooooo`00Goooool00ol0003oooooooooo`0<ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Uooooo`00
Goooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0
1Oooool3o`000>Gooooo001Oooooo`03o`000?oooooooooo00gooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0iOooool005oooooo00?o
0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0iOooool005oooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Uooooo`00GOooool0
0omEEEGoIVIVo`00000<ooooo`Go00001?ooool4o`0000Oooooo00?o0000ooooooooool0iOooool0
083ooooo0_l0003Vooooo`00P?ooool00ol0003oooooooooo`3Uooooo`00P?ooool00ol0003ooooo
ooooo`3Uooooo`00P?ooool00ol0003oooooooooo`3Uooooo`00P?ooool00ol0003oooooooooo`3U
ooooo`00P?ooool2o`000>Kooooo0020ooooo`03o`000?oooooooooo0>Gooooo0020ooooo`03o`00
0?oooooooooo0>Gooooo0020ooooo`03o`000?oooooooooo0>Gooooo0020ooooo`03o`000?oooooo
oooo0>Gooooo0020ooooo`;o0000i_ooool0083ooooo00?o0000ooooooooool0iOooool0083ooooo
00?o0000ooooooooool0iOooool0083ooooo00?o0000ooooooooool0iOooool0083ooooo00?o0000
ooooooooool0iOooool0083ooooo0_l0003Vooooo`00P?ooool00ol0003oooooooooo`3Uooooo`00
M?ooool5o`0000Oooooo00?o0000ooooooooool0iOooool007Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A007ooooo`03o`000?oooooooooo0>Gooooo001eooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o
0000ooooooooool0iOooool007Kooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000>Gooooo001goooo
o`03ogMgMomVIVKooooo0>kooooo001hooooo`03o`000?oooooooooo0>gooooo001dooooo`05o`00
0?nj^[[ooooooiRHV?l@4100koooool007Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c03_ooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.24338, -0.152711, \
0.0121405, 0.0124722}}]
}, Open  ]],

Cell[TextData[{
  "The power series expansion about ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", shown as a dashed line, works quite well provided that ",
  StyleBox["x",
    FontSlant->"Italic"],
  " is not too different from 0.  By keeping more terms in the series, you \
can convince yourself that the power series  will only converge to the right \
answer if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(x\)\(|\)\(\(<\)\(r\)\)\)\)]],
  ",  where",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(r\)\)\)]],
  " is the ",
  StyleBox["radius of convergence",
    FontSlant->"Italic"],
  " of the series. For this example, one can show that ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ", so the power series only works in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < x < 1\)]],
  ". This is because ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x + 1\)\)]],
  " has a singularity at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-1\)\)]],
  ", and this singularity cannot be well represented by a polynomial \
expansion."
}], "Text",
  CellTags->"i:117"],

Cell[TextData[{
  "\tActually, ",
  StyleBox["Series",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can perform expansions that are more general than the simple polynomial \
Taylor series of Eq. ",
  ButtonBox["(9.9.1)",
    ButtonData:>"(9.9.1)",
    ButtonStyle->"Hyperlink"],
  ". For example,  expanding the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@\(1/x\^\(2/3\) + \ 1\)\)\(\ \)\)\)]],
  " about ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " (where there is a singularity) yields the following non-polynomial \
expression:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[Sqrt[1/x\^\(2/3\) + 1], {x, 0, 3}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.142"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(1\/x\^\(1/3\)\), "+", \(x\^\(1/3\)\/2\), "-", \(x\/8\), 
        "+", \(x\^\(5/3\)\/16\), "-", \(\(5\ x\^\(7/3\)\)\/128\), 
        "+", \(\(7\ x\^3\)\/256\), "+", 
        InterpretationBox[\(O[x]\^\(11/3\)\),
          SeriesData[ x, 0, {}, -1, 11, 3]]}],
      SeriesData[ x, 0, {1, 0, 
        Rational[ 1, 2], 0, 
        Rational[ -1, 8], 0, 
        Rational[ 1, 16], 0, 
        Rational[ -5, 128], 0, 
        Rational[ 7, 256]}, -1, 11, 3]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.9.3 Integration", "Subsubtitle",
  CellTags->{"i:72", "c:51"}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can perform symbolic integration.  In order to evaluate the indefinite \
integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(f(x)\) \[DifferentialD]x\)]],
  " of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", use the notation ",
  StyleBox["Integrate[f[x],x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The second argument gives the variable over which the first argument is \
integrated. For example, the indefinite integral  of the hyperbolic tangent \
is "
}], "Text",
  CellTags->"i:74"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Tanh[x], x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.143"],

Cell[BoxData[
    \(Log[Cosh[x]]\)], "Output"]
}, Open  ]],

Cell["One can verify this result by taking its derivative:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[%, x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.144"],

Cell[BoxData[
    \(Tanh[x]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To evaluate definite integrals, you need only specify the range of \
integration along with the integration variable. For example,  to evaluate \
the integral of",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`\(cos\^2\) x\)]]]]}], TraditionalForm]]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " to",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(2  \[Pi]\)\)\)]],
  ", use"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Cos[x]^2, {x, 0, 2\ Pi}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.145"],

Cell[BoxData[
    \(\[Pi]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is generally very careful when evaluating integrals to make sure that \
they converge properly. When there is a question as to the existence of the \
result, ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " will often supply ranges of free parameters in the integrand for which \
the integral exists. For example, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " recognizes that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\( 
              1\/\(x\^a + 1\)\) \[DifferentialD]x\)]],
  " exists only if ",
  Cell[BoxData[
      \(TraditionalForm\`Re\ a > 1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[1/\((1\  + \ x^a)\), {x, 0, Infinity}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.146"],

Cell[BoxData[
    RowBox[{"If", "[", 
      RowBox[{\(Re[a] > 1\), ",", \(\(\[Pi]\ Csc[\[Pi]\/a]\)\/a\), ",", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", "0", 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 
              1]]], \(\(1\/\(1 + x\^a\)\) \[DifferentialD]x\)}]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here, for the first time, we have encountered an if statement. This if \
statement takes three arguments: ",
  StyleBox["If[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["logical expression",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["result if true, result if false",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". That is, the second argument is returned if ",
  StyleBox["logical expresion",
    FontSlant->"Italic"],
  " is true, but if it is  false the third argument is returned.  In other \
words, if we substitute ",
  Cell[BoxData[
      \(TraditionalForm\`a\  \[Rule] \ \ \(-1\)\)]],
  ", then ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " can't find the integral and it returns  the third argument evaluated at \
",
  Cell[BoxData[
      \(TraditionalForm\`a = \(-1\)\)]],
  ":"
}], "Text",
  CellTags->"i:79"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. a \[Rule] \(-1\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.147"],

Cell[BoxData[
    RowBox[{\(Integrate::"idiv"\), \(\(:\)\(\ \)\), "\<\"Integral of \
\\!\\(1\\/\\(1 + 1\\/x\\)\\) does not converge on \\!\\({0, \
\\*InterpretationBox[\\\"\[Infinity]\\\", DirectedInfinity[1]]}\\).\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 
          1]]], \(\(1\/\(1 + 1\/x\)\) \[DifferentialD]x\)}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, for ",
  Cell[BoxData[
      \(TraditionalForm\`a\  > 1\)]],
  " the second argument is returned:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%% /. a \[Rule] 7\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.148"],

Cell[BoxData[
    \(1\/7\ \[Pi]\ Csc[\[Pi]\/7]\)], "Output"]
}, Open  ]],

Cell["\<\
Of course, there are many convergent integrals for which there is \
no analytic answer in terms of pre-defined functions. A simple example is \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[Exp[\(-Exp[x^2]\)], {x, 0, Infinity}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.149"],

Cell[BoxData[
    RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 
          1]]], \(\(\[ExponentialE]\^\(-\[ExponentialE]\^\(x\^2\)\)\) \
\[DifferentialD]x\)}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "However, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can evaluate integrals like this numerically, as we will discuss in ",
  ButtonBox["Sec. 9.11",
    ButtonData:>"Sec. 9.11",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox["Table",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["9",
              FontSize->9], 
            StyleBox[".19",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Calculus",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["in",
              FontSize->9], 
            StyleBox[" ",
              FontSize->9], 
            StyleBox["Mathematica",
              FontSize->9,
              FontSlant->"Italic"]}]},
        {GridBox[{
              {
                StyleBox[\(D[f, x]\),
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["The",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox[\((partial)\),
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["derivative",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["f",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["with",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["respect",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["to",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Times",
                    FontSlant->"Italic"]}]},
              {
                StyleBox[\(Integrate[f, x]\),
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["The",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox[\((indefinite)\),
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["integral",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox[
                    RowBox[{
                      StyleBox["of",
                        FontFamily->"Times"], 
                      StyleBox["f",
                        FontFamily->"Times",
                        FontSlant->"Italic"]}]], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["with",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["respect",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["to",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Times",
                    FontSlant->"Italic"]}]},
              {
                StyleBox[\(Integrate[f, {x, xmin, xmax}]\),
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["The",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["definite",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["integral",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["f",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["from",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["xmin",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["to",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["xmax",
                    FontFamily->"Times",
                    FontSlant->"Italic"]}]},
              {
                StyleBox[\(Series[f, {x, x\_o, n}]\),
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["The",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["power",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["series",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["order",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["n",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["for",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["f",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["with",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["respect",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["to",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["around",
                    FontFamily->"Times"], 
                  StyleBox[
                    FormBox[
                      StyleBox[\(x\_o\),
                        FontFamily->"Times"],
                      "TraditionalForm"],
                    FontFamily->"Times"]}]},
              {
                RowBox[{
                  StyleBox["Normal",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox["series",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                
                StyleBox[\(Convert\ a\ power\ series\ into\ a\ normal\ \
expression\),
                  FontFamily->"Times"]},
              {
                StyleBox[
                  RowBox[{"Limit", "[", 
                    RowBox[{"f", ",", 
                      RowBox[{"x", Cell["\[Rule]"], " ", \(x\_o\)}]}], "]"}],
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["Take",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["the",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["limit",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["of",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["f",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["as",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["approaches",
                    FontFamily->"Times"], 
                  StyleBox[
                    FormBox[
                      StyleBox[\(x\_o\),
                        FontFamily->"Times"],
                      "TraditionalForm"],
                    FontFamily->"Times"]}]}
              },
            ColumnSpacings->1.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.9", "Subsubtitle",
  CellTags->{"Ex. 9.9", "c:52"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Find all local extrema of the following polynomial:  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4 + 5\ x\^3 - 3\ x\^2 + 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Find all local extrema of the following function of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", and classify these extrema as either minima, maxima or saddlepoints: \n\t\
\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y) = y\ x\^2 + y\^2\ x - 2\ \(x(y + 2)\)\)]],
  "."
}], "Text"],

Cell["\<\
Find the value of the function at each extremum. (Hint: A \
high-resolution contour plot is helpful. )\
\>", "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Find the following indefinite integrals, and prove by differentiating the \
result that ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "did the integral properly. (Some of the results may be in terms of special \
functions, whose definitions need not concern you at this time. You may need \
to manipulate the results in order to return them to their original form \
after differentiating the integrals.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(x\^3\/\(\(sin\^2\)(
                x)\)\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(x\^a\ \(\(log\^3\)(
              x)\)\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(\[ExponentialE]\^\(-x\^3\)\) \
\[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Evaluate the following definite integrals:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( cos(
                p\ x)\)\/\(a\^2 + x\^2\)\) \[DifferentialD]x\)]],
  " , assuming that ",
  StyleBox["p ",
    FontSlant->"Italic"],
  " and ",
  StyleBox["a",
    FontSlant->"Italic"],
  " are real."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(2\ \[Pi]\)\(cos(
            z\ \(sin(x)\))\) \[DifferentialD]x\)]],
  " , assuming that ",
  StyleBox["z",
    FontSlant->"Italic"],
  " is real."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\( 
            x\ \[ExponentialE]\^\(-x\^4\)\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Find the power series expansion to 6th order around ",
  StyleBox["x=0",
    FontSlant->"Italic"],
  " of the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \((x + 1)\) \(ln(x + 1)\)\)]],
  " . Plot the resulting series on the same graph as ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x",
    FontSlant->"Italic"],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < x < 2\)]],
  ". Repeat for the 100th-order series. Can you tell from these plots what is \
the radius of convergence of this power series?"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " A particle moves in one dimension. Its velocity as a function of time is \
given by the function   ",
  Cell[BoxData[
      \(TraditionalForm\`v(t) = \(-4\)\ t\^3 + t\^2 + 1\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " is measured in seconds."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find and plot the particle's position ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " seconds, assuming that the particle is at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-1\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the maximum positive excursion, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_max\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["7(a)",
    FontWeight->"Bold"],
  " Assuming that the particle in Exercise (6) has a mass of ",
  Cell[BoxData[
      \(TraditionalForm\`5\ kg\)]],
  ", plot the total force ",
  Cell[BoxData[
      \(TraditionalForm\`F(t)\)]],
  " on the particle for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " seconds."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the work done by the force as a function of time,  ",
  Cell[BoxData[
      \(TraditionalForm\`W(
          t) = \[Integral]\_0\%t\(\( F(t)\)\ \(v(
                t)\)\) \[DifferentialD]t\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that for this particle the work ",
  Cell[BoxData[
      \(TraditionalForm\`W(t)\)]],
  " equals the change in kinetic energy of the particle ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["K",
                FontSlant->"Italic"]}]], 
          "=", \(1\/2\ m[\(v(t)\)\^2 - \(v(0)\)\^2]\)}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(W(t)\)\(\ \)\(=\)\(\ \)\)\)]],
  StyleBox["\[CapitalDelta]",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  StyleBox["K(t)",
    FontSlant->"Italic"],
  ", "
}], "Text"],

Cell[" (This is called the work-kinetic-energy theorem.)", "Text",
  CellTags->"i:118"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.10 Analytic Solution of Algebraic Equations", "Subtitle",
  CellTags->{"Sec. 9.10", "i:99", "c:53"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "9.10.1 ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " and ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"]
}], "Subsubtitle",
  CellTags->{"i:83", "c:54"}],

Cell[CellGroupData[{

Cell["One Equation in a Single Variable", "Section",
  CellTags->"c:55"],

Cell[TextData[{
  "Say we want to find the solution for ",
  StyleBox["x",
    FontSlant->"Italic"],
  " to an equation such as  ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["x)",
    FontSlant->"Italic"],
  " = 0. If an analytic solution exists, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can usually find it using the ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The syntax for this function is as follows:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  StyleBox["Solve[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["f",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["]== ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  CellTags->"i:81"],

Cell[TextData[{
  "The first argument is the equation to be solved,  and the second argument \
gives the variable ",
  StyleBox["x ",
    FontSlant->"Italic"],
  "for which we are solving. "
}], "Text"],

Cell[TextData[{
  " \tNote the double equal signs in the equation ",
  StyleBox["f[x]== 0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  Here we have yet another meaning of \"equals\". In this case, the \
equation ",
  StyleBox["f[x]== 0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  expresses a question: is the ",
  "left-hand",
  " side ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  " equal to the right-hand side ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  "? It is called a ",
  StyleBox["logical statement ",
    FontSlant->"Italic"],
  "because the result is either ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, the statement",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(1\)\(\ \)\(==\)\(\ \)\(0\)\(\ \)\)\)\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will return ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; and the statement ",
  StyleBox["Simplify[(x+1)^2 = = x^2 + 2x + 1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " yields ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". (Try it!) We have seen logical statements before.  For instance, we used \
them to place conditions on function definitions in Sec. ",
  ButtonBox["9.8.6",
    ButtonData:>"c:46",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:78"],

Cell[TextData[{
  "\tIf  we used a single equal sign to define our equation, ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ 0\)]],
  ", we would be assigning the value 0 to the function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " when its argument takes on the value ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", which is not what we want to do here. "
}], "Text"],

Cell[TextData[{
  "\tAs a simple example of the function ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", let's find the roots of the cubic polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\  + \ 2\ x\^2\  - x\  - \ 2. \)]],
  " To do so we use"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[x^3\  + \ 2\ x^2\  - \ x\  - 2 \[Equal] 0, x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.150"],

Cell[BoxData[
    \({{x \[Rule] \(-2\)}, {x \[Rule] \(-1\)}, {x \[Rule] 1}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is the three solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", written as a list of replacements. We can check that these are in fact \
the solutions by substituting the list back into the polynomial:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x^3\  + \ 2\ x^2\  - \ x\  - \ 2\  /. %\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.151"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tWhile analytic solutions to cubic and even quartic polynomials can be \
found, solutions to higher order polynmials can usually only be found \
numerically. Nevertheless, ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "will take a stab, returning some strange-looking stuff:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[x^5\  + \ x^2\  + \ 1\  \[Equal] 0, x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.152"],

Cell[BoxData[
    \({{x \[Rule] Root[1 + #1\^2 + #1\^5 &, 1]}, {x \[Rule] 
          Root[1 + #1\^2 + #1\^5 &, 2]}, {x \[Rule] 
          Root[1 + #1\^2 + #1\^5 &, 3]}, {x \[Rule] 
          Root[1 + #1\^2 + #1\^5 &, 4]}, {x \[Rule] 
          Root[1 + #1\^2 + #1\^5 &, 5]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "What we have here is a list of numerical values for the solutions, found \
using a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function called ",
  StyleBox["Root ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "whose specialty is polynomial root finding. (The ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function calls ",
  StyleBox["Root",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when it recognizes a polynomial equation.) In this form the result is not \
much use to anyone, but one can get numerical values for the roots by \
applying the ",
  StyleBox["N",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to this list:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[%]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.153"],

Cell[BoxData[
    \({{x \[Rule] \(-1.1938591113212231`\)}, {x \[Rule] \
\(-0.15458967671833224`\) - 
            0.8280741332013`\ \[ImaginaryI]}, {x \[Rule] \
\(-0.15458967671833224`\) + 
            0.8280741332013`\ \[ImaginaryI]}, {x \[Rule] \
\(\(0.7515192323789438`\)\(\[InvisibleSpace]\)\) - 
            0.784615921039448`\ \[ImaginaryI]}, {x \[Rule] \
\(\(0.7515192323789438`\)\(\[InvisibleSpace]\)\) + 
            0.784615921039448`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Alternatively, we can avoid the weird intermediate stuff by using the \
function ",
  StyleBox["NSolve[f[x]== 0,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which basically  stands for ",
  StyleBox["N[Solve[f[x]==0,x]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  This takes us directly to the numerical form of the solution: "
}], "Text",
  CellTags->"i:82"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[x^5\  + \ x^2\  + \ 1\  \[Equal] 0, x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.154"],

Cell[BoxData[
    \({{x \[Rule] \(-1.1938591113212231`\)}, {x \[Rule] \
\(-0.15458967671833224`\) - 
            0.8280741332013`\ \[ImaginaryI]}, {x \[Rule] \
\(-0.15458967671833224`\) + 
            0.8280741332013`\ \[ImaginaryI]}, {x \[Rule] \
\(\(0.7515192323789438`\)\(\[InvisibleSpace]\)\) - 
            0.784615921039448`\ \[ImaginaryI]}, {x \[Rule] \
\(\(0.7515192323789438`\)\(\[InvisibleSpace]\)\) + 
            0.784615921039448`\ \[ImaginaryI]}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Coupled Equations in Several Variables", "Section",
  CellTags->"c:56"],

Cell[TextData[{
  "\t",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can also be used to solve coupled systems of equations. Now the arguments \
are"
}], "Text"],

Cell[TextData[{
  "\t\t",
  StyleBox["Solve[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "{",
  StyleBox["eqns",
    FontSlant->"Italic"],
  "}",
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "{",
  StyleBox["vars",
    FontSlant->"Italic"],
  "}",
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "where {",
  StyleBox["eqns",
    FontSlant->"Italic"],
  "} is a list of equations, and {",
  StyleBox["vars",
    FontSlant->"Italic"],
  "} is the list of variables to be solved for. For example,  the coupled \
system of linear equations"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(x + y + z = 0\)\(,\)\(\ \)\)\)]],
  "\t\t\t\t\t\t\n",
  Cell[BoxData[
      \(TraditionalForm\`z + 2  y = 4\)]],
  ", \t\t\t\t\t\t\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z + 3 = 2\)\(,\)\)\)]]
}], "NE4",
  TextAlignment->Left,
  TextJustification->0,
  CellTags->"(9.10.1)"],

Cell["has the following solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{x + y + z \[Equal] 0, x + 2  y\  \[Equal] \ 4, 
        z + 3 \[Equal] 2}, {x, y, z}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.155"],

Cell[BoxData[
    \({{x \[Rule] \(-2\), y \[Rule] 3, z \[Rule] \(-1\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Tip: if you forget to use the double equal sign, and instead use a single \
equal sign, remember that you have now assigned the right-hand side to the ",
  "left-hand",
  " side. Sometimes ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "will not allow such an assignment, as in",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["+",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["y",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". (Try it: you will get an error.) However, if your equation takes a form \
such as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["y",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["-",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["3",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ", ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "will assign",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`y - 3\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  Now the result of evaluating  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["==",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["y",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["-",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["3",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " will  be the logical result ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " substitutes for the value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". To stop this from happening,  you need to clear the value of ",
  StyleBox["x ",
    FontSlant->"Italic"],
  " using ",
  StyleBox["Remove[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Clear[x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\tAs another example of coupled equations, consider a system of masses \
connected by springs. Such systems are often used to model the behavior of \
elastic materials. For instance, the compression of an elastic rod standing \
on its end on a table can be modeled by a system of ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " one-dimensional coupled harmonic oscillators at positions ",
  Cell[BoxData[
      \(TraditionalForm\`y = y\_i\)]],
  ". The first mass is at ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(y\_0 = 0\)\)]],
  ", and the location of subsequent masses is determined by the force balance \
equations"
}], "Text",
  CellTags->"i:107"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`0 = \(-\(k(y\_i - y\_\(i - 1\))\)\) + 
          k(y\_\(i + 1\) - y\_i) - \ m\ g, \ i = 1, 2, 
      3, \(\(...\) \(M\)\) - 1\)]],
  ". "
}], "Text"],

Cell["\<\
The last mass, at the top of the chain, has no mass above it,  so \
its equation of motion  is different:\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`0 = \(-\(k(y\_M - y\_\(M - 1\) - a)\)\)\  - \ 
          m\ g\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\)\(\ \)\)\)]],
  "is the equilibrium displacement between the masses in the absence of \
gravity. "
}], "Text"],

Cell[TextData[{
  "\tWe can use ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to determine the equilibrium positions of the masses in such a system.  \
First, we choose a value of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and define the position of the lowest mass, sitting at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(M = 20;\)\), "\n", 
    \(\(y[0]\  = \ 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.156"],

Cell[TextData[{
  "Next, we make a table of equations for the other masses, ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1,  .. , M - 1\)]]
}], "Text"],

Cell[BoxData[
    \(\(eqns\  = \ 
        Table[0 \[Equal] \(-\((2  y[i] - y[i - 1] - y[i + 1])\)\) - \ 
              m\ g/k, {i, 1, M - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.157"],

Cell["To this list we must add the final equation:", "Text"],

Cell[BoxData[
    \(\(eqns\  = \ 
        Append[\ eqns, 
          0 \[Equal] \(-\((y[M] - y[M - 1] - \ a\ )\)\) - \ 
              m\ g/k];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.158"],

Cell["\<\
 Finally, we define the list of variables, and solve the equations:\
\
\>", "Text"],

Cell[BoxData[{
    \(\(vars\  = \ Table[y[i], {i, 1, M}];\)\), "\n", 
    \(\(soln\  = \ Solve[eqns, \ vars];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.159"],

Cell[TextData[{
  "Although we suppressed the output in order to save space, one can check \
that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " actually solved the coupled equations analytically. For more complicated \
problems, it is usually better to solve the problem numerically, providing \
values for the parameters in the equations before a solution is attempted."
}], "Text"],

Cell[TextData[{
  "\tIn Cell ",
  ButtonBox["9.160",
    ButtonData:>"Cell 9.160",
    ButtonStyle->"Hyperlink"],
  " we plot the positions of the masses using a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(g = 9.8\), " ", ",", " ", \(m = 0.1\), ",", 
          RowBox[{
            RowBox[{Cell[""], "k"}], "=", "10"}], ",", " ", \(a\  = \ 0.2\)}],
         TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(g = 9.8; m = 0.01; k = 10; a = 0.2;\), "\n", 
    \(\(pos\  = \ Table[{0, y[i]}, {i, 0, M}] /. soln[\([1]\)];\)\), "\n", 
    \(\(ListPlot[pos, PlotStyle \[Rule] PointSize[0.02], 
        PlotLabel -> "\<equilibrium positions\>", 
        Axes \[Rule] {False, True}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.160"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.0147151 0.303092 [
[.4875 .01472 -6 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16626 -18 -4.5 ]
[.4875 .16626 0 4.5 ]
[.4875 .31781 -6 -4.5 ]
[.4875 .31781 0 4.5 ]
[.4875 .46935 -18 -4.5 ]
[.4875 .46935 0 4.5 ]
[.5 .63053 -65.0625 0 ]
[.5 .63053 65.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .01472 m
.50625 .01472 L
s
[(0)] .4875 .01472 1 0 Mshowa
.5 .16626 m
.50625 .16626 L
s
[(0.5)] .4875 .16626 1 0 Mshowa
.5 .31781 m
.50625 .31781 L
s
[(1)] .4875 .31781 1 0 Mshowa
.5 .46935 m
.50625 .46935 L
s
[(1.5)] .4875 .46935 1 0 Mshowa
.125 Mabswid
.5 .04502 m
.50375 .04502 L
s
.5 .07533 m
.50375 .07533 L
s
.5 .10564 m
.50375 .10564 L
s
.5 .13595 m
.50375 .13595 L
s
.5 .19657 m
.50375 .19657 L
s
.5 .22688 m
.50375 .22688 L
s
.5 .25719 m
.50375 .25719 L
s
.5 .2875 m
.50375 .2875 L
s
.5 .34812 m
.50375 .34812 L
s
.5 .37842 m
.50375 .37842 L
s
.5 .40873 m
.50375 .40873 L
s
.5 .43904 m
.50375 .43904 L
s
.5 .49966 m
.50375 .49966 L
s
.5 .52997 m
.50375 .52997 L
s
.5 .56028 m
.50375 .56028 L
s
.5 .59059 m
.50375 .59059 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -126.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(equilibrium) show
135.125 13.000 moveto
(positions) show
189.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.5 .01472 Mdot
.5 .01593 Mdot
.5 .02011 Mdot
.5 .02726 Mdot
.5 .03739 Mdot
.5 .05048 Mdot
.5 .06654 Mdot
.5 .08558 Mdot
.5 .10758 Mdot
.5 .13256 Mdot
.5 .1605 Mdot
.5 .19142 Mdot
.5 .2253 Mdot
.5 .26216 Mdot
.5 .30199 Mdot
.5 .34478 Mdot
.5 .39055 Mdot
.5 .43929 Mdot
.5 .49099 Mdot
.5 .54567 Mdot
.5 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
Z?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0002cooooo`00Z?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo1_l0002booooo`00Z?ooool01Ol@413ooooooooooooooooo410@00?o
oooo1_l0002booooo`00Z?ooool01Ol0003ooooooooooooooooo000000?ooooo1_l0002booooo`00
Z?ooool01Ol0003ooooooooooooooooo000000?ooooo1_l0002booooo`00Z?ooool01Ol@413ooooo
oooooooooooo410@00?ooooo1_l0002booooo`00Z?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo1_l0002booooo`00Z?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1_l0002booooo`00
/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/?ooool6o`00
0;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo002`
ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/Oooool4o`000;?ooooo002`ooooo`Ko0000
/_ooool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;7o
oooo1?l0002cooooo`00/oooool2o`000;?ooooo002aooooo`Co0000/oooool00;3ooooo1_l0002b
ooooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/Ooo
ool4o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002aooooo`Co0000/oooool00;3o
oooo1_l0002booooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002b
ooooo`00/Oooool4o`000;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002aooooo`Co0000/oooool00;3ooooo1_l0002booooo`00/?ooool6o`00
0;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/Oooool4o`000;?ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002aooooo`Co0000/oooool00;3ooooo1_l0002booooo`00V?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0_ooool6o`000;;ooooo002Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00CoMgMgoc8b<_oooooooooo1_l0002booooo`00V?ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool01_l0002booooo`00V?ooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00_ooool4o`000;?ooooo002Hooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0/_ooool009So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0/_ooool009Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0/_ooool009Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool00ol0003oooooooooo`2booooo`00/Oooool4o`000;?ooooo002`ooooo`Ko0000
/_ooool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;7o
oooo1?l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/Oooool4o`000;?ooooo002`ooooo`Ko0000/_oo
ool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;7ooooo
1?l0002cooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/Oooool4
o`000;?ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo
002`ooooo`Ko0000/_ooool00;7ooooo1?l0002cooooo`00/oooool00ol0003oooooooooo`2boooo
o`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/ooo
ool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002aooooo`Co0000/oooool00;3ooooo1_l0
002booooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00
ZOooool4o`000004oa0@4?ooooooooooooooo`Co0000/oooool00:_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2booooo`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Gooooo0ol0002booooo`00Zoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0;;ooooo002[ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0/_ooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2booooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002aooooo`Co0000/oooool00;3ooooo1_l0002booooo`00
/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/Oooool4o`00
0;?ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo
002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool0
0;7ooooo1?l0002cooooo`00/?ooool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0
002booooo`00/?ooool6o`000;;ooooo002aooooo`Co0000/oooool00;?ooooo00?o0000oooooooo
ool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003o
ooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003ooooooooo
o`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2boooo
o`00/Oooool4o`000;?ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/?ooool6
o`000;;ooooo002`ooooo`Ko0000/_ooool00;7ooooo1?l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00VOooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`2booooo`00Voooool00ol0003oooooooooo`04oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo0;;ooooo002Kooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2booooo`00
Voooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002booooo`00Vooo
ool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`2booooo`00Voooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0/_ooool009_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0;;ooooo002Iooooo`03oeEEEOmVIVKo000000gooooo1?l00006oooo
o`03o`000?oooooooooo0;;ooooo002aooooo`Co0000/oooool00;3ooooo1_l0002booooo`00/?oo
ool6o`000;;ooooo002`ooooo`Ko0000/_ooool00;3ooooo1_l0002booooo`00/Oooool4o`000;?o
oooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002c
ooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03
o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo
0;;ooooo002cooooo`;o0000/oooool00;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo00?o
0000ooooooooool0/_ooool00;7ooooo1?l0002cooooo`00/?ooool6o`000;;ooooo002`ooooo`Ko
0000/_ooool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo002aooooo`Co0000/oooool0
0;?ooooo00?o0000ooooooooool0/_ooool00;?ooooo0_l0002cooooo`00/oooool00ol0003ooooo
ooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00
/oooool00ol0003oooooooooo`2booooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool0
0ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`000?oooooooooo0;;o
oooo002aooooo`Co0000/oooool00;3ooooo1_l0002booooo`00/?ooool6o`000;;ooooo002`oooo
o`Ko0000/_ooool00;3ooooo1_l0002booooo`00/Oooool4o`000;?ooooo002cooooo`03o`000?oo
oooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo001`ooooo`?o000000?o410@oooo
ooooool0BOooool01?l@413o0000o`000?l0002Uooooo`00L_ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo0:Gooooo001booooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0YOooool006Gooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`06onk^k_mEEEGo0000
o`000?mgMgOo00000oooool01_nHV9So0000o`000?mgMgOo0000oa0@40;ooooo1Ol00002ooooo`Go
00001?ooool5o`0000;ooooo00?o410@o`000?n7QhL00_l000000omVIVKok^k^oa0@4005o`0000Co
oooo1Ol00003ooooo`06oiRHV?l0003o0000ogMgMol0003o410@0_l00002ooooo`05o`000?oooooo
ooooo`000?l@41000oooool02Ol0003oMgMgo`000?l0003oEEEEonk^k_ooooook^k^oeEEE@02o`00
0006oeEEEOo^k^koooooooooool@413o<S8b0_l000000ol@413oZJVYooooo`02ooooo`Go00000ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo1Ol00002ooooo`06onk^k_mEEEGo0000o`000?mE
EEGok^k^0_ooool01?l@413o0000o`000?ooool2o`000004oa0@4?oooooo410@oc8b<P;o000000?o
410@ojVYZOooool0H_ooool006Gooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06oeEE
EOmgMgOoooooonk^k_mEEEGo00000oooool01Ol0003oZJVYoooooon7QhOo000000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Ko0000
oeEEEOo^k^koooooogMgMomVIVH2ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`09o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMg00;ooooo
00KoMgMgoeEEEOooooooooooo`000?nYZJT2ooooo`03okZj^_l0003ooooo00Cooooo00?o0000oooo
ooooool00oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool0
1_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ooooooooooooooooo`000002ooooo`06
o`000?nYZJWooooooooooonj^[[o0000Hoooool006Gooooo00?o0000ooooooooool01Oooool01_l0
003oooooooooooooooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?o^k^kooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000004ooooo`06o`000?oooooo
oooooooooonj^[[oQhN70_mVIVH00ol@413oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooooooooooooonj^[[oQhN70_mVIVH0
0ol@413oooooooooo`1Qooooo`00IOooool6o`0000;ooooo00Ko0000ooooooooooooooooonk^k_l0
0003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ok^k^ooooo`02ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooolb<S;o8B4Q00;oMgMg00?o
QhN7onk^k_ooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooolb<S;o8B4Q00;oMgMg00?oQhN7onk^k_ooool0H_ooool006Gooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00000ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEED2oooo
o`03o`000?lb<S;ogMgM00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00Oo0000olc<c?o<c<co0000ojVYZOoMgMgo8B4Q00Cooooo00Wo0000oeEEEOo^k^ko
ooooogMgMomVIVKooooooeEEEOmgMgL00_ooool02_mgMgOoEEEEoooooooooooo0000okZj^_oooooo
k^k^ogMgMol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool01Ol0003oQhN7oooo
oonYZJWo000000;ooooo00Ko0000okZj^_ooooook^k^ogMgMol0001Sooooo`00IOooool01_o^k^ko
EEEEo`000?l0003oA4A4onk^kP;ooooo00[ok^k^oeEEEOl0003o0000ogMgMol0003o410@ooooool@
413o00000_ooool2o`0000?ooooo00?o410@o`000?l000001_ooool00ol0003oooooooooo`04oooo
o`03oa0@4?l0003o000000Gooooo00Oo0000olc<c?l@413o0000oeEEEOo^k^kooooo00;o000000Co
ZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000004ooooo`04oa0@4?l0003oooooooooo`;o
000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJT00oooool00ol@413o0000ogMg
M`02o`000005ofIVI_o^k^koooooonk^k_mEEED00_l000001_mEEEGok^k^ooooooooooooZJVYob4Q
8@;o000000?o<S8bo`000?ooool00_ooool00ol@413o0000o`000003ooooo`03oa0@4?l0003o0000
00?o00001?ooool00ol@413o0000o`000004ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_oo
ool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooojVYZOlQ8B400_l000000olb<S;o0000
ooooo`1Rooooo`00Qoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0QOooool0083ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1k
ooooo`00P?ooool00ol@413oooooooooo`02ooooo`03oa0@4?l0003o000000Sooooo00?o410@oooo
ooooool00_ooool00ol@413o0000ooooo`0@ooooo`03oa0@4?oooooooooo02oooooo00?o410@oooo
ooooool03Oooool00ol@413oooooooooo`1kooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
The rod is compressed near the bottom because of the weight of the \
masses above it. The reader is invited to vary the parameters in this \
problem, to answer the following questions:\
\>", "Text"],

Cell[TextData[{
  "\tHow does the overall height of the rod depend on the combination ",
  Cell[BoxData[
      \(TraditionalForm\`m\ g/k\)]],
  "? How does it depend on ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "?  How does it depend on the number of masses ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "? (For this simple system, these questions can also be easily addressed \
analytically. Some examples in the exercises are given for which  the answers \
are not quite so obvious.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Equations and Under-Determined Systems", "Section",
  CellTags->"c:57"],

Cell[TextData[{
  "\tNote that the ",
  ButtonBox["equations (9.10.1)",
    ButtonData:>"(9.10.1)",
    ButtonStyle->"Hyperlink"],
  " are linear, and so can be written as a matrix equation "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", \((x, y, z)\)}], 
          "=", \(\((0, 4, 2 - 3)\) = \((0, 4, \(-1\))\)\)}], 
        TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "1", "1"},
                {"0", "2", "1"},
                {"0", "0", "1"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], 
        TraditionalForm]]],
  ".This matrix has a nonzero determinant, and therefore a unique solution \
can be found by the matrix inversion technique discussed in ",
  ButtonBox["Sec. 9.5",
    ButtonData:>"Sec. 9.5",
    ButtonStyle->"Hyperlink"],
  ". Consider, however, the case of a matrix with zero determinant, such as \
the matrix ",
  StyleBox["g ",
    FontWeight->"Bold"],
  " that appeared in ",
  ButtonBox["Eq. (9.5.10)",
    ButtonData:>"(9.5.10)",
    ButtonStyle->"Hyperlink"],
  ".Matrix inversion does not work for such a matrix, because when the \
determinant of ",
  StyleBox["g",
    FontWeight->"Bold"],
  " is zero, a solution need not exist, and if it exists it will not be \
unique. Nevertheless, one can apply ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the system to find the solution(s), if any:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g = {{1, 2, 3}, {2, 4, 6}, {3, 6, 9}};\)\), "\n", 
    \(Solve[g . {x, y, z} == {1, 1, 1}, {x, y, z}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.161"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In this case, no solution exists because the three equations are \
self-contradictory.  However, for other equations involving ",
  StyleBox["g",
    FontWeight->"Bold"],
  " there can be an infinite number of solutions (the system is",
  StyleBox[" under-determined",
    FontSlant->"Italic"],
  "):"
}], "Text",
  CellTags->"i:85"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[g . {x, y, z} \[Equal] {1, 2, 3}, {x, y, z}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.162"],

Cell[BoxData[
    \(Solve::"svars" \(\(:\)\(\ \)\) 
      "Equations may not give solutions for all \"solve\" variables."\)], \
"Message"],

Cell[BoxData[
    \({{x \[Rule] 1 - 2\ y - 3\ z}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now  the three equations for",
  StyleBox[" x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ",",
  " and ",
  StyleBox["z ",
    FontSlant->"Italic"],
  "are identical and so there are more unknowns than there are independent \
equations,  leading to a range of possible values for ",
  StyleBox["x, y, ",
    FontSlant->"Italic"],
  " and ",
  StyleBox["z",
    FontSlant->"Italic"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Nonlinear Equations", "Section",
  CellTags->"c:58"],

Cell[TextData[{
  "\tThere are many ",
  StyleBox["nonlinear ",
    FontSlant->"Italic"],
  "equations with perfectly good solutions that can't be found analytically \
using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or numerically using ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only work on certain simple types of equations like polynomial equations \
or linear equations. An example where both ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " fail is the equation"
}], "Text",
  CellTags->"i:110"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`cos\ x = \ \(\(\[ExponentialE]\^x\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "If we try to solve this equation using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we get an error:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[Cos[x]\  \[Equal] \ Exp[x], x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.163"],

Cell[BoxData[
    \(Solve::"tdep" \(\(:\)\(\ \)\) 
      "The equations appear to involve the variables to be solved for in an \
essentially non-algebraic way."\)], "Message"],

Cell[BoxData[
    \(Solve[Cos[x] == \[ExponentialE]\^x, x]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[Cos[x]\  \[Equal] \ Exp[x], x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.164"],

Cell[BoxData[
    \(Solve::"tdep" \(\(:\)\(\ \)\) 
      "The equations appear to involve the variables to be solved for in an \
essentially non-algebraic way."\)], "Message"],

Cell[BoxData[
    \(NSolve[Cos[x] == \[ExponentialE]\^x, x]\)], "Output"]
}, Open  ]],

Cell["\<\
In the next section, we will consider numerical methods for solving \
general nonlinear equations. \
\>", "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          
          StyleBox[\(Table\ 9.20\ \ Three\ different\ Types\ \ of\ \
Equations\),
            FontSize->9]},
        {GridBox[{
              {
                StyleBox[\(x = y\),
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["Immediately",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["evaluate",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["y",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["and",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["assign",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["result",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["to",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}]},
              {
                StyleBox[\(x := y\),
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["Evaluate",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["and",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["assign",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["y",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["to",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["  ",
                    FontFamily->"Times"], 
                  StyleBox["only",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["after",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["  ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["is",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["evaluated",
                    FontFamily->"Times"]}]},
              {
                StyleBox[\(x == y\),
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["Test",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["whether",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["x",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["and",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["y",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontFamily->"Times",
                    FontSlant->"Italic"], 
                  StyleBox["are",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["equal",
                    FontFamily->"Times"]}]}
              },
            ColumnSpacings->1.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:109"],

Cell[TextData[StyleBox["",
  FontSize->9]], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table  9  .21\ Solving\ Equations\ for\ All\ Roots, \ 
              Analytically\ and\ Numerically\),
              FontSize->9], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  StyleBox[\(Solve[lhs == rhs, x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{\(Solve\ an\ equation\), ",", 
                    RowBox[{
                    "giving", " ", "a", " ", "list", " ", "of", " ", 
                      "replacements", " ", "for", " ", 
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontSlant->"Italic"]}]}]},
                {
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["/.",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox["solution",
                      FontSlant->"Italic"]}], 
                  RowBox[{
                  "Use", " ", "the", " ", "list", " ", "of", " ", 
                    "replacements", " ", "to", " ", "get", " ", "values", " ",
                     "for", " ", 
                    StyleBox["x",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}]},
                {
                  RowBox[{"\[IndentingNewLine]", 
                    RowBox[{
                      StyleBox[\(NSolve[lhs == rhs, x]\),
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "\[IndentingNewLine]", "or", 
                      "\n", 
                      StyleBox[\(N[Solve[lhs == rhs, x]]\),
                        FontFamily->"Courier",
                        
                        FontWeight->
                          "Bold"]}]}], \(\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(Solve\ certain\ simple\ types\ of\ equations\ \
numerically\)\)}
                },
              ColumnSpacings->1.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.10", "Subsubtitle",
  CellTags->{"Ex. 9.10", "c:59"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Figure ",
  ButtonBox["9.4",
    ButtonData:>"Fig. 9.4",
    ButtonStyle->"Hyperlink"],
  " shows several masses suspended in equilibrium from a mobile, with the \
length ratios of the crossbars shown. Assuming that the crossbars and strings \
have negligible mass, that mass 1 is 2 kg, and mass 6 is 1 kg,  find the \
values for the unknown masses ",
  Cell[BoxData[
      \(TraditionalForm\`m\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`m\_3\)]],
  ",\[Ellipsis]",
  Cell[BoxData[
      \(TraditionalForm\`m\_5\)]],
  ". (Hint: Recall that in equilibrium the torques from each weight must \
balance: torque = perpendicular force \[Times] lever arm length.) Use a \
pencil and paper to set up this problem. Don't try to do everything at the \
keyboard!"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?O0001WB000`400?l00000o`00003ooooooooo
ooooooooooooh_ooool00?ooooooooooooooooooon;ooooo003ooooooooooooooooooooRooooo`00
ooooooooooooooooooooh_ooool00?ooooooooooooooooooon;ooooo003ooooooooooooooooooooR
ooooo`00ooooooooooooooooooooh_ooool00?ooooooooooooooooooon;ooooo003ooooooooooooo
oooooooRooooo`00ooooooooooooooooooooh_ooool00?ooooooooooooooooooon;ooooo000Hoooo
ool0ooooo`3ooooo0?oook00oooo6_ooool001Soooooo`3ooooo0?ooool0oooo/03ooolJooooo`00
6?oooooo0?ooool0ooooo`3ooon`0?oooa[ooooo000Hooooool0ooooo`3ooooo0?oook00oooo6_oo
ool001Sooooo[P3oool90820P?l0ooooo`3ooooh0?oooa[ooooo000Hoooooj/0oooo00<0P8200410
@00000002P0000000`10@400P8200?ooo`3o0?ooool0oooom03ooolJooooo`006?oooonX0?ooo`03
0820P010@40000000100000000<0@4100<30`03oool0o`3ooomR0?ooo`030<30`020P800P82000L0
P820o`3ooon50?oooa[ooooo000HooooojH0oooo00<0P820000000000000500000000`10@400`<30
0?ooo`3o0?oooe`0oooo0P20P8000`10@40000000000000;000000030410@020P800`<300?l0oooo
P03ooolJooooo`006?oooonT0?ooo`030<30`0000000000001P0000000<0@4100<30`03oool0o`3o
oomI0?ooo`030820P000000000000100000000<0@4100<30`03oool0o`3ooomn0?oooa[ooooo000H
oooooj<0oooo00<0`<300000000000006`0000000`20P800oooo0?ooo`3o0?oooeD0oooo00<0P820
000000000000500000000`10@400`<300?ooo`3o0?ooog`0oooo6_ooool001SoooooXP3oool00`10
@40000000000000M000000030410@03oool0oooo0?l0ooooDP3oool00`30`<0000000000000H0000
00030410@030`<00oooo0?l0ooooNP3ooolJooooo`006?oooonQ0?ooo`030410@0000000000001l0
000000<0@4100?ooo`3oool0o`3ooom@0?ooo`030<30`0000000000001/0000000<0`<300?ooo`3o
ool0>03oool2000000030820P03oool0oooo0?l0oooo>`3ooolJooooo`006?oooonP0?ooo`030820
P000000000000240000000<0@4100?ooo`3oool0:P3oool50820P?l0oooo7`3oool00`10@4000000
0000000M000000030<30`03oool0oooo03L0oooo0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo
6_ooool001SoooooW`3oool00`30`<0000000000000S000000030<30`03oool0oooo02H0oooo00<0
`<300410@00000001P0000000`20P800oooo0?ooo`3o0?oooaT0oooo00<0`<300410@00000008000
00000`20P800oooo0?ooo`0f0?ooo`80000000<0P8200?ooo`3oool0o`3ooolk0?oooa[ooooo000H
oooooih0oooo00<0ZZZZ0000000000009@0000000`2ZZZX0oooo0?ooo`0T0?ooo`050:ZZZP000000
000002/[:`20P8000`2ZZZX01@20P800:b/[0000000[:b/0eMGE0?l0oooo603oool00`3EeMD0:b/[
0000000R0000000302/[:`3oool0oooo03D0oooo0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo
6_ooool001SoooooWP3ooolY000002H0oooo0P0000000`10@400oooo0?ooo`050?ooo`030820P000
000000000?l0oooo603oool00`10@40000000000000S000000030410@03oool0oooo03@0oooo0P00
00000`20P800oooo0?ooo`3o0?oooc/0oooo6_ooool001SoooooW@3oool00`20P80000000000000W
000000030820P03oool0oooo02<0oooo0P20P8000`30`<00oooo0?ooo`060?ooo`80000000<0P820
0?ooo`3oool0o`3ooolD0?ooo`030410@0000000000002D0000000<0@4100?ooo`3oool0<`3oool2
000000030820P03oool0oooo0?l0oooo>`3ooolJooooo`006?oooonL0?ooo`030<30`00000000000
02T00000<03oool00`20P80000000000003o0?oooaD0oooo00<0P8200000000000009`0000000`30
`<00oooo0?ooo`0W0?ooo`030<30`020P800P82000P0P8200P0000001010@400P8200820P020P83o
0?ooocX0oooo6_ooool001SoooooW03oool00`10@40000000000000Y000000030820P03oool0oooo
02d0oooo00<0P820000000000000o`3ooolE0?ooobX0000000<0@4100?ooo`3oool03P3oool00`30
`<00P8200820P0070?ooo`80P82000<0`<300?ooo`3oool0103oool20820P0050<30`03oool0oooo
0?ooo`20P8004000003o0?ooocX0oooo6_ooool001SoooooV`3oool00`30`<0000000000000Z0000
00030410@03oool0oooo02d0oooo00<0P820000000000000o`3ooolD0?ooo`030820P00000000000
02T0000000<0`<300?ooo`3oool03@3oool00`30`<000000000000070?ooo`030410@0000000P820
00H0oooo0P0000001@10@400oooo0?ooo`3oool0P820008000002020P802000000040410@020P800
P8200820P?l0oooo>P3ooolJooooo`006?oooonK0?ooo`030820P0000000000002/000002P3oool2
0820P0030<30`03oool0oooo00@0oooo00<0`<300820P020P8001P3oool00`30`<00P8200820P00@
0?ooo`80000000<0@4100?ooo`3oool0o`3ooolB0?ooob`0000000<0P8200?ooo`3oool03P3oool2
000000030820P03oool0oooo00@0oooo00<0P8200000000000001P3oool00`20P800000000000004
0?ooo`030410@0000000@41000L0oooo0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo6_ooool0
01SoooooV`3oool^000000030:ZZZP3oool0oooo00L0oooo00<0@41000000020P8001P3oool00`30
`<000000000000060?ooo`040820P000000000000<30`0h0oooo00@0@410000000000000P820o`3o
oolC0?ooo`030<30`0000000000002X0000000<0@4100?ooo`3oool03P3oool2000000030820P03o
ool0oooo00@0oooo00<0P8200000000000001P3oool00`20P8000000000000050?ooo`030410@000
0000P82000H0oooo0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo6_ooool001SoooooVP3oool0
0`30`<0000000000000/000000030820P03oool0oooo00L0oooo00<0P8200000000000001`3oool2
000000030820P03oool0oooo00@0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`050<30`010@400
000000000010@400o`3ooolD0?ooo`030820P0000000000002/00000403oool00`20P80000000410
@0070?ooo`80000000<0`<300?ooo`3oool00`3oool01030`<00000000000020P8040?ooo`040<30
`000000000000<30`0D0oooo0P0000000`20P800oooo0?ooo`3o0?oooc/0oooo6_ooool001Sooooo
VP3oool00`20P80000000000000/0000000305EEE@3oool0oooo00L0oooo00<0P820000000000000
1`3oool2000000030820P03oool0oooo00@0oooo0P0000000`20P800oooo0?ooo`050?ooo`@0P820
100000000`10@400oooo0?ooo`3o0?oooa<0oooo;P0000000`20P800oooo0?ooo`0=0?ooo`030820
P0000000000000L0oooo0P0000000`20P800oooo0?ooo`040?ooo`80000000<0P8200?ooo`3oool0
0`3oool01030`<00000000000030`<040?ooo`80000000<0P8200?ooo`3oool0o`3ooolk0?oooa[o
oooo000HoooooiX0oooo00<0P820000000000000;00000000`1EEED0oooo0?ooo`080?ooo`800000
00<0`<300?ooo`3oool0103oool00`20P80000000410@0060?ooo`030410@0000000000000L0oooo
1P0000000`20P800`<300?ooo`3o0?oooa@0oooo00<0eMGE000000000000;00000000`10@400oooo
0?ooo`0=0?ooo`030<30`0000000000000L0oooo00<0@41000000020P8001P3oool2000000030410
@03oool0oooo00@0oooo00<0P820000000000000103oool2000000030820P03oool0oooo0?l0oooo
>`3ooolJooooo`006?oooonJ0?ooo`030820P0000000000002`0000000<0:b/[0?ooo`3oool0203o
ool2000000030820P03oool0oooo00@0oooo00<0P8200000000000001P3oool00`20P80000000000
00070?ooo`@0P8200`0000000`10@400`<300?ooo`3o0?oooa<0oooo00<0ZZZZ000000000000;@00
000@0?ooo`80000000<0P8200?ooo`3oool0103oool00`20P8000000000000060?ooo`030820P000
0000000000L0oooo00<0@41000000010@4000`3oool2000000030820P03oool0oooo0?l0oooo>`3o
oolJooooo`006?oooonJ0?oooc0000002P3oool00`10@40000000820P0060?ooo`030<30`0000000
000000H0oooo00@0P820000000000000`<302`3oool01@30`<00@410000000000000`<300?l0oooo
4`3oool00`2ZZZX000000000000]00000100oooo0P0000000`20P800oooo0?ooo`040?ooo`030820
P0000000000000H0oooo00<0P820000000000000203oool00`10@40000000410@0020?ooo`800000
00<0P8200?ooo`3oool0o`3ooolk0?oooa[ooooo000HoooooiX0oooo<000000:0?ooo`030820P000
0000000000L0oooo0P0000000`20P800oooo0?ooo`040?ooo`80000000<0P8200?ooo`3oool02`3o
ool00`10@40000000410@03o0?oooa<0oooo00<0ZZZZ000000000000;@0000000`30`<00oooo0?oo
o`0=0?ooo`030820P0000000000000L0oooo0P0000000`20P800oooo0?ooo`030?ooo`040<30`000
000000000820P0P0oooo0P0000001@30`<00oooo000000000000P8200?l0oooo?@3ooolJooooo`00
6?oooonJ0?oooc0000002P3oool00`20P8000000000000070?ooo`80000000<0P8200?ooo`3oool0
103oool2000000030820P03oool0oooo00/0oooo00@0`<30000000000000`<30o`3ooolB0?ooo`03
05EEE@000000000002d0000000<0P8200?ooo`3oool03@3oool00`20P8000000000000070?ooo`80
000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00H0oooo00@0`<3000000000
0000`<300P0000000`20P800oooo0?ooo`3o0?oooc/0oooo6_ooool001SoooooVP3oool`000000/0
oooo0P0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000H0oooo00<0@41000000000
00003P3oool2000000030820P03oool0oooo0?l0oooo403oool00`1EEED000000000000]00000003
0820P03oool0oooo00d0oooo00@0`<30000000000000P8201P3oool3000000H0oooo0P0000000`20
P800oooo0?ooo`070?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0o`3ooolk0?oo
oa[ooooo000HoooooiX0oooo00<0@410000000000000;@00000;0?ooo`80000000<0P8200?ooo`3o
ool0103oool00`20P8000000000000060?ooo`030820P0000000000000<0oooo0P20P8000`30`<00
oooo0?ooo`060?ooo`80000000<0P8200?ooo`3oool0o`3oool@0?ooo`0305EEE@000000000002d0
000000<0P8200?ooo`3oool03P3oool3000000030<30`03oool0oooo00<0oooo00@0P82000000000
0000@4101@3oool00`20P80000000000000:0?ooo`050410@0000000000000000020P800o`3ooolm
0?oooa[ooooo000HoooooiX0oooo00<0P820000000000000;00000000`1EEED0oooo0?ooo`090?oo
o`030410@0000000000000H0oooo00@0P820000000000000P8201@3oool00`20P800000000000003
0?ooo`80000000<0@4100?ooo`3oool01@3oool01020P800000000000030`<3o0?oooa80oooo00<0
EEEE000000000000;@0000000`20P800oooo0?ooo`0>0?ooo`@0000000<0`<300?ooo`3oool00P3o
ool01@10@4000000000000000000@41000@0oooo00<0@4100000000000002`3oool01010@4000000
00000020P83o0?ooocd0oooo6_ooool001SoooooVP3oool00`20P80000000000000/0000000305EE
E@3oool0oooo00T0oooo00@0P820000000000000@4101P3oool3000000030<30`03oool0oooo00<0
oooo0P0000001020P800oooo0?ooo`20P802000000030410@030`<00oooo0080oooo00D0`<300410
@000000000000410@03o0?oooa<0oooo00<0P820000000000000;@0000000`20P800oooo0?ooo`0>
0?ooo`060820P000000000000410@0000000P8200P3oool02P20P8000000000000000000`<300000
0010@400eMGE0?ooo`30`<02000000030410@03oool0oooo00X0oooo0P20P8000`30`<00oooo0?oo
o`3o0?oooc/0oooo6_ooool001SoooooVP3oool00`20P80000000000000/0000000305EEE@3oool0
oooo00T0oooo00D0P82000000000000000000410@0040?ooo`030<30`000000000000080000000D0
`<300?ooo`3oool0oooo0<30`002000000050820P03oool0oooo0?ooo`10@4002@0000000`10@400
oooo0?ooo`3o0?oooa80oooo00<0ZZZZ000000000000;@00000A0?ooo`050820P000000000000?oo
o`10@4001P0000000`10@400oooo0<30`006000000030<30`03oool0oooo0?l0ooooBP3ooolJoooo
o`006?oooonK0?ooobh0000000<0ZZZZ0?ooo`3oool02P3oool2000000070410@0000000@4100<30
`03oool0`<300410@002000000040820P010@40000000:ZZZP80oooo00@0@410000000000000`<30
103oool00`30`<00P8200000000400000080P820o`3ooolE0?ooo`030:ZZZP000000000002d00000
4@3oool00`30`<00P8200820P0020?ooo`030820P010@40000000080000000<0P8200?ooo`3oool0
0P3oool01@1EEED0000000000010@400`<300?l0ooooC@3ooolJooooo`006?oooonK0?ooo`030820
P0000000000002/0000000<0eMGE0?ooo`3oool02P3oool2000000030820P030`<00000000H00000
00<0`<300?ooo`10@4001@0000000`10@400oooo0?ooo`3o0?ooob40oooo00<0ZZZZ000000000000
;@00003o0?ooog80oooo6_ooool001SoooooV`3oool00`30`<0000000000000Z000000030410@03o
ool0oooo00/0oooo0P20P8001030`<00oooo0<30`020P803000000030410@030`<00oooo0080oooo
00D0ZZZZ00000000000000000820P03o0?ooobD0oooo;P0000000`20P800oooo0?ooo`3o0?ooog00
oooo6_ooool001SoooooW03oool/000000030820P03oool0oooo0?l0oooo@`3oool00`20P8000000
0000000[000000030<30`03oool0oooo0?l0ooooL03ooolJooooo`006?oooonL0?ooo`030820P000
0000000002T0000000<0`<300?ooo`3oool0o`3ooom30?ooo`030<30`0000000000002X0000000<0
@4100?ooo`3oool0o`3oooma0?oooa[ooooo000Hoooooid0oooo00<0@4100000000000009`000000
0`10@400oooo0?ooo`3o0?ooodD0oooo;00000000`20P800oooo0?ooo`3o0?ooog40oooo6_ooool0
01SoooooW@3oool00`30`<0000000000000W000000030<30`03oool0oooo0?l0ooooA@3oool00`20
P80000000000000Y000000030<30`03oool0oooo0?l0ooooL@3ooolJooooo`006?oooonN0?ooo`03
0410@0000000000002D0000000<0@4100?ooo`3oool0o`3ooom70?ooobX0000000<0@4100?ooo`3o
ool0o`3ooomb0?oooa[ooooo000Hoooooil0oooo00<0P8200000000000008`0000000`1EEED0oooo
0?ooo`3o0?ooodP0oooo00<0ZZZZ0000000000009`0000000`3EeMD0oooo0?ooo`3o0?ooog80oooo
6_ooool001SoooooX03oool00`10@40000000000000Q000000030410@03oool0oooo0?l0ooooBP3o
ool00`20P80000000000000U000000030<30`03oool0oooo0?l0ooooL`3ooolJooooo`006?oooonQ
0?ooo`030410@0000000000001l0000000<0@4100?ooo`3oool0o`3ooom<0?ooo`030410@0000000
000002<0000000<0P8200?ooo`3oool0o`3ooomd0?oooa[ooooo000Hoooooj80oooo00<0@4100000
000000007@0000000`10@400oooo0?ooo`3o0?ooodh0oooo00<0@4100000000000008@0000000`10
@400oooo0?ooo`3o0?ooogD0oooo6_ooool001SoooooX`3oool00`30`<0000000000000K00000003
0820P03oool0oooo0?l0ooooC`3oool00`30`<0000000000000P000000030410@03oool0oooo0?l0
ooooMP3ooolJooooo`006?oooonT0?ooo`030<30`0000000000001T0000000<0`<300?ooo`3oool0
o`3ooomB0?ooo`030410@0000000000001d0000000<0`<300?ooo`3oool0o`3ooomg0?oooa[ooooo
000HooooojH0oooo00<0@4100000000000005@0000000`20P800oooo0?ooo`3o0?oooeD0oooo00<0
`<300000000000006`0000000`30`<00oooo0?ooo`3o0?ooogP0oooo6_ooool001SoooooY`3oool0
0`30`<0000000000000B000000030410@03oool0oooo0?l0ooooF03oool00`30`<0000000000000I
000000030<30`03oool0oooo0?l0ooooN@3ooolJooooo`006?oooonY0?ooo`80P8203`0000000`20
P800`<300?ooo`3o0?oooe`0oooo00<0@4100000000000005@0000000`20P800oooo0?ooo`3o0?oo
og/0oooo6_ooool001Sooooo[03oool00`20P800@41000000008000000030820P030`<00oooo0?l0
ooooH03oool00`30`<0000000000000B000000030410@03oool0oooo0?l0ooooO@3ooolJooooo`00
6?oooonb0?ooo`030<30`000000000000?l0ooooI`3oool20820P0030410@0000000000000/00000
00<0@4100820P030`<00o`3ooon00?oooa[ooooo000Hoooook<0oooo0P00003o0?ooof/0oooo00<0
P8200000000000001`00003o0?ooohD0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool0
0`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20
P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P800
00000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P8000000
0820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820
P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o
0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?oo
ohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0
oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo
6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_oo
ool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool0
01Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001So
oooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo
/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3o
ool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool2
00000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool20000
0?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0
ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0oooo
K`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3o
ool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool0
0`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20
P80000000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P800
00000820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P8000000
0820P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820
P03o0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o
0?ooohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?oo
ohP0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0
oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo
6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_oo
ool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool0
01Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001So
oooo/`3oool200000?l0ooooK`3oool00`20P80000000820P03o0?ooohP0oooo6_ooool001Sooooo
/`3oool200000?l0ooooK`3oool00`20P80000000820P02;0?ooo`80P8202@0000001010@400P820
0820P030`<3=0?ooo`030<30`020P800@41000T0000000<0@4100820P020P8004@3ooolJooooo`00
6?oooonc0?ooo`800000o`3ooom_0?ooo`030820P0000000P82008P0oooo00<0P820000000000000
400000000`20P800oooo0?ooo`370?oooa<000003`3ooolJooooo`006?oooonc0?ooo`800000o`3o
oom_0?ooo`030820P0000000P82008L0oooo00<0EEEE0000000000004P0000000`10@400`<300?oo
o`340?ooo`030820P0000000000001<0000000<0ZZZZ0?ooo`3oool02`3ooolJooooo`006?oooonc
0?ooo`800000o`3ooom_0?ooo`030820P0000000P82008D0oooo00<0P8200000000000005P000000
0`10@400`<300?ooo`300?ooo`030820P0000000000001H0000000<0@4100<30`03oool02P3ooolJ
ooooo`006?oooonc0?ooo`800000o`3ooom_0?ooo`030820P0000000P82008<0oooo00<0`<300000
000000006P0000000`30`<00oooo0?ooo`2m0?ooo`030410@0000000000001T0000000<0`<300?oo
o`3oool0203ooolJooooo`006?oooonc0?ooo`800000o`3ooom_0?ooo`030820P0000000P8200880
oooo00<0P820000000000000700000000`10@400oooo0?ooo`2j0?ooo`030=GEe@10@400000001`0
000000<0@4100?ooo`3oool01`3ooolJooooo`006?oooonc0?ooo`800000o`3ooom_0?ooo`030820
P0000000P8200840oooo00<0@4100000000000007P0000000`20P800oooo0?ooo`2i0?ooo`0302/[
:`000000000001d0000000<0@4100?ooo`3oool01P3ooolJooooo`006?oooonc0?ooo`800000o`3o
oom_0?ooo`030820P0000000P8200800oooo00<0@410000000000000800000000`20P800oooo0?oo
o`2g0?ooob<000001`3ooolJooooo`006?oooonc0?ooo`800000o`3ooom_0?ooo`030820P0000000
P82006@0oooo00<0`<300820P00000000`0000000`10@400P8200?ooo`0B0?ooo`030<30`0000000
00000280000000<0`<300?ooo`3oool0]@3oool00`10@40000000000000Q000000030410@03oool0
oooo00@0oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P01S0?oo
o`030820P0000000000000H0000000<0EEEE0?ooo`3oool03`3oool00`30`<0000000000000T0000
0;H0oooo00<0`<300000000000008`0000000`20P800oooo0?ooo`030?oooa[ooooo000Hoooook<0
oooo0P00003o0?ooofl0oooo00<0P82000000020P800HP3oool01@30`<00000000000010@400`<30
00<0oooo00@0P820000000000000P820403ooolW000000030820P03oool0oooo09L0oooo00<0P820
0410@00000000P0000000`10@400P8200?ooo`0C0?ooo`030<30`0000000000002D0000000<0`<30
0?ooo`3oool00P3ooolJooooo`006?oooonc0?ooo`800000o`3ooom_0?ooo`030820P0000000P820
0680oooo0P0000000`1EEED0oooo0?ooo`040?ooo`040=GEe@0L71`000000=GEe@h0oooo00<0P820
0000000000009P0000000`3EeMD0oooo0?ooo`2D0?ooo`040820P00000000000000000<0EEEE00D0
:b/[000000000000EEEE0=GEe@0@0?ooo`030=GEe@0[:b/0000002L0000000@0eMGE0?ooo`3oool0
oooo6_ooool001Sooooo/`3oool200000?l0ooooK`3oool00`20P80000000820P01/0?ooo`0305EE
E@000000@41000d0oooo00<0`<30000000000000:00000000`30`<00oooo0?ooo`2B0?ooo`040410
@000000000000<30`0D0oooo00@0`<30000000000000@410403oool00`10@40000000000000W0000
00040410@03oool0oooo0?oooa[ooooo000Hoooook<0oooo0P00003o0?ooofl0oooo00<0P8200000
0020P800K03oool00`2ZZZX000000000000=0?ooo`030410@0000000000002P0000000<0@4100?oo
o`3oool0TP3oool2000000030820P03oool0oooo00D0oooo00@0`<30000000000000P8203P3oool0
0`30`<0000000000000Y000000030<30`03oool0oooo01[ooooo000Hoooook<0oooo0P00003o0?oo
ofl0oooo00<0P82000000020P800K03oool00`2ZZZX000000000000=0?ooob`00000W`3oool00`10
@40000000820P00>0?ooo`030820P0000000000002T0000000<0P8200?ooo`3oool06_ooool001So
oooo/`3oool200000?l0ooooK`3oool00`20P80000000820P01/0?ooo`030:ZZZP000000000000`0
oooo00<0P820000000000000:P0000000`20P800oooo0?ooo`2L0?ooo`030820P0000000000000h0
oooo;@0000020?oooa[ooooo000Hoooook<0oooo0P00003o0?ooofl0oooo00<0P82000000020P800
A`3oool00`20P8000000000000070?ooo`8000001`3oool2000000030820P03oool0oooo00d0oooo
00<0EEEE000000000000303oool00`10@40000000000000Z000000030410@03oool0oooo06`0oooo
0P0000000`20P800oooo0?ooo`0A0?ooo`80000000<0P8200?ooo`3oool0103oool01010@4000000
00000030`<050?ooo`030<30`020P80000000080000000@0P8200?ooo`3oool0P8200P00000=0?oo
o`030<30`0000000000002/0000000<0`<300?ooooooool06Oooool001Sooooo/`3oool200000?l0
ooooK`3oool00`20P80000000820P0180?ooo`80000000<0`<300?ooo`3oool0103oool00`1EEED0
00000<30`0060?ooo`030410@0000000000000l0oooo0P0000000`20P800oooo0?ooo`0:0?ooobh0
0000KP3oool2000000030820P03oool0oooo0140oooo0P0000000`20P800oooo0?ooo`030?ooo`04
0410@000000000000410@0D0oooo00<0`<300000000000001@0000001030`<00P82000000000000=
0?ooo`030820P0000000000002/0000000<0P8200?ooooooool06Oooool001Sooooo/`3oool20000
0?l0ooooK`3oool00`20P80000000820P0180?ooo`80000000<0P8200?ooo`3oool0103oool00`1E
EED000000820P0060?ooo`030820P0000000000000d0oooo00@0`<300410@00000000000303oool0
0`20P80000000000000/000000030820P03oool0oooo06/0oooo0P0000000`20P800oooo0?ooo`0A
0?ooo`80000000<0P8200?ooo`3oool00P3oool01030`<00000000000010@4050?ooo`050<30`000
000000000410@020P8000P3oool01020P800000000000020P802000000d0oooo;`0000000`3ooooo
ooooooooo`0Hooooo`006?oooonc0?ooool00000L`0000000`20P800oooo0?ooo`160?ooo`030410
@0000000P82000H0oooo00<0P82000000020P8001P3oool01020P800000000000030`<050?ooo`03
0<30`020P800P8200080P82000<0@4100000000000000P0000000`30`<00oooo0?ooo`0:0?ooo`03
0820P0000000000002`0000000<0P8200?ooo`3oool0J`3oool2000000030820P03oool0oooo0140
oooo0P0000001@20P800oooo0?ooo`3oool0`<300080000000<0@4100?ooo`3oool0103oool20000
00030410@03oool0oooo00<0oooo00<0`<300000000000000P00000=0?ooobl0000000<0oooooooo
ooooool06?ooool001Sooooo/`3ooooo000007<0000000<0P8200?ooo`3oool0AP3oool00`20P800
0000000000060?ooo`030:ZZZP000000000000L0oooo0P0000000`20P800oooo0?ooo`030?ooo`03
0820P0000000000000D0000000<0@4100=GEe@3oool0303oool00`20P80000000000000/00000003
0820P03oool0oooo06/0oooo0P0000000`20P800oooo0?ooo`0A0?ooo`80000000@0P8200?ooo`3o
ool0`<300`0000060?ooo`040820P000000000000<30`0H0oooo00@0P82000000000000000003@3o
ool_000000030?oooooooooooooo01Sooooo000Hoooook<0ooooo`00001c000000030820P03oool0
oooo04H0oooo00<0P8200000000000001P3oool00`2ZZZX00000000000070?ooo`80000000<0P820
0?ooo`3oool00`3oool00`20P8000000000000040820P100oooo00<0@410000000000000;@00001]
0?ooo`80000000<0P8200?ooo`3oool04@3oool2000000030820P03oool0oooo00<0000000<0`<30
0?ooo`3oool0103oool00`10@4000000000000080?ooo`<00000303oool00`30`<0000000000000]
000000030820P?oooooooooo01Sooooo000Hoooook<0ooooo`00001c000000030820P03oool0oooo
04L0oooo0P0000000`30`<00oooo0?ooo`040?ooo`80000000<0`<300?ooo`3oool0103oool00`10
@4000000000000050?ooo`030820P0000000000001@0oooo<000001]0?ooo`80000000<0P8200?oo
o`3oool04@3oool2000000030820P03oool0@4100080000000<0`<300?ooo`3oool01@3oool20000
00030820P03oool0oooo00H0oooo00<0@410000000000000303oool00`20P80000000000000]0000
00030820P?oooooooooo01Sooooo000Hoooook<0ooooo`00001c000000030820P03oool0oooo04L0
oooo0P0000000`20P800oooo0?ooo`040?ooo`80000000<0P8200?ooo`3oool0103oool00`20P800
0000000000050?ooo`030820P0000000000001@0oooo<000001]0?ooo`80000000<0P8200?ooo`3o
ool04@3oool2000000050820P010@400000000000030`<00203oool2000000030820P03oool0oooo
00H0oooo00<0P820000000000000303oool00`20P80000000000000]000000030820P?oooooooooo
01Sooooo000Hoooook<0ooooo`00001c000000030820P03oool0oooo04L0oooo00<0@41000000010
@4001P3oool00`10@40000000410@0060?ooo`040820P000000000000<30`0@0oooo00<0P8200000
00000000503oool`000006d0oooo0P0000000`20P800oooo0?ooo`0A0?ooo`80000000@0@4100000
00000000@4102@3oool2000000030820P03oool0oooo00H0oooo00<0P820000000000000303oool0
0`20P80000000000000]000000030820P?oooooooooo01Sooooo000Hoooook<0ooooo`00001c0000
00030820P03oool0oooo04L0oooo00<0P8200000000000001P3oool00`20P8000000000000070?oo
o`80000000<0P8200?ooo`3oool00P3oool00`20P80000000000000D0?oooc000000K@3oool20000
00030820P03oool0oooo0140oooo0P0000001@20P800`<30000000000000`<3000P0oooo0P000000
0`20P800oooo0?ooo`060?ooo`030820P0000000000000`0oooo00<0P820000000000000;@000000
0`20P83oooooooooo`0Hooooo`006?oooonc0?ooool00000L`0000000`20P800oooo0?ooo`170?oo
o`040820P000000000000<30`0D0oooo00@0P820000000000000`<301P3oool2000000030820P03o
ool0oooo0080oooo00<0P820000000000000503oool00`20P80000000000000/000000030410@03o
ool0oooo06/0oooo0P0000000`20P800oooo0?ooo`0A0?ooo`80000000<0P8200?ooo`30`<000P00
00000`30`<00oooo0?ooo`050?ooo`030410@0000000@41000P0oooo00<0@4100000000000003@3o
ool_000000030<30`?oooooooooo01Sooooo000Hoooook<0ooooo`00001c000000030820P03oool0
oooo04P0oooo0P0000000`10@400oooo0?ooo`030?ooo`040<30`000000000000410@0H0oooo00<0
@41000000010@400103oool00`20P80000000000000D0?ooo`030820P0000000000002`0000000<0
P8200?ooo`3oool0J`3oool2000000030820P03oool0oooo0140oooo0P0000001020P800oooo0?oo
o`10@402000000030<30`03oool0oooo00@0oooo00<0P820000000000000203oool3000000d0oooo
;`0000000`3oooooooooooooo`0Hooooo`006?oooonc0?ooool00000L`0000000`20P800oooo0?oo
o`180?ooo`<0000000<0@4100?ooo`3oool00`3oool3000000030410@03oool0oooo00<0oooo00<0
P820000000000000103oool00`20P800000000000008000000030820P03oool0oooo00T0oooo00<0
P820000000000000;00000000`20P800oooo0?ooo`1[0?ooo`80000000<0P8200?ooo`3oool04@3o
ool2000000070820P03oool0oooo0?ooo`10@40000000410@0060?ooo`040<30`000000000000410
@0H0oooo00@0@41000000000000000003@3oool_000000030?oooooooooooooo01Sooooo000Hoooo
ool0ooooB03oool200000?l0oooo:03oool01@10@4000000000000000000@41000<0oooo00H0P820
000000000000@41000000010@4040?ooo`<00000103oool00`20P800000000000008000000030820
P03oool0oooo00T0oooo00<0`<30000000000000;00000000`30`<00oooo0?ooo`1[0?ooo`800000
00<0P8200?ooo`3oool04@3oool2000000030820P03oool0oooo0080oooo00<0@41000000010@400
1P3oool01010@400000000000010@4040?ooo`030410@00000000000008000003@3oool00`10@400
00000000000[000000030410@03ooooooooo01Wooooo000Hooooool0ooooB03oool200000?l0oooo
:03oool01020P800000000000030`<02000000030820P01EEED000000080000000@0P8200<30`000
000000000P20P8001010@400000000000020P80L0?ooo`030410@0000000000002/00000KP3oool2
000000030820P03oool0oooo0140oooo0P0000000`20P800oooo0?ooo`030?ooo`030410@0000000
@41000H0oooo00@0@41000000000000000000P20P802000000040410@020P8000000000000d0oooo
00<0`<30000000000000:`0000000`20P800ooooooooo`0Iooooo`006?oooooo0?ooodP0oooo0P00
003o0?ooobP0oooo00D0P820000000000000oooo0<30`005000000050410@03oool0oooo0<30`010
@400100000000`10@400oooo0?ooo`0K0?ooo`030820P0000000000002X0000000<0P8200?ooo`3o
ool0K03oool2000000030820P03oool0oooo0140oooo0P0000000`20P800oooo0?ooo`040?ooo`03
0410@0000000@41000H0oooo00<0@4100000000000000`0000000`10@400oooo0820P002000000h0
oooo;@0000020?oooa[ooooo000Hooooool0ooooB03oool200000?l0oooo;P3oool01030`<00P820
0820P030`<050?ooo`040<30`020P800P8200<30`1l0oooo;000001_0?ooo`80000000<0P8200?oo
o`3oool04@3oool2000000030820P03oool0oooo00l0oooo0`20P80D0?ooo`030820P00000000000
02T0000000<0P8200?ooo`3oool06_ooool001Soooooo`3ooom80?ooo`800000o`3ooomJ0?ooo`03
0410@0000000000002P0000000<0@4100?ooo`3oool0J03oool20<30`0<0oooo0P0000000`20P800
oooo0?ooo`0A0?ooo`80000000<0P8200?ooo`3oool09P3oool00`30`<0000000000000Y00000003
0820P03oool0oooo01[ooooo000Hooooool0ooooB03oool200000?l0ooooFP3oool00`30`<000000
0000000X000000030<30`03oool0oooo06P0oooo00D0P820000000000000P8200?ooo`0200000003
0820P03oool0oooo0140oooo0P0000000`20P800oooo0?ooo`0W0?ooo`030410@0000000000002P0
00000`3ooolJooooo`006?oooooo0?ooodP0oooo0P00003o0?oooe/0oooo00<0@410000000000000
9P0000000`10@400oooo0?ooo`1Y0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool0
4@3oool2000000030820P03oool0oooo02L0oooo00<0`<300000000000009`0000001020P800oooo
0?ooo`3ooolJooooo`006?oooooo0?ooodP0oooo0P00003o0?oooe/0oooo00<0`<30000000000000
9P00001]0?ooo`030820P010@400000000<0000000<0P8200?ooo`3oool04@3oool2000000030820
P03oool0oooo02P0oooo00<0@4100000000000009P0000040?oooa[ooooo000HooooooL0oooo3P20
P8120?ooo`800000o`3ooomL0?ooo`030410@0000000000002@0000000<0`<300?ooo`3oool0K@3o
ool01@30`<00@410000000000000P82001<0oooo0P0000000`20P800oooo0?ooo`0X0?ooo`030<30
`010@400000002@0000000<0@4100<30`03oool00`3ooolJooooo`006?ooooog0?ooo`h00000@P3o
ool200000?l0ooooG@3oool00`10@40000000000000R000000030410@03oool0oooo08H0oooo0P00
00000`20P800oooo0?ooo`0Y0?ooo`030<30`0000000000002<0000000<0`<300?ooo`3oool00`3o
oolJooooo`006?ooooog0?ooo`80000000<0EEEE0:ZZZP2ZZZX02@2ZZZY20?ooo`800000G@3oool0
0`3EeMD0P82005EEE@050000000305EEE@2ZZZX0oooo0?@0oooo00<0eMGE02/[:`0000008@000000
0`0[:b/0oooo0?ooo`2f0?ooo`030=GEe@00000000000240000000<0ZZZZ0?ooo`3oool0103ooolJ
ooooo`006?ooooog0?ooo`80000000<0P8200?ooo`3oool0B`3oool2000005`0oooo00D0`<300000
0000000000000410@0030820P0040410@000000000000410@?H0oooo00<0@4100000000000007P00
00000`1EEED0oooo0?ooo`2h0?ooo`030<30`00[:b/0000001h0000000<0@4100<30`03oool01P3o
oolJooooo`006?ooooog0?ooo`030820P0000000000004d0oooo0P00001L0?ooo`040410@0000000
00000<30`0D0oooo00@0`<300410@0000000@410mP3oool00`20P80000000000000L000000030410
@03oool0oooo0;X0oooo00<0eMGE0410@0000000700000000`10@400oooo0?ooo`070?oooa[ooooo
000HooooooP0oooo0P0000000`20P800oooo0?ooo`1:0?ooo`800000G03oool2000000030820P03o
ool0oooo00D0oooo00@0`<30000000000000`<30mP3oool00`30`<0000000000000J000000030<30
`03oool0oooo0;d0oooo00<0@4100000000000006@0000000`30`<00oooo0?ooo`080?oooa[ooooo
000HooooooP0oooo00@0P820000000000000`<30B`3oool2000006L0oooo00<0@41000000010@400
m`3oool00`30`<00P8200000000H000000030<30`03oool0oooo0;l0oooo00<0P820000000000000
5`0000000`30`<00oooo0?ooo`090?oooa[ooooo000HooooooT0oooo00@0@410000000000000`<30
BP3oool2000006L0oooo00<0P820000000000000n@3oool00`30`<00:b/[0000000D000000030820
P03oool0oooo0<80oooo00<0`<300410@0000000500000000`1EEED0oooo0?ooo`0;0?oooa[ooooo
000HooooooX0oooo00@0@410000000000000`<30B@3oool00`20P80000000820P01V0?ooo`030820
P000000000000?X0oooo00<0eMGE0410@00000004@0000000`10@400`<300?ooo`360?ooo`030820
P000000000000140000000<0P8200?ooo`3oool0303ooolJooooo`006?oooook0?ooo`040410@000
000000000410@4P0oooo00<0P82000000020P800IP3oool00`10@40000000000003m0?ooo`030820
P010@400000000/0000000<0@4100820P03oool0b`3oool00`30`<00P8200000000<000000030820
P030`<00oooo00l0oooo6_ooool001Soooooo03oool01030`<0000000000000[:b]70?ooo`030820
P0000000P82006D0oooo00@0`<30000000000000P820o`3oool10?ooo`H0P8200P0000020820P=80
oooo00L0`<300820P020P800P8200410@0000000@41000<0P82000<0`<300?ooo`3oool04@3ooolJ
ooooo`006?ooooom0?ooo`050<30`010@400000000000030`<00A@3oool00`20P80000000820P01T
0?ooo`050<30`0000000000000000030`<00o`3oool70?ooo`800000f03oool00`20P80000000820
P00G0?oooa[ooooo000Hooooool0oooo00@0:b/[000000000000`<30A03oool00`20P80000000820
P01R0?ooo`030820P010@40000000080000000<0`<300?ooo`3oool0o`3oool60?ooo`800000f03o
ool00`20P80000000820P00G0?oooa[ooooo000Hooooool0oooo00D0eMGE00000000000000000<30
`0130?ooo`030820P0000000P82005h0oooo1`0000000`10@400`<300?ooo`3o0?ooo`P0oooo0P00
003H0?ooo`030820P0000000P82001L0oooo6_ooool001Soooooo`3oool10?ooo`040<30`0000000
00000410@4<0oooo00<0P82000000020P800GP3oool6000000030820P030`<00oooo0?l0oooo2@3o
ool200000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooooo0?ooo`80oooo00@0P820
000000000000`<30@P3oool00`20P80000000820P01R0?ooo`050820P010@400000000000010@400
o`3oool90?ooo`800000f03oool00`20P80000000820P00G0?oooa[ooooo000Hooooool0oooo0`3o
ool2000000030820P03oool0oooo0400oooo00<0P82000000020P800I03oool01030`<0000000000
0020P83o0?ooo`P0oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool001Soooooo`3o
ool30?ooo`80000000<0P8200?ooo`3oool0@03oool00`20P80000000820P01U0?ooo`030820P000
000000000?l0oooo203oool200000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?ooooog
0?ooo`80000000<0P8200?ooo`3oool01@3oool01030`<00000000000030`<120?ooo`030820P000
0000P82006H0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`D0oooo0P00003H0?ooo`030820P000
0000P82001L0oooo6_ooool001Sooooom`3oool01010@400000000000030`<050?ooo`040<30`000
000000000410@4<0oooo00<0P82000000020P800IP3oool2000000030820P03oool0oooo0?l0oooo
1@3oool200000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooooh0?ooo`040410@000
000000000410@0<0P82000D0:b/[00000000000000000<30`0130?ooo`030820P0000000P82005/0
oooo0P0000000`20P800oooo0?ooo`050?ooo`040<30`000000000000820P?l0oooo1`3oool20000
0=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooooi0?ooo`030820P0000000000000D0
000000<0@4100<30`03oool0@`3oool00`20P80000000820P01K0?ooo`040410@000000000000<30
`0D0oooo00@0`<300410@00000000000o`3oool80?ooo`800000f03oool00`20P80000000820P00G
0?oooa[ooooo000Hoooooo/0oooo1@20P8170?ooo`030820P0000000P82005/0oooo00D0`<300000
0000000000000410@0030820P0050410@0000000000000000030`<00o`3oool80?ooo`800000f03o
ool00`20P80000000820P00G0?oooa[ooooo000Hooooool0ooooB03oool00`20P80000000820P01L
0?ooo`030<30`010@400000000L0000000<0`<300?ooo`3oool0o`3oool70?ooo`800000f03oool0
0`20P80000000820P00G0?oooa[ooooo000Hooooool0ooooB03oool00`20P80000000820P01O0?oo
o`D0P820o`3oool<0?ooo`800000f03oool00`20P80000000820P00G0?oooa[ooooo000Hooooool0
ooooB03oool00`20P80000000820P03o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0
oooo6_ooool001Soooooo`3ooom80?ooo`030820P0000000P8200?l0ooooL03oool200000=P0oooo
00<0P82000000020P8005`3ooolJooooo`006?oooooo0?ooodP0oooo00<0P82000000020P800o`3o
oom`0?ooo`800000f03oool00`20P80000000820P00G0?oooa[ooooo000Hooooool0ooooB03oool0
0`20P80000000820P03o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool0
01Soooooo`3ooom80?ooo`030820P0000000P8200?l0ooooL03oool200000=P0oooo00<0P8200000
0020P8005`3ooolJooooo`006?oooooo0?ooodP0oooo00<0P82000000020P800o`3ooom`0?ooo`80
0000f03oool00`20P80000000820P00G0?oooa[ooooo000Hooooojh0oooo2@20P82@0?ooo`030820
P0000000P8200?l0ooooL03oool200000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oo
oon[0?ooo`030820P010@400000000X0000000<0@4100820P03oool0S03oool00`20P80000000820
P03o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool001SoooooZ03oool0
0`30`<00@4100000000@000000030410@030`<00oooo08T0oooo00<0P82000000020P800o`3ooom`
0?ooo`800000f03oool00`20P80000000820P00G0?oooa[ooooo000HooooojH0oooo00<0`<300410
@0000000500000000`20P800oooo0?ooo`0a0?ooo`h0P82000<0eMGE0?ooo`3oool0A@3oool00`20
P80000000820P03o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool001So
ooooY@3oool00`20P80000000000000F000000030410@030`<00oooo0300oooo3P0000000`2ZZZX0
oooo0?ooo`150?ooo`030820P0000000P8200?l0ooooL03oool200000=P0oooo00<0P82000000020
P8005`3ooolJooooo`006?oooonT0?ooo`030410@0000000000001T0000000<0@4100?ooo`3oool0
;P3oool2000000030410@020P800P82000T0P82000<0eMGE0?ooo`3oool0A@3oool00`20P8000000
0820P03o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool001SoooooXP3o
ool00`30`<00@4100000000M000000030<30`03oool0oooo02`0oooo0P0000000`20P800oooo0?oo
o`1A0?ooo`030820P0000000P8200?l0ooooL03oool200000=P0oooo00<0P82000000020P8005`3o
oolJooooo`006?oooonQ0?ooo`030<30`0000000000001l0000000<0`<300?ooo`3oool0:`3oool0
0`10@40000000410@01C0?ooo`030820P0000000P8200?l0ooooL03oool200000=P0oooo00<0P820
00000020P8005`3ooolJooooo`006?oooonP0?ooo`030<30`000000000000240000000<0`<300?oo
o`3oool0:P3oool01030`<00000000000030`<1B0?ooo`030820P0000000P8200?l0ooooL03oool2
00000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooonP0?ooo`030410@00000000000
02800000;@3oool00`10@40000000410@01B0?ooo`030820P0000000P8200?l0ooooL03oool20000
0=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooonO0?ooo`030410@0000000000002<0
000000<0@4100?ooo`3oool0:P3oool01030`<00000000000010@41A0?ooo`030820P0000000P820
0?l0ooooL03oool200000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooonN0?ooo`03
0410@0000000000002D0000000<0@4100?ooo`3oool03P3oool20820P0030<30`03oool0oooo00@0
oooo00<0`<300820P020P8001P3oool00`30`<00P8200820P0070?ooo`040<30`000000000000410
@500oooo00<0P82000000020P800o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G0?oo
oa[ooooo000Hoooooid0oooo00<0`<300000000000009`0000000`30`<00oooo0?ooo`0=0?ooo`03
0410@0000000P82000H0oooo00<0`<300000000000001P3oool01020P800000000000030`<070?oo
o`050<30`000000000000410@030`<00CP3oool00`20P80000000820P03o0?ooog00oooo0P00003H
0?ooo`030820P0000000P82001L0oooo6_ooool001SoooooW@3oool00`10@40000000000000W0000
00030410@03oool0oooo00d0oooo00<0P8200000000000001`3oool2000000030820P03oool0oooo
00@0oooo0P0000000`20P800oooo0?ooo`060?ooo`050<30`010@400000000000020P800CP3oool2
00000?l0ooooL03oool200000=P0oooo00<0P82000000020P8005`3ooolJooooo`006?oooonL0?oo
o`030820P0000000000002T0000000<0`<300?ooo`3oool0303oool00`20P8000000000000070?oo
o`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00P0oooo00D0@4100000
00000000@4100<30`01<0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G
0?oooa[ooooo000Hoooooi`0oooo;00000000`20P800oooo0?ooo`0=0?ooo`80000000<0`<300?oo
o`3oool0103oool00`20P80000000410@0060?ooo`030410@0000000000000/0oooo00D0`<300000
0000000000000<30`01;0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G
0?oooa[ooooo000Hoooooi/0oooo00<0P820000000000000:`00000?0?ooo`80000000<0P8200?oo
o`3oool0103oool00`20P8000000000000060?ooo`030820P0000000000000`0oooo00D0`<300000
0000000000000<30`01:0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G
0?oooa[ooooo000Hoooooi/0oooo00<0@410000000000000:`0000000`3EeMD0oooo0?ooo`0<0?oo
o`030410@0000000P82000H0oooo00<0`<300000000000001P3oool01020P800000000000030`<0<
0?ooo`040<30`00000000000000004X0oooo0P00003o0?ooog00oooo0P00003H0?ooo`030820P000
0000P82001L0oooo6_ooool001SoooooV`3oool^000000030:ZZZP3oool0oooo00`0oooo00<0P820
0000000000001`3oool2000000030:ZZZP3oool0oooo00@0oooo0P0000000`20P800oooo0?ooo`0;
0?ooo`040<30`000000000000820P4T0oooo0P00003o0?ooog00oooo0P00003H0?ooo`030820P000
0000P82001L0oooo6_ooool001SoooooVP3oool00`20P80000000000000/0000000305EEE@3oool0
oooo00`0oooo00<0P8200000000000001`3oool2000000030:ZZZP3oool0oooo00@0oooo0P000000
0`20P800oooo0?ooo`0<0?ooo`030410@0000000000004T0oooo0P00003o0?ooog00oooo0P00003H
0?ooo`030820P0000000P82001L0oooo6_ooool001SoooooVP3oool00`20P80000000000000/0000
000305EEE@3oool0oooo00d0oooo0P0000000`20P800oooo0?ooo`040?ooo`030820P0000000EEEE
00H0oooo00<0@4100000000000003P3oool00`20P8000000000000190?ooo`800000o`3ooom`0?oo
o`800000f03oool00`20P80000000820P00G0?oooa[ooooo000HoooooiX0oooo00<0P82000000000
0000;00000000`1EEED0oooo0?ooo`0=0?ooo`80000000<0P8200?ooo`3oool0103oool00`20P800
000005EEE@060?ooo`030820P0000000000000<0oooo0P20P8000`30`<00oooo0?ooo`060?ooo`03
0820P0000000000004T0oooo0P00003o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0
oooo6_ooool001SoooooVP3oool00`20P80000000000000/0000000302/[:`3oool0oooo00d0oooo
00<0@4100000000000001P3oool00`20P8000000000000060?ooo`030820P0000000000000<0oooo
0P0000000`10@400oooo0?ooo`050?ooo`040<30`000000000000820P4T0oooo0P00003o0?ooog00
oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool001SoooooVP3oool`000000l0oooo
00@0P820000000000000@4101P3oool2000000030410@03oool0oooo00@0oooo0P0000001020P800
oooo0?ooo`30`<02000000030410@030`<00oooo0080oooo00<0`<300820P00000000P00001:0?oo
o`800000o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G0?oooa[ooooo000HoooooiX0
oooo<000000?0?ooo`050820P0000000000000000010@400103oool01@30`<000000000000000000
@41000@0oooo00@0`<30000000000000P8200`3oool00`30`<00000000000008000000030<30`03o
ool0oooo04P0oooo0P00003o0?ooog00oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_oo
ool001SoooooVP3oool`00000100oooo0P0000001`10@40000000410@030`<00oooo0<30`010@400
0P0000001030`<0000000410@030`<020?ooo`040410@000000000000<30`0D0oooo00<0P8200000
000000000`0000000`10@400P8200?ooo`1;0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20
P80000000820P00G0?oooa[ooooo000HoooooiX0oooo<000000@0?ooo`80000000<0P8200<30`000
00001@0000000`0[:b/0oooo0<30`006000000030410@03oool0oooo05P0oooo0P00003o0?ooog00
oooo0P00003H0?ooo`030820P0000000P82001L0oooo6_ooool001SoooooVP3oool00`20P8000000
0000000/0000000303Ti>@3oool0oooo00h0oooo0P2ZZZX0103EeMD0oooo0=GEe@2ZZZX305EEE@03
0820P03Shn<0oooo0080oooo00D0ZZZZ05EEE@1EEED0EEEE0:ZZZP1K0?ooo`800000o`3ooom`0?oo
o`800000f03oool00`20P80000000820P00G0?oooa[ooooo000HoooooiX0oooo00<0P82000000000
0000;00000000`1EEED0oooo0?ooo`1l0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20P800
00000820P00G0?oooa[ooooo000HoooooiX0oooo00<0P820000000000000;00000000`1EEED0oooo
0?ooo`1l0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G0?oooa[ooooo
000Hoooooi/0oooo;P0000000`2ZZZX0oooo0?ooo`1l0?ooo`800000o`3ooom`0?ooo`800000f03o
ool00`20P80000000820P00G0?oooa[ooooo000Hoooooi/0oooo00<0@410000000000000:`000000
0`3EeMD0oooo0?ooo`1l0?ooo`800000o`3ooom`0?ooo`800000f03oool00`20P80000000820P00G
0?oooa[ooooo000Hoooooi/0oooo00<0P820000000000000:`00001o0?ooo`800000o`3ooom`0?oo
o`800000f03oool00`20P80000000820P00G0?oooa[ooooo000Hoooooi`0oooo;00000000`20P800
oooo0?ooo`1m0?ooo`800000o`3ooom`0?ooo`800000f020P8001@10@40000000410@020P800`<30
01D0oooo6_ooool001SoooooW03oool00`20P80000000000000Y000000030<30`03oool0oooo07d0
oooo0P00003o0?ooog00oooogP0000000`20P800oooo0?ooo`0C0?oooa[ooooo000Hoooooid0oooo
00<0@4100000000000009`0000000`10@400oooo0?ooo`1n0?ooo`800000o`3ooom`0?ooomh00000
00<0P8200?ooo`3oool04`3ooolJooooo`006?oooonM0?ooo`030<30`0000000000002L0000000<0
`<300?ooo`3oool0OP3oool200000?l0ooooL03ooooN000000030820P03oool0oooo01<0oooo6_oo
ool001SoooooWP3oool00`10@40000000000000U000000030410@03oool0oooo07l0oooo0P00003o
0?ooog00oooogP0000000`20P800oooo0?ooo`0C0?oooa[ooooo000Hoooooih0oooo00<0`<300000
000000009@0000000`30`<00oooo0?ooo`1o0?ooo`800000o`3ooom`0?ooomh0000000<0P8200?oo
o`3oool04`3ooolJooooo`006?oooonO0?ooo`030<30`0000000000002<0000000<0P8200?ooo`3o
ool0P03oool200000?l0ooooL03ooooN000000030820P03oool0oooo01<0oooo6_ooool001Sooooo
X03oool00`10@40000000000000Q000000030410@03oool0oooo0840oooo0P00003o0?ooog00oooo
gP0000000`20P800oooo0?ooo`0C0?oooa[ooooo000Hoooooj40oooo00<0@4100000000000007`00
00000`10@400oooo0?ooo`220?ooo`800000o`3ooom`0?ooomh0000000<0P8200?ooo`3oool04`3o
oolJooooo`006?oooonR0?ooo`030410@0000000000001d0000000<0@4100?ooo`3oool0P`3oool2
00000?l0ooooL03ooooN000000030820P03oool0oooo01<0oooo6_ooool001SoooooX`3oool00`30
`<0000000000000K000000030820P03oool0oooo08@0oooo0P00003o0?ooool0oooo0P3oool00`20
P80000000000001P0?oooa[ooooo000Hoooooj@0oooo00<0`<300000000000006@0000000`30`<00
oooo0?ooo`250?ooo`800000o`3ooooo0?ooo`80oooo00<0P820000000000000H03ooolJooooo`00
6?oooonV0?ooo`030820P0000000000001@0000000<0@4100<30`03oool0R03oool200000?l0oooo
o`3oool20?ooo`030820P000000000000600oooo6_ooool001SoooooZ03oool00`20P80000000000
000@000000030410@030`<00oooo08X0oooo0P00003o0?ooool0oooo0P3oool00`20P80000000000
001P0?oooa[ooooo000Hoooooj/0oooo00<0P8200000000000002P0000000`10@400P8200?ooo`2=
0?ooo`800000o`3ooooo0?ooo`80oooo00<0P820000000000000H03ooolJooooo`006?oooon]0?oo
o`030<30`020P800P8200080P82000<0@4100000000000000P20P82A0?ooo`800000o`3ooooo0?oo
o`80oooo00<0P820000000000000H03ooolJooooo`006?oooonc0?ooo`800000T`3oool00`10@400
00000<30`03o0?ooool0oooo0@3oool00`20P80000000000001P0?oooa[ooooo000Hoooook<0oooo
0P00002C0?ooo`030820P0000000P8200?l0ooooo`3oool10?ooo`030820P000000000000600oooo
6_ooool001Sooooo/`3oool2000009<0oooo00<0P82000000020P800o`3ooooo0?ooo`40oooo00<0
P820000000000000H03ooolJooooo`006?oooonc0?ooo`800000T`3oool00`20P80000000820P03o
0?ooool0oooo0@3oool00`20P80000000000001P0?oooa[ooooo000Hoooook<0oooo0P00002C0?oo
o`030820P0000000P8200?l0ooooo`3oool10?ooo`030820P000000000000600oooo6_ooool001So
oooo/`3oool2000009<0oooo00<0P82000000020P800o`3ooond0?ooo`0305EEE@000000000000/0
000000<0P8200?ooo`3oool0>`3oool00`20P80000000000001P0?oooa[ooooo000Hoooook<0oooo
0P00002C0?ooo`030820P0000000P8200?l0oooo]03oool00`1EEED0000002/[:`0;05EEE@030:ZZ
ZP3oool0oooo03/0oooo00<0P820000000000000:03oool00`3EeMD0ZZZZ0:ZZZP0e0?oooa[ooooo
000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0oooo]03oool00`1EEED000000820
P0190?ooo`030820P0000000000002P0oooo00<0P820000000000000=@3ooolJooooo`006?oooonc
0?ooo`800000T`3oool00`20P80000000820P03o0?oook@0oooo00<0P82000000010@400B@3oool0
0`20P80000000000000X0?ooo`030820P0000000000003D0oooo6_ooool001Sooooo/`3oool20000
09<0oooo00<0P82000000020P800o`3ooond0?ooo`040=GEe@00000000000<30`4P0oooo00<0P820
000000000000:03oool00`20P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?oo
o`030820P0000000P8200?l0oooo]@3oool00`10@40000000410@0180?ooo`030820P00000000000
02P0oooo00<0P820000000000000=@3ooolJooooo`006?oooonc0?ooo`800000T`3oool00`20P800
00000820P03o0?oookD0oooo00@0`<30000000000000@410A`3oool00`20P80000000000000X0?oo
o`030820P0000000000003D0oooo6_ooool001Sooooo/`3oool2000009<0oooo00<0P82000000020
P800o`3ooonf0?ooo`040<30`000000000000410@4H0oooo00<0P820000000000000:03oool00`20
P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0
oooo]`3oool01@30`<00000000000010@400`<3004@0oooo00<0P820000000000000:03oool00`20
P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0
oooo^03oool01@30`<00@410000000000000P82004<0oooo00<0P820000000000000:03oool00`20
P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0
oooo^P3oool01@10@400000000000010@400`<300440oooo00<0P820000000000000:03oool00`20
P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0
oooo^`3oool01@30`<000000000000000000`<300400oooo00<0P820000000000000:03oool00`20
P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0
oooo_03oool01@30`<000000000000000000`<3003l0oooo00<0P820000000000000:03oool00`20
P80000000000000e0?oooa[ooooo000Hoooook<0oooo0P00002C0?ooo`030820P0000000P8200?l0
oooo_@3oool01030`<00000000000000000o0?ooo`030820P0000000000002P0oooo00<0P8200000
00000000=@3ooolJooooo`006?oooonc0?ooo`800000T`3oool00`20P80000000820P03o0?oookh0
oooo00@0`<30000000000000P820?P3oool00`20P80000000000000X0?ooo`030820P00000000000
03D0oooo6_ooool001Sooooo/`3oool2000009<0oooo00<0P82000000020P800o`3ooono0?ooo`03
0410@0000000000003h0oooo00<0P820000000000000:03oool00`20P80000000000000e0?oooa[o
oooo000Hooooof<0oooo00<0P8200410@0000000200000020820P4<0oooo0P00002C0?ooo`030820
P0000000P8200?l0oooo_`3oool00`20P80000000000000n0?ooo`030820P0000000000002P0oooo
00<0P820000000000000=@3ooolJooooo`006?oooomP0?ooo`030820P010@400000000h0000000<0
@4100820P03oool0?`3oool2000009<0oooo00<0P82000000020P800o`3ooond0?ooo`030:ZZZP20
P800`<3000P0oooo00<0P820000000000000?P3oool00`20P80000000000000X0?ooo`030820P000
0000000003D0oooo6_ooool001SoooooGP3oool00`2ZZZX000000000000C000000030820P03oool0
oooo03`0oooo0P00002C0?ooo`030820P0000000P8200?l0oooo]03oool00`1EEED000000410@007
0?ooo`040<30`000000000000820P3h0oooo00<0P820000000000000:03oool00`20P80000000000
000e0?oooa[ooooo000Hoooooe`0oooo00<0`<300410@00000005`0000000`20P800oooo0?ooo`0j
0?ooo`800000T`3oool00`20P80000000820P03o0?oook@0oooo00D0eMGE000000000000@4100<30
`0030?ooo`030<30`020P800000000800000?`3oool00`20P80000000000000T0?ooo`0500000020
P800`<300?ooo`20P8000P00000e0?oooa[ooooo000Hoooooe/0oooo00<0@4100000000000006@00
00000`10@400oooo0?ooo`0i0?ooo`800000T`3oool00`20P80000000820P03o0?oookD0oooo00<0
`<30000000000000200000000`30`<00oooo0?ooo`0m0?ooo`030820P0000000000002@0oooo0`00
00020410@0800000=@3ooolJooooo`006?oooomI0?ooo`030<30`010@400000001`0000000<0:b/[
0?ooo`3oool0>03oool2000009<0oooo00<0P82000000020P800o`3ooong0?ooo`030820P0000000
000000<0000000<0@4100820P03oool0@03oool00`20P80000000000000T0?ooo`030410@0000000
000000@00000=@3ooolJooooo`006?oooomH0?ooo`030<30`0000000000001h0000000<0@4100?oo
o`3oool0=`3oool2000009<0oooo00<0P82000000020P800o`3ooooo0?ooo`40oooo00<0P8200000
000000009P3oool00`20P800000000000002000003D0oooo6_ooool001SoooooE`3oool00`30`<00
00000000000Q000003P0oooo0P00002C0?ooo`030820P0000000P8200?l0ooooo`3oool10?ooo`03
0820P0000000000002P0oooo0`20P80e0?oooa[ooooo000Hoooooc80oooo1020P8000`30`<00oooo
0?ooo`0N0?ooo`030410@000000000000240000000<0@4100?ooo`3oool0=@3oool2000009<0oooo
00<0P82000000020P800o`3ooooo0?ooo`40oooo00<0P820000000000000H03ooolJooooo`006?oo
ool_0?ooo`030<30`010@400000000H0000000<0P8200?ooo`3oool06`3oool00`10@40000000000
000S000000030820P03oool0oooo03@0oooo0P00002C0?ooo`030820P0000000P8200?l0ooooo`3o
ool10?ooo`030820P000000000000600oooo6_ooool001Sooooo;P3oool01@30`<00000000000000
0000@41000<0P82000D0@41000000000000000000<30`00J0?ooo`030820P0000000000002D00000
=P3oool2000009<0oooo00<0P82000000020P800o`3ooooo0?ooo`40oooo00<0P820000000000000
H03ooolJooooo`006?ooool]0?ooo`040<30`000000000000410@0H0oooo00@0`<30000000000000
@4106P3oool00`10@40000000000000V000003D0oooo0P00002C0?ooo`030820P0000000P8200?l0
ooooo`3oool10?ooo`030820P000000000000600oooo6_ooool001Sooooo;@3oool00`20P8000000
000000080?ooo`040<30`000000000000820P1P0oooo00<0`<300000000000009`0000000`20P800
oooo0?ooo`0b0?ooo`800000T`3oool00`20P80000000820P03o0?ooool0oooo0@3oool00`20P800
00000000001P0?oooa[ooooo000HooooocT0oooo00<0EEEE0000001EEED0603oool00`0[:b/00000
0000000X000000030=GEe@3oool0oooo0340oooo0P00002C0?ooo`030820P0000000P8200?l0oooo
o`3oool10?ooo`030820P000000000000600oooo6_ooool001Sooooo0P3oool00`30`<00P8200820
P00;0820P0030<30`03oool0oooo00/0oooo00<0`<300820P020P8001`3oool20820P0030<30`03o
ool0oooo00D0oooo00@0`<300820P020P800P8200`3oool00`20P80000000000000G0?ooo`030820
P0000000000002T0000000<0P8200?ooo`3oool0<@3oool2000009<0oooo00<0P82000000020P800
o`3ooooo0?ooo`40oooo00<0P820000000000000H03ooolJooooo`006?ooool20?ooo`030820P000
0000000000/0000000<0P8200?ooo`3oool02`3oool00`20P8000000000000060?ooo`030410@000
0000000000H0oooo00<0`<30000000000000100000000`20P800oooo0820P002000001L0oooo;@00
000c0?ooo`800000U03oool200000?l0ooooo`3oool10?ooo`030820P000000000000600oooo6_oo
ool001Sooooo0P3oool00`20P80000000000000;0820P0030<30`03oool0oooo00/0oooo00<0P820
0000000000001@3oool01020P800000000000030`<050?ooo`050<30`0000000000000000010@400
0P20P802000000040410@020P8000000000001H0oooo00<0`<30000000000000:`0000000`30`<00
oooo0?ooo`0`0?ooo`800000U03oool200000?l0ooooo`3oool10?ooo`030820P000000000000600
oooo6_ooool001Sooooo0P3oool00`20P80000000000000I0?ooo`030820P0000000000000@0oooo
00@0`<30000000000000P8201@3oool01030`<00000000000010@4050?ooo`030410@0000000@410
008000005P3oool00`20P80000000000000[000000030820P03oool0oooo0300oooo0P00002D0?oo
o`800000o`3ooooo0?ooo`40oooo00<0P820000000000000H03ooolJooooo`006?ooool20?ooo`04
0<30`000000000000<30`1P0oooo00<0P8200000000000000`3oool01030`<00000000000010@406
0?ooo`030410@0000000000000L0oooo00@0@41000000000000000005P3oool_00000380oooo0P00
002D0?ooo`800000o`3ooooo0?ooo`40oooo00<0P820000000000000H03ooolJooooo`006?ooool3
0?ooo`030410@0000000@41001P0oooo00<0P8200000000000000P3oool01@30`<00000000000000
0000`<3000H0oooo0P0000000`20P800oooo0?ooo`050?ooo`040<30`00000000000000001H0oooo
;`00000b0?ooo`800000U03oool200000?l0ooooo`3oool10?ooo`030820P000000000000600oooo
6_ooool001Sooooo0`3oool01030`<00000000000030`<0G0?ooo`030820P000000000000080oooo
00@0@410000000000000`<301P3oool01020P800000000000030`<080?ooo`<000005P3oool_0000
0380oooo0P00002D0?ooo`800000o`3ooooo0?ooo`40oooo00<0P820000000000000H03ooolJoooo
o`006?ooool40?ooo`040410@000000000000<30`1H0oooo00D0P820000000000000oooo0410@002
000000030<30`03oool0oooo00D0oooo00<0P8200000000000002@3oool00`20P80000000000000E
0?ooo`030<30`0000000000002d0000000<0P8200?ooo`3oool0;`3oool2000009@0oooo0P00003o
0?ooool0oooo0@3oool00`20P80000000000001P0?oooa[ooooo000Hooooo`D0oooo00@0@4100000
00000000`<305@3oool01020P800000000000010@402000000030820P03oool0oooo00H0oooo00<0
P8200000000000002@3oool00`20P80000000000000E0?ooo`030820P0000000000002d0000000<0
P8200?ooo`3oool0;`3oool2000009@0oooo0P00003o0?ooool0oooo0@3oool00`20P80000000000
001P0?oooa[ooooo000Hooooo`H0oooo00@0@410000000000000P820503oool01020P80000000000
0030`<02000000030<30`03oool0oooo00H0oooo00<0P8200000000000002@3oool00`20P8000000
0000000E0?ooo`030820P0000000000002d0000000<0P8200?ooo`3oool0;`3oool2000009@0oooo
0P00003o0?ooool0oooo0@3oool00`20P80000000000001P0?oooa[ooooo000Hooooo`L0oooo00D0
P820000000000000@4100<30`00B0?ooo`050820P000000000000?ooo`30`<000P0000000`30`<00
oooo0?ooo`050?ooo`030820P0000000000000T0oooo00<0P8200000000000005@3oool00`20P800
00000000000]000000030820P03oool0oooo02l0oooo0P00002D0?ooo`800000o`3ooooo0?ooo`40
oooo00<0P820000000000000H03ooolJooooo`006?ooool80?ooo`050<30`0000000000000000020
P8004@3oool00`20P8000000000000020?ooo`040820P000000000000<30`0L0oooo0P0000000`20
P800oooo0?ooo`060?ooo`<000005@3oool00`20P80000000000000]000000030820P03oool0oooo
02l0oooo0P00002D0?ooo`800000o`3ooooo0?ooo`40oooo00<0P820000000000000H03ooolJoooo
o`006?ooool:0?ooo`040410@000000000000820P100oooo00<0P8200000000000000`3oool00`10
@4000000000000070?ooo`80000000<0@4100?ooo`3oool01@3oool01030`<00000000000000000F
0?ooobl0000000<0`<300?ooo`3oool0;`3oool2000009@0oooo0P00003o0?ooool0oooo0@3oool0
0`20P80000000000001P0?oooa[ooooo000Hooooo`/0oooo00@0@410000000000000`<303`3oool0
0`20P8000000000000040?ooo`030410@0000000@41000H0oooo00@0P820000000000000@4101@3o
ool00`30`<00000000000002000001H0oooo;`00000b0?ooo`800000U03oool200000?l0ooooo`3o
ool10?ooo`030820P000000000000600oooo6_ooool001Sooooo303oool00`10@40000000000000?
0?ooo`030820P0000000000000D0oooo00<0@41000000020P8001P3oool01@10@400000000000010
@400`<300080oooo00@0P820000000000000@4100P00000F0?ooobl00000<P3oool2000009@0oooo
0P00003o0?ooool0oooo0@3oool00`20P80000000000001P0?oooa[ooooo000Hooooo`d0oooo00<0
:b/[00000020P8003P3oool00`20P8000000000000060?ooo`030410@0000000`<3000H0oooo00<0
@4100000000000001@0000001030`<00P82000000000000F0?ooo`030410@0000000000002/00000
00<0@4100?ooo`3oool0<03oool2000009@0oooo0P00003o0?ooool0oooo0@3oool00`20P8000000
0000001P0?oooa[ooooo000Hooooo`d0oooo00<0P8200000000000003P3oool00`20P80000000000
00070?ooo`80P8201`3oool00`20P800@41000000002000000040820P030`<00oooo0<30`080P820
5P3oool00`20P80000000000000[000000030820P03oool0oooo0300oooo0P00002D0820P0800000
o`20P83o0820P040P82000<0@410000000000000H03ooolJooooo`006?ooool=0?ooo`030:ZZZP00
0000000000h0oooo00<0P820000000000000<P3oool]000003<0ooooo`00003o000009`00000H03o
oolJooooo`006?ooool20?ooo`030<30`020P800P82000P0oooo00<0ZZZZ0000000000003P3oool0
0`20P80000000000000b0?ooo`030410@0000000000002T0000000<0@4100?ooo`3oool0<@3ooooo
00000?l00000W000001P0?oooa[ooooo000Hooooo`80oooo00@0P820000000000000`<301`3oool0
0`0[:b/000000820P00>0?ooo`030820P000000000000380oooo00<0`<30000000000000:@000000
0`20P800oooo0?ooo`0a0?ooool00000o`00002L00000600oooo6_ooool001Sooooo0`3oool01010
@400000000000020P8040?ooo`040820P010@4000000000000l0oooo00<0P820000000000000<`3o
ool00`10@40000000000000X000003@0ooooo`00003o000009`00000H03ooolJooooo`006?ooool4
0?ooo`030410@0000000000000L0000000<0`<300?ooo`3oool03@3oool00`20P80000000000000c
0?ooo`030<30`0000000000002L0000000<0P8200?ooo`3oool0<P3ooooo00000?l00000W000001P
0?oooa[ooooo000Hooooo`D0oooo00<0`<300410@0000000100000000`20P800eMGE0?ooo`0?0?oo
o`030820P0000000000003@0oooo00<0@4100000000000009P00000e0?ooool00000o`00002L0000
0600oooo6_ooool001Sooooo7P3oool00`30`<00P8200820P00d0?ooo`030<30`0000000000002@0
000000<0@4100<30`03oool0=03ooooo00000?l00000W000001P0?oooa[ooooo000HoooooeH0oooo
00<0`<300000000000008`0000000`30`<00oooo0?ooo`0d0?ooool00000o`00002L00000600oooo
6_ooool001SoooooE`3oool00`10@40000000000000Q000000030820P03oool0oooo03D0ooooo`00
003o000009`00000H03ooolJooooo`006?oooomH0?ooo`030410@0000000000001l0000000<0@410
0?ooo`3oool0=P3ooooo00000?l00000W000001P0?oooa[ooooo000HoooooeP0oooo00<0eMGE05EE
E@0000007@0000000`0L71`0P8200?ooo`0h0?ooool00000o`00002L00000600oooo6_ooool001So
ooooFP3oool00`30`<00@4100000000K000000030=GEe@3oool0oooo03P0ooooo`00003o000009`0
0000H03ooolJooooo`006?oooomL0?ooo`030820P010@400000001L0000000<0@4100?ooo`3oool0
>P3ooooo00000?l00000W000001P0?oooa[ooooo000Hoooooeh0oooo00<0EEEE0000000000004`00
00000`10@400`<300?ooo`3o0?ooof80oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000H
oooooel0oooo00<0P8200000000000004@0000000`20P800oooo0?ooo`3o0?ooof<0oooo00<0P820
00000020P800o`3ooooC0?oooa[ooooo000Hooooof40oooo00<0`<300820P0000000300000000`20
P800`<300?ooo`3o0?ooofH0oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000Hooooof@0
oooo00<0`<300820P020P8000`20P8001@10@40000000410@020P800`<300?l0ooooJP3oool00`20
P80000000820P03o0?ooom<0oooo6_ooool001SoooooJP3oool00`20P80000000820P03o0?ooof`0
oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800
o`3ooom/0?ooo`030820P0000000P8200?l0ooood`3ooolJooooo`006?oooomZ0?ooo`030820P000
0000P8200?l0ooooK03oool00`20P80000000820P03o0?ooom<0oooo6_ooool001SoooooJP3oool0
0`20P80000000820P03o0?ooof`0oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000Hoooo
ofX0oooo00<0P82000000020P800o`3ooom/0?ooo`030820P0000000P8200?l0ooood`3ooolJoooo
o`006?oooomZ0?ooo`030820P0000000P8200?l0ooooK03oool00`20P80000000820P03o0?ooom<0
oooo6_ooool001SoooooJP3oool00`20P80000000820P03o0?ooof`0oooo00<0P82000000020P800
o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800RP3oool00`20P80000000000
000;000000030820P03oool0oooo0=00oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000H
ooooofX0oooo00<0P82000000020P800RP3oool00`20P80000000000000;000000030820P03oool0
oooo0=00oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P8200000
0020P800RP3oool00`20P80000000000003N0?ooo`030820P0000000P8200?l0ooood`3ooolJoooo
o`006?oooomZ0?ooo`030820P0000000P82008X0oooo00<0P820000000000000X03oool>0820P300
oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800
R`3oool2000000030820P03oool0oooo09d0oooo3P00000`0?ooo`030820P0000000P8200?l0oooo
d`3ooolJooooo`006?oooomZ0?ooo`030820P0000000P82008/0oooo00<0P820000000000000W`3o
ool2000000030410@020P800P82000T0P820<03oool00`20P80000000820P03o0?ooom<0oooo6_oo
ool001SoooooJP3oool00`20P80000000820P02<0?ooo`80000000<0@4100?ooo`3oool0W03oool2
000000030820P03oool0oooo03T0oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000Hoooo
ofX0oooo00<0P82000000020P800S03oool01030`<00000000000010@42M0?ooo`030410@0000000
@41003/0oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P8200000
0020P800S@3oool01030`<00000000000010@42L0?ooo`040<30`000000000000<30`3X0oooo00<0
P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800SP3oool0
1@30`<000000000000000000eMGE09/0oooo00<0@41000000010@400>P3oool00`20P80000000820
P03o0?ooom<0oooo6_ooool001SoooooJP3oool00`20P80000000820P02@0?ooo`040410@0000000
00000<30`9X0oooo00@0`<30000000000000@410>@3oool00`20P80000000820P03o0?ooom<0oooo
6_ooool001SoooooJP3oool00`20P80000000820P02A0?ooo`040820P000000000000410@9X0oooo
00@0`<30000000000000@410>03oool00`20P80000000820P02m0?ooo`030820P010@400000000<0
000000<0P8200<30`03oool0o`3oool=0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800
TP3oool01020P800000000000010@42J0?ooo`040<30`0000000000005EEECL0oooo00<0P8200000
0020P800^`3oool00`30`<00@41000000007000000030820P03oool0oooo0?l0oooo2`3ooolJoooo
o`006?oooomZ0?ooo`030820P0000000P82009<0oooo00@0@410000000000000@410VP3oool01@30
`<00@41000000010@400`<3003D0oooo00<0P82000000020P800^`3oool01010@400000000000020
P8030?ooo`050<30`010@400000000000020P800o`3oool<0?oooa[ooooo000HooooofX0oooo00<0
P82000000020P800U03oool01020P80000000000002ZZZZK0?ooo`05075aL@000000000005EEE@3E
eMD0<`3oool00`20P80000000820P02j0?ooo`040820P000000000000=GEe@H0oooo00@0P8200000
00000000eMGEo`3oool;0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800U@3oool00`10
@40000000000002L0?ooo`050<30`0000000000000000030`<00<P3oool00`20P80000000820P035
0?ooo`80000000<0@4100?ooo`3oool0o`3oool90?oooa[ooooo000HooooofX0oooo00<0P8200000
0020P800U@3oool00`20P80000000000002M0?ooo`050<30`0000000000000000030`<00<@3oool0
0`20P80000000820P0350?ooo`030820P000000000000?l0oooo2`3ooolJooooo`006?oooomZ0?oo
o`030820P0000000P82008X0oooo00<0`<300820P020P800203oool00`20P80000000000002N0?oo
o`040<30`000000000000410@340oooo00<0P82000000020P800a@3oool00`20P80000000000003o
0?ooo`/0oooo6_ooool001SoooooJP3oool00`20P80000000820P02:0?ooo`040820P00000000000
0<30`0H0oooo00@0`<30000000000000P820W`3oool01020P800000000000030`<0`0?ooo`030820
P0000000P8200<D0oooo00<0P820000000000000o`3oool;0?oooa[ooooo000HooooofX0oooo00<0
P82000000020P800R`3oool01010@400000000000020P8030?ooo`030=GEe@20P800000000800000
X@3oool2000000030820P03oool0oooo02h0oooo00<0P82000000020P800a@3oool300000?l0oooo
2`3ooolJooooo`006?oooomZ0?ooo`030820P0000000P82008`0oooo00<0@4100000000000001`00
00000`30`<00oooo0?ooo`2O0?ooo`80000000<0P8200?ooo`3oool0;P3oool00`20P80000000820
P0340?ooo`040820P000000000000820P?l0oooo2`3ooolJooooo`006?oooomZ0?ooo`030820P000
0000P82008d0oooo00<0`<300410@00000000`0000000`10@400P8200?ooo`2G0?ooo`80000000<0
P8200?ooo`3oool01@3oool01030`<00000000000030`<0`0?ooo`030820P0000000P8200<<0oooo
00@0P8200000000000000000o`3oool<0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800
o`3oool^0?ooo`040410@000000000000<30`0D0oooo00@0`<30000000000000@410<@3oool00`20
P80000000820P02l0?ooo`D0P8201@0000000`30`<00oooo0?ooo`3o0?ooo`X0oooo6_ooool001So
ooooJP3oool00`20P80000000820P03o0?ooobl0oooo00@0@410000000000000@4100`20P8040000
00030<30`03oool0oooo02l0oooo00<0P82000000020P800_03oool8000000030820P03oool0oooo
0?l0oooo303ooolJooooo`006?oooomZ0?ooo`030820P0000000P8200?l0oooo<03oool00`20P800
000000000005000000030410@030`<00oooo0340oooo00<0P82000000020P800_03oool200000005
0410@020P800P8200820P030`<00o`3oool@0?oooa[ooooo000HooooofX0oooo00<0P82000000020
P800o`3ooolb0?ooo`D0P820=@3oool00`20P80000000820P02l0?ooo`80000000<0P8200?ooo`3o
ool0o`3ooolB0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800o`3ooom/0?ooo`030820
P0000000P8200;`0oooo0P0000000`20P800oooo0?ooo`3o0?oooa80oooo6_ooool001SoooooJP3o
ool00`20P80000000820P03o0?ooof`0oooo00<0P82000000020P800_03oool2000000030820P03o
ool0oooo0?l0oooo4P3ooolJooooo`006?oooomZ0?ooo`030820P0000000P8200?l0ooooK03oool0
0`20P80000000820P02l0?ooo`80000000<0P8200?ooo`3oool0o`3ooolB0?oooa[ooooo000Hoooo
ofX0oooo00<0P82000000020P800o`3ooom/0?ooo`030820P0000000P8200;`0oooo0P0000000`20
P800oooo0?ooo`3o0?oooa80oooo6_ooool001SoooooJP3oool00`20P80000000820P03o0?ooof`0
oooo00<0P82000000020P800_03oool2000000030820P03oool0oooo0?l0oooo4P3ooolJooooo`00
6?oooomZ0?ooo`030820P0000000P8200?l0ooooK03oool00`20P80000000820P02l0?ooo`/00000
00<0P8200?ooo`3oool0o`3oool90?oooa[ooooo000HooooofX0oooo00<0P82000000020P800o`3o
oom/0?ooo`030820P0000000P8200;`0oooo2`0000000`20P800oooo0?ooo`3o0?ooo`T0oooo6_oo
ool001SoooooJP3oool00`20P80000000820P03o0?ooof`0oooo00<0P82000000020P800o`3ooooC
0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800o`3ooom/0?ooo`030820P0000000P820
0?l0ooood`3ooolJooooo`006?oooomZ0?ooo`030820P0000000P8200?l0ooooK03oool00`20P800
00000820P03o0?ooom<0oooo6_ooool001SoooooJP3oool00`20P80000000820P03o0?ooof`0oooo
00<0P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800o`3o
oom/0?ooo`030820P0000000P8200?l0ooood`3ooolJooooo`006?oooomZ0?ooo`030820P0000000
P8200?l0ooooK03oool00`20P80000000820P03o0?ooom<0oooo6_ooool001SoooooJP3oool00`20
P80000000820P03o0?ooof`0oooo00<0P82000000020P800o`3ooooC0?oooa[ooooo000HooooofX0
oooo00<0P82000000020P800o`3ooom/0?ooo`030820P0000000P8200?l0ooood`3ooolJooooo`00
6?oooomZ0?ooo`030820P0000000P8200?l0ooooK03oool00`20P80000000820P03o0?ooom<0oooo
6_ooool001SoooooJP3oool00`20P80000000820P03o0?ooof`0oooo00<0P82000000020P800o`3o
oooC0?oooa[ooooo000HooooofX0oooo00<0P82000000020P800o`3ooom/0?ooo`030820P0000000
P8200?l0ooood`3ooolJooooo`006?oooomX0?ooo`050<30`020P800@41000000010@400o`20P81/
0820P0030410@0000000P8200?l0ooood`3ooolJooooo`006?oooomX0?ooo`030820P00000000000
0?l00000L00000000`20P800oooo0?ooo`3o0?ooom40oooo6_ooool001SoooooJ03oool00`20P800
00000000003o00000700000000<0P8200?ooo`3oool0o`3ooooA0?oooa[ooooo000HooooofP0oooo
00<0P820000000000000o`00001`000000030820P03oool0oooo0?l0ooood@3ooolJooooo`006?oo
oomX0?ooo`030820P000000000000?l00000L00000000`20P800oooo0?ooo`3o0?ooom40oooo6_oo
ool001SoooooJ03oool00`20P80000000000003o00000700000000<0P8200?ooo`3oool0o`3ooooA
0?oooa[ooooo000HooooofP0oooo00<0P820000000000000o`00001`000000030820P03oool0oooo
0?l0ooood@3ooolJooooo`006?oooomX0?ooo`030820P000000000000?l00000L00000000`20P800
oooo0?ooo`3o0?ooom40oooo6_ooool001SoooooJ03oool00`20P80000000000003o000007000000
00<0P8200?ooo`3oool0o`3ooooA0?oooa[ooooo000HooooofP0oooo00<0P820000000000000o`00
001`000000030820P03oool0oooo0?l0ooood@3ooolJooooo`006?oooomX0?ooo`030<30`020P800
P8200=h0P8200P00002?0820P0030<30`03oool0oooo0?l0ooood@3ooolJooooo`006?oooooo0?oo
odX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0
ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oo
oooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o
0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJoooo
o`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo
0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03o
oolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?oo
odX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0
ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oo
oooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o
0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJoooo
o`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo
0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03o
oolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?oo
odX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0
ooooI03ooolJooooo`006?oooooo0?ooodX0oooo0P00003o0?ooool0ooooI03ooolJooooo`006?oo
ooo30?ooo`030820P010@400000000<0000000<0EEEE0?ooo`3oool0O@3oool200000?l0ooooo`3o
oomT0?oooa[ooooo000Hoooool40oooo00<0`<300000000000001`0000000`30`<00oooo0?ooo`1k
0?ooo`800000o`3ooooo0?ooof@0oooo6_ooool001Sooooo`@3oool3000000030820P03oool0oooo
0080oooo00@0EEEE000000000000`<30O03oool200000?l0ooooo`3ooomT0?oooa[ooooo000Hoooo
ol00oooo00@0P820000000000000`<301P3oool00`20P80000000000001l0?ooo`800000o`3ooooo
0?ooof@0oooo6_ooool001Sooooo`03oool00`30`<00P8200820P0080?ooo`80000000<0P8200?oo
o`3oool0N@3oool200000?l0ooooo`3ooomT0?oooa[ooooo000Hoooool/0oooo00<0P82000000000
0000N`3oool200000?l0ooooo`3ooomT0?oooa[ooooo000Hoooool/0oooo00<0P820000000000000
N`3oool200000480oooo3P0000000`20P800oooo0?ooo`3o0?ooool0oooo4@3ooolJooooo`006?oo
ooo;0?ooo`030820P0000000000007/0oooo0P0000120?ooo`h0000000<0P8200?ooo`3oool0o`3o
oooo0?oooa40oooo6_ooool001Sooooob`3oool2000000030410@03oool0oooo07T0oooo0P000012
0?ooo`80000000<0P8200?ooo`3oool0o`3ooooo0?oooad0oooo6_ooool001SooooobP3oool01010
@400000000000020P81k0?ooo`800000@P3oool2000000030820P03oool0oooo0?l0ooooo`3ooolM
0?oooa[ooooo000HooooolT0oooo00@0EEEE000000000000@410O03oool200000480oooo00<0P820
000000000000o`3ooooo0?oooal0oooo6_ooool001Sooooo``3oool01@30`<00P8200820P020P800
@41000<0000000<0@4100?ooo`3oool0N`3oool2000004<0oooo0P0000000`20P800oooo0?ooo`3o
0?ooool0oooo703ooolJooooo`006?ooooo30?ooo`030820P0000000000000<0000000<0EEEE0<30
`03oool0O@3oool2000004<0oooo00@0P820000000000000`<30o`3ooooo0?oooad0oooo6_ooool0
01Sooooo``3oool01@30`<00P8200820P020P800@4100080000000<0@4100<30`03oool0O03oool2
000004@0oooo00@0@410000000000000`<30o`3ooooo0?oooa`0oooo6_ooool001Sooooob@3oool0
101EEED0000000000030`<1l0?ooo`800000A@3oool01010@400000000000030`<3o0?ooool0oooo
6`3ooolJooooo`006?ooooo:0?ooo`030410@0000000@41007`0oooo0P0000160?ooo`040410@000
000000000410@?l0ooooo`3ooolJ0?oooa[ooooo000HooooolX0oooo00@0`<30000000000000`<30
N`3oool2000004L0oooo00D0`<3000000000000000000<30`03o0?ooool0oooo603ooolJooooo`00
6?ooooo;0?ooo`80000000<0P8200?ooo`3oool0N@3oool2000004P0oooo00D0`<300410@0000000
00000410@03o0?ooool0oooo5`3ooolJooooo`006?ooooo00?ooo`030<30`020P800P82000P0oooo
0P0000000`20P800oooo0?ooo`1i0?ooo`800000BP3oool01010@400000000000010@43o0?ooool0
oooo5P3ooolJooooo`006?ooooo00?ooo`040820P000000000000<30`0H0oooo00@0P82000000000
0000`<30N`3oool2000004/0oooo00@0@410000000000000@410o`3ooooo0?oooaD0oooo6_ooool0
01Sooooo`@3oool0100[:b/000000000001EEED40:ZZZP0403Ti>@00000000000820P7`0oooo0P00
001<0?ooo`040820P000000000000:ZZZ_l0ooooo`3ooolD0?oooa[ooooo000Hoooool80oooo00<0
P8200000000000001P0000000`30`<00oooo0?ooo`1k0?ooo`800000C@3oool00`10@40000000000
003o0?ooool0oooo503ooolJooooo`006?ooooo40?ooo`030<30`020P800P8200080P82000<0eMGE
0?ooo`3oool0O@3oool2000004d0oooo00<0P820000000000000o`3ooooo0?oooa@0oooo6_ooool0
01Soooooo`3ooom:0?ooo`800000@P3oool20820P0030<30`03oool0oooo00H0oooo00<0P8200000
00000000o`3ooooo0?oooa@0oooo6_ooool001Soooooo`3ooom:0?ooo`800000@P3oool200000003
0410@03oool0oooo00D0oooo00@0`<30000000000000P820o`3ooooo0?oooa@0oooo6_ooool001So
ooooo`3ooom:0?ooo`800000@P3oool01@30`<00000000000010@400`<3000<0oooo00<0`<300820
P00000000P00003o0?ooool0oooo5@3ooolJooooo`006?oooooo0?ooodX0oooo0P0000130?ooo`03
0<30`0000000000000P0000000<0`<300?ooo`3oool0o`3ooooo0?oooa<0oooo6_ooool001Sooooo
o`3ooom:0?ooo`800000A@3oool00`20P800000000000003000000030410@020P800oooo0?l0oooo
o`3ooolF0?oooa[ooooo000Hooooool0ooooBP3oool200000?l0ooooo`3ooomT0?oooa[ooooo000H
ooooool0ooooo`3ooooo0?oook00oooo6_ooool001Soooooo`3ooooo0?ooool0oooo/03ooolJoooo
o`006?oooooo0?ooool0ooooo`3ooon`0?oooa[ooooo000Hooooool0ooooo`3ooooo0?oook00oooo
6_ooool001Soooooo`3ooooo0?ooool0oooo/03ooolJooooo`006?oooooo0?ooool0ooooo`3ooon`
0?oooa[ooooo003ooooooooooooooooooooRooooo`00ooooooooooooooooooooh_ooool00?oooooo
ooooooooooooon;ooooo003ooooooooooooooooooooRooooo`00ooooooooooooooooooooh_ooool0
0?ooooooooooooooooooon;ooooo003ooooooooooooooooooooRooooo`00oooooooooooooooooooo
h_ooool00?ooooooooooooooooooon;ooooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{330.438, 137.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 9.4", "Caption",
  CellTags->"Fig. 9.4"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Find the current ",
  Cell[BoxData[
      \(TraditionalForm\`I\_1\)]],
  " running through resistor ",
  Cell[BoxData[
      \(TraditionalForm\`R\_1\)]],
  " in the circuit of Fig. ",
  ButtonBox["9.5",
    ButtonData:>"Fig. 9.5",
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P00038R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo001E0?ooool00000=000003o0?ooomT0oooo001E0?ooool00000=00000020820
P3X0oooo0`20P80j0?ooo`80P820>P3oool00`30`<00P8200820P00j0?ooo`030<30`020P800oooo
0><0oooo001E0?ooo`040820P000000000000820P?l0oooo;`3oool01020P800000000000020P80h
0?ooo`D00000>03oool4000003T0oooo1000000i0?ooocH00000/03oool005D0oooo00@0P8200000
00000000P820o`3oool_0?ooo`@00000=`3oool00`20P800000000000003000000030820P03oool0
oooo03@0oooo00<0P8200000000000000`00000g0?ooo`H00000=`3ooolg00000;00oooo001E0?oo
o`040820P000000000000820P?l0oooo2`3oool300000240oooo00<0`<300000000000000P000000
0`20P800oooo0?ooo`0b0?ooo`030820P0000000000000D0000000<0P8200?ooo`3oool0<P3oool0
0`20P800000000000004000000030410@03oool0oooo0380oooo00<0`<300000000000001@000000
0`10@400oooo0?ooo`0b0?ooo`030<30`0000000000003H00000/03oool005D0oooo00@0P8200000
00000000P820o`3oool;0?ooo`<000008`3oool4000000030820P03oool0oooo0300oooo1@000000
0`3oool0000000000002000000030820P03oool0oooo0300oooo00<0P8200000000000000P000000
0`20P800000000000002000003<0oooo100000000`3oool0P82000000003000003<0oooo1000003U
0?ooo`00E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00000T0?ooo`050410@0000000
000000000020P800<03oool01@10@4000000000000000000P82000<0oooo00D0P820000000000000
00000820P00`0?ooo`050820P0000000000000000020P8000P3oool00`20P8000000000000020000
00030<30`03oool0oooo02d0oooo00<0P8200000000000000P0000001030`<00oooo0?ooo`20P804
000000030<30`03oool0oooo02d0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0b
0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<000009@3oool5
000002h0oooo100000000`20P800oooo0?ooo`030?ooo`030820P0000000000000800000;P3oool4
000000030820P03oool0oooo00<0oooo1000000^0?ooo`030820P00000000000008000001P3oool4
000002h0oooo00<0P8200000000000000P00000f0?ooo`<00000[P3oool005D0oooo00@0P8200000
00000000P820o`3oool;0?ooo`<000009P3oool4000000030820P03oool0oooo02X0oooo1@000007
0?ooo`@0000000<0P8200?ooo`3oool0:P3oool00`20P800000000000002000000H0oooo00<0P820
0000000000000P00000]0?ooo`@000001`3oool00`20P800000000000002000002d0oooo1000000g
0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<000009`3oool0
1@10@4000000000000000000P82002X0oooo00D0@41000000000000000000820P0090?ooo`050410
@0000000000000000020P800:P3oool01@20P8000000000000000000@41000P0oooo00D0P8200000
0000000000000410@00Z0?ooo`030820P000000000000080000000<0`<300?ooo`3oool01P3oool0
0`20P800000000000002000000030<30`03oool0oooo02L0oooo00<0`<300000000000000P000000
0`30`<00oooo0?ooo`0e0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;
0?ooo`<00000:03oool5000002P0oooo100000000`20P800oooo0?ooo`090?ooo`D00000:03oool5
000000/0oooo1000000X0?ooo`030820P0000000000000800000303oool4000002T0oooo1000000i
0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000:@3oool4
000000030820P03oool0oooo02@0oooo00<0P8200000000000000P00000=0?ooo`@0000000<0P820
0?ooo`3oool0903oool00`20P800000000000002000000`0oooo00<0P8200000000000000P00000W
0?ooo`@000003@3oool00`20P800000000000002000002L0oooo1000000j0?ooo`<00000[P3oool0
05D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000:P3oool01@10@400000000000000
0000P82002@0oooo00D0P82000000000000000000820P00?0?ooo`050410@0000000000000000020
P800903oool01@20P8000000000000000000@41000h0oooo00D0P82000000000000000000410@00T
0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0303oool00`20P800000000000002
000000030<30`03oool0oooo0240oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0h
0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000:`3oool4
000000030820P03oool0oooo0200oooo100000000`20P800oooo0?ooo`0?0?ooo`D000008P3oool5
00000100oooo00<0P8200000000000000P00000R0?ooo`030820P00000000000008000004P3oool4
000002<0oooo1000000l0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;
0?ooo`<00000;03oool400000240oooo00<0P8200000000000000P00000C0?ooo`@0000000<0P820
0?ooo`3oool07P3oool00`20P80000000000000200000180oooo1@00000Q0?ooo`@000004`3oool0
0`20P80000000000000200000240oooo100000000`20P800oooo0?ooo`0j0?ooo`<00000[P3oool0
05D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000;@3oool01@10@400000000000000
0000P82001h0oooo00D0P82000000000000000000410@00E0?ooo`050410@0000000000000000020
P8007P3oool01@20P8000000000000000000@41001@0oooo00D0P82000000000000000000410@00N
0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool04P3oool01@20P800000000000000
0000@41001h0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0k0?ooo`<00000[P3o
ool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000;P3oool5000001`0oooo1@00
000G0?ooo`D0000000<0P8200?ooo`3oool06@3oool5000001H0oooo00<0P8200000000000000`00
000L0?ooo`@00000603oool5000001`0oooo1000000o0?ooo`<00000[P3oool005D0oooo00@0P820
000000000000P820o`3oool;0?ooo`<00000;`3oool5000001X0oooo1@00000I0?ooo`D000006P3o
ool5000001P0oooo1@0000000`20P800oooo0?ooo`0G0?ooo`D000006@3oool00`20P80000000000
0002000000030820P03oool0oooo01L0oooo1@0000000`20P800oooo0?ooo`0m0?ooo`<00000[P3o
ool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000;`3oool00`30`<00P8200000
0003000000030<30`03oool0oooo01@0oooo00<0P8200000000000000P0000000`10@400oooo0?oo
o`0I0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0503oool00`30`<0000000000
0002000000030410@03oool0oooo01P0oooo00<0P8200410@00000000P0000000`20P800oooo0?oo
o`0E0?ooo`030410@000000000000080000000<0`<300?ooo`3oool0603oool00`20P800@4100000
0002000000030820P03oool0oooo01D0oooo00<0@4100000000000000P0000000`20P800oooo0?oo
o`0n0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000<P3o
ool4000001D0oooo00<0P8200000000000000P00000O0?ooo`@000005P3oool4000001h0oooo1@00
000E0?ooo`@0000000<0P8200?ooo`3oool0703oool5000001D0oooo100000000`20P800oooo0?oo
o`100?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000<P3o
ool00`30`<00000000000002000000030820P03oool0oooo0100oooo00D0P8200000000000000000
0410@00Q0?ooo`050410@0000000000000000020P8004P3oool01@20P8000000000000000000@410
0200oooo00D0P82000000000000000000410@00B0?ooo`030<30`000000000000080000000<0P820
0?ooo`3oool07P3oool01@20P8000000000000000000@4100180oooo00<0`<300000000000000P00
00000`20P800oooo0?ooo`110?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3o
ool;0?ooo`<00000=03oool4000000030820P03oool0oooo00h0oooo1@00000S0?ooo`@0000000<0
P8200?ooo`3oool03P3oool00`20P80000000000000200000280oooo00<0P8200000000000000P00
000A0?ooo`@000008`3oool00`20P80000000000000200000140oooo100000150?ooo`<00000[P3o
ool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000=@3oool4000000l0oooo00<0
P8200000000000000P00000U0?ooo`@00000403oool4000002@0oooo100000000`20P800oooo0?oo
o`0=0?ooo`@0000000<0P8200?ooo`3oool08P3oool5000000l0oooo100000000`20P800oooo0?oo
o`130?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000=@3o
ool00`30`<00000000000002000000030820P03oool0oooo00X0oooo00D0P8200000000000000000
0410@00V0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool02P3oool00`20P8000000
00000002000000030<30`03oool0oooo02<0oooo00D0P82000000000000000000820P00<0?ooo`03
0<30`000000000000080000000<0P8200?ooo`3oool0903oool01@20P8000000000000000000@410
00d0oooo00D0@41000000000000000000820P0160?ooo`<00000[P3oool005D0oooo00@0P8200000
00000000P820o`3oool;0?ooo`<00000=`3oool4000000030820P03oool0oooo00P0oooo00<0P820
0000000000000P00000Y0?ooo`@0000000<0P8200?ooo`3oool0203oool00`20P800000000000002
000002P0oooo00<0P8200000000000000P00000;0?ooo`@00000:@3oool00`20P800000000000002
000000/0oooo100000180?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;
0?ooo`<00000>03oool4000000X0oooo1000000[0?ooo`@000002P3oool4000002X0oooo10000000
0`20P800oooo0?ooo`070?ooo`@0000000<0P8200?ooo`3oool0:03oool4000000030820P03oool0
oooo00L0oooo100000000`20P800oooo0?ooo`160?ooo`<00000[P3oool005D0oooo00@0P8200000
00000000P820o`3oool;0?ooo`<00000>03oool00`30`<00000000000002000000030<30`03oool0
oooo00@0oooo00D0P82000000000000000000410@00/0?ooo`030<30`000000000000080000000<0
P8200?ooo`3oool0103oool00`20P800000000000002000000030<30`03oool0oooo02T0oooo00D0
@41000000000000000000820P0070?ooo`050410@0000000000000000020P800;03oool01@20P800
0000000000000000P82000L0oooo00D0@41000000000000000000820P0190?ooo`<00000[P3oool0
05D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000>P3oool4000000D0oooo00<0P820
0000000000000P00000_0?ooo`@0000000<0P8200?ooo`3oool00P3oool00`20P800000000000002
000002h0oooo1@0000050?ooo`@00000;`3oool00`20P800000000000002000000D0oooo10000000
0`20P800oooo0?ooo`180?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;
0?ooo`<00000>`3oool4000000@0oooo1000000a0?ooo`@00000103oool400000300oooo10000000
1020P800oooo0?ooo`3oool4000000030820P03oool0oooo02h0oooo100000001020P800oooo0?oo
o`3oool5000004/0oooo0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?ooo`/0oooo
0`00000k0?ooo`030<30`000000000000080000000<0`<300820P00000000`0000000`30`<00oooo
0?ooo`0_0?ooo`030<30`000000000000080000000<0`<300820P00000000`0000000`30`<00oooo
0?ooo`0_0?ooo`070410@0000000000000000020P800oooo0410@003000000030820P03oool0oooo
0300oooo00L0@41000000000000000000820P03oool0@41000<0000000<0P8200?ooo`3oool0BP3o
ool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo2`3oool3000003d0oooo2000
000e0?ooo`P00000=03oool8000000030820P03oool0oooo0380oooo200000000`20P800oooo0?oo
o`1;0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000?@3o
ool00`30`<00000000000003000000030410@03oool0oooo03D0oooo00<0@4100000000000000P00
00000`10@400oooo0?ooo`0d0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0=03o
ool00`20P800000000000003000000030820P03oool0oooo04`0oooo0`00002^0?ooo`00E@3oool0
1020P800000000000020P83o0?ooo`/0oooo0`00000o0?ooo`@00000>@3oool4000003P0oooo00@0
P8200000000000000000>@3oool01020P800000000000000001@0?ooo`<00000[P3oool005D0oooo
00@0P820000000000000P820o`3oool;0?ooo`<00000@03oool2000003/0oooo0P00000j0?ooo`80
000000<0P8200?ooo`3oool0>03oool2000000030820P03oool0oooo04h0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00003o0?ooodX0oooo0`00002^0?ooo`00
E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00002j0?ooo`D00000RP3oool300000:h0
oooo001E0?ooo`040820P000000000000820P?l0oooo2`3oool300000;T0oooo1`0000000`20P800
oooo0?ooo`260?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<0
0000]`3oool01@20P800000000000020P800`<300080oooo00@0`<300820P0000000P820Q`3oool3
00000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo2`3oool300000;L0oooo0P000007
0?ooo`030820P0000000000008H0oooo0`00002^0?ooo`00E@3oool01020P800000000000020P83o
0?ooo`/0oooo0`00002f0?ooo`<000001`3oool00`20P8000000000000260?ooo`<00000[P3oool0
05D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000]@3oool01020P800000000000020
P8080?ooo`80000000<0P8200?ooo`3oool0P`3oool300000:h0oooo001E0?ooo`040820P0000000
00000820P?l0oooo2`3oool300000;D0oooo00@0P820000000000000P820203oool3000008D0oooo
0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00002e0?ooo`<00000
2@3oool3000008D0oooo0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?ooo`/0oooo
0`00002e0?ooo`<000002@3oool3000008D0oooo0`00002^0?ooo`00E@3oool01020P80000000000
0020P83o0?ooo`/0oooo0`00002e0?ooo`<000002@3oool3000008D0oooo0`00002^0?ooo`00E@3o
ool01020P800000000000020P83o0?ooo`/0oooo0`00002e0?ooo`<00000203oool01020P8000000
0000000000250?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<0
0000UP3oool<000000030820P03oool0oooo00H0oooo2@000000103oool000000000000000080?oo
o`<0000000<0P8200?ooo`3oool0P`3oool300000:h0oooo001E0?ooo`040820P000000000000820
P?l0oooo2`3oool3000009T0oooo1P0000000`20P800oooo0?ooo`090?ooo`L000000`3oool30000
00P0oooo0`0000000`20P800oooo0?ooo`230?ooo`<00000[P3oool005D0oooo00@0P82000000000
0000P820o`3oool;0?ooo`<00000V@3oool00`30`<00000000000002000000030820P03oool0oooo
00T0oooo00<0@4100000000000000P0000000`20P800oooo0?ooo`030?ooo`050820P00000000000
0410@020P800103oool01@20P8000000000000000000P82008H0oooo0`00002^0?ooo`00E@3oool0
1020P800000000000020P83o0?ooo`/0oooo0`00002J0?ooo`@000002`3oool5000000L0oooo00@0
P820000000000000P820200000280?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820
o`3oool;0?ooo`<00000VP3oool4000000/0oooo100000000`20P800oooo0?ooo`060?ooo`800000
00@0P8200?ooo`3oool0P820100000290?ooo`<00000[P3oool005D0oooo00@0P820000000000000
P820o`3oool;0?ooo`<00000VP3oool4000000T0oooo00<0`<300000000000000P0000000`20P800
oooo0?ooo`070?ooo`<00000T03oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0
oooo2`3oool3000009X0oooo100000090?ooo`030820P00000000000008000002`3oool3000008l0
oooo0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00002J0?ooo`@0
0000203oool01@20P8000000000000000000@41000d0oooo0P0000000`20P800oooo0?ooo`2<0?oo
o`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000VP3oool40000
00L0oooo1@00000>0?ooo`040820P000000000000820P8d0oooo0`00002^0?ooo`00E@3oool01020
P800000000000020P83o0?ooo`/0oooo0`00002J0?ooo`@000001`3oool5000000l0oooo0`00002=
0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`<00000VP3oool4
000000H0oooo00D0@41000000000000000000820P00A0?ooo`040820P010@40000000820P8/0oooo
0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?ooo`/0oooo0`00002J0?ooo`@00000
1P3oool4000001@0oooo0`00002:0?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820
o`3oool;0?ooo`<00000VP3oool4000000D0oooo100000000`20P800oooo0?ooo`0D0?ooo`<00000
R03oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo2`3oool00`20P8000000
0000002J0?ooo`@00000103oool01@10@4000000000000000000P82001T0oooo0`20P8000`30`<00
oooo0?ooo`230?ooo`<00000[P3oool005D0oooo00@0P820000000000000P820o`3oool;0?ooo`04
0820P000000000000820P9T0oooo3000002S0?ooo`<00000[P3oool005D0oooo00@0P82000000000
0000P820o`3oool;0?ooo`@00000V@3oool=00000:80oooo0`00002^0?ooo`00E@3oool01020P800
000000000020P83o0?ooo`/0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`2E0?oo
o`@000001@3oool20820P0@0000000<0P8200<30`03oool0W@3oool300000:h0oooo001E0?ooo`04
0820P000000000000820P?l0oooo3@3oool4000000030820P03oool0oooo09@0oooo100000090?oo
o`@00000WP3oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo3P3oool40000
09H0oooo100000090?ooo`030820P0000000000000800000W@3oool300000:h0oooo001E0?ooo`04
0820P000000000000820P?l0oooo3P3oool00`30`<00000000000002000000030820P03oool0oooo
0980oooo1000000:0?ooo`D00000W03oool300000:h0oooo001E0?ooo`040820P000000000000820
P?l0oooo403oool4000000030820P03oool0oooo0940oooo1000000;0?ooo`@0000000<0P8200?oo
o`3oool0V@3oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo4@3oool01@10
@4000000000000000000P8200980oooo1000000;0?ooo`@0000000<0P8200?ooo`3oool0V@3oool3
00000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo4P3oool4000000030820P03oool0
oooo08l0oooo1000000;0?ooo`@0000000<0P8200?ooo`3oool0V@3oool300000:h0oooo001E0?oo
o`040820P000000000000820P?l0oooo4`3oool400000940oooo1000000;0?ooo`@0000000<0P820
0?ooo`3oool0V@3oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo503oool0
1@10@4000000000000000000P82008l0oooo1000000:0?ooo`030820P000000000000080000000<0
P8200?ooo`3oool0V@3oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo5@3o
ool4000000030820P03oool0oooo08`0oooo1000000:0?ooo`D00000W03oool300000:h0oooo001E
0?ooo`040820P000000000000820P?l0oooo5P3oool4000008h0oooo100000090?ooo`030820P000
0000000000<00000W03oool300000:h0oooo001E0?ooo`040820P000000000000820P?l0oooo5P3o
ool00`30`<00000000000002000000030820P03oool0oooo08X0oooo100000080?ooo`030820P000
000000000080000000<0P8200?ooo`3oool0V`3oool300000:h0oooo001E0?ooo`040820P0000000
00000820P?l0oooo603oool5000008X0oooo00<0P8200000000000000`0000000`20P800oooo0?oo
o`020?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0W03oool300000:h0oooo001E
0?ooo`040820P000000000000820P?l0oooo6@3oool5000008T0oooo4000002P0?ooo`<00000[P3o
ool005D0oooo00@0P820000000000000P820o`3ooolI0?ooo`030<30`020P800000000<0000000<0
`<300?ooo`3oool0PP3ooolA0820P:80oooo0`00002^0?ooo`00E@3oool01020P800000000000020
P83o0?oooa`0oooo1000003o0?ooocP0oooo0`00002^0?ooo`00E@3oool01020P800000000000020
P83o0?oooa`0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`3o0?oooc@0oooo0`00
002^0?ooo`00E@3oool01020P800000000000020P83o0?oooah0oooo100000000`20P800oooo0?oo
o`3o0?oooc<0oooo0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?oooal0oooo1000
003o0?ooocD0oooo0`00002^0?ooo`00E@3oool01020P800000000000020P83o0?oooal0oooo00<0
`<300000000000000P0000000`30`<00oooo0?ooo`3o0?oooc40oooo0`00002^0?ooo`00E@3oool0
1020P800000000000020P83o0?ooob40oooo1000003o0?oooc<0oooo0`00002^0?ooo`00E@3oool0
1020P800000000000020P83o0?ooob80oooo1000003o0?oooc80oooo0`00002^0?ooo`00E@3oool0
1020P800000000000020P83o0?ooob80oooo00<0`<300000000000000P0000000`30`<00oooo0?oo
o`3o0?ooobh0oooo0`00002^0?ooo`00FP3oool00`000000P8200?ooo`3o0?ooob00oooo1000003o
0?oooc00oooo0`00002^0?ooo`00F@3oool300000?l0oooo8@3oool00`20P8000000000000020000
0?l0oooo;`3oool300000:h0oooo001H0?ooo`030<30`000000000000080000000<0`<300?ooo`3o
ool0o`3ooolN0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0o`3oool[0?ooo`<0
0000[P3oool005X0oooo1000003o0?ooob80oooo1000003o0?ooobd0oooo0`00002^0?ooo`00F`3o
ool400000?l0oooo8@3oool00`20P800000000000002000008H0oooo4@00002D0?ooo`<00000[P3o
ool005/0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`3o0?oooah0oooo00D0P820
00000000000000000820P01m0?ooo`040<30`020P800P8200820P1P0000000@0@4100820P020P800
`<30S@3oool300000:h0oooo001M0?ooo`@00000o`3ooolP0?ooo`D00000N`3ooolT000008/0oooo
0`00002^0?ooo`00G@3oool00`30`<00000000000002000000030820P03oool0oooo0?l0oooo6`3o
ool01@10@4000000000000000000P82007T0oooo00<0P8200000000000001P0000040820P0d0oooo
1@20P80900000080P820R03oool300000:h0oooo001O0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oolI0?ooo`@0000000<0P8200?ooo`3oool0MP3oool8000001h0oooo200000260?ooo`<00000[P3o
ool00600oooo1000003o0?oooaX0oooo1@00001g0?ooo`T00000803oool8000008D0oooo0`00002^
0?ooo`00H03oool00`30`<00000000000002000000030820P03oool0oooo0?l0oooo5@3oool01@10
@4000000000000000000P82007H0oooo00<0@410000000000000100000000`20P800`<300?ooo`0S
0?ooo`030<30`020P800000000D000000P20P8210?ooo`<00000[P3oool00680oooo100000000`20
P800oooo0?ooo`3o0?oooa<0oooo100000000`20P800oooo0?ooo`1c0?ooo`P00000:P3oool80000
0800oooo0`00002^0?ooo`00H`3oool400000?l0oooo503oool00`20P800000000000002000005l0
oooo00<0P8200000000000004`3oool6000000030820P03oool0oooo02`0oooo00<0P82000000000
00001000001o0?ooo`<00000[P3oool006<0oooo00<0`<300000000000000P0000000`30`<00oooo
0?ooo`3o0?ooo`l0oooo00D0P82000000000000000000820P01P0?ooo`D0000000<0P8200?ooo`3o
ool02`3oool00`30`<00P82000000003000000030410@020P800oooo0300oooo0P20P80500000003
0410@03oool0oooo07/0oooo0`00002^0?ooo`00I@3oool400000?l0oooo403oool4000000030820
P03oool0oooo05l0oooo2000000;0?ooo`H00000=P3oool7000007/0oooo0`00002^0?ooo`00IP3o
ool400000?l0oooo3P3oool00`20P80000000000000200000680oooo2@0000080?ooo`030820P000
0000000000<00000>@3oool6000000030820P03oool0oooo07P0oooo0`00002^0?ooo`00IP3oool0
1@30`<000000000000000000P8200?l0oooo303oool01@20P8000000000000000000@4100680oooo
300000001030`<00oooo0?ooo`3oool20820P0<000000P20P80k0?ooo`030<30`020P800000000@0
0000N@3oool300000:h0oooo001X0?ooo`<0000000<0P8200?ooo`3oool0o`3oool80?ooo`D00000
H`3oool>000000030?ooo`20P800000000<0000000<0P8200?ooo`3oool0?P3oool5000007P0oooo
0`00002^0?ooo`00J03oool01@30`<000000000000000000P8200?l0oooo203oool01@10@4000000
000000000000P82006<0oooo4`0000000`20P800oooo0?ooo`110?ooo`030820P000000000000080
000000<0P8200?ooo`3oool0M03oool300000:h0oooo001Z0?ooo`@00000o`3oool60?ooo`@00000
00<0P8200?ooo`3oool0HP3ooolB000004H0oooo00<0P8200000000000000`00001e0?ooo`<00000
[P3oool006/0oooo0`0000000`20P800oooo0?ooo`3o0?ooo`40oooo00<0P8200000000000000`00
001T0?ooo`030820P0000000000000l00000B03oool6000007@0oooo0`00002^0?ooo`00J`3oool0
1@30`<000000000000000000P8200?l0oooo0@3oool00`20P800000000000002000000030820P03o
ool0oooo06<0oooo00<0P820000000000000400000000`20P800oooo0?ooo`160?ooo`030410@000
000000000080000000<0P8200?ooo`3oool0L03oool300000:h0oooo001]0?ooo`@00000oP3oool5
000006L0oooo00<0P8200000000000004@0000000`20P800oooo0?ooo`160?ooo`D0000000<0P820
0?ooo`3oool0K`3oool300000:h0oooo001^0?ooo`<0000000<0P8200?ooo`3oool0nP3oool00`20
P800000000000002000006P0oooo5@0000190?ooo`H00000L03oool300000:h0oooo001^0?ooo`05
0<30`0000000000000000020P800nP3oool01@20P8000000000000000000@41006T0oooo5@000000
0`20P800oooo0?ooo`170?ooo`030410@000000000000080000000<0P8200?ooo`3oool0K@3oool3
00000240oooo00<000000?ooo`3oool0RP3oool00700oooo1000003h0?ooo`030820P00000000000
00800000J@3ooolG000000030820P03oool0oooo04P0oooo1000001_0?ooo`<000008@3oool00`00
0000oooo0?ooo`2:0?ooo`00L@3oool3000000030820P03oool0oooo0?D0oooo1000001Z0?oooaL0
0000C03oool4000006h0oooo0`00000Q0?ooo`030000003oool0oooo08X0oooo001a0?ooo`050<30
`0000000000000000020P800m03oool01@20P8000000000000000000@41006X0oooo00<0P8200000
000000004`0000000`20P800oooo0?ooo`1<0?ooo`050820P0000000000000000030`<00K03oool3
00000240oooo00<000000?ooo`3oool0RP3oool007<0oooo0`0000000`20P800oooo0?ooo`0I0?oo
o`030820P03oool0oooo0=@0oooo00<0P8200000000000000P00001[0?oooaD00000D@3oool01020
P800000000000000001/0?ooo`<000008@3oool00`000000oooo0?ooo`2:0?ooo`00M03oool30000
01/0oooo00<0P8200?ooo`3oool0e03oool4000006`0oooo4`0000000`20P800oooo0?ooo`1@0?oo
o`030820P0000000000000800000J`3oool300000240oooo00<000000?ooo`3oool0RP3oool007@0
oooo00D0`<3000000000000000000820P00H0?ooo`0300000020P800oooo0=<0oooo00<0P8200000
000000000P0000000`30`<00oooo0?ooo`1Y0?ooo`030<30`0000000000000l000000P20P81D0?oo
o`050820P0000000000000000020P800JP3oool300000240oooo00<000000?ooo`3oool0RP3oool0
07H0oooo0`0000000`20P800oooo0?ooo`0D0?ooo`80000000<0P8200?ooo`3oool0d@3oool00`20
P800000000000002000006d0oooo00<0P8200000000000003P0000000`20P800oooo0?ooo`1F0?oo
o`<0000000<0P8200?ooo`3oool0I`3oool300000240oooo00<000000?ooo`3oool0RP3oool007@0
oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0C0?ooo`040820P000000000000820
P=80oooo00D0P82000000000000000000410@01^0?ooo`030410@0000000000000d0000000<0P820
0?ooo`3oool0E`3oool01@30`<000000000000000000P82006P0oooo0`00000Q0?ooo`030000003o
ool0oooo08X0oooo001d0?ooo`@000005`3oool3000000030820P03oool0oooo0<l0oooo1@00001_
0?ooo`h0000000<0P8200?ooo`3oool0F`3oool4000006L0oooo0`00000Q0?ooo`030000003oool0
oooo08X0oooo001c0?ooo`@000005`3oool4000000030820P03oool0oooo0<h0oooo00<0P8200000
000000000P00001`0?ooo`h00000GP3oool4000000030820P03oool0oooo06@0oooo0`00000Q0?oo
o`030000003oool0oooo08X0oooo001a0?ooo`030<30`000000000000080000000<0`<300?ooo`3o
ool0503oool00`30`<0000000000000300000=00oooo00@0@410000000000000@410L03oool<0000
00030410@03oool0oooo05l0oooo00D0@41000000000000000000820P01U0?ooo`<000005P3ooolG
00000840oooo001a0?ooo`@00000603oool00`20P80000000000000300000=00oooo00@0P8200000
00000000P820L03oool;000006D0oooo0`00001U0?ooo`<000008@3oool00`000000oooo0?ooo`2:
0?ooo`00L03oool4000000030820P03oool0oooo01H0oooo1P00003@0?ooo`@00000L03oool:0000
06H0oooo1000001T0?ooo`<000008@3oool00`000000oooo0?ooo`2:0?ooo`00KP3oool00`30`<00
000000000002000000030820P03oool0oooo01H0oooo1`00003@0?ooo`030<30`000000000000080
000000<0P8200?ooo`3oool0J`3oool00`20P800000000000005000000030410@020P800oooo06L0
oooo00@0@410000000000000@410H`3oool300000240oooo00<000000?ooo`3oool0RP3oool006h0
oooo1000000I0?ooo`P00000dP3oool4000000030820P03oool0oooo06X0oooo00<0P82000000000
00001@00001Z0?ooo`030820P0000000000000800000HP3oool300000240oooo00<000000?ooo`3o
ool0RP3oool006d0oooo100000000`20P800oooo0?ooo`0F0?ooo`030820P0000000000000L00000
dP3oool4000006`0oooo1`00001/0?ooo`@00000HP3oool300000240oooo00<000000?ooo`3oool0
RP3oool006/0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0G0?ooo`030410@000
0000000000L00000dP3oool00`30`<00000000000002000000030820P03oool0oooo06P0oooo1@00
00000`30`<00oooo0?ooo`1/0?ooo`040820P000000000000410@640oooo0`00000Q0?ooo`030000
003oool0oooo08X0oooo001[0?ooo`@000006`3oool:00000=@0oooo100000000`20P800oooo0?oo
o`1W0?ooo`@00000L@3oool400000600oooo0`00000Q0?ooo`030000003oool0oooo08X0oooo001Y
0?ooo`030820P000000000000080000000<0`<300?ooo`3oool05`3oool00`20P800000000000009
00000=D0oooo00D0@41000000000000000000820P01W0?ooo`<0000000<0`<300?ooo`3oool0L03o
ool00`30`<00000000000002000005l0oooo0`00000Q0?ooo`030000003oool0oooo08X0oooo001X
0?ooo`030820P00000000000008000006`3oool<00000=H0oooo100000000`20P800oooo0?ooo`1T
0?ooo`0300000020P800oooo07@0oooo100000000`20P800oooo0?ooo`1L0?ooo`<000008@3oool0
0`000000oooo0?ooo`2:0?ooo`00J03oool01020P800000000000000000K0?ooo`030820P0000000
000000X00000e`3oool4000006D0oooo00<000000?ooo`3oool0MP3oool4000005h0oooo0`00000Q
0?ooo`030000003oool0oooo08X0oooo001W0?ooo`050820P0000000000000000030`<006`3oool0
0`10@40000000000000;00000=L0oooo00D0@41000000000000000000820P03L0?ooo`050820P000
0000000000000020P800G@3oool300000240oooo00<000000?ooo`3oool0RP3oool006H0oooo00<0
P8200000000000000P00000K0?ooo`l00000f03oool4000000030820P03oool0oooo0=X0oooo1000
001M0?ooo`<00000[P3oool006H0oooo1000000L0?ooo`l00000f@3oool400000=d0oooo1000001L
0?ooo`<00000[P3oool006@0oooo00D0P82000000000000000000410@00K0?ooo`030<30`0000000
000000h00000f@3oool00`30`<00000000000002000000030820P03oool0oooo0=T0oooo00D0P820
00000000000000000820P01K0?ooo`<00000[P3oool006<0oooo00<0P8200000000000000P00000L
0?ooo`030820P0000000000000h00000f`3oool500000=/0oooo1000001K0?ooo`<00000[P3oool0
06<0oooo1000000M0?oooa400000g03oool500000=X0oooo00<0P8200000000000000P00001J0?oo
o`<00000[P3oool00640oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0J0?ooo`03
0820P0000000000000l0000000<0P8200?ooo`3oool0f@3oool00`30`<00P8200000000300000003
0<30`03oool0oooo0=L0oooo100000000`20P800oooo0?ooo`1G0?ooo`<00000[P3oool00600oooo
00<0P8200000000000000P00000M0?ooo`030820P000000000000100000000<0P8200?ooo`3oool0
g03oool400000=X0oooo1000001I0?ooo`<00000[P3oool005l0oooo00D0P8200000000000000000
0410@00N0?ooo`030410@000000000000100000000<0P8200?ooo`3oool0g03oool00`30`<000000
00000002000000030820P03oool0oooo0=L0oooo0`0000000`10@400oooo0?ooo`1F0?ooo`<00000
[P3oool005h0oooo1@00000N0?oooa@0000000<0P8200?ooo`3oool0gP3oool4000000030820P03o
ool0oooo0=H0oooo00@0P8200000000000000000F03oool300000:h0oooo001M0?ooo`030820P000
00000000008000007`3ooolD000000030820P03oool0oooo0=l0oooo1000003H0?ooo`030820P000
0000000000800000E`3oool300000:h0oooo001L0?ooo`050820P0000000000000000010@4007`3o
oolE000000030410@03oool0oooo0=l0oooo00<0`<300000000000000P0000000`30`<00oooo0?oo
o`2X0?ooo`030820P0000000000000`000007P3oool01@20P8000000000000000000P82005H0oooo
0`00002^0?ooo`00F`3oool00`20P800000000000002000001l0oooo00<0P8200000000000005000
003S0?ooo`@00000[03oool>000001h0oooo1000001F0?ooo`<00000[P3oool005/0oooo1000000R
0?oooaD00000i03oool400000:/0oooo00<0P8200000000000002`00000O0?ooo`@00000E@3oool3
00000:h0oooo001I0?ooo`050820P0000000000000000010@400903oool00`30`<0000000000000A
00000>@0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`2X0?ooo`030820P0000000
`<3000L0oooo00@0`<300820P0000000`<307P3oool01@20P8000000000000000000P82005@0oooo
0`00002^0?ooo`00F03oool00`20P800000000000002000002L0oooo00<0P8200000000000003`00
003V0?ooo`@00000[03oool00`000000oooo0?ooo`080?ooo`030820P03oool0oooo01d0oooo1000
001D0?ooo`<00000[P3oool005T0oooo0`00000Z0?oooa000000iP3oool00`20P800000000000002
00000:/0oooo00<0P8200000003oool0:@3oool3000000030820P03oool0oooo0540oooo0`00002^
0?ooo`00F03oool00`30`<00000000000002000000030<30`03oool0oooo02X0oooo3000003W0?oo
o`030820P000000000000080000000<0`<300?ooo`3oool0Z03oool00`20P80000000<30`00X0?oo
o`040410@000000000000410@5<0oooo0`00001Z0?ooo`030410@0000000000000/00000=P3oool0
05X0oooo1000000/0?ooo`<00000lP3oool400000:`0oooo00<000000?ooo`3oool09P3oool01020
P800000000000000001C0?ooo`<00000J`3oool>000003D0oooo001K0?ooo`@00000:`3oool30000
0?80oooo00<0P8200000000000000P00002[0?ooo`030820P0000000oooo02L0oooo1000001B0?oo
o`<00000K03oool=000003D0oooo001K0?ooo`030<30`000000000000080000000<0`<300?ooo`3o
ool09`3oool300000?<0oooo00D0P82000000000000000000820P02Z0?ooo`030<30`0000000@410
02L0oooo00D0P82000000000000000000820P01A0?ooo`<00000K03oool00`30`<0000000820P008
0?ooo`030820P0000000P82003@0oooo001M0?ooo`@00000:@3oool300000?<0oooo1@00002/0?oo
o`030000003oool0oooo02H0oooo100000320?ooo`0300000020P800oooo00P0oooo00<000000?oo
o`3oool0<P3oool005d0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0T0?ooo`04
0820P000000000000820P?80oooo00D0@41000000000000000000820P02D0?ooo`<0P8201P000000
1010@400P8200820P030`<0<0?ooo`030820P0000000P82002L0oooo0`0000000`20P800oooo0?oo
o`0=0?ooogd00000=P3oool00`10@400P8200?ooo`0l0?ooo`00G`3oool4000000030820P03oool0
oooo02<0oooo0`00003b0?ooo`@0000000<0P8200?ooo`3oool0UP3oool00`20P800000000000003
00000140oooo0P00000W0?ooo`040820P00000000000000000l0ooooO@00000g0?ooo`800000?03o
ool00600oooo1000000U0?ooo`<00000l@3oool5000009X0oooo1000000B0?ooo`80000000<0P820
0?ooo`3oool0903oool01020P800000000000000000?0?ooogd00000>03oool00`000000P8200?oo
o`0j0?ooo`00H03oool00`30`<00000000000002000000030820P03oool0oooo0240oooo0`00003`
0?ooo`050410@0000000000000000020P800V`3oool400000180oooo00<0P82000000010@4009`3o
ool400000<@0oooo00<000000820P03oool0>@3oool00680oooo100000000`20P800oooo0?ooo`0P
0?ooo`<00000k`3oool4000000030820P03oool0oooo09X0oooo1000000C0?ooo`800000:03oool4
00000<<0oooo00<0P820000000000000>@3oool006<0oooo1000000Q0?ooo`@00000kP3oool00`20
P800000000000002000009d0oooo1000000C0?ooo`<000009`3oool400000:X0oooo00<0P8200?oo
o`3oool05`3oool2000003T0oooo001S0?ooo`030<30`000000000000080000000<0`<300?ooo`3o
ool07@3oool300000>h0oooo00D0P82000000000000000000820P02N0?ooo`@00000203oool00`00
0000`<300?ooo`080?ooo`<00000:03oool300000:T0oooo0P00000J0?ooo`0300000010@400oooo
03L0oooo001U0?ooo`@000007`3oool300000>d0oooo100000000`20P800oooo0?ooo`2M0?ooo`@0
0000203oool00`000000P8200?ooo`070?ooo`@00000:03oool3000000030820P03oool0oooo0:D0
oooo0`00000K0?ooo`030000003oool0oooo03H0oooo001V0?ooo`@000007P3oool300000<L0oooo
0`00000R0?ooo`030820P0000000000000800000X03oool4000000T0oooo00<000000?ooo`3oool0
1P3oool4000002P0oooo00@0P820000000000000P820Y`3oool4000001X0oooo0P00000g0?ooo`00
IP3oool01@30`<000000000000000000P82001`0oooo00@0`<300000000000000000a`3oool30000
0240oooo00D0P82000000000000000000410@02Q0?ooo`@000002@3oool01010@40000000820P030
`<030?ooo`030820P010@400000000800000:@3oool01030`<00000000000000002V0?ooo`030<30
`000000000000080000000<0P8200?ooo`3oool05`3oool00`10@40000000<30`00f0?ooo`00J03o
ool3000000030820P03oool0oooo01T0oooo00@0P820000000000000P820a`3oool300000200oooo
1@00002R0?ooo`@000002@3oool00`20P800000000000008000000030820P03oool0oooo02P0oooo
0`00002V0?ooo`030820P0000000000000<000006@3oool00`20P80000000820P00f0?ooo`00J03o
ool01@10@4000000000000000000P82001X0oooo00@0P820000000000000P820a`3oool3000001l0
oooo00D0@41000000000000000000820P02S0?ooo`@000002P3oool00`20P8000000000000060000
00030820P03oool0oooo02T0oooo00@0P8200000000000000000Y@3oool3000000040410@0000000
00000<30`0d0oooo00<0`<300?ooo`3oool0203oool00`20P80000000000000f0?ooo`00J@3oool5
000001T0oooo00@0P820000000000000P820a`3oool3000001h0oooo100000000`20P800oooo0?oo
o`2R0?ooo`@000003@3oool4000000030820P03oool0oooo02`0oooo1000002S0?ooo`@0000000@0
P820000000000000P8203@3oool00`20P80000000?ooo`080?ooo`030820P0000000000003H0oooo
001Z0?ooo`@0000000<0P8200?ooo`3oool05P3oool01020P800000000000020P8370?ooo`<00000
7@3oool500000:D0oooo100000110?ooo`<00000X`3oool400000080oooo0P00000=0?ooo`030820
P0000000oooo00P0oooo0`00000f0?ooo`00J`3oool01@10@4000000000000000000P82001L0oooo
00@0P820000000000000P820_03oool00`30`<00P8200820P0080820P0<000000`20P80I0?ooo`05
0410@0000000000000000020P800YP3oool400000440oooo00@0@410000000000000P820X@3oool0
0`20P80000000000000200000080oooo0P00000>0?ooo`0300000010@400oooo00H0oooo00@0P820
000000000000@410=P3oool006`0oooo1@00000F0?ooo`040820P000000000000820P;`0oooo00<0
P8200000000000003P00000H0?ooo`@0000000<0P8200?ooo`3oool0Y@3oool400000440oooo00@0
P820000000000000P820X@3oool4000000@0oooo0P00000>0?ooo`<000000`3oool00`20P8000000
00000002000000030820P03oool0oooo03@0oooo001]0?ooo`@0000000<0P8200?ooo`3oool04`3o
ool3000000030820P03oool0oooo0;X0oooo00<0P8200000000000003P00000G0?ooo`D00000Z03o
ool400000440oooo00@0P8200000000000000000X03oool00`20P800000000000002000000@0oooo
0P00000>0?ooo`/00000=`3oool006h0oooo00D0@41000000000000000000820P00D0?ooo`<00000
_P3oool2000000P0oooo0`00000I0?ooo`050410@0000000000000000020P800Z@3oool400000480
oooo0`0000000`20P800oooo0?ooo`2M0?ooo`040410@00000000000000000D0oooo00<0@4100000
0030`<003@3oool00`30`<00000000000006000000030410@03oool0oooo03H0oooo001_0?ooo`D0
00004`3oool300000;l0oooo00<000000820P03oool01P3oool3000001P0oooo100000000`20P800
oooo0?ooo`2X0?ooo`@00000@`3oool3000009l0oooo0`0000000`20P800oooo0?ooo`030?ooo`03
0820P0000000P8200100oooo00<0P8200000000000000P00000j0?ooo`00L03oool4000000030820
P03oool0oooo0100oooo0`00002O0?ooo`030820P0000000000000X000002@3oool8000000040820
P03oool0oooo000000L0oooo0`00000G0?ooo`030820P0000000000000800000Z`3oool4000004<0
oooo0`00002O0?ooo`<0000000<0P8200?ooo`3oool0103oool2000004l0oooo001a0?ooo`050410
@0000000000000000020P8004@3oool300000:80oooo00<0`<300000000000000`0000000`20P800
oooo0?ooo`090?ooo`030820P00000000000008000000P20P8000`30`<00oooo0?ooo`020?ooo`03
0410@0000000oooo00D0oooo0`00000F0?ooo`050820P0000000000000000020P800[03oool40000
04<0oooo00@0P820000000000000P820W@3oool4000000030<30`03oool0oooo00@0oooo0P00001?
0?ooo`00LP3oool4000000030820P03oool0oooo00h0oooo0`00002T0?ooo`<0000000<0P8200?oo
o`3oool02@3oool5000000030820P03oool0oooo00H0oooo0P0000050?ooo`<000005@3oool40000
00030820P03oool0oooo0:/0oooo100000140?ooo`<00000W03oool5000000P0oooo0P00001>0?oo
o`00L`3oool400000100oooo0`00002T0?ooo`<0000000<0P8200?ooo`3oool0203oool00`20P800
000000000003000000X0oooo00<000000820P03oool00`3oool3000001@0oooo00<0P82000000000
00000P00002^0?ooo`@00000A03oool00`20P80000000000002L0?ooo`@000002@3oool2000004h0
oooo001d0?ooo`050410@0000000000000000020P8003P3oool300000:@0oooo0`0000000`20P800
oooo0?ooo`080?ooo`050410@0000000000000000020P8002`3oool00`20P800@4100?ooo`030?oo
o`<000004`3oool01@20P8000000000000000000@4100:l0oooo100000140?ooo`040820P0000000
00000820P9X0oooo00D0P82000000000000000000820P0090?ooo`030820P0000000000004d0oooo
001e0?ooo`@0000000<0P8200?ooo`3oool02`3oool300000:@0oooo0`0000000`20P800oooo0?oo
o`070?ooo`@0000000<0P8200?ooo`3oool02`3oool00`20P80000000?ooo`020?ooo`<000004P3o
ool500000;00oooo100000150?ooo`<00000VP3oool01020P800000000000000000:0?ooo`030820
P0000000000004d0oooo001d0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool02P3o
ool300000:D0oooo0`0000000`20P800oooo0?ooo`060?ooo`030820P000000000000080000000<0
`<300?ooo`3oool02`3oool00`30`<000000000000020?ooo`<000004@3oool01@10@40000000000
00000000P8200;40oooo100000150?ooo`<0000000<0P8200?ooo`3oool0U`3oool3000000030410
@03oool0oooo00T0oooo0P0000000`20P800oooo0?ooo`1:0?ooo`00M03oool4000000h0oooo0`00
002U0?ooo`<0000000<0P8200?ooo`3oool01@3oool00`20P80000000000000200000140oooo00<0
00000820P03oool00`00000@0?ooo`@0000000<0P8200?ooo`3oool0/03oool4000004H0oooo0`00
002H0?ooo`@0000000<0P8200?ooo`3oool02P3oool2000004`0oooo001c0?ooo`@000003`3oool3
00000:D0oooo0`0000000`20P800oooo0?ooo`050?ooo`@000004`3oool00`000000oooo00000002
000000l0oooo1@00002c0?ooo`@00000AP3oool3000009P0oooo1000000=0?ooo`800000C03oool0
0740oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`0=0?ooo`<00000Y@3oool30000
00030820P03oool0oooo00@0oooo00D0P82000000000000000000410@00C0?ooo`030410@020P800
0000008000003P3oool01@10@4000000000000000000P8200;<0oooo00<0@4100000000000000`00
00000`30`<00oooo0?ooo`120?ooo`040410@000000000000820P9H0oooo00D0P820000000000000
00000820P00=0?ooo`030820P0000000P82004/0oooo001a0?ooo`@000004@3oool300000:D0oooo
0`0000000`20P800oooo0?ooo`030?ooo`030820P00000000000008000005@3oool4000000h0oooo
1000002a0?ooo``0000000<0P8200?ooo`3oool0?`3oool01020P800000000000020P82F0?ooo`04
0820P00000000000000000l0oooo0P00001;0?ooo`00L03oool4000000030820P03oool0oooo00l0
oooo0`00002U0?ooo`<0000000<0P8200?ooo`3oool00`3oool00`20P800000000000002000001H0
oooo0`00000>0?ooo`030820P0000000000000800000oP3oool01020P800000000000000002F0?oo
o`@000003`3oool00`20P80000000000001:0?ooo`00KP3oool00`30`<0000000000000200000003
0820P03oool0oooo0100oooo0`00002U0?ooo`<0000000<0P8200?ooo`3oool00P3oool01@20P800
0000000000000000P82001L0oooo00<0P8200000000000003`3oool00`20P8000000000000020000
00030<30`03oool0oooo0?/0oooo0`00002E0?ooo`040820P0000000000000000100oooo00<0P820
000000000000BP3oool006h0oooo1000000D0?ooo`<00000Y@3oool3000000040820P03oool0oooo
0?ooo`@0000000<0P8200?ooo`3oool0:P3oool400000?d0oooo1000002D0?ooo`@00000403oool0
1020P800000000000020P8190?ooo`00K@3oool4000000030820P03oool0oooo0140oooo0`00002V
0?ooo`/0000000<0P8200?ooo`3oool0:P3oool00`20P80000000000000200000?d0oooo0`000011
0?ooo`<00000C`3oool500000100oooo00@0P8200000000000000000B@3oool006/0oooo00<0`<30
0000000000000P0000000`20P800oooo0?ooo`0B0?ooo`<00000YP3oool3000000030410@020P800
P82000<0P8200`0000020820P0030<30`03oool0oooo02P0oooo00<0P8200000000000000P000000
0`30`<00oooo0?ooo`3i0?ooo`<0000000<0P8200?ooo`3oool0<03oool00`20P80000000000000O
000000030820P03oool0oooo03X0oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`0<
0?ooo`030820P010@400000000<0000000<0P8200?ooo`3oool0A@3oool006/0oooo1000000F0?oo
o`<00000YP3oool3000000030820P03oool0oooo00D0oooo1@00000[0?ooo`@00000o03oool30000
0380oooo00<0P8200000000000007`0000000`20P800oooo0?ooo`0g0?ooo`030820P00000000000
00T000002P3oool00`20P800000000000007000004H0oooo000h0?ooo`80P8201@0000020820P2P0
oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0D0?ooo`<00000YP3oool300000003
0820P03oool0oooo00H0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0W0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool0n03oool3000000030<30`03oool0oooo02l0
oooo00<0`<300820P020P8002`20P80300000140P82000<0`<300?ooo`3oool0W@3oool003/0oooo
0`00000Z0?ooo`030820P0000000000000800000603oool300000:H0oooo0`0000000`20P800oooo
0?ooo`080?ooo`@00000:`3oool400000?X0oooo00@0P820000000000000P820?`3oool300000;40
oooo000k0?ooo`<00000:P3oool01020P800000000000000000I0?ooo`<00000YP3oool300000003
0820P03oool0oooo00P0oooo1000000/0?ooo`@00000n@3oool01020P800000000000020P80o0?oo
o`<00000/@3oool003/0oooo0`00000Y0?ooo`050820P0000000000000000030`<006@3oool30000
0:H0oooo0`0000000`20P800oooo0?ooo`080?ooo`030820P0000000000000800000:`3oool00`30
`<00000000000002000000030<30`03oool0oooo0?D0oooo00@0`<300000000000000000?`3oool3
00000;40oooo000k0?ooo`<00000:03oool00`20P800000000000002000001X0oooo0`00002V0?oo
o`<0000000<0P8200?ooo`3oool0203oool00`20P800000000000002000002d0oooo1000003h0?oo
o`<00000?`3oool300000;40oooo000k0?ooo`<00000:03oool4000001/0oooo0`00002V0?ooo`<0
000000<0P8200?ooo`3oool0203oool00`20P800000000000002000002d0oooo00<0P82000000000
00000P00003g0?ooo`@00000?P3oool300000;40oooo000k0?ooo`<000009P3oool01@20P8000000
000000000000@41001`0oooo0`00002V0?ooo`<0000000<0P8200?ooo`3oool0203oool00`20P800
000000000002000002h0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3d0?ooo`<0
0000?P3oool300000;40oooo000k0?ooo`<000009@3oool00`20P800000000000002000001`0oooo
00@0P820000000000000P820YP3oool3000000030820P03oool0oooo00P0oooo1@00000`0?ooo`D0
0000m@3oool3000003h0oooo0`00002a0?ooo`00>`3oool3000002D0oooo1000000M0?ooo`040820
P000000000000820P:H0oooo0`0000000`20P800oooo0?ooo`080?ooo`@00000<@3oool00`20P800
00000000000300000?@0oooo1000000m0?ooo`<00000/@3oool003/0oooo0`00000S0?ooo`030820
P000000000000080000000<0`<300?ooo`3oool06`3oool01020P800000000000020P82V0?ooo`<0
000000<0P8200?ooo`3oool01P3oool00`20P800000000000002000000030410@03oool0oooo0340
oooo00D0P82000000000000000000410@03d0?ooo`<00000?@3oool300000;40oooo000k0?ooo`<0
00008P3oool00`20P800000000000002000001l0oooo00@0P820000000000000P820YP3oool30000
00030820P03oool0oooo00D0oooo00<0P8200000000000000`00000e0?ooo`030820P00000000000
00800000l`3oool3000003d0oooo0`00002a0?ooo`005@3oool<000000T0oooo2@0000080?ooo`<0
00008P3oool400000200oooo00@0P820000000000000P820Y@3oool6000000D0oooo1P00000g0?oo
o`D00000lP3oool3000000030820P03oool0oooo03X0oooo0`00002a0?ooo`00603oool00`10@400
000000000002000000030410@03oool0oooo00T0oooo00<0P8200000000000000P0000000`10@400
P8200820P00:0?ooo`<00000803oool00`20P800000000000002000000030<30`03oool0oooo01h0
oooo00@0P820000000000000P820X@3oool01030`<00P8200820P010@40=00000080P82000<0`<30
0?ooo`3oool0=`3oool01@20P8000000000000000000@4100?40oooo00@0P820000000000000P820
?03oool300000;40oooo000I0?ooo`@000002`3oool00`20P800000000000003000000d0oooo0`00
000O0?ooo`030820P00000000000008000008P3oool01020P800000000000020P83_0?ooo`030820
P0000000000000800000l03oool01020P800000000000000000l0?ooo`<00000/@3oool001T0oooo
1000000;0?ooo`@0000000<0P8200?ooo`3oool0303oool3000001h0oooo00D0P820000000000000
00000410@00S0?ooo`040820P000000000000820P?00oooo00D0P82000000000000000000410@03`
0?ooo`<00000?03oool300000;40oooo000I0?ooo`@000002P3oool4000000030820P03oool0oooo
00d0oooo0`00000M0?ooo`030820P0000000000000800000903oool01020P800000000000020P83b
0?ooo`@00000k`3oool3000003`0oooo0`00002a0?ooo`006@3oool4000000T0oooo00<0P8200000
000000000P00000@0?ooo`<000007@3oool4000002D0oooo00@0P820000000000000P820lP3oool0
0`20P80000000000000200000>h0oooo1000000k0?ooo`<00000/@3oool001T0oooo100000090?oo
o`050410@0000000000000000020P800403oool3000001/0oooo00D0P82000000000000000000410
@00V0?ooo`040820P000000000000820P?<0oooo00D0P82000000000000000000410@03^0?ooo`<0
0000>`3oool3000000h0oooo5@00002>0?ooo`006@3oool4000000P0oooo1000000B0?ooo`<00000
6P3oool00`20P800000000000002000002L0oooo00@0P820000000000000P820m03oool00`20P800
00000000000200000>d0oooo0`00000k0?ooo`<000003P3ooolE000008h0oooo000I0?ooo`@00000
1`3oool4000000030820P03oool0oooo0100oooo0`00000J0?ooo`030820P0000000000000800000
9`3oool01020P800000000000020P83e0?ooo`D00000k03oool4000003X0oooo0`00000>0?oooaD0
0000SP3oool001T0oooo100000060?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0
403oool3000001/0oooo00D0P82000000000000000000410@00V0?ooo`<00000m`3oool01@20P800
0000000000000000@4100>`0oooo0`00000j0?ooo`<00000/@3oool001T0oooo100000060?ooo`@0
0000403oool2000000030?ooo`0000000000008000007@3oool4000002D0oooo0`00003h0?ooo`03
0820P0000000000000800000j`3oool3000003X0oooo0`00002a0?ooo`006@3oool4000000H0oooo
1000000A0?ooo`H000007@3oool00`20P800000000000002000002@0oooo0`00003i0?ooo`D00000
jP3oool3000000030820P03oool0oooo03L0oooo0`00002a0?ooo`006@3oool4000000@0oooo00<0
P8200000000000000P0000000`30`<00oooo0?ooo`0A0?ooo`80P82000<0@4100000003oool07@3o
ool01@20P8000000000000000000@41002<0oooo0`00003i0?ooo`050820P0000000000000000020
P800jP3oool01020P800000000000020P80i0?ooo`<00000/@3oool001T0oooo100000030?ooo`03
0820P0000000000000800000>03oool00`20P80000000000000200000280oooo0`00003h0?ooo`03
0820P0000000000000800000j`3oool01020P800000000000020P80i0?ooo`<00000/@3oool001T0
oooo300000000`20P800oooo0?ooo`0f0?ooo`030820P000000000000080000000<0`<300?ooo`3o
ool07P3oool300000?L0oooo00D0P82000000000000000000410@03]0?ooo`<00000>@3oool30000
0;40oooo000I0?ooo`@000001@3oool6000003P0oooo1000000P0?ooo`<00000mP3oool500000>h0
oooo0`00000i0?ooo`<00000/@3oool001T0oooo100000070?ooo`D00000=`3oool00`20P8000000
00000002000001l0oooo0`00003e0?ooo`030820P0000000000000800000k`3oool3000003T0oooo
0`00002a0?ooo`006@3oool4000000T0oooo00D0@41000000000000000000820P00f0?ooo`030820
P000000000000080000000<0`<300?ooo`3oool06`3oool300000?@0oooo00D0P820000000000000
00000410@03`0?ooo`<00000>@3oool300000;40oooo000I0?ooo`@000002P3oool4000000030820
P03oool0oooo03D0oooo1000000M0?ooo`<00000l`3oool00`20P80000000000000200000?80oooo
0`00000h0?ooo`<00000/@3oool001T0oooo1000000:0?ooo`@0000000<0P8200?ooo`3oool0=@3o
ool00`20P800000000000002000001`0oooo0`00003c0?ooo`@00000l`3oool3000003P0oooo0`00
002a0?ooo`006@3oool4000000/0oooo1000000h0?ooo`050820P0000000000000000010@4006`3o
ool300000?40oooo00D0P82000000000000000000410@03d0?ooo`<00000>03oool300000;40oooo
000I0?ooo`@000002`3oool4000003X0oooo1000000J0?ooo`<00000l03oool00`20P80000000000
000200000?D0oooo0`00000h0?ooo`<00000/@3oool001T0oooo1000000;0?ooo`@00000>P3oool0
0`20P800000000000002000001T0oooo0`00003`0?ooo`@00000m`3oool2000000030820P03oool0
oooo03D0oooo0`00002a0?ooo`006@3oool4000000/0oooo1000000k0?ooo`050820P00000000000
00000010@400603oool300000>h0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`3e
0?ooo`80000000<0P8200?ooo`3oool0=@3oool300000;40oooo000I0?ooo`@000002P3oool50000
03`0oooo00<0P8200000000000000P00000G0?ooo`<00000k@3oool00`20P8000000000000020000
0?T0oooo0P0000000`20P800oooo0?ooo`0e0?ooo`<00000/@3oool001T0oooo100000090?ooo`03
0<30`000000000000080000000<0P8200?ooo`3oool0>`3oool00`20P80000000000000200000003
0<30`03oool0oooo01<0oooo0`00003/0?ooo`050820P0000000000000000010@400nP3oool20000
00030410@03oool0oooo03D0oooo0`00002a0?ooo`006@3oool4000000T0oooo1@0000100?ooo`@0
00005@3oool300000>X0oooo00<0P8200000000000000`00003k0?ooo`030820P0000000000003L0
oooo0`00002a0?ooo`006@3oool4000000P0oooo1@0000110?ooo`030820P0000000000000800000
4`3oool300000>/0oooo1@00003l0?ooo`030820P0000000000003L0oooo0`00002a0?ooo`00603o
ool00`10@400000000000003000000D0P82000<0@4100000000000000P0000000`20P800oooo0?oo
o`110?ooo`030820P000000000000080000000<0`<300?ooo`3oool03`3oool300000>T0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`3k0?ooo`030820P0000000000003L0oooo0`00
002a0?ooo`005@3ooolA000004P0oooo1000000A0?ooo`<00000j03oool00`20P800000000000002
00000?l0oooo00<0P820000000000000=`3oool300000;40oooo001^0?ooo`030820P00000000000
00800000403oool300000>P0oooo1000003o0?ooo`40oooo00@0P8200000000000000000=P3oool3
00000;40oooo001_0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0303oool30000
0>H0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`3o0?ooo`<00000=P3oool30000
0;40oooo001a0?ooo`@000003P3oool300000>H0oooo1000003o0?ooocd0oooo0`00002a0?ooo`00
L@3oool00`20P800000000000002000000d0oooo0`00003U0?ooo`@00000o`3oooln0?ooo`<00000
/@3oool00780oooo00D0P82000000000000000000410@00<0?ooo`<00000h`3oool00`30`<000000
00000002000000030<30`03oool0oooo0?l0oooo?03oool300000;40oooo001d0?ooo`@000002`3o
ool300000><0oooo1000003o0?oood00oooo0`00002a0?ooo`00M03oool00`20P800000000000002
000000X0oooo0`00003R0?ooo`@0000000<0P8200?ooo`3oool0o`3oooln0?ooo`<00000/@3oool0
07D0oooo00D0P82000000000000000000<30`0090?ooo`<00000h03oool00`30`<00000000000002
000000030820P03oool0oooo0?l0oooo?`3oool300000;40oooo001e0?ooo`@0000000<0P8200?oo
o`3oool01`3oool300000>00oooo1000003o0?oood<0oooo0`00002a0?ooo`00M03oool01@10@400
0000000000000000P82000X0oooo0`00003N0?ooo`030820P000000000000080000000<0`<300?oo
o`3oool0o`3ooom10?ooo`<00000/@3oool007<0oooo1000000<0?ooo`<00000g@3oool00`20P800
00000000000200000?l0ooooA@3oool300000;40oooo001b0?ooo`@0000000<0P8200?ooo`3oool0
2P3oool300000=d0oooo1000003o0?ooodH0oooo0`00002a0?ooo`00L@3oool01@10@40000000000
00000000P82000d0oooo0`00003M0?ooo`040820P000000000000820P?l0ooooAP3oool300000;40
oooo001`0?ooo`@0000000<0P8200?ooo`3oool0303oool300000=d0oooo1000003o0?ooodH0oooo
0`00002a0?ooo`00K`3oool5000000l0oooo0`00003M0?ooo`030820P0000000000000800000o`3o
oom50?ooo`<00000/@3oool006h0oooo00D0@41000000000000000000820P00@0?ooo`<00000gP3o
ool00`20P800000000000002000000030<30`03oool0oooo0?l0oooo@@3oool300000;40oooo001]
0?ooo`@0000000<0P8200?ooo`3oool03`3oool300000>00oooo1000003o0?oood<0oooo0`00002a
0?ooo`00K03oool500000180oooo0`00003P0?ooo`030820P0000000000000800000o`3ooom20?oo
o`<00000/@3oool006/0oooo00D0@41000000000000000000820P00C0?ooo`<00000h@3oool00`20
P800000000000002000000030<30`03oool0oooo0?l0oooo?P3oool300000;40oooo001Z0?ooo`@0
000000<0P8200?ooo`3oool04P3oool300000><0oooo1000003o0?oood00oooo0`00002a0?ooo`00
J03oool00`30`<00000000000002000000030820P03oool0oooo01<0oooo0`00003S0?ooo`030<30
`000000000000080000000<0`<300?ooo`3oool0o`3oooll0?ooo`<00000/@3oool006P0oooo00@0
P8200000000000000000603oool300000>@0oooo1000003o0?oooch0oooo0`00002a0?ooo`00J03o
ool3000000030820P03oool0oooo01H0oooo0`00003U0?ooo`@00000o`3ooolm0?ooo`<00000/@3o
ool006H0oooo00D0`<3000000000000000000820P00I0?ooo`<00000i@3oool00`30`<0000000000
0002000000030<30`03oool0oooo0?l0oooo>@3oool300000;40oooo001V0?ooo`<000006`3oool3
00000>L0oooo1000003o0?oooc/0oooo0`00002a0?ooo`00I@3oool3000000030820P03oool0oooo
01T0oooo0`00003W0?ooo`030820P0000000000000800000o`3ooolj0?ooo`<00000/@3oool006<0
oooo00D0`<3000000000000000000820P00L0?ooo`<00000j03oool00`20P8000000000000020000
00030820P03oool0oooo0?l0oooo=P3oool300000;40oooo001S0?ooo`<0000000<0P8200?ooo`3o
ool06`3oool300000>X0oooo1@00003o0?ooocL0oooo0`00002a0?ooo`00HP3oool4000001h0oooo
0`00003Z0?ooo`030820P0000000000000<00000o`3ooolf0?ooo`<00000/@3oool00600oooo00D0
`<3000000000000000000820P00O0?ooo`<00000k03oool01@20P8000000000000000000@4100?l0
oooo=@3oool300000;40oooo001P0?ooo`<0000000<0P8200?ooo`3oool07P3oool300000>d0oooo
00<0P8200000000000000P00003o0?oooc@0oooo0`00002a0?ooo`00G`3oool400000240oooo0`00
003^0?ooo`D00000o`3ooolc0?ooo`<00000/@3oool005d0oooo00D0`<3000000000000000000820
P00R0?ooo`<00000k`3oool01@20P8000000000000000000@4100?l0oooo<P3oool300000;40oooo
001M0?ooo`<0000000<0P8200?ooo`3oool08@3oool300000?00oooo00<0P8200000000000000P00
003o0?oooc40oooo0`00002a0?ooo`00F`3oool01@30`<000000000000000000P82002@0oooo0`00
003a0?ooo`050820P0000000000000000010@400o`3oool`0?ooo`<00000/@3oool005/0oooo0`00
000V0?ooo`<00000l`3oool400000?l0oooo;`3oool300000;40oooo001J0?ooo`<0000000<0P820
0?ooo`3oool0903oool300000?<0oooo00<0P8200000000000000P00003o0?ooobh0oooo0`00002a
0?ooo`00F03oool01@30`<000000000000000000P82002L0oooo0`00003d0?ooo`050820P0000000
000000000010@400o`3oool]0?ooo`<00000/@3oool005T0oooo0`00000X0?ooo`<00000m@3oool0
0`20P80000000000000200000?l0oooo;03oool300000;40oooo001H0?ooo`030820P00000000000
008000009`3oool300000?H0oooo1@00003o0?ooob/0oooo0`00002a0?ooo`00F@3oool01@20P800
0000000000000000@41002H0oooo00@0P820000000000000P820:`3oool90820P<80oooo00D0P820
00000000000000000410@03o0?ooobX0oooo0`00002a0?ooo`00F`3oool4000002D0oooo00@0P820
000000000000P820;@3oool4000000030820P03oool0oooo0<<0oooo00<0P8200000000000000P00
003o0?ooobT0oooo0`00002a0?ooo`00F`3oool00`20P800000000000002000002@0oooo00@0P820
000000000000P820;P3oool300000<L0oooo1@00003o0?ooobP0oooo0`00002a0?ooo`00G03oool0
1@20P8000000000000000000@41002<0oooo00@0P820000000000000P820;P3oool300000<L0oooo
00D0P82000000000000000000820P03o0?ooobP0oooo0`00002a0?ooo`00G@3oool00`20P8000000
0000000200000280oooo00@0P820000000000000P820;P3oool300000<H0oooo00<0P82000000000
00000P00003o0?ooobT0oooo0`00002a0?ooo`00GP3oool00`20P800000000000002000000030<30
`03oool0oooo01h0oooo00@0P820000000000000P820;P3oool300000<D0oooo00D0P82000000000
000000000410@03o0?ooobX0oooo0`00002a0?ooo`00H03oool400000200oooo00@0P82000000000
0000P820;P3oool300000<@0oooo1@00003o0?ooob/0oooo0`00002a0?ooo`00H03oool00`20P800
000000000002000001l0oooo00@0P820000000000000P820;P3oool300000<<0oooo00<0P8200000
000000000P00003o0?ooob`0oooo0`00002a0?ooo`00H@3oool00`20P80000000000000200000003
0<30`03oool0oooo01/0oooo00@0P820000000000000P820;P3oool300000<80oooo00D0P8200000
0000000000000410@03o0?ooobd0oooo0`00002a0?ooo`00H`3oool4000001d0oooo00@0P8200000
00000000P820;P3oool300000<40oooo00<0P8200000000000000P00003o0?ooobh0oooo0`00002a
0?ooo`00H`3oool00`20P800000000000002000001`0oooo00@0P820000000000000P820;P3oool3
00000<40oooo1000003o0?ooobl0oooo0`00002a0?ooo`00I03oool01@20P8000000000000000000
@41001/0oooo00@0`<30000000000000@4105`3oool<0820P0030<30`03oool0oooo00P0oooo0`00
002o0?ooo`050820P0000000000000000010@400o`3oool`0?ooo`<00000/@3oool006H0oooo1000
000K0?ooo`<000006P3oool7000000d0oooo0`00002n0?ooo`030820P0000000000000800000o`3o
oola0?ooo`<00000/@3oool006H0oooo00@0P82000000000000000006`3oool3000001/0oooo1@00
000>0?ooo`<00000_P3oool4000009`0oooo1@00002@0?ooo`<00000/@3oool006L0oooo00D0P820
00000000000000000<30`00I0?ooo`<000006`3oool01020P800000000000000000?0?ooo`<00000
_03oool00`20P800000000000002000000030<30`03oool0oooo09T0oooo00@0@410000000000000
00000`20P8000`000000P8200?ooo`2<0?ooo`<00000/@3oool006P0oooo1000000I0?ooo`<00000
6`3oool01020P800000000000000000?0?ooo`<00000^`3oool00`20P800000000000002000009d0
oooo0P0000000`20P800oooo0?ooo`030?ooo`030820P0000000oooo08/0oooo0`00002a0?ooo`00
J03oool00`20P800000000000002000001P0oooo0`00000K0?ooo`040820P00000000000000000l0
oooo0`00002k0?ooo`@00000Y`3oool2000008/0oooo0`00002a0?ooo`00J@3oool00`20P8000000
00000002000000030<30`03oool0oooo01@0oooo0`00000K0?ooo`040820P00000000000000000l0
oooo0`00002h0?ooo`030<30`020P800000000<0000000<0`<300?ooo`3oool0YP3oool00`000000
@4100?ooo`290?ooo`<00000/@3oool006/0oooo1000000F0?ooo`<000006`3oool01020P8000000
00000000000?0?ooo`<00000^03oool500000:/0oooo00<000000?ooo`3oool0R03oool300000;40
oooo001[0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool04P3oool3000001/0oooo
00@0P82000000000000000003`3oool300000;H0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`2Z0?ooo`0300000020P800oooo08P0oooo0`00002a0?ooo`00K@3oool4000000030820
P03oool0oooo0140oooo1000000J0?ooo`040820P00000000000000000l0oooo0`00002e0?ooo`03
0820P0000000000000800000[P3oool2000008T0oooo0`00002a0?ooo`00KP3oool4000001@0oooo
0`00000J0?ooo`040820P00000000000000000l0oooo0`00002e0?ooo`@00000[`3oool2000008T0
oooo0`00002a0?ooo`00KP3oool00`30`<00000000000002000000030820P03oool0oooo0100oooo
0`00000J0?ooo`040820P00000000000000000/0oooo00<0P82000000020P8001000002c0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool0[03oool3000008T0oooo0`00002a0?ooo`00
L03oool4000000030820P03oool0oooo00l0oooo0`00000J0?ooo`040820P00000000000000000h0
oooo1000002c0?ooo`@00000[`3oool4000008T0oooo0`00002a0?ooo`00L@3oool400000140oooo
0`00000J0?ooo`040820P0000000000000000100oooo00<0P8200000003oool0/@3oool4000008H0
oooo3@0000080?ooo`030820P0000000000000H0000000<0P8200?ooo`3oool0203oool01020P800
000000000000002:0?ooo`<00000/@3oool00740oooo00<0`<300000000000000P0000000`30`<00
oooo0?ooo`0=0?ooo`<000006P3oool01020P80000000000000000320?ooo`030<30`00000000000
0080000000<0`<300?ooo`3oool0Q`3oool00`20P800000000000003000000030820P03oool0oooo
00T0oooo00<0@4100000000000000P0000020820P0`0oooo00D0P82000000000000000000410@02:
0?ooo`<00000/@3oool007<0oooo1000000?0?ooo`@000006@3oool01020P8000000000000000032
0?ooo`@00000S@3oool3000000030820P03oool0oooo00T0oooo1@00000=0?ooo`030820P0000000
000000<0000000<0P8200?ooo`3oool0R03oool300000;40oooo001d0?ooo`@000003`3oool30000
01T0oooo00@0P8200000000000000000`@3oool4000000030820P03oool0oooo08/0oooo0`000000
0`20P800oooo0?ooo`080?ooo`030820P000000000000080000000<0P8200?ooo`3oool02@3oool8
000008/0oooo0`00002a0?ooo`00M03oool00`30`<00000000000002000000030<30`03oool0oooo
00/0oooo0`00000I0?ooo`040820P0000000000000000;l0oooo00<0`<300000000000000P000000
0`20P800oooo0?ooo`2<0?ooo`<0000000<0P8200?ooo`3oool0203oool01@10@400000000000000
0000P82000T0oooo00<0P8200000000000001@0000000`10@400P8200?ooo`2;0?ooo`<00000/@3o
ool007D0oooo100000000`20P800oooo0?ooo`0;0?ooo`<000006@3oool01020P800000000000000
002o0?ooo`@00000T03oool3000000030820P03oool0oooo00L0oooo1000000<0?ooo`H00000S`3o
ool300000;40oooo001d0?ooo`050410@0000000000000000020P8003P3oool3000001T0oooo00@0
P8200000000000000000_@3oool00`20P800000000000002000000030<30`03oool0oooo08h0oooo
0`0000000`20P800oooo0?ooo`060?ooo`050820P0000000000000000010@400303oool01020P800
00000820P020P82A0?ooo`<00000/@3oool007<0oooo1000000@0?ooo`<000006@3oool01020P800
000000000000002l0?ooo`030820P0000000000000800000TP3oool3000000030820P03oool0oooo
00D0oooo00<0P8200000000000000P00000>0?ooo`030000003oool0oooo0940oooo0`00002a0?oo
o`00LP3oool4000000030820P03oool0oooo00h0oooo0`0000000`20P800oooo0?ooo`0F0?ooo`04
0820P0000000000000000;`0oooo1000002C0?ooo`<0000000<0P8200?ooo`3oool01@3oool40000
00l0oooo00<0P8200000003oool0T@3oool300000;40oooo001a0?ooo`050410@000000000000000
0020P8004@3oool01020P800000000000020P80H0?ooo`040820P0000000000000000;`0oooo00@0
`<30000000000000`<30T`3oool3000000030820P03oool0oooo00@0oooo00D0P820000000000000
00000410@00?0?ooo`030820P0000000P8200940oooo0`00002a0?ooo`00L03oool4000000030820
P03oool0oooo0100oooo00@0P820000000000000P820603oool01020P800000000000000003o0?oo
oe@0oooo0`0000000`20P800oooo0?ooo`030?ooo`D000004@3oool8000000030820P03oool0oooo
08P0oooo0`00002a0?ooo`00K`3oool5000001<0oooo00@0P820000000000000P820603oool01020
P800000000000000002i0?ooo`040820P000000000000820P9H0oooo0`0000000`20P800oooo0?oo
o`030?ooo`D000004@3oool9000008X0oooo0`00002a0?ooo`00KP3oool01@10@400000000000000
0000P82001@0oooo00@0P820000000000000P820603oool01020P800000000000000002i0?ooo`04
0820P000000000000820P9H0oooo0`0000000`20P800oooo0?ooo`020?ooo`050410@00000000000
00000020P8004`3oool8000000030820P03oool0oooo08L0oooo0`00002a0?ooo`00K@3oool40000
00030820P03oool0oooo01<0oooo00@0P820000000000000P820603oool01020P800000000000000
002i0?ooo`040820P000000000000820P9H0oooo0`0000001020P800oooo0?ooo`3oool400000003
0820P03oool0oooo0:@0oooo0`00002a0?ooo`00K03oool5000001H0oooo00@0P820000000000000
0000603oool01020P800000000000000002i0?ooo`040820P000000000000820P9H0oooo2`000000
0`20P800oooo0?ooo`2T0?ooo`<00000/@3oool006/0oooo00D0@41000000000000000000820P00H
0?ooo`<00000603oool01@10@4000000000000000000P8200;P0oooo00@0P820000000000000P820
UP3oool3000000030410@020P800P8200080P82000@0@41000000000000000000P20P8000`30`<00
oooo0?ooo`2Q0?ooo`<00000/@3oool006X0oooo100000000`20P800oooo0?ooo`0G0?ooo`<00000
5`3oool700000;L0oooo00@0P820000000000000P820UP3oool3000000030820P03oool0oooo00D0
oooo1@00002R0?ooo`<00000/@3oool006T0oooo1@00000J0?ooo`<00000503oool<000000030820
P03oool0oooo0;80oooo00@0P820000000000000P820UP3oool3000000030820P03oool0oooo00H0
oooo100000000`20P800oooo0?ooo`2O0?ooo`<00000/@3oool006P0oooo00D0P820000000000000
00000820P00K0?ooo`<00000e@3oool01020P800000000000020P82F0?ooo`<0000000<0P8200?oo
o`3oool01`3oool01@20P8000000000000000000P8200:00oooo0`00002a0?ooo`00J03oool30000
00030820P03oool0oooo01X0oooo0`00003E0?ooo`040820P000000000000820P9H0oooo0`000000
0`20P800oooo0?ooo`080?ooo`@00000X03oool300000;40oooo001V0?ooo`030<30`00000000000
008000007@3oool01020P800000000000000003D0?ooo`040820P000000000000820P9H0oooo0`00
00000`20P800oooo0?ooo`080?ooo`030820P0000000000000800000W`3oool300000;40oooo001V
0?ooo`@000007`3oool300000=@0oooo00@0P820000000000000P820UP3oool3000000030820P03o
ool0oooo00P0oooo00<0P8200000000000000P00002O0?ooo`<00000/@3oool006D0oooo1000000P
0?ooo`<00000e03oool01020P800000000000020P82F0?ooo`<0000000<0P8200?ooo`3oool0203o
ool00`20P800000000000002000009l0oooo0`00002a0?ooo`00H`3oool00`30`<00000000000002
000000030<30`03oool0oooo01h0oooo0`00003D0?ooo`040820P000000000000820P9H0oooo0`00
00000`20P800oooo0?ooo`080?ooo`030820P0000000000000800000W`3oool300000;40oooo001S
0?ooo`@000008P3oool400000=<0oooo00@0P820000000000000P820UP3oool3000000030820P03o
ool0oooo00P0oooo1@00002O0?ooo`<00000/@3oool00680oooo100000000`20P800oooo0?ooo`0P
0?ooo`@00000d`3oool01020P800000000000020P82F0?ooo`<0000000<0P8200?ooo`3oool0203o
ool400000:00oooo0`00002a0?ooo`00H03oool00`30`<00000000000002000000030820P03oool0
oooo0240oooo00@0P8200000000000000000d`3oool01020P800000000000020P82F0?ooo`<00000
00<0P8200?ooo`3oool01P3oool00`20P800000000000002000000030820P03oool0oooo09h0oooo
0`00002a0?ooo`00H03oool4000002H0oooo0`00003C0?ooo`040820P000000000000820P9H0oooo
0`0000000`20P800oooo0?ooo`050?ooo`030820P000000000000080000000<0P8200?ooo`3oool0
W`3oool300000;40oooo001O0?ooo`@0000000<0P8200?ooo`3oool0903oool300000=<0oooo00@0
P820000000000000P820U@3oool6000000D0oooo1P00002R0?ooo`<00000/@3oool005d0oooo00<0
`<300000000000000P0000000`20P800oooo0?ooo`0U0?ooo`<0000000<0P8200?ooo`3oool0d03o
ool01020P800000000000020P82A0?ooo`<0P8203P0000020820P0030<30`03oool0oooo0:40oooo
0`00002a0?ooo`00G@3oool4000002T0oooo0`0000000`20P800oooo0?ooo`3@0?ooo`040820P000
000000000820P?l0ooooB@3oool300000;40oooo001K0?ooo`030<30`000000000000080000000<0
`<300?ooo`3oool09`3oool3000000030820P03oool0oooo0=00oooo00@0P820000000000000P820
o`3ooom90?ooo`<00000/@3oool005/0oooo1000000[0?ooo`040820P000000000000820P=80oooo
00@0P820000000000000P820o`3ooom90?ooo`<00000/@3oool005X0oooo1000000/0?ooo`040820
P0000000000000000=80oooo00@0P820000000000000P820o`3ooom90?ooo`<00000/@3oool005P0
oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0Z0?ooo`040820P000000000000000
0=80oooo00@0P820000000000000P820o`3ooom90?ooo`<00000/@3oool005T0oooo100000000`20
P800oooo0?ooo`0Z0?ooo`040820P0000000000000000=80oooo00@0P820000000000000P820o`3o
oom90?ooo`<00000/@3oool005X0oooo0`0000000`20P800oooo0?ooo`0Z0?ooo`040820P0000000
000000000=80oooo00@0P820000000000000P820o`3ooom90?ooo`<00000/@3oool005/0oooo0P00
00000`20P800oooo0?ooo`0Z0?ooo`050820P0000000000000000020P800d@3oool01020P8000000
00000020P83o0?ooodT0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo02/0oooo
1000003A0?ooo`040820P000000000000820P?l0ooooB@3oool300000;40oooo001K0?ooo`800000
00<0P8200?ooo`3oool0:`3oool400000=40oooo00@0P820000000000000P820o`3ooom90?ooo`<0
0000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0[0?ooo`@00000d@3oool01020P8000000
00000020P83o0?ooodT0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo02/0oooo
1000003A0?ooo`040820P000000000000820P?l0ooooB@3oool300000;40oooo001K0?ooo`800000
00<0P8200?ooo`3oool0:`3oool01@20P8000000000000000000P8200=00oooo00@0P82000000000
0000P820o`3ooom90?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0/0?ooo`<0
000000<0P8200?ooo`3oool0cP3oool01020P800000000000020P80a000000030820P03oool0oooo
0?l0oooo5@3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0;03oool300000003
0820P03oool0oooo0<h0oooo00@0P820000000000000P820<@0000000`20P800oooo0?ooo`3o0?oo
oaD0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo02`0oooo0`0000000`10@400
oooo0?ooo`3>0?ooo`040820P000000000000820P3<0000000<0P8200?ooo`3oool0=P3oool01@10
@40000000820P0000000P82003P0oooo00@0`<30000000000000@410>03oool01@20P80000000410
@0000000@41003P0oooo00<0P82000000010@4008P20P800103oool0000000000000002a0?ooo`00
F`3oool2000000030820P03oool0oooo02d0oooo0`00003@0?ooo`040820P000000000000820P300
oooo100000000`20P800oooo0?ooo`0d0?ooo`L00000=`3oool5000003H0oooo00<0P82000000000
00001000000f0?ooo`030820P0000000000002<0000000@0oooo0000000000000000/@3oool005/0
oooo0P0000000`20P800oooo0?ooo`0]0?ooo`<00000d03oool01020P800000000000020P80a0?oo
o`@00000=@3oool8000000030820P03oool0oooo03<0oooo1`00000e0?ooo`P00000=@3ooolV0000
00040?ooo`000000000000000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0;@3oool30000
0=00oooo00@0P820000000000000P820<@3oool00`30`<00000000000002000000030820P03oool0
oooo0300oooo00L0@41000000000000000000820P03oool0@41000<0000000<0P8200?ooo`3oool0
<03oool00`30`<00000000000002000000050820P0000000000000000010@400<P3oool00`20P800
000000000002000000030<30`020P80000000080000000<0@4100?ooo`3oool0<03oool00`20P800
000000000002000000030<30`020P800P8200200P82000@0oooo0000000000000000/@3oool005/0
oooo0P0000000`20P800oooo0?ooo`0]0?ooo`@00000c`3oool01020P800000000000020P80c0?oo
o`@0000000<0P8200?ooo`3oool0;P3oool4000000040820P03oool0oooo0?ooo`@0000000<0P820
0?ooo`3oool0;`3oool400000080oooo00<0P8200000000000000P00000`0?ooo`030820P0000000
0000008000000`3oool00`20P80000000000000200000300oooo00<0P8200000000000000P00000U
0?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0]0?ooo`040820P00000000000
00000<l0oooo00@0P820000000000000P820=03oool4000002l0oooo1@0000050?ooo`@00000<03o
ool4000000040820P03oool0oooo0?ooo`D00000;`3oool4000000D0oooo1@00000_0?ooo`@00000
9P3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0;@3oool01020P80000000000
0000003?0?ooo`040820P000000000000820P3@0oooo00<0`<300000000000000P0000000`20P800
oooo0?ooo`0Z0?ooo`050410@0000000000000000020P8001`3oool01@10@4000000000000000000
P82002d0oooo00D0@41000000000000000000820P0050?ooo`050820P0000000000000000010@400
;03oool00`20P800000000000002000000030<30`03oool0oooo00@0oooo00D0P820000000000000
00000410@00/0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0903oool300000;40
oooo001K0?ooo`80000000<0P8200?ooo`3oool0;@3oool01020P800000000000000003?0?ooo`04
0820P000000000000820P3H0oooo100000000`20P800oooo0?ooo`0X0?ooo`@0000000<0P8200?oo
o`3oool01`3oool4000000030820P03oool0oooo02T0oooo100000080?ooo`030820P00000000000
00800000:P3oool00`20P800000000000002000000T0oooo00<0P8200000000000000P00000Z0?oo
o`030820P0000000000000800000:03oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0;@3oool00`20P80000000000000200000<h0oooo00@0P820000000000000P820=`3oool40000
02T0oooo00<0P8200000000000000P00000;0?ooo`@00000:P3oool4000000030820P03oool0oooo
00L0oooo100000000`20P800oooo0?ooo`0W0?ooo`@000002`3oool5000002T0oooo1000000Y0?oo
o`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0^0?ooo`@00000cP3oool01020P800
000000000020P80g0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0903oool01@20
P8000000000000000000P82000`0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0U
0?ooo`050410@0000000000000000020P8002`3oool01@20P8000000000000000000P82002H0oooo
00<0P8200000000000000P0000000`30`<00oooo0?ooo`0:0?ooo`050820P0000000000000000010
@4009P3oool00`30`<00000000000002000000030<30`03oool0oooo02L0oooo0`00002a0?ooo`00
F`3oool2000000030820P03oool0oooo02h0oooo1000003>0?ooo`040820P000000000000820P3T0
oooo100000000`20P800oooo0?ooo`0R0?ooo`@0000000<0P8200?ooo`3oool03@3oool400000003
0820P03oool0oooo02<0oooo100000000`20P800oooo0?ooo`0;0?ooo`030820P000000000000080
0000903oool00`20P800000000000002000000l0oooo00<0P8200000000000000P00000U0?ooo`@0
0000:`3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0;P3oool4000000030<30
`03oool0oooo0</0oooo00@0P820000000000000P820>P3oool01@10@4000000000000000000P820
0280oooo00D0@41000000000000000000820P00A0?ooo`050410@0000000000000000020P8008P3o
ool00`30`<00000000000002000000030820P03oool0oooo00d0oooo00D0P8200000000000000000
0410@00R0?ooo`050820P0000000000000000010@4004@3oool01@20P8000000000000000000@410
0280oooo00D0P82000000000000000000410@00/0?ooo`<00000/@3oool005/0oooo0P0000000`20
P800oooo0?ooo`0_0?ooo`<0000000<0P8200?ooo`3oool0b`3oool01020P800000000000020P80k
0?ooo`@0000000<0P8200?ooo`3oool07P3oool4000000030820P03oool0oooo0140oooo1@00000Q
0?ooo`@000004P3oool00`20P80000000000000200000200oooo00<0P8200000000000000P00000D
0?ooo`@00000803oool00`20P800000000000002000002d0oooo0`00002a0?ooo`00F`3oool20000
00030820P03oool0oooo02l0oooo0`0000000`20P800oooo0?ooo`3;0?ooo`040820P00000000000
0820P3`0oooo1000000O0?ooo`D000005@3oool4000000030820P03oool0oooo01d0oooo10000000
0`20P800oooo0?ooo`0A0?ooo`D000007`3oool4000001D0oooo00<0P8200000000000000P00000O
0?ooo`@00000;P3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0;`3oool30000
00030820P03oool0oooo0</0oooo00@0P820000000000000P820?@3oool01@10@400000000000000
0000P82001`0oooo00D0P82000000000000000000820P00G0?ooo`050410@0000000000000000020
P800703oool00`30`<00000000000002000000030820P03oool0oooo01<0oooo00D0P82000000000
000000000410@00M0?ooo`<0000000<0@4100?ooo`3oool05@3oool01@20P8000000000000000000
@41001d0oooo100000000`30`<00oooo0?ooo`0/0?ooo`<00000/@3oool005/0oooo0P0000000`20
P800oooo0?ooo`0_0?ooo`@00000c@3oool01020P800000000000020P80n0?ooo`@00000703oool3
000000030820P03oool0oooo01L0oooo1000000L0?ooo`@00000603oool01020P800000000000000
000L0?ooo`@000006@3oool01020P800000000000000000L0?ooo`@00000<03oool300000;40oooo
001K0?ooo`80000000<0P8200?ooo`3oool0;`3oool01020P800000000000000003=0?ooo`040820
P000000000000820P3l0oooo0`0000000`20P800oooo0?ooo`0H0?ooo`@000006`3oool300000003
0820P03oool0oooo01P0oooo100000000`20P800oooo0?ooo`0G0?ooo`@000006P3oool01020P800
000000000000000K0?ooo`@000006P3oool01020P800000000000000000a0?ooo`<00000/@3oool0
05/0oooo0P0000000`20P800oooo0?ooo`0_0?ooo`040820P0000000000000000<d0oooo00@0P820
000000000000P820?`3oool01@20P8000000000000000000P82001L0oooo00<0`<30000000000000
0P0000000`20P800oooo0?ooo`0J0?ooo`<0000000<0P8200?ooo`3oool05P3oool01@10@4000000
000000000000P82001/0oooo100000000`30`<00oooo0?ooo`0E0?ooo`050820P000000000000000
0010@400703oool4000000030<30`03oool0oooo01D0oooo00D0P82000000000000000000410@00a
0?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0_0?ooo`040820P00000000000
00000<d0oooo00@0P820000000000000P820@03oool5000001H0oooo1000000N0?ooo`030820P000
00000000008000005P3oool4000001h0oooo1000000F0?ooo`D000007P3oool4000001H0oooo1@00
000b0?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0`0?ooo`@00000c03oool0
1020P800000000000020P8110?ooo`@0000000<0P8200?ooo`3oool04P3oool4000000030820P03o
ool0oooo01d0oooo100000000`20P800oooo0?ooo`0B0?ooo`@0000000<0P8200?ooo`3oool0703o
ool00`20P800000000000002000001@0oooo00<0P8200000000000000P00000O0?ooo`030820P000
0000000000800000503oool00`20P800000000000002000003<0oooo0`00002a0?ooo`00F`3oool2
000000030820P03oool0oooo0300oooo1000003<0?ooo`040820P000000000000820P480oooo00D0
@41000000000000000000820P00A0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0
7`3oool01@10@4000000000000000000P8200180oooo00D0@41000000000000000000820P00P0?oo
o`030820P000000000000080000000<0`<300?ooo`3oool03`3oool01@20P8000000000000000000
@4100240oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0?0?ooo`050820P0000000
000000000010@400=03oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0<03oool4
00000<`0oooo00@0P820000000000000P820@`3oool500000100oooo1000000T0?ooo`D00000403o
ool4000000030820P03oool0oooo0240oooo1000000@0?ooo`D00000903oool400000100oooo00<0
P8200000000000000P00000e0?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0a
0?ooo`@00000b`3oool01020P800000000000020P8140?ooo`050820P0000000000000000010@400
3@3oool00`30`<00000000000002000000030<30`03oool0oooo02<0oooo00D0P820000000000000
00000410@00=0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool08P3oool00`30`<00
000000000002000000030<30`03oool0oooo00/0oooo00D0@41000000000000000000820P00U0?oo
o`030<30`000000000000080000000<0P8200?ooo`3oool02`3oool01@20P8000000000000000000
P82003H0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo0340oooo1000003;0?oo
o`040820P000000000000820P4D0oooo00<0P8200000000000000P00000<0?ooo`@00000:03oool0
0`20P800000000000002000000`0oooo1000000X0?ooo`@00000303oool4000000030820P03oool0
oooo02H0oooo100000000`20P800oooo0?ooo`090?ooo`@0000000<0P8200?ooo`3oool0=@3oool3
00000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0<@3oool400000</0oooo00@0P8200000
00000000P820AP3oool4000000030820P03oool0oooo00P0oooo1000000Z0?ooo`D000002P3oool4
000000030820P03oool0oooo02L0oooo1000000:0?ooo`D00000:P3oool4000000X0oooo00<0P820
0000000000000P00000h0?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0b0?oo
o`<0000000<0P8200?ooo`3oool0a`3oool01@20P800@410000000000000P82004L0oooo00D0P820
00000000000000000820P0070?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0:@3o
ool01@20P8000000000000000000@41000L0oooo00<0`<300000000000000P0000000`20P800oooo
0?ooo`0X0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool01@3oool01@10@4000000
000000000000P82002/0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`050?ooo`05
0820P0000000000000000010@400>@3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0<P3oool3000000030820P03oool0oooo0<H0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`160?ooo`030820P00000000000008000001P3oool4000002h0oooo00<0P82000000000
00000P0000060?ooo`@00000;P3oool4000000H0oooo100000000`20P800oooo0?ooo`0/0?ooo`@0
00001P3oool5000003X0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo0380oooo
00@0P820000000000000P820b03oool5000000030820P03oool0oooo04L0oooo100000000`20P800
oooo0?ooo`020?ooo`@0000000<0P8200?ooo`3oool0;@3oool5000000@0oooo100000000`20P800
oooo0?ooo`0/0?ooo`030820P0000000000000800000103oool00`20P80000000000000200000300
oooo100000040?ooo`030820P0000000000000800000>`3oool300000;40oooo001K0?ooo`800000
00<0P8200?ooo`3oool0<P3oool01020P80000000000000000380?ooo`030<30`000000000000080
000000<0P8200?ooo`3oool0B03oool01`10@4000000000000000000P8200?ooo`30`<0010000000
0`20P800oooo0?ooo`0_0?ooo`070820P0000000000000000010@400oooo0<30`004000000030820
P03oool0oooo02h0oooo00<0P8200000000000000P0000000`30`<00oooo0820P003000000030820
P03oool0oooo02l0oooo00<0`<300000000000000P0000000`30`<00oooo0820P003000000030410
@03oool0oooo03X0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo0380oooo00@0
P8200000000000000000bP3oool4000004/0oooo2@00000d0?ooo`030820P0000000000000H00000
=03oool8000000030820P03oool0oooo0380oooo2@00000m0?ooo`<00000/@3oool005/0oooo0P00
00000`20P800oooo0?ooo`0c0?ooo`<00000bP3oool00`20P800000000000002000004/0oooo1`00
00000`20P800oooo0?ooo`0c0?ooo`L0000000<0P8200?ooo`3oool0<P3oool00`20P80000000000
0005000003D0oooo00<0P8200000000000001@00000n0?ooo`<00000/@3oool005/0oooo0P000000
0`20P800oooo0?ooo`0c0?ooo`@00000bP3oool00`20P800000000000002000000030<30`03oool0
oooo04P0oooo00<0@4100000000000000P0000000`20P800oooo0?ooo`0e0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0=03oool00`20P800000000000002000000030410@03oool0
oooo03D0oooo00<0P8200000000000000P0000000`10@400oooo0?ooo`0m0?ooo`<00000/@3oool0
05/0oooo0P0000000`20P800oooo0?ooo`0d0?ooo`<00000c03oool4000004/0oooo0`00000j0?oo
o`030820P0000000000003X0oooo0`00000j0?ooo`<00000@03oool300000;40oooo001K0?ooo`80
000000<0P8200?ooo`3oool0=03oool300000<`0oooo00<0P8200000000000000P00003o0?ooodD0
oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo03@0oooo1000003<0?ooo`030820
P000000000000080000000<0`<300?ooo`3oool0o`3ooom10?ooo`<00000/@3oool005/0oooo0P00
00000`20P800oooo0?ooo`0e0?ooo`<00000cP3oool400000?l0oooo@`3oool300000;40oooo001K
0?ooo`80000000<0P8200?ooo`3oool0=@3oool3000000030<30`03oool0oooo0</0oooo00<0`<30
0000000000000P0000000`20P800oooo0?ooo`3o0?ooocl0oooo0`00002a0?ooo`00F`3oool20000
00030820P03oool0oooo03D0oooo0`0000000`20P800oooo0?ooo`3=0?ooo`@0000000<0P8200?oo
o`3oool0o`3oooln0?ooo`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0e0?ooo`04
0820P000000000000820P=00oooo1000003o0?oood00oooo0`00002a0?ooo`00F`3oool200000003
0820P03oool0oooo03D0oooo00@0P820000000000000@410d03oool00`30`<000000000000020000
00030<30`03oool0oooo0?l0oooo?03oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0=P3oool300000=80oooo1000003o0?oooch0oooo0`00002a0?ooo`00F`3oool2000000030820
P03oool0oooo03H0oooo0`00003C0?ooo`@00000o`3ooolm0?ooo`<00000/@3oool005/0oooo0P00
00000`20P800oooo0?ooo`0f0?ooo`<0000000<0P8200?ooo`3oool0d03oool00`30`<0000000000
0002000000030<30`03oool0oooo0?l0oooo>@3oool300000;40oooo001K0?ooo`80000000<0P820
0?ooo`3oool0=`3oool300000=@0oooo1000003o0?oooc/0oooo0`00002a0?ooo`00F`3oool20000
00030820P03oool0oooo03L0oooo0`00003D0?ooo`030820P0000000000000800000o`3ooolj0?oo
o`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0g0?ooo`040820P000000000000000
0=@0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`3o0?ooocH0oooo0`00002a0?oo
o`00F`3oool2000000030820P03oool0oooo03P0oooo0`00003F0?ooo`@00000o`3ooolh0?ooo`<0
0000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`040410@000000000000820P=D0
oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`3o0?oooc@0oooo0`00002a0?ooo`00
F`3oool2000000030820P03oool0oooo03P0oooo00@0P820000000000000P820e`3oool400000003
0820P03oool0oooo0?l0oooo<`3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0
>03oool01020P800000000000020P83H0?ooo`@00000o`3ooole0?ooo`<00000/@3oool005/0oooo
0P0000000`20P800oooo0?ooo`0h0?ooo`040<30`0000000000000000=P0oooo00<0`<3000000000
00000P0000000`20P800oooo0?ooo`3o0?oooc40oooo0`00002a0?ooo`00F`3oool2000000030820
P03oool0oooo03T0oooo0`00003J0?ooo`@0000000<0P8200?ooo`3oool0o`3oool`0?ooo`<00000
/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0i0?ooo`@00000fP3oool400000?l0oooo<P3o
ool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0>P3oool300000=X0oooo00<0`<30
0000000000000P0000000`30`<00oooo0?ooo`3o0?ooobh0oooo0`00002a0?ooo`00F`3oool20000
00030820P03oool0oooo03X0oooo0`0000000`20P800oooo0?ooo`3I0?ooo`@00000o`3oool`0?oo
o`<00000/@3oool005/0oooo0P0000000`20P800oooo0?ooo`0k0?ooo`80000000<0P8200?ooo`3o
ool0fP3oool400000?l0oooo;`3oool300000;40oooo001K0?ooo`80000000<0P8200?ooo`3oool0
>`3oool2000000030820P03oool0oooo0=X0oooo00<0`<300000000000000P0000000`30`<00oooo
0?ooo`3o0?ooob/0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo03/0oooo0`00
003M0?ooo`@0000000<0P8200?ooo`3oool0o`3oool[0?ooo`<00000/@3oool005/0oooo0P000000
0`20P800oooo0?ooo`0k0?ooo`030820P000000000000=`0oooo00<0P8200000000000000P00003o
0?ooobh0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo03/0oooo00@0P8200000
00000000P820fP3oool01@20P8000000000000000000P8200?l0oooo;`3oool300000;40oooo001K
0?ooo`80000000<0P8200?ooo`3oool0?03oool300000=T0oooo100000000`20P800oooo0?ooo`3o
0?ooobh0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo03`0oooo00@0P8200000
000000000000e`3oool01@10@4000000000000000000P8200?l0oooo<@3oool300000;40oooo001K
0?ooo`80000000<0P8200?ooo`3oool0?@3oool300000=H0oooo100000000`20P800oooo0?ooo`3o
0?oooc00oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo03d0oooo0`0000000`20
P800oooo0?ooo`3B0?ooo`D00000o`3ooolc0?ooo`<00000/@3oool005/0oooo0P0000000`20P800
oooo0?ooo`0m0?ooo`040820P000000000000410@=<0oooo00D0@41000000000000000000820P03o
0?oooc@0oooo0`00002a0?ooo`00F`3oool2000000030820P03oool0oooo03d0oooo00@0P8200000
000000000000dP3oool4000000030820P03oool0oooo0?l0oooo<`3oool300000;40oooo001K0?oo
o`80000000<0P8200?ooo`3oool0?P3oool300000=40oooo1@00003o0?ooocH0oooo0`00002a0?oo
o`00F`3oool2000000030820P03oool0oooo03h0oooo00@0P8200000000000000000c`3oool01@10
@4000000000000000000P8200?l0oooo=`3oool01030`<00000000000030`<2`0?ooo`00F`3oool2
000000030820P03oool0oooo03l0oooo1000003=0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolf
0?ooo`@00000/03oool005/0oooo0P0000000`20P800oooo0?ooo`0o0?ooo`@00000c03oool50000
0?l0oooo>@3oool00`20P80000000000000200000:l0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0@03oool3000000030<30`03oool0oooo0<P0oooo00D0@41000000000000000000820P03o0?oo
oc/0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2[0?ooo`00F`3oool200000003
0820P03oool0oooo0400oooo00@0P820000000000000P820b@3oool4000000030820P03oool0oooo
0?l0oooo?03oool400000:d0oooo001K0?ooo`80000000<0P8200?ooo`3oool0@03oool01020P800
00000000000000380?ooo`050410@0000000000000000020P800o`3ooolo0?ooo`030<30`0000000
00000080000000<0`<300?ooo`3oool0Z@3oool005/0oooo0P0000000`20P800oooo0?ooo`110?oo
o`<00000a`3oool400000?l0oooo@`3oool400000:/0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0@@3oool400000<D0oooo100000000`20P800oooo0?ooo`3o0?oood80oooo1000002Z0?ooo`00
F`3oool2000000030820P03oool0oooo0440oooo00D0P82000000000000000000820P0330?ooo`05
0410@0000000000000000020P800o`3ooom50?ooo`030<30`000000000000080000000<0`<300?oo
o`3oool0YP3oool005/0oooo0P0000000`20P800oooo0?ooo`120?ooo`@00000`P3oool400000003
0820P03oool0oooo0?l0ooooAP3oool400000:P0oooo001K0?ooo`80000000<0P8200?ooo`3oool0
@`3oool300000<40oooo1@00003o0?ooodT0oooo00<0P8200000000000000P00002W0?ooo`00F`3o
ool2000000030820P03oool0oooo04<0oooo0`0000000`20P800oooo0?ooo`2m0?ooo`050410@000
0000000000000020P800o`3ooom;0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0
X`3oool005/0oooo0P0000000`20P800oooo0?ooo`130?ooo`040820P0000000000000000;h0oooo
100000000`20P800oooo0?ooo`3o0?oood`0oooo1000002U0?ooo`00F`3oool2000000030820P03o
ool0oooo04<0oooo00@0P8200000000000000000_@3oool500000?l0ooooC`3oool00`20P8000000
0000000200000:@0oooo001K0?ooo`80000000<0P8200?ooo`3oool0A03oool400000;/0oooo00D0
@41000000000000000000820P03o0?oooe40oooo00<0P8200000000000000P0000000`30`<00oooo
0?ooo`2P0?ooo`00F`3oool2000000030820P03oool0oooo04D0oooo0`00002j0?ooo`@0000000<0
P8200?ooo`3oool0o`3ooomB0?ooo`@00000XP3oool005/0oooo0P0000000`20P800oooo0?ooo`15
0?ooo`040820P0000000000000000;L0oooo00<0`<300000000000000P0000000`20P800oooo0?oo
o`3o0?oooe<0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`2N0?ooo`00F`3oool2
000000030820P03oool0oooo04H0oooo0`0000000`20P800oooo0?ooo`2d0?ooo`@00000o`3ooomI
0?ooo`@0000000<0P8200?ooo`3oool0W@3oool005/0oooo0P0000000`20P800oooo0?ooo`160?oo
o`040820P000000000000820P;D0oooo100000000`20P800oooo0?ooo`3o0?oooeP0oooo1000002O
0?ooo`00F`3oool2000000030820P03oool0oooo04H0oooo00@0`<300000000000000000]03oool0
1@10@4000000000000000000P8200?l0ooooF`3oool00`30`<00000000000002000000030<30`03o
ool0oooo09/0oooo001K0?ooo`80000000<0P8200?ooo`3oool0A`3oool400000;<0oooo00<0P820
000000000000o`3ooomO0?ooo`@00000W@3oool005/0oooo0P0000000`20P800oooo0?ooo`180?oo
o`<00000/`3oool400000?l0ooooG`3oool4000009`0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0B03oool01020P800000000000030`<2b0?ooo`030<30`000000000000080000000<0`<300?oo
o`3oool0o`3ooomK0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0V03oool005/0
oooo0P0000000`20P800oooo0?ooo`190?ooo`80000000<0P8200?ooo`3oool0/P3oool400000?l0
ooooG`3oool4000009X0oooo001K0?ooo`80000000<0P8200?ooo`3oool0B@3oool00`20P8000000
0000002d0?ooo`030820P0000000000000800000o`3ooomN0?ooo`030820P0000000000000800000
V@3oool005/0oooo0P0000000`20P800oooo0?ooo`190?ooo`040<30`000000000000820P;@0oooo
00<0P8200000000000000P0000000`30`<00oooo0?ooo`3o0?oooe/0oooo00<0P820000000000000
0P0000000`30`<00oooo0?ooo`2E0?ooo`00F`3oool2000000030820P03oool0oooo04X0oooo0`00
002f0?ooo`@00000o`3ooomO0?ooo`@00000U`3oool005/0oooo0P0000000`20P800oooo0?ooo`1;
0?ooo`<00000]@3oool00`20P80000000000000200000?l0ooooGP3oool00`20P800000000000002
000009H0oooo001K0?ooo`80000000<0P8200?ooo`3oool0B`3oool01010@400000000000030`<2e
0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0o`3ooomK0?ooo`030820P0000000
00000080000000<0`<300?ooo`3oool0TP3oool005/0oooo0P0000000`20P800oooo0?ooo`1;0?oo
o`040820P000000000000820P;L0oooo1000003o0?oooel0oooo1000002D0?ooo`00F`3oool20000
00030820P03oool0oooo04`0oooo0`00002g0?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool0o`3ooomK0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0T03oool005/0
oooo0P0000000`20P800oooo0?ooo`1=0?ooo`<00000^03oool4000000030820P03oool0oooo0?l0
ooooF`3oool500000980oooo001K0?ooo`80000000<0P8200?ooo`3oool0C@3oool400000;P0oooo
1000003o0?oooe`0oooo00<0P8200000000000000P00002C0?ooo`00F`3oool2000000030820P03o
ool0oooo04h0oooo0`0000000`30`<00oooo0?ooo`2e0?ooo`030<30`000000000000080000000<0
`<300?ooo`3oool0o`3ooomG0?ooo`050820P0000000000000000010@400U03oool005/0oooo0P00
00000`20P800oooo0?ooo`1>0?ooo`040820P000000000000820P;T0oooo1000003o0?oooeP0oooo
1@00002E0?ooo`00F`3oool2000000030820P03oool0oooo04h0oooo00@0P8200000000000000000
^P3oool400000?l0ooooEP3oool00`20P800000000000002000009H0oooo001K0?ooo`80000000<0
P8200?ooo`3oool0C`3oool3000000030820P03oool0oooo0;L0oooo00<0`<300000000000000P00
00000`30`<00oooo0?ooo`3o0?oooe40oooo00D0P82000000000000000000410@02G0?ooo`00F`3o
ool2000000030820P03oool0oooo0500oooo1000002j0?ooo`@00000o`3ooomB0?ooo`D00000V03o
ool005/0oooo0P0000000`20P800oooo0?ooo`1@0?ooo`@00000^P3oool00`20P800000000000002
00000?l0ooooD03oool00`20P800000000000002000009T0oooo001K0?ooo`80000000<0P8200?oo
o`3oool0D@3oool3000000030820P03oool0oooo0;P0oooo00<0P8200000000000000P0000000`30
`<00oooo0?ooo`3o0?oood/0oooo00D0P82000000000000000000410@02J0?ooo`00F`3oool20000
00030820P03oool0oooo0540oooo00@0P8200000000000000000_03oool400000?l0ooooC03oool0
0`20P800000000000002000009/0oooo001K0?ooo`80000000<0P8200?ooo`3oool0D@3oool01@30
`<000000000000000000P8200;/0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`3o
0?ooodL0oooo00D0P82000000000000000000820P02L0?ooo`00F`3oool2000000030820P03oool0
oooo0580oooo1@00002l0?ooo`@0000000<0P8200?ooo`3oool0o`3ooom50?ooo`@0000000<0P820
0?ooo`3oool0V`3oool005/0oooo0P0000000`20P800oooo0?ooo`1C0?ooo`@00000_@3oool40000
0?l0ooooAP3oool00`20P800000000000002000009h0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0E03oool01020P800000000000010@42l0?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool0o`3ooom10?ooo`050820P0000000000000000010@400W`3oool005/0oooo0P0000000`20
P800oooo0?ooo`1E0?ooo`@00000_@3oool4000000030820P03oool0oooo0?l0oooo?`3oool50000
0:00oooo001K0?ooo`80000000<0P8200?ooo`3oool0EP3oool300000;h0oooo1000003o0?oood00
oooo00<0P8200000000000000P00002Q0?ooo`00F`3oool2000000030820P03oool0oooo05H0oooo
00@0P820000000000000@410_@3oool00`30`<00000000000002000000030<30`03oool0oooo0?l0
oooo>`3oool01@20P8000000000000000000@4100:80oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0E`3oool01020P800000000000000002n0?ooo`@00000o`3oooll0?ooo`D00000X`3oool005/0
oooo0P0000000`20P800oooo0?ooo`1G0?ooo`040820P0000000000000000;l0oooo1000003/0?oo
o`@00000B@3oool00`20P80000000000000200000:@0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0F03oool01@20P8000000000000000000`<300;d0oooo00<0`<300000000000000P0000000`30
`<00oooo0?ooo`3X0?ooo`@00000B03oool01@20P8000000000000000000@4100:D0oooo001K0?oo
o`80000000<0P8200?ooo`3oool0F@3oool3000000030820P03oool0oooo0;`0oooo100000000`20
P800oooo0?ooo`3Y0?ooo`<00000A`3oool500000:H0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0F@3oool01020P800000000000000002m0?ooo`030820P0000000000000800000k03oool40000
04D0oooo00<0P8200000000000000P00002W0?ooo`00F`3oool2000000030820P03oool0oooo05X0
oooo100000000`20P800oooo0?ooo`2h0?ooo`050820P0000000000000000020P800k@3oool40000
04@0oooo00D0P82000000000000000000410@02X0?ooo`00F`3oool2000000030820P03oool0oooo
05/0oooo1000002i0?ooo`@0000000<0P8200?ooo`3oool0k03oool4000004<0oooo00<0P8200000
000000000P00002Y0?ooo`00F`3oool2000000030820P03oool0oooo05`0oooo0P0000000`20P800
`<300?ooo`2f0?ooo`050410@0000000000000000020P800k`3oool01020P8000000000000000012
0?ooo`050820P0000000000000000020P800ZP3oool005/0oooo0P0000000`20P800oooo0?ooo`3o
0?oooaL0oooo100000000`20P800oooo0?ooo`3_0?ooo`<00000@@3oool4000000030820P03oool0
oooo0:T0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3ooolF0?ooo`D00000lP3oool30000
0400oooo00<0P8200000000000000P00002/0?ooo`00F`3oool2000000030820P03oool0oooo0?l0
oooo5@3oool01@10@4000000000000000000P8200?<0oooo0`00000o0?ooo`050820P00000000000
00000010@400[@3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?oooa@0oooo100000000`20
P800oooo0?ooo`3b0?ooo`<0000000<0P8200?ooo`3oool0>`3oool500000:h0oooo001K0?ooo`80
000000<0P8200?ooo`3oool0o`3ooolC0?ooo`D00000m@3oool3000000030820P03oool0oooo03X0
oooo00<0P8200000000000000P00002_0?ooo`00F`3oool2000000030820P03oool0oooo0?l0oooo
4P3oool01@10@4000000000000000000P8200?H0oooo00@0P820000000000000P820?03oool01010
@400000000000010@42`0?ooo`00F`3oool2000000030820P03oool0oooo0?l0oooo4@3oool40000
00030820P03oool0oooo0?D0oooo00@0P820000000000000P820?03oool400000;00oooo001K0?oo
o`80000000<0P8200?ooo`3oool0o`3oool@0?ooo`D00000n03oool01020P800000000000020P80l
0?ooo`030820P0000000000000800000[`3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?oo
o`l0oooo00D0@41000000000000000000820P03i0?ooo`040820P000000000000820P3d0oooo00<0
P8200000000000000P0000000`30`<00oooo0?ooo`2[0?ooo`00F`3oool2000000030820P03oool0
oooo0?l0oooo3P3oool4000000030820P03oool0oooo0?P0oooo00@0P820000000000000P820?`3o
ool400000:d0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool=0?ooo`050410@0000000
000000000020P800n`3oool01020P800000000000020P80o0?ooo`030<30`0000000000000800000
00<0`<300?ooo`3oool0Z@3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo``0oooo1000
003m0?ooo`040820P000000000000820P440oooo1000002[0?ooo`00F`3oool2000000030820P03o
ool0oooo0?l0oooo2`3oool4000000030820P03oool0oooo0?/0oooo00@0P820000000000000P820
@P3oool400000:X0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool:0?ooo`050410@000
0000000000000020P800oP3oool01020P800000000000010@4120?ooo`030<30`000000000000080
000000<0`<300?ooo`3oool0YP3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`T0oooo
100000000`20P800oooo0?ooo`3n0?ooo`<00000A03oool400000:P0oooo001K0?ooo`80000000<0
P8200?ooo`3oool0o`3oool80?ooo`D00000o`3oool20?ooo`<00000A03oool00`20P80000000000
000200000:L0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool70?ooo`050410@0000000
000000000020P800o`3oool30?ooo`<00000A@3oool00`20P800000000000002000000030<30`03o
ool0oooo0:<0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool60?ooo`@0000000<0P820
0?ooo`3oool0o`3oool20?ooo`<00000A`3oool400000:D0oooo001K0?ooo`80000000<0P8200?oo
o`3oool0o`3oool50?ooo`D00000o`3oool50?ooo`<00000A`3oool00`20P8000000000000020000
0:@0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool40?ooo`050410@000000000000000
0020P800o`3oool60?ooo`<00000B03oool00`20P800000000000002000000030<30`03oool0oooo
0:00oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool30?ooo`@0000000<0P8200?ooo`3o
ool0o`3oool50?ooo`<00000BP3oool400000:80oooo001K0?ooo`80000000<0P8200?ooo`3oool0
o`3oool20?ooo`D00000o`3oool80?ooo`<00000BP3oool00`20P80000000000000200000:40oooo
001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool10?ooo`050410@0000000000000000020P800
o`3oool90?ooo`<00000B`3oool00`20P800000000000002000000030<30`03oool0oooo09d0oooo
001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool4000000030820P03oool0oooo0?l0oooo203o
ool3000004d0oooo1000002O0?ooo`00F`3oool2000000030820P03oool0oooo0?h0oooo00D0@410
00000000000000000820P03o0?ooo`/0oooo0`00001=0?ooo`030<30`000000000000080000000<0
`<300?ooo`3oool0V`3oool005/0oooo0P0000000`20P800oooo0?ooo`3^0?ooo`l0000000<0oooo
0000000000000P00003o0?ooo``0oooo0`00001?0?ooo`@00000W@3oool005/0oooo0P0000000`20
P800oooo0?ooo`3_0?ooo`h0000000<0oooo0820P00000000`00003o0?ooo`/0oooo0`00001@0?oo
o`@00000W03oool005/0oooo0P0000000`20P800oooo0?ooo`3`0?ooo`030410@0000000000000/0
000000<0oooo0820P00000000P0000000`10@400oooo0?ooo`3o0?ooo`P0oooo0`00001@0?ooo`03
0<30`000000000000080000000<0`<300?ooo`3oool0V03oool005/0oooo0P0000000`20P800oooo
0?ooo`3a0?ooo`800000203oool00`20P8000000000000020?ooo`030820P0000000000000800000
o`3oool90?ooo`<00000DP3oool4000009X0oooo001K0?ooo`80000000<0P8200?ooo`3oool0lP3o
ool00`000000P8200?ooo`080?ooo`0400000020P800oooo0?ooo`D00000o`3oool70?ooo`040820
P0000000000000000580oooo00<0P8200000000000000P00002I0?ooo`00F`3oool2000000030820
P03oool0oooo0?<0oooo00<0@4100820P03oool0203oool01@30`<00oooo0?ooo`3oool0P82000<0
000000<0@4100?ooo`3oool0o`3oool40?ooo`040820P00000000000000005<0oooo00<0P8200000
000000000P0000000`30`<00oooo0?ooo`2E0?ooo`00F`3oool2000000030820P03oool0oooo0?@0
oooo00<000000820P03oool0303oool00`20P80000000000000200000?l0oooo1@3oool01020P800
000000000000001E0?ooo`@00000U`3oool005/0oooo0P0000000`20P800oooo0?ooo`3e0?ooo`03
0000003oool0oooo00`0oooo1@00003o0?ooo`@0oooo00@0P8200000000000000000E@3oool00`20
P800000000000002000009H0oooo001K0?ooo`80000000<0P8200?ooo`3oool0m@3oool00`30`<00
00000820P00=0?ooo`050820P0000000000000000010@400o`3oool30?ooo`040820P00000000000
000005H0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2B0?ooo`00F`3oool20000
00030820P03oool0oooo0?H0oooo0P0000000`20P800oooo0?ooo`0;0?ooo`030820P00000000000
00800000o`3oool20?ooo`040820P00000000000000005P0oooo1000002D0?ooo`00F`3oool20000
00030820P03oool0oooo0?L0oooo00<0P8200000003oool03@3oool00`20P8000000000000020000
00030<30`03oool0oooo0?d0oooo00@0`<300000000000000000F03oool00`30`<00000000000002
000000030820P03oool0oooo0900oooo001K0?ooo`80000000<0P8200?ooo`3oool0c`3oool=0000
00T0oooo200000000`20P800oooo0?ooo`080?ooo`030820P0000000oooo00h0oooo1000003o0?oo
o`40oooo0`00001J0?ooo`<00000T`3oool005/0oooo0P0000000`20P800oooo0?ooo`3B0?ooo`L0
0000303oool6000000d0oooo00<0P8200000000000003P3oool00`20P80000000000000200000?l0
oooo0`00001I0?ooo`D00000TP3oool005/0oooo0P0000000`20P800oooo0?ooo`3C0?ooo`050820
P0000000000000000010@4002`3oool00`20P800000000000002000000030820P03oool0oooo00h0
oooo0P0000000`30`<00oooo0?ooo`0<0?ooo`060820P0000000000000000010@400P820o03oool0
1030`<00000000000010@41H0?ooo`050410@0000000000000000020P800T`3oool005/0oooo0P00
00000`20P800oooo0?ooo`3D0?ooo`<0000000<0P8200?ooo`3oool0203oool00`20P80000000000
0002000000030820P03oool0oooo00l0oooo0P0000000`20P800oooo0?ooo`0>0?ooo`D00000n`3o
ool01020P800000000000020P81G0?ooo`@0000000<0P8200?ooo`3oool0TP3oool005/0oooo0P00
00000`20P800oooo0?ooo`3D0?ooo`<0000000<0P8200?ooo`3oool0203oool00`20P80000000000
0002000001<0oooo0P00000@0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0n03o
ool01020P800000000000020P81F0?ooo`D00000U@3oool005/0oooo0P0000000`20P800oooo0?oo
o`3D0?ooo`<0000000<0P8200?ooo`3oool01`3oool01@20P8000000000000000000@41001@0oooo
0P0000000`20P800oooo0?ooo`0?0?ooo`050410@0000000000000000020P800n@3oool01020P800
000000000020P81E0?ooo`050410@0000000000000000020P800UP3oool005/0oooo0P0000000`20
P800oooo0?ooo`3D0?ooo`<0000000<0P8200?ooo`3oool01`3oool4000000030820P03oool0oooo
00L0oooo00<000000?ooo`3oool0203oool300000180oooo1@00003h0?ooo`040820P00000000000
0820P5@0oooo100000000`20P800oooo0?ooo`2E0?ooo`00F`3oool2000000030820P03oool0oooo
0=@0oooo0`0000000`20P800oooo0?ooo`060?ooo`D000002P3oool00`000000P8200?ooo`080?oo
o`<000004`3oool4000000030820P03oool0oooo0?D0oooo00@0P820000000000000P820D`3oool5
000009P0oooo001K0?ooo`80000000<0P8200?ooo`3oool0e03oool3000000030820P03oool0oooo
00D0oooo00D0@41000000000000000000820P00;0?ooo`030820P010@400oooo00L0oooo1000000D
0?ooo`050410@0000000000000000020P800mP3oool01020P800000000000020P81B0?ooo`050410
@0000000000000000020P800V@3oool005/0oooo0P0000000`20P800oooo0?ooo`3D0?ooo`<00000
00<0P8200?ooo`3oool01@3oool4000000d0oooo0P0000060?ooo`040820P00000000000000001H0
oooo1@00003e0?ooo`<00000DP3oool4000000030820P03oool0oooo09P0oooo001K0?ooo`800000
00<0P8200?ooo`3oool0e03oool3000000030820P03oool0oooo00@0oooo100000000`20P800oooo
0?ooo`0;0?ooo`040820P000000000000820P0<0oooo1@00000G0?ooo`@0000000<0P8200?ooo`3o
ool0lP3oool300000540oooo00<0P8200000000000000P00002K0?ooo`00F`3oool2000000030820
P03oool0oooo0=@0oooo0`0000000`20P800oooo0?ooo`030?ooo`D000003P3oool00`30`<000000
00000008000000030<30`03oool0oooo01H0oooo00D0@41000000000000000000820P03c0?ooo`<0
0000803oool00`20P800@41000000004000000030410@020P800oooo02H0oooo00D0P82000000000
000000000820P02L0?ooo`00F`3oool2000000030820P03oool0oooo0=@0oooo0`0000000`20P800
oooo0?ooo`020?ooo`030820P00000000000008000004@3oool8000001/0oooo1@00003b0?ooo`<0
0000803oool4000000040820P03oool0oooo0?ooo`80000000<0P8200?ooo`3oool08P3oool40000
00030820P03oool0oooo09/0oooo001K0?ooo`80000000<0P8200?ooo`3oool0e03oool300000005
0820P03oool0oooo0?ooo`20P8000`0000000`10@400oooo0?ooo`0B0?ooo`@0P82000<0`<300?oo
o`3oool06`3oool01@20P8000000000000000000@4100?40oooo0`00000Q0?ooo`80P8201P3oool0
0`20P80000000820P00R0?ooo`050410@0000000000000000020P800WP3oool005/0oooo0P000000
0`20P800oooo0?ooo`3D0?ooo`/0000000<0P8200?ooo`3oool0=@3oool00`20P800000000000002
00000?00oooo0`00000Z0?ooo`80000000<0P8200?ooo`3oool07P3oool4000000030820P03oool0
oooo09d0oooo001K0?ooo`80000000<0P8200?ooo`3oool0e03oool<000003P0oooo100000000`20
P800oooo0?ooo`3/0?ooo`@00000:P3oool00`20P80000000820P00N0?ooo`030820P00000000000
00<00000X03oool005/0oooo0P0000000`20P800oooo0?ooo`3D0?ooo`<0000000<0P8200?ooo`3o
ool00P3oool00`30`<00P8200820P003000000030410@020P800oooo03@0oooo00D0P82000000000
000000000820P03]0?ooo`<00000:`3oool00`20P80000000410@00M0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0W`3oool005/0oooo0P0000000`20P800oooo0?ooo`3D0?ooo`<0
000000<0P8200?ooo`3oool01P3oool5000003D0oooo00<0P8200000000000000P00003/0?ooo`<0
0000:`3oool00`20P80000000000000L0?ooo`D00000X`3oool005/0oooo0P0000000`20P800oooo
0?ooo`3D0?ooo`<0000000<0P8200?ooo`3oool01`3oool4000000030820P03oool0oooo03<0oooo
100000000`20P800oooo0?ooo`3Y0?ooo`<00000:`3oool00`20P80000000000000K0?ooo`030820
P0000000000000800000Y03oool005/0oooo0P0000000`20P800oooo0?ooo`3D0?ooo`<0000000<0
P8200?ooo`3oool0203oool4000003D0oooo00D0P82000000000000000000<30`03Z0?ooo`040820
P00000000000000002/0oooo0`00000J0?ooo`050820P0000000000000000010@400Y@3oool005/0
oooo0P0000000`20P800oooo0?ooo`3D0?ooo`<0000000<0P8200?ooo`3oool0203oool00`20P800
000000000002000003<0oooo00<0P8200000000000000P00003[0?ooo`<00000:`3oool4000001T0
oooo1@00002V0?ooo`00F`3oool2000000030820P03oool0oooo0=@0oooo0`0000000`20P800oooo
0?ooo`080?ooo`030820P0000000000000800000<`3oool400000>`0oooo0`00000Z0?ooo`@00000
00<0P8200?ooo`3oool05P3oool00`20P80000000000000200000:L0oooo001K0?ooo`80000000<0
P8200?ooo`3oool0e03oool3000000030820P03oool0oooo00P0oooo00<0P8200000000000000P00
000a0?ooo`050820P0000000000000000010@400k@3oool3000000<0oooo0`20P807000000<0P820
203oool00`20P80000000000000400000080P8201@3oool00`30`<00P8200820P005000000030<30
`03oool0oooo01D0oooo00D0P82000000000000000000410@02X0?ooo`00F`3oool2000000030820
P03oool0oooo0=@0oooo0`0000000`20P800oooo0?ooo`080?ooo`030820P0000000000000800000
<03oool00`20P80000000000000200000>h0oooo0`0000070?ooo`D00000303oool5000000/0oooo
1@00000H0?ooo`030820P0000000000000800000Z@3oool005/0oooo0P0000000`20P800oooo0?oo
o`3D0?ooo`<0000000<0P8200?ooo`3oool0203oool00`10@400000000000002000002l0oooo00D0
P82000000000000000000410@03^0?ooo`040820P000000000000410@0L0oooo00@0P82000000000
000000002`3oool00`20P800000000000002000000030410@03oool0oooo00/0oooo00@0`<300000
0020P800`<305`3oool01@20P8000000000000000000P8200:X0oooo001K0?ooo`80000000<0P820
0?ooo`3oool0e03oool3000000030820P03oool0oooo00P0oooo1000000_0?ooo`D00000k`3oool0
1020P800000000000020P8070?ooo`040820P00000000000000000/0oooo1@00000@0?ooo`030000
003oool0oooo01D0oooo100000000`20P800oooo0?ooo`2Y0?ooo`00F`3oool2000000030820P03o
ool0oooo0=@0oooo0`0000000`20P800oooo0?ooo`070?ooo`D00000;P3oool00`20P80000000000
000200000?00oooo00@0P820000000000000P8201`3oool01020P800000000000000000:0?ooo`03
0820P00000000000008000004@3oool00`000000P8200?ooo`0D0?ooo`030820P000000000000080
0000[03oool005/0oooo0P0000000`20P800oooo0?ooo`3D0?ooo`<0000000<0P8200?ooo`3oool0
1@3oool00`30`<00000000000003000000030<30`03oool0oooo02/0oooo00D0P820000000000000
00000410@03a0?ooo`040410@000000000000820P0L0oooo00@0P82000000000000000002P3oool4
000001<0oooo00<000000820P03oool04P3oool01@20P8000000000000000000@4100:d0oooo001K
0?ooo`80000000<0P8200?ooo`3oool0d`3oool6000000D0oooo1P00000^0?ooo`D00000lP3oool3
000000P0oooo00@0P82000000000000000002@3oool4000000030820P03oool0oooo0140oooo0P00
00000`20P800oooo0?ooo`0?0?ooo`D00000[P3oool005/0oooo0P0000000`20P800oooo0?ooo`3B
0?oooa00000000<0P8200?ooo`3oool0;03oool00`20P80000000000000200000?<0oooo0`000008
0?ooo`040820P00000000000000000P0oooo1@00000D0?ooo`80000000<0P8200?ooo`3oool03P3o
ool00`20P80000000000000200000:l0oooo001K0?ooo`80000000<0P8200?ooo`3oool0c`3ooolA
0820P300oooo00D0P82000000000000000000410@03c0?ooo`040820P00000000000000000P0oooo
00@0P82000000000000000001`3oool00`20P800000000000002000000/0oooo00<0P8200<30`03o
ool01P3oool01020P800000000000020P80@0?ooo`@00000/03oool005/0oooo0P0000000`20P800
oooo0?ooo`3o0?oooa00oooo1@00003d0?ooo`<000002@3oool01020P80000000000000000070?oo
o`@000003@3oool00`000000oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool03P3oool00`20
P80000000000000200000:l0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool?0?ooo`03
0820P0000000000000800000m@3oool3000000T0oooo00@0P82000000000000000001P3oool40000
00030820P03oool0oooo00/0oooo00<0P8200000000000000`3oool00`20P8000000000000020000
0180oooo1@00002^0?ooo`00F`3oool2000000030820P03oool0oooo0?l0oooo3P3oool01@20P800
0000000000000000@4100?H0oooo0`0000090?ooo`040820P00000000000000000D0oooo00<0`<30
0000000000000P0000000`30`<00oooo0?ooo`0<0?ooo`030820P0000000000000D0000000<0@410
0?ooo`3oool04P3oool01@20P8000000000000000000@4100:d0oooo001K0?ooo`80000000<0P820
0?ooo`3oool0o`3oool=0?ooo`030820P0000000000000800000mP3oool3000000X0oooo00@0P820
00000000000000001@3oool400000180oooo00<0P8200000000000000P00000G0?ooo`030820P000
0000000000800000[03oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo``0oooo00D0P820
00000000000000000820P03g0?ooo`<000002P3oool01020P80000000000000000040820P0@00000
<03oool01@20P8000000000000000000@4100:/0oooo001K0?ooo`80000000<0P8200?ooo`3oool0
o`3oool;0?ooo`@0000000<0P8200?ooo`3oool0mP3oool3000000X0oooo00<0P820000000000000
2P00000a0?ooo`@00000ZP3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`X0oooo00<0
P8200000000000000P00003h0?ooo`040820P00000000000000000X0oooo00@0P820000000000000
00001@3oool00`20P800000000000003000002l0oooo00<0P8200000000000000P00002Y0?ooo`00
F`3oool2000000030820P03oool0oooo0?l0oooo2@3oool01@20P8000000000000000000@4100?T0
oooo00@0P820000000000000P8202P3oool01020P80000000000000000070?ooo`030<30`020P800
000000<0000000<0`<300?ooo`3oool0:`3oool01@20P8000000000000000000@4100:P0oooo001K
0?ooo`80000000<0P8200?ooo`3oool0o`3oool80?ooo`D00000nP3oool3000000030820P03oool0
oooo00P0oooo00@0P82000000000000000002P3oool4000002h0oooo00<0P8200000000000000P00
002W0?ooo`00F`3oool2000000030820P03oool0oooo0?l0oooo1`3oool00`20P800000000000002
00000?/0oooo0`0000000`20P800oooo0?ooo`080?ooo`040820P00000000000000000X0oooo00<0
P8200000000000000P00000^0?ooo`D00000YP3oool005/0oooo0P0000000`20P800oooo0?ooo`3o
0?ooo`H0oooo00D0P82000000000000000000410@03l0?ooo`<000002`3oool01020P80000000000
0000000:0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0;03oool01@20P8000000
000000000000@4100:D0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool50?ooo`D00000
o03oool4000000/0oooo00@0P82000000000000000002`3oool5000002l0oooo00<0P82000000000
00000P00002T0?ooo`00F`3oool2000000030820P03oool0oooo0?l0oooo103oool00`20P8000000
0000000200000?d0oooo1000000;0?ooo`040820P00000000000000000/0oooo1@00000`0?ooo`D0
0000X`3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`<0oooo00D0P820000000000000
00000410@03m0?ooo`040<30`00000000000000000`0oooo00@0P82000000000000000002`3oool5
00000340oooo00D0P82000000000000000000410@02R0?ooo`00F`3oool2000000030820P03oool0
oooo0?l0oooo0P3oool500000?h0oooo00@0P8200000000000000000303oool01020P80000000000
0000000;0?ooo`D00000<P3oool00`20P80000000000000200000:40oooo001K0?ooo`80000000<0
P8200?ooo`3oool0o`3oool10?ooo`030820P0000000000000800000o`3oool00`20P80000000000
000=0?ooo`040820P00000000000000000X0oooo00<0P8200000000000000`00000c0?ooo`D00000
X03oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`050820P0000000000000000010@400
o`3oool10?ooo`030410@0000000000000d0oooo00@0P82000000000000000002P3oool00`10@400
000000000002000003D0oooo00D0P82000000000000000000410@02O0?ooo`00F`3oool200000003
0820P03oool0oooo0?h0oooo00<0P8200000000000000P00003o0?ooo`80oooo0`00000=0?ooo`04
0820P00000000000000000T0oooo1@00000g0?ooo`030820P0000000000000800000WP3oool005/0
oooo0P0000000`20P800oooo0?ooo`3n0?ooo`040410@000000000000820P?l0oooo0P3oool01020
P800000000000020P80=0?ooo`040410@0000000000000000080P8201@3oool00`20P80000000000
0003000000030<30`03oool0oooo03H0oooo00D0P82000000000000000000410@02M0?ooo`00F`3o
ool2000000030820P03oool0oooo0?h0oooo1000003o0?ooo`80oooo0`0000000`20P800oooo0?oo
o`0:0?oooa000000?@3oool4000009`0oooo001K0?ooo`80000000<0P8200?ooo`3oool0oP3oool0
0`20P80000000000000200000?l0oooo0@3oool3000000X0oooo4@00000o0?ooo`030820P0000000
000000800000V`3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`050820P00000000000
00000010@400oP3oool4000005/0oooo00D0P82000000000000000000410@02J0?ooo`00F`3oool2
000000030820P03oool0oooo0?l0oooo0@3oool00`20P80000000000000200000?d0oooo0`00001M
0?ooo`030820P0000000000000800000V@3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?oo
o`80oooo1@00003k0?ooo`040820P00000000000000005h0oooo1@00002H0?ooo`00F`3oool20000
00030820P03oool0oooo0?l0oooo0`3oool01@20P8000000000000000000@4100;h0oooo00<0P820
0410@0000000100000000`10@400P8200?ooo`0b0?ooo`040410@000000000000410@5l0oooo00D0
P82000000000000000000410@02G0?ooo`00F`3oool2000000030820P03oool0oooo0?l0oooo103o
ool00`20P80000000000000200000;d0oooo100000001020P800oooo0?ooo`3oool2000000030820
P03oool0oooo02l0oooo0`0000000`20P800oooo0?ooo`1N0?ooo`030820P0000000000000800000
UP3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`D0oooo1@00002m0?ooo`8000001P3o
ool200000340oooo0`00001R0?ooo`D00000U@3oool005/0oooo0P0000000`20P800oooo0?ooo`3o
0?ooo`H0oooo00D0P82000000000000000000410@0350?ooo`80000000<0`<300?ooo`3oool0;03o
ool4000006<0oooo00D0P82000000000000000000410@02D0?ooo`00F`3oool2000000030820P03o
ool0oooo0?l0oooo1`3oool00`20P80000000000000200000<@0oooo00<0P82000000020P800;P3o
ool3000006D0oooo00<0P8200000000000000P00002C0?ooo`00F`3oool2000000030820P03oool0
oooo0?l0oooo203oool00`20P800000000000002000000030<30`03oool0oooo0<00oooo00<0P820
00000010@400;@3oool4000006H0oooo1@00002B0?ooo`00F`3oool2000000030820P03oool0oooo
0?l0oooo2P3oool400000<80oooo00<0P820000000000000;03oool01020P800000000000000001V
0?ooo`030820P0000000000000800000T`3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?oo
o`X0oooo00<0P8200000000000000P0000310?ooo`030820P0000000000002`0oooo00@0P8200000
000000000000IP3oool4000009@0oooo001K0?ooo`80000000<0P8200?ooo`3oool0o`3oool;0?oo
o`050820P0000000000000000010@400`03oool3000002`0oooo00@0@410000000000000P820I03o
ool00`20P800000000000002000000030<30`03oool0oooo0980oooo001K0?ooo`80000000<0P820
0?ooo`3oool0Q`3oool9000007`0oooo1000002n0?ooo`@00000;03oool3000000030820P03oool0
oooo0640oooo00<0P8200000000000000P00002F0?ooo`00F`3oool2000000030820P03oool0oooo
08T0oooo00<0P8200000000000000P00001n0?ooo`030820P0000000000000800000_03oool40000
00030820P03oool0oooo02T0oooo1000001T0?ooo`@00000U`3oool005/0oooo0P0000000`20P800
oooo0?ooo`2:0?ooo`<00000P03oool01@20P8000000000000000000@4100:<0oooo0`20P8060000
00040410@020P800P8200<30`0L0oooo00<0`<300820P020P8001@0000000`30`<00oooo0?ooo`0X
0?ooo`050820P0000000000000000020P800HP3oool00`20P800000000000002000000030<30`03o
ool0oooo09D0oooo001K0?ooo`80000000<0P8200?ooo`3oool0RP3oool300000840oooo00<0P820
0000000000000P00002U0?ooo`030820P0000000000000<000003@3oool5000002`0oooo1000001R
0?ooo`030820P0000000000000800000V@3oool005/0oooo0P0000000`20P800oooo0?ooo`2:0?oo
o`<00000PP3oool500000:D0oooo1000000?0?ooo`040820P000000000000820P2`0oooo0`00001S
0?ooo`@00000VP3oool005/0oooo0P0000000`20P800oooo0?ooo`2:0?ooo`<00000P`3oool01@20
P8000000000000000000@4100:@0oooo1000000@0?ooo`80P820;03oool01020P800000000000010
@41Q0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0V03oool005/0oooo0P000000
0`20P800oooo0?ooo`2:0?ooo`<00000Q03oool00`20P80000000000000200000:<0oooo1000000A
0?ooo`0300000020P800oooo02X0oooo0`0000000`20P800oooo0?ooo`1O0?ooo`@00000W03oool0
05/0oooo0P0000000`20P800oooo0?ooo`2:0?ooo`<00000Q@3oool500000:80oooo1000000B0?oo
o`030000003oool0oooo02T0oooo0`00001Q0?ooo`@00000W@3oool005/0oooo0P0000000`20P800
oooo0?ooo`2:0?ooo`<00000QP3oool01@20P8000000000000000000@4100:40oooo1000000B0?oo
o`80000000<0`<300?ooo`3oool09P3oool3000000030820P03oool0oooo05d0oooo00<0`<300000
000000000P0000000`30`<00oooo0?ooo`2K0?ooo`00F`3oool2000000030820P03oool0oooo08X0
oooo0`0000270?ooo`030820P0000000000000800000X03oool400000180oooo0P0000000`20P800
oooo0?ooo`0U0?ooo`@00000H03oool4000009l0oooo001K0?ooo`80000000<0P8200?ooo`3oool0
LP3oool00`30`<00oooo0?ooo`0E0?ooo`<00000R03oool00`20P800000000000002000000030<30
`03oool0oooo09`0oooo100000080?ooo`030820P030`<00oooo00H0oooo00@0P820000000000000
P8209P3oool01@30`<000000000000000000P82005h0oooo00<0P8200000000000000P0000000`30
`<00oooo0?ooo`2M0?ooo`00F`3oool2000000030820P03oool0oooo0740oooo0P00000G0?ooo`<0
0000RP3oool4000009h0oooo100000090?ooo`030000003oool0oooo00@0oooo100000000`20P800
oooo0?ooo`0T0?ooo`@00000GP3oool00`20P80000000000000200000:40oooo001K0?ooo`800000
00<0P8200?ooo`3oool0L@3oool2000001L0oooo0`00002:0?ooo`030820P0000000000000800000
W@3oool4000000T0oooo00<0P8200000000000000`3oool00`20P800000000000002000002L0oooo
0`0000000`20P800oooo0?ooo`1L0?ooo`@00000XP3oool005/0oooo0P0000000`20P800oooo0?oo
o`1`0?ooo`040820P000000000000820P1H0oooo0`00002;0?ooo`050820P0000000000000000010
@400W03oool4000000X0oooo00<0P8200000000000001@0000000`10@400oooo0?ooo`0U0?ooo`@0
000000<0`<300?ooo`3oool0FP3oool00`20P800000000000002000000030<30`03oool0oooo0:00
oooo001K0?ooo`80000000<0P8200?ooo`3oool0L03oool01020P800000000000000000F0?ooo`<0
0000S@3oool4000009/0oooo1000000<0?ooo`030820P0000000000000800000:03oool00`20P800
000000000002000005`0oooo00<0P8200000000000000P00002T0?ooo`00F`3oool2000000030820
P03oool0oooo0700oooo1@00000E0?ooo`<00000S@3oool00`20P800000000000002000009X0oooo
1000000i0?ooo`040820P00000000000000005d0oooo1000002U0?ooo`00F`3oool2000000030820
P03oool0oooo06l0oooo00<0P8200000000000000`00000E0?ooo`<00000SP3oool4000000030820
P03oool0oooo09L0oooo1000000i0?ooo`<0000000<0P8200?ooo`3oool0F@3oool00`20P8000000
00000002000000030<30`03oool0oooo0:<0oooo001K0?ooo`80000000<0P8200?ooo`3oool0K`3o
ool3000000040820P000000000000820P1@0oooo0`00002=0?ooo`030820P0000000000000800000
VP3oool4000003P0oooo0`0000000`20P800oooo0?ooo`1I0?ooo`030820P0000000000000800000
Y`3oool005/0oooo0P0000000`20P800oooo0?ooo`1^0?ooo`@0000000@0P820000000000000P820
503oool3000008d0oooo1000002K0?ooo`@00000>03oool3000000030820P03oool0oooo05T0oooo
1000002X0?ooo`00F`3oool2000000030820P03oool0oooo06h0oooo100000020?ooo`800000503o
ool3000008/0oooo00D0P82000000000000000000410@02L0?ooo`@00000=`3oool4000005X0oooo
00<0`<300000000000000P0000000`30`<00oooo0?ooo`2V0?ooo`00F`3oool2000000030820P03o
ool0oooo06d0oooo00<0P8200000000000000P0000020?ooo`800000503oool3000008X0oooo00<0
P8200000000000000P00002M0?ooo`@00000=P3oool01020P800000000000000001K0?ooo`@00000
ZP3oool005/0oooo0P0000000`20P800oooo0?ooo`1]0?ooo`040410@00000000000000000@0oooo
0P00000?0?ooo`040<30`020P800oooo0<30`0<00000R@3oool01@20P8000000000000000000@410
09h0oooo1000000f0?ooo`<0000000<0@4100?ooo`3oool0E`3oool01@20P8000000000000000000
@4100:/0oooo001K0?ooo`80000000<0P8200?ooo`3oool0K@3oool3000000030820P03oool0oooo
0080oooo0P00000@0?ooo`H00000R03oool5000009l0oooo1000000e0?ooo`@00000F@3oool00`20
P80000000000000200000:`0oooo001K0?ooo`80000000<0P8200?ooo`3oool0K03oool400000003
0820P03oool0oooo0080oooo00<0P8200000000000004@3oool01020P80000000000000000270?oo
o`030820P0000000000000800000X03oool4000003D0oooo1000001I0?ooo`@00000[@3oool005/0
oooo0P0000000`20P800oooo0?ooo`1/0?ooo`@000001@3oool01030`<00000000000030`<0B0?oo
o`030<30`020P800oooo08D0oooo00D0P82000000000000000000410@02Q0?ooo`@00000<`3oool0
1@30`<000000000000000000P82005P0oooo00<0P8200000000000000P0000000`30`<00oooo0?oo
o`2[0?ooo`00F`3oool2000000030820P03oool0oooo06/0oooo1@0000060?ooo`80000000<0P820
0?ooo`3oool0U`3oool500000:80oooo1000000c0?ooo`040820P00000000000000005P0oooo00<0
P8200000000000000P00002_0?ooo`00F`3oool2000000030820P03oool0oooo06/0oooo10000007
0?ooo`80000000<0P8200?ooo`3oool0UP3oool00`20P80000000000000200000:<0oooo1000000c
0?ooo`<0000000<0P8200?ooo`3oool0EP3oool400000;00oooo001K0?ooo`80000000<0P8200?oo
o`3oool0JP3oool01@20P8000000000000000000P82000P0oooo0P00002G0?ooo`050820P0000000
000000000010@400Y03oool400000380oooo00@0P8200000000000000000F@3oool01010@4000000
00000010@42`0?ooo`00F`3oool2000000030820P03oool0oooo06X0oooo1000000:0?ooo`800000
U@3oool500000:D0oooo1000000a0?ooo`@00000FP3oool00`20P80000000000000200000:l0oooo
001K0?ooo`80000000<0P8200?ooo`3oool0JP3oool3000000030820P03oool0oooo00P0oooo0P00
002D0?ooo`030820P0000000000000800000YP3oool400000340oooo0`00001L0?ooo`D00000[P3o
ool005/0oooo0P0000000`20P800oooo0?ooo`1Y0?ooo`050820P0000000000000000020P8002P3o
ool00`10@40000000820P02B0?ooo`050820P0000000000000000010@400YP3oool00`10@4000000
00000003000000030<30`03oool0oooo02`0oooo00@0@410000000000000P820G@3oool01@20P800
0000000000000000@4100:d0oooo001K0?ooo`80000000<0P8200?ooo`3oool0J@3oool4000000/0
oooo00<0P820000000000000T@3oool00`20P80000000000000200000:@0oooo300000000`20P800
oooo0?ooo`0X0?ooo`@00000G`3oool00`20P80000000000000200000:`0oooo001K0?ooo`800000
00<0P8200?ooo`3oool0J03oool5000000`0oooo0P0000000`20P800oooo0?ooo`2>0?ooo`@00000
f`3oool01020P800000000000000001Q0?ooo`@0000000<0P8200?ooo`3oool0Z@3oool005/0oooo
0P0000000`20P800oooo0?ooo`1W0?ooo`030<30`00000000000008000003@3oool2000000030820
P03oool0oooo08`0oooo00D0P82000000000000000000410@03L0?ooo`<00000H`3oool01@20P800
0000000000000000P8200:X0oooo001K0?ooo`80000000<0P8200?ooo`3oool0I`3oool01020P800
000000000000000?0?ooo`800000S@3oool00`20P80000000000000200000=`0oooo0`0000000`20
P800oooo0?ooo`1R0?ooo`030820P0000000000000800000Z@3oool005/0oooo0P0000000`20P800
oooo0?ooo`1W0?ooo`040410@00000000000000000l0oooo00<0P82000000020P800R`3oool01@20
P8000000000000000000@4100=/0oooo00D0`<3000000000000000000820P01V0?ooo`050820P000
0000000000000010@400Z03oool005/0oooo0P0000000`20P800oooo0?ooo`1W0?ooo`<0000000<0
P8200?ooo`3oool03P3oool2000008X0oooo1@00003L0?ooo`<0000000<0P8200?ooo`3oool0IP3o
ool00`20P80000000000000200000:L0oooo001K0?ooo`80000000<0P8200?ooo`3oool0IP3oool4
000000030820P03oool0oooo00h0oooo0P0000290?ooo`030820P0000000000000800000g03oool4
000006X0oooo1@00002V0?ooo`00F`3oool2000000030820P03oool0oooo06D0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`0>0?ooo`<0000000<0`<300?ooo`3oool0Q03oool01@20
P8000000000000000000@4100=/0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`1Y
0?ooo`050820P0000000000000000010@400Y@3oool005/0oooo0P0000000`20P800oooo0?ooo`1T
0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool03P3oool4000008D0oooo1@00003L
0?ooo`@00000KP3oool00`20P80000000000000200000:@0oooo001K0?ooo`80000000<0P8200?oo
o`3oool0I03oool7000000h0oooo1`0000230?ooo`030820P0000000000000800000g03oool40000
00030820P03oool0oooo06d0oooo1@00002S0?ooo`00F`3oool2000000030820P03oool0oooo0680
oooo2`20P8000`30`<00oooo0?ooo`080?ooo`T0P820P@3oool01@20P8000000000000000000@410
0=/0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`1_0?ooo`050820P00000000000
00000010@400XP3oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`80oooo1@00003L0?oo
o`@00000M03oool00`20P80000000000000200000:40oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0o`3oool10?ooo`030820P0000000000000800000eP3oool2000000@0oooo100000000`20P800
oooo0?ooo`1c0?ooo`D00000X03oool005/0oooo0P0000000`20P800oooo0?ooo`3o0?ooo`050820
P0000000000000000010@400e@3oool01`20P800@410000000000000P8200?ooo`30`<0010000000
0`20P800oooo0?ooo`1e0?ooo`050820P0000000000000000010@400W`3oool005/0oooo0P000000
0`20P800oooo0?ooo`3n0?ooo`030820P0000000000000800000e@3oool6000000030?ooo`000000
000000800000NP3oool00`20P800000000000002000009h0oooo001K0?ooo`80000000<0P8200?oo
o`3oool0oP3oool01010@400000000000020P83D0?ooo`030820P0000000000000T0000000<0`<30
0?ooo`3oool0N@3oool01@20P8000000000000000000@41009d0oooo001K0?ooo`80000000<0P820
0?ooo`3oool0o`3oool00`000000P8200?ooo`3B0?ooo`030820P0000000000000X00000O`3oool4
000009`0oooo001K0?ooo`80000000<0P8200?ooo`3oool0oP3oool2000000030820P03oool0oooo
0=40oooo300000200?ooo`030820P0000000000000800000V`3oool005/0oooo0P0000000`20P800
oooo0?ooo`3n0?ooo`80000000<0P8200?ooo`3oool0c`3oool00`20P80000000000000;00000003
0820P03oool0oooo07h0oooo00D0P82000000000000000000410@02J0?ooo`00F`3oool200000003
0820P03oool0oooo0?h0oooo0P0000000`20P800oooo0?ooo`3>0?oooa000000P@3oool00`20P800
000000000002000009T0oooo001K0?ooo`80000000<0P8200?ooo`3oool0oP3oool2000000030820
P03oool0oooo0<d0oooo4P0000210?ooo`D00000V03oool005/0oooo0P0000000`20P800oooo0?oo
o`3n0?ooo`80000000<0P8200?ooo`3oool0c03oool00`10@40000000000000@000000030<30`03o
ool0oooo07l0oooo00D0P82000000000000000000410@02G0?ooo`00F`3oool2000000030820P03o
ool0oooo0?h0oooo0P0000000`20P800oooo0?ooo`3;0?oooa@0000000<0P8200?ooo`3oool0P03o
ool00`20P800000000000002000009H0oooo001K0?ooo`80000000<0P8200?ooo`3oool0oP3oool2
000000030820P03oool0oooo0<X0oooo5@0000000`20P800oooo0?ooo`210?ooo`D00000U@3oool0
05/0oooo0P0000000`20P800oooo0?ooo`3n0?ooo`80000000<0P8200?ooo`3oool0b@3oool00`10
@40000000000000C000000030410@03oool0oooo0880oooo00D0P82000000000000000000410@02D
0?ooo`00F`3oool2000000030820P03oool0oooo0?h0oooo0P0000000`20P800oooo0?ooo`380?oo
oaP00000Q@3oool00`20P800000000000002000009<0oooo001K0?ooo`80000000<0P8200?ooo`3o
ool0oP3oool2000000030820P03oool0oooo0<H0oooo00<0`<300000000000005`0000260?ooo`D0
0000TP3oool005/0oooo0P0000000`20P800oooo0?ooo`3n0?ooo`80000000<0P8200?ooo`3oool0
a@3ooolL000008@0oooo00<0P8200000000000000P00002C0?ooo`00F`3oool2000000030820P03o
ool0oooo0?h0oooo0P0000000`20P800oooo0?ooo`340?oooad00000Q03oool4000009@0oooo001K
0?ooo`80000000<0P8200?ooo`3oool0oP3oool2000000030820P03oool0oooo0<<0oooo00<0@410
0000000000006`0000220?ooo`030820P000000000000080000000<0`<300?ooo`3oool0TP3oool0
05/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo
0<40oooo00<0P8200000000000007@0000210?ooo`030820P0000000000000800000UP3oool005/0
oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0<40
oooo800000210?ooo`@00000U`3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000
VP3oool2000000030820P03oool0oooo0;l0oooo00<0P8200000000000007`00001o0?ooo`030820
P000000000000080000000<0`<300?ooo`3oool0U@3oool005/0oooo0P0000000`20P800oooo0?oo
o`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0;h0oooo8`00001n0?ooo`030820P000
0000000000800000V@3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2
000000030820P03oool0oooo0?l0ooooH03oool4000009X0oooo001K0?ooo`80000000<0P8200?oo
o`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo0?ooo`3o0?oooeh0oooo00<0`<300000
000000000P0000000`30`<00oooo0?ooo`2H0?ooo`00F`3oool2000000030820P03oool0oooo0640
oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooomN0?ooo`@00000W03oool005/0oooo
0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0oooo
G@3oool4000009d0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P00
00000`20P800oooo0?ooo`3o0?oooe/0oooo00<0`<300000000000000P0000000`30`<00oooo0?oo
o`2K0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P820
0?ooo`3oool0o`3ooomK0?ooo`@00000W`3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?oo
o`<00000VP3oool2000000030820P03oool0oooo0?l0ooooF@3oool00`20P8000000000000020000
00030<30`03oool0oooo09d0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0
oooo0P0000000`20P800oooo0?ooo`3o0?oooeP0oooo00<0P8200000000000000P00002Q0?ooo`00
F`3oool2000000030820P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0
o`3ooomH0?ooo`@00000XP3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3o
ool2000000030820P03oool0oooo0?l0ooooEP3oool00`20P800000000000002000000030<30`03o
ool0oooo0:00oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P000000
0`20P800oooo0?ooo`3o0?oooeD0oooo00<0P8200000000000000P00002T0?ooo`00F`3oool20000
00030820P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooomE0?oo
o`@00000Y@3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool200000003
0820P03oool0oooo0?l0ooooD`3oool00`20P800000000000002000000030<30`03oool0oooo0:<0
oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo
0?ooo`3o0?oooe80oooo00<0P8200000000000000P00002W0?ooo`00F`3oool2000000030820P03o
ool0oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooomB0?ooo`@00000Z03o
ool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0
oooo0?l0ooooD03oool00`30`<00000000000002000000030<30`03oool0oooo0:H0oooo001K0?oo
o`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo0?ooo`3o0?oo
oe00oooo1000002Z0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00002J0?ooo`80
000000<0P8200?ooo`3oool0o`3ooom>0?ooo`050820P0000000000000000010@400Z`3oool005/0
oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0
ooooC@3oool00`20P80000000000000200000:`0oooo001K0?ooo`80000000<0P8200?ooo`3oool0
H@3oool3000009X0oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0oooo1000002]0?ooo`00F`3o
ool2000000030820P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3o
oom;0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0Z`3oool005/0oooo0P000000
0`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0ooooBP3oool0
0`20P80000000000000300000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool30000
09X0oooo0P0000000`20P800oooo0?ooo`3o0?ooodX0oooo1P00002^0?ooo`00F`3oool200000003
0820P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooom:0?ooo`03
0<30`0000000000000<00000[P3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000
VP3oool2000000030820P03oool0oooo0?l0ooooC@3oool300000:h0oooo001K0?ooo`80000000<0
P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0oooo0`00
002^0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P820
0?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?oo
o`<00000VP3oool2000000030820P03oool0oooo0?l0ooooC@3oool300000:h0oooo001K0?ooo`80
000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0
oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00002J0?ooo`800000
00<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo0P0000000`20P800oooo0?oo
o`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0ooooC@3oool300000:h0oooo001K
0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo0?ooo`3o
0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00002J0?oo
o`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo0P0000000`20P800
oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0ooooC@3oool300000:h0
oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20P800oooo
0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00
002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo0P000000
0`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0ooooC@3oool3
00000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P0000000`20
P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0oooo0640
oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo
0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo0?l0oooo
C@3oool300000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0oooo0P00
00000`20P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0
oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool0
05/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<00000VP3oool2000000030820P03oool0oooo
0?l0ooooC@3oool300000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000009X0
oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820
P03oool0oooo0640oooo0`00002J0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000
[P3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<000007`3oool30820P7P0oooo0P00
00000`20P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0
oooo0640oooo0`00000O0?ooo`<00000N03oool2000000030820P03oool0oooo0?l0ooooC@3oool3
00000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000001l0oooo0`00001h0?oo
o`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo0P0000000`20P800
oooo0?ooo`1Q0?ooo`<000007`3oool3000007P0oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0
oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00000O0?ooo`<00000
N03oool2000000030820P03oool0oooo0?l0ooooC@3oool300000:h0oooo001K0?ooo`80000000<0
P8200?ooo`3oool0H@3oool3000001l0oooo0`00001h0?ooo`80000000<0P8200?ooo`3oool0o`3o
oom=0?ooo`<00000[P3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<000007`3oool3
000007P0oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool20000
00030820P03oool0oooo0640oooo0`00000O0?ooo`<00000N03oool2000000030820P03oool0oooo
0?l0ooooC@3oool300000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000001l0
oooo0`00001h0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo
0P0000000`20P800oooo0?ooo`1Q0?ooo`<000007`3oool3000007P0oooo0P0000000`20P800oooo
0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0oooo0640oooo0`00
000O0?ooo`<00000N03oool2000000030820P03oool0oooo0?l0ooooC@3oool300000:h0oooo001K
0?ooo`80000000<0P8200?ooo`3oool0H@3oool3000001l0oooo0`00001h0?ooo`80000000<0P820
0?ooo`3oool0o`3ooom=0?ooo`<00000[P3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?oo
o`<000007`3oool3000007P0oooo0P0000000`20P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?oo
o`00F`3oool2000000030820P03oool0oooo0640oooo0`00000O0?ooo`<00000N03oool200000003
0820P03oool0oooo0?l0ooooC@3oool300000:h0oooo001K0?ooo`80000000<0P8200?ooo`3oool0
H@3oool3000001l0oooo0`00001h0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`<00000
[P3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<000007`3oool3000007P0oooo0P00
00000`20P800oooo0?ooo`3o0?ooodd0oooo0`00002^0?ooo`00F`3oool2000000030820P03oool0
oooo0640oooo0`00000O0?ooo`<00000o`3oooo:0?ooo`<00000[P3oool005/0oooo0P0000000`20
P800oooo0000001T000001l0ooooo`00003@000000030820P03oool0oooo0:/0oooo001K0?ooo`80
000000<0P8200?ooo`000000I000000O0?ooool00000d00000000`20P800oooo0?ooo`2[0?ooo`00
F`3oool2000000030820P03oool0000006@000007`3ooooo00000=00000000<0P8200?ooo`3oool0
Z`3oool005/0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`<000007`3oool300000?l0ooooo`3o
ooml0?ooo`00`@3oool3000001l0oooo0`00003o0?ooool0ooooO03oool00<40oooo0`00000O0?oo
o`<00000o`3ooooo0?ooog`0oooo00310?ooo`<000007`3oool300000?l0ooooo`3oooml0?ooo`00
`@3oool3000001l0oooo0`00003o0?ooool0ooooO03oool00<40oooo0`00000O0?ooo`<00000o`3o
oooo0?ooog`0oooo00310?ooo`<000007`3oool300000?l0ooooo`3oooml0?ooo`00`@3oool30000
01l0oooo0`00003o0?ooool0ooooO03oool00<40oooo0`00000O0?ooo`<00000o`3ooooo0?ooog`0
oooo00310?ooo`<000007`3oool300000?l0ooooo`3oooml0?ooo`00`@3oool3000001l0oooo0`00
003o0?ooool0ooooO03oool00<40oooo0`00000O0?ooo`<00000o`3ooooo0?ooog`0oooo00310?oo
o`<000007`3oool300000?l0ooooo`3oooml0?ooo`00`@3oool3000001l0oooo0`00003o0?ooool0
ooooO03oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3o
ool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40
oooo0`00003o0?ooool0ooooWP3oool00:00oooo00<0`<300820P03oool07P3oool300000?l0oooo
o`3ooonN0?ooo`00X03oool00`20P80000000?ooo`0N0?ooo`<00000o`3ooooo0?oooih0oooo002P
0?ooo`030820P0000000oooo01h0oooo0`00003o0?ooool0ooooWP3oool00:00oooo00<0P8200000
003oool07P3oool300000?l0ooooo`3ooonN0?ooo`00X03oool00`20P80000000?ooo`0N0?ooo`<0
0000o`3ooooo0?oooih0oooo002P0?ooo`030820P0000000oooo01h0oooo0`00003o0?ooool0oooo
WP3oool00:00oooo00<0P8200000003oool07P3oool300000?l0ooooo`3ooonN0?ooo`00X03oool0
0`20P80000000?ooo`0N0?ooo`<00000o`3ooooo0?oooih0oooo002P0?ooo`030820P0000000oooo
01h0oooo0`00003o0?ooool0ooooWP3oool00:00oooo00<0P8200000003oool07P3oool300000?l0
ooooo`3ooonN0?ooo`00X03oool00`20P80000000?ooo`0N0?ooo`<00000o`3ooooo0?oooih0oooo
002E0?ooo`030<30`020P800P82000P0P82000<0@41000000020P8002P20P80D0?ooo`<00000o`3o
oooo0?oooih0oooo002E0?ooo`030820P0000000000001D00000503oool3000002L0oooo00<0P820
0000000000004`00003o0?ooool0ooooH@3oool00:00oooo00<0P8200000003oool07P3oool30000
02L0oooo00<0P8200000000000004`00003o0?ooool0ooooH@3oool00:00oooo00<0P8200000003o
ool07P3oool3000002L0oooo00<0P8200000000000004`00003o0?ooool0ooooH@3oool00:00oooo
00<0P8200000003oool07P3oool300000?l0ooooo`3ooonN0?ooo`00X03oool00`20P80000000?oo
o`0N0?ooo`<00000o`3ooooo0?oooih0oooo002P0?ooo`030820P0000000oooo01h0oooo0`00003o
0?ooool0ooooWP3oool00:00oooo00<0P8200000003oool07P3oool300000?l0ooooo`3ooonN0?oo
o`00X03oool00`20P80000000?ooo`0N0?ooo`<00000o`3ooooo0?oooih0oooo002P0?ooo`030820
P0000000oooo01h0oooo0`00003o0?ooool0ooooWP3oool00:00oooo00<0P8200000003oool07P3o
ool300000?l0ooooo`3ooonN0?ooo`00X03oool00`20P80000000?ooo`0N0?ooo`<00000o`3ooooo
0?oooih0oooo002P0?ooo`030820P0000000oooo01h0oooo0`00003o0?ooool0ooooWP3oool00<40
oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00
003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?oo
ool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0oooo
WP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool0
0<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo
0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o0?ooool0ooooWP3oool00<40oooo0`00003o
0?ooool0ooooWP3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{216.625, 201.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 9.5", "Caption",
  CellTags->"Fig. 9.5"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)]],
  " = 12V, ",
  Cell[BoxData[
      \(TraditionalForm\`V\_2\)]],
  " = 8V, ",
  Cell[BoxData[
      \(TraditionalForm\`R\_1\)]],
  " = 20",
  StyleBox["\[CapitalOmega]",
    FontFamily->"Symbol"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`R\_2\)]],
  " = 15",
  StyleBox["\[CapitalOmega]",
    FontFamily->"Symbol"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`R\_3\)]],
  " = 3",
  StyleBox["\[CapitalOmega]",
    FontFamily->"Symbol"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`R\_4\)]],
  " = 6",
  StyleBox["\[CapitalOmega]",
    FontFamily->"Symbol"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`R\_5\)]],
  " = 12",
  StyleBox["\[CapitalOmega], ",
    FontFamily->"Symbol"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\_6\)]],
  " = 2 ",
  StyleBox["\[CapitalOmega]",
    FontFamily->"Symbol"],
  ". \n",
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Solve the following coupled equations analytically, finding all solutions \
(real and complex):"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\^2 + 2\ y = 0\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`y\^2 + 2\ x = 0\)]]
}], "Text"],

Cell["Find numerical values for the solutions.", "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " An elastic band is  fixed between posts a distance ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " apart in the horizontal ",
  Cell[BoxData[
      \(TraditionalForm\`\((x)\)\)]],
  " direction. A simple model for the deformation of the band in the presence \
of gravity is as a system of equal masses ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " coupled by springs, each with spring constant ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". In the absence of gravity, the masses are at positions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontSlant->"Plain"], 
              StyleBox["i",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((i\ a\ , 0)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2,  ... , M\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{\(L/M\), Cell["."]}]}], TraditionalForm]]],
  "The  first and last mass in the chain are fixed at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", \({0, 0}\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "M"], "=", \({L, 0}\)}], 
        TraditionalForm]]],
  ".  In between the masses are located according to the force-balance \
equations"
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\((0, 0)\), "=", 
          RowBox[{
            RowBox[{"-", " ", 
              RowBox[{"k", "(", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["r",
                        FontSlant->"Plain"], 
                      RowBox[{
                        StyleBox["i",
                          FontWeight->"Plain",
                          FontSlant->"Italic"], " "}]],
                    FontWeight->"Bold"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], \(i - 1\)]}], ")"}]}], "+", 
            RowBox[{"k", "(", 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(i + 1\)], "-", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}], ")"}], 
            "-", \(m\ g\ \((0, 1)\)\)}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Find and plot the shape of the band in equilibrium by solving for the \
positions of the masses and creating a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Solve for the case ",
  Cell[BoxData[
      \(TraditionalForm\`M = 30, \ m = \(k = \(a = 1\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g = 1/50\)]],
  ". (Hint: ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can handle vector equations of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{\({0, 0}\), "=", " ", 
          RowBox[{
            RowBox[{"2", 
              StyleBox[
                SubscriptBox[
                  StyleBox["r",
                    FontSlant->"Plain"], 
                  StyleBox["i",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}], 
            StyleBox[" ",
              FontWeight->"Bold"], "-", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(i - 1\)], "-", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(i + 1\)], "+", 
            RowBox[{\((m\ g/k)\), "  ", \((0, 1)\), 
              StyleBox[" ",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  "without having to break the equation up into components However, the \
variables to be solved for cannot be vectors. Instead, define ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["i",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["{",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["i",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], 
              StyleBox[",",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["i",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}]}], 
            StyleBox["}",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ", and create a list of variables ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["i",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], 
              StyleBox[",",
                FontFamily->"Courier"], 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["i",
                  FontFamily->"Courier",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}]}],
            FontWeight->"Plain"], 
          StyleBox["}",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "using a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. (Be sure to ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the table, so that the list is in the right format to be used in ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " A rod or plate differs from the elastic band model used in the previous \
problem in that atoms in a rod are stacked in crystal planes, and repel \
one-another if they are too closely-spaced.  These two effects, which were \
not included in the previous problem, provide added strength against external \
shearing forces on the rod.  Here we will determine the effect of gravity on \
a horizontal rod. The rod consists of two horizontal layers of atoms whose \
positions are given, in the absence of gravity, by ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox["R",
                    FontSlant->"Plain"], 
                  StyleBox["i",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]],
                FontWeight->"Bold"], 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[\((i - 1)\),
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox["p",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], "+", 
                RowBox[{\(Mod[i, 2]\), " ", 
                  StyleBox["q",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3,  ... , M\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(a(1/2, 0)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              StyleBox["q",
                FontWeight->"Bold",
                FontSlant->"Plain"], "=", \(a(0, \ \@\(3/2\))\)}],
            "TraditionalForm"]}], TraditionalForm]]],
  ". The rod is shown in Cell ",
  ButtonBox["9.165",
    ButtonData:>"Cell 9.165",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{"M", "=", 
          RowBox[{"81", Cell[""]}]}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1/4\)]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`L = 10\)]],
  "):"
}], "Text",
  CellTags->"i:89"],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \ M = 81; a = 1/4;\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.165"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p = a {1/2, 0}; \ q = a {0, Sqrt[3]/2};\), "\n", 
    \(\(R[i_]\  = \ \((i - 1)\)\ p\  + \ Mod[i, 2]\ q;\)\), "\n", 
    \(\(ListPlot[Table[R[i], {i, 1, M}], PlotStyle \[Rule] PointSize[0.02], 
        PlotRange \[Rule] {{\(-1\), 11}, {\(-1\), 1}}, 
        AspectRatio \[Rule] 1/6, 
        Ticks \[Rule] {Automatic, None}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.166"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.0833333 0.0833333 0.0833333 [
[.25 .07083 -3 -9 ]
[.25 .07083 3 0 ]
[.41667 .07083 -3 -9 ]
[.41667 .07083 3 0 ]
[.58333 .07083 -3 -9 ]
[.58333 .07083 3 0 ]
[.75 .07083 -3 -9 ]
[.75 .07083 3 0 ]
[.91667 .07083 -6 -9 ]
[.91667 .07083 6 0 ]
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25 .08333 m
.25 .08958 L
s
[(2)] .25 .07083 0 1 Mshowa
.41667 .08333 m
.41667 .08958 L
s
[(4)] .41667 .07083 0 1 Mshowa
.58333 .08333 m
.58333 .08958 L
s
[(6)] .58333 .07083 0 1 Mshowa
.75 .08333 m
.75 .08958 L
s
[(8)] .75 .07083 0 1 Mshowa
.91667 .08333 m
.91667 .08958 L
s
[(10)] .91667 .07083 0 1 Mshowa
.125 Mabswid
.125 .08333 m
.125 .08708 L
s
.16667 .08333 m
.16667 .08708 L
s
.20833 .08333 m
.20833 .08708 L
s
.29167 .08333 m
.29167 .08708 L
s
.33333 .08333 m
.33333 .08708 L
s
.375 .08333 m
.375 .08708 L
s
.45833 .08333 m
.45833 .08708 L
s
.5 .08333 m
.5 .08708 L
s
.54167 .08333 m
.54167 .08708 L
s
.625 .08333 m
.625 .08708 L
s
.66667 .08333 m
.66667 .08708 L
s
.70833 .08333 m
.70833 .08708 L
s
.79167 .08333 m
.79167 .08708 L
s
.83333 .08333 m
.83333 .08708 L
s
.875 .08333 m
.875 .08708 L
s
.04167 .08333 m
.04167 .08708 L
s
.95833 .08333 m
.95833 .08708 L
s
.25 Mabswid
0 .08333 m
1 .08333 L
s
.08333 0 m
.08333 .16667 L
s
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
.02 w
.08333 .10138 Mdot
.09375 .08333 Mdot
.10417 .10138 Mdot
.11458 .08333 Mdot
.125 .10138 Mdot
.13542 .08333 Mdot
.14583 .10138 Mdot
.15625 .08333 Mdot
.16667 .10138 Mdot
.17708 .08333 Mdot
.1875 .10138 Mdot
.19792 .08333 Mdot
.20833 .10138 Mdot
.21875 .08333 Mdot
.22917 .10138 Mdot
.23958 .08333 Mdot
.25 .10138 Mdot
.26042 .08333 Mdot
.27083 .10138 Mdot
.28125 .08333 Mdot
.29167 .10138 Mdot
.30208 .08333 Mdot
.3125 .10138 Mdot
.32292 .08333 Mdot
.33333 .10138 Mdot
.34375 .08333 Mdot
.35417 .10138 Mdot
.36458 .08333 Mdot
.375 .10138 Mdot
.38542 .08333 Mdot
.39583 .10138 Mdot
.40625 .08333 Mdot
.41667 .10138 Mdot
.42708 .08333 Mdot
.4375 .10138 Mdot
.44792 .08333 Mdot
.45833 .10138 Mdot
.46875 .08333 Mdot
.47917 .10138 Mdot
.48958 .08333 Mdot
.5 .10138 Mdot
.51042 .08333 Mdot
.52083 .10138 Mdot
.53125 .08333 Mdot
.54167 .10138 Mdot
.55208 .08333 Mdot
.5625 .10138 Mdot
.57292 .08333 Mdot
.58333 .10138 Mdot
.59375 .08333 Mdot
.60417 .10138 Mdot
.61458 .08333 Mdot
.625 .10138 Mdot
.63542 .08333 Mdot
.64583 .10138 Mdot
.65625 .08333 Mdot
.66667 .10138 Mdot
.67708 .08333 Mdot
.6875 .10138 Mdot
.69792 .08333 Mdot
.70833 .10138 Mdot
.71875 .08333 Mdot
.72917 .10138 Mdot
.73958 .08333 Mdot
.75 .10138 Mdot
.76042 .08333 Mdot
.77083 .10138 Mdot
.78125 .08333 Mdot
.79167 .10138 Mdot
.80208 .08333 Mdot
.8125 .10138 Mdot
.82292 .08333 Mdot
.83333 .10138 Mdot
.84375 .08333 Mdot
.85417 .10138 Mdot
.86458 .08333 Mdot
.875 .10138 Mdot
.88542 .08333 Mdot
.89583 .10138 Mdot
.90625 .08333 Mdot
.91667 .10138 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{298.75, 49.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005e0000?R000`400?l00000o`00003o8Oooool0
0ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027o
oooo00?o0000ooooooooool0oooooomBooooo`008Oooool00ol0003oooooooooo`3ooooooe;ooooo
000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027ooooo00?o0000ooooooooool0oooooomB
ooooo`008Oooool00ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?oo
ooooD_ooool0027ooooo00?o0000ooooooooool0oooooomBooooo`008Oooool00ol0003ooooooooo
o`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027ooooo00?o0000oooo
ooooool0oooooomBooooo`008Oooool00ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`00
0?oooooooooo0?ooooooD_ooool0027ooooo00?o0000ooooooooool0oooooomBooooo`008Oooool0
0ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027o
oooo00?o0000ooooooooool0=oooool5o`0003[ooooo0_l000000ol@413oooooooooo`0fooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`0>?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<03Kooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7?ooool0027ooooo00?o0000ooooooooool0
=oooool01OnHV9So8B4Qonk^k_ooooooA4A403_ooooo00?o0000ooooooooool0=oooool01OmEEEGo
MgMgoooooonHV9So8B4Q03Sooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0hooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`008Oooool00ol0003oooooooooo`0h
ooooo`03oiRHV?lQ8B7ok^k^03Wooooo1Ol0000hooooo`05o`000?ooooooooooooooool00000>?oo
ool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01cooooo000Qooooo`03o`000?oooooooooo03Wooooo00?oV9RHob4Q8Oo^k^h0
>?ooool01?m4A4CogMgMooooool0000iooooo`05o`000?nHV9SooooooiRHV?lQ8B40>?ooool01Olb
<S;oV9RHoooooonHV9So<S8b03Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001cooooo000Qooooo`03o`000?oooooooooo03[ooooo00?oMgMgofIVI_ooool0=oooool0
1?oMgMgoEEEEooooool0000iooooo`05o`000?mEEEGo0000oa0@4?o<c<`0>?ooool01Oo<c<co0000
o`000?l0003oc<c<03Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01cooooo000Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=oooool00omgMgOo
c<c<o`00000iooooo`03oeEEEOn7QhOooooo03[ooooo00Go410@okZj^_oooooo^[Zjoa0@400hoooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Looooo`008Oooool00ol0
003oooooooooo`0gooooo`05o`000?nj^[[ooooooiRHV?l@4100>Oooool00oo^k^koA4A4o`00000i
ooooo`03omgMgOl@413oV9RH03[ooooo00Go0000okZj^_oooooo^[Zjo`00000hooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Looooo`008Oooool00ol0003ooooooooo
o`0gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0>_ooool00omgMgOo0000ooooo`0iooooo`04olc<
c?m4A4Co0000oa0@43Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0fooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Looooo`008Oooool00ol0003oooooooooo`3ooooo
oe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027ooooo00?o0000ooooooooool0
oooooomBooooo`008Oooool00ol0003oooooo`000002o`0000Gooooo0ol00005ooooo`?o00001?oo
ool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?oo
ool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?oo
ool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Ooo
ool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Ooo
ool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Ooo
ool3o`0000Cooooo0ol00005ooooo`?o00001Oooool3o`0000Cooooo0ol00005ooooo`?o00001Ooo
ool3o`0002Cooooo000Qooooo`Ko00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5
o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5
o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5
o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go00000oooool5
o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go00000oooool5
o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go00000_ooool5
o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go00008oooool0
027ooooo1ol000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`00
0?l000003?l000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000co000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`00
0?l000003?l000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`00
0?l000001Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`00
0?l000003?l000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`00
0?l000003?l000000ooooooo0000o`000005o`000003ooooool0003o000000Go00008_ooool000;o
ooooool0001ao`0000?ooooo000Aooooo`03o`000?oooooooooo00gooooo1ol000000ooooooo0000
o`00000Lo`000003ooooool0003o000000co000000?oooooo`000?l000007?l000000ooooooo0000
o`00000<o`000003ooooool0003o000002_o000000?oooooo`000?l000003?l000000ooooooo0000
o`00000Lo`000003ooooool0003o000000co000000?oooooo`000?l000007?l000000ooooooo0000
o`00000<o`000003ooooool0003o000000co000000?oooooo`000?l000007?l000000ooooooo0000
o`000006o`0000kooooo00?o0000ooooooooool04?ooool0027ooooo1_l00003ooooo`Go00000ooo
ool5o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go000000?o
ooooo`000?ooool01Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000ooo
ool5o`0000?ooooo1Ol00002ooooo`Go000000?oooooo`000?ooool01Ol00002ooooo`Go00000ooo
ool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go000000?o
ooooo`000?ooool01Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go00000_oo
ool5o`0000?ooooo1Ol00003ooooo`Ko000000?oooooo`000?l000000ol00003ooooo`Go00000_oo
ool5o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go000000?o
ooooo`000?ooool08?ooool0027ooooo00?o0000ooooool000000_l00005ooooo`?o00001Oooool3
o`0000Cooooo0ol00005ooooo`?o00001Oooool3o`0000Cooooo0ol00005ooooo`?o00001Oooool3
o`0000Cooooo0ol00005ooooo`?o00001Oooool3o`0000Cooooo0ol00005ooooo`?o00001Oooool3
o`0000Cooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3
o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3
o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3
o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3
o`0000Gooooo0ol0000Tooooo`008?ooool3o`0000Cooooo0ol00005ooooo`?o00001Oooool3o`00
00Cooooo0ol00005ooooo`?o00001Oooool3o`0000Cooooo0ol00005ooooo`?o00001?ooool3o`00
00Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`00
00Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`00
00Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`00
00Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`00
00Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`00
00Gooooo0ol0000Pooooo`007oooool5o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000;o
oooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go00000_ooool5o`0000?o
oooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?o
oooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?o
oooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?o
oooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?o
oooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?o
oooo1Ol0000Oooooo`007_ooool>o`000003ooooool0003o000000Go000000?oooooo`000?l00000
3?l000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l00000
3?l000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l00000
3?l000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000co000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l00000
3?l000000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l00000
1Ol000000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l00000
1Ol0000Nooooo`007_ooool>o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l0
00000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000003?l0
00000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l0
00000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000<o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l0
00000ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol0
00000ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l000001Ol0
000Nooooo`007_ooool>o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l00000
0ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000003?l00000
0ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00000
0ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l00000
0ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00000
0ooooooo0000o`00000<o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00000
0ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l000003?l00000
0ooooooo0000o`000005o`000003ooooool0003o000000co000000?oooooo`000?l000001Ol00000
0ooooooo0000o`00000<o`000003ooooool0003o000000Go000000?oooooo`000?l000001Ol0000N
ooooo`007oooool5o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003oooo
o`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003oooo
o`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003oooo
o`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003oooo
o`Go00000_ooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002oooo
o`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol00002oooo
o`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo1Ol0000Ooooo
o`008?ooool3o`0000Cooooo0ol00005ooooo`?o00001Oooool3o`0000Cooooo0ol00005ooooo`?o
00001Oooool3o`0000Cooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o
00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o
00001?ooool3o`0000Gooooo0ol00005ooooo`?o00001?ooool3o`0000Gooooo0ol00005ooooo`?o
00001?ooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o
00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol00004ooooo`?o
00001Oooool3o`0000Gooooo0ol00004ooooo`?o00001Oooool3o`0000Gooooo0ol0000Pooooo`00
8Oooool00ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_oo
ool0027ooooo00?o0000ooooooooool0oooooomBooooo`008Oooool00ol0003oooooooooo`3ooooo
oe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027ooooo00?o0000ooooooooool0
oooooomBooooo`008Oooool00ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooo
oooo0?ooooooD_ooool0027ooooo00?o0000ooooooooool0oooooomBooooo`008Oooool00ol0003o
ooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool0027ooooo00?o
0000ooooooooool0oooooomBooooo`008Oooool00ol0003oooooooooo`3ooooooe;ooooo000Qoooo
o`03o`000?oooooooooo0?ooooooD_ooool0027ooooo00?o0000ooooooooool0oooooomBooooo`00
8Oooool00ol0003oooooooooo`3ooooooe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_oo
ool0027ooooo00?o0000ooooooooool0oooooomBooooo`008Oooool00ol0003oooooooooo`3ooooo
oe;ooooo000Qooooo`03o`000?oooooooooo0?ooooooD_ooool00001\
\>"],
  ImageRangeCache->{{{0, 372.438}, {61.1875, 0}} -> {-1, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The first two and last two masses in the rod are assumed to be attached to \
walls, so only the masses with ",
  Cell[BoxData[
      \(TraditionalForm\`3 \[LessEqual] \ i \[LessEqual] \ M - 2\)]],
  " are allowed to move. All the masses are assumed to interact via a simple \
nearest-neighbor interaction. For neighbors ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " separated by displacement vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold"], TraditionalForm]]],
  ", we assume that the force between them is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["-",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox[\(k\_\(i\ j\)\),
                FontWeight->"Plain"], "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox[
                    OverscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Bold"]}]}], ")"}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_\(i\ j\)\)]],
  " is the spring constant:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(F[i_, j_\ , r_]\), " ", ":=", " ", 
      RowBox[{\(-k[i, j]\), 
        RowBox[{"(", 
          RowBox[{"r", " ", "-", " ", 
            RowBox[{"a", " ", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold"], "/", 
                SqrtBox[
                  StyleBox[\(r . r\),
                    FontWeight->"Bold"]]}]}]}], ")"}]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.167"],

Cell[TextData[{
  " This is an isotropic spring force with a resting length ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", so that in equilibrium the atoms are spaced by ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", in the absence of other forces. However, this force is nonlinear in the \
displacement ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", since the unit vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "/", 
            SqrtBox[
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]]}]}], TraditionalForm]]],
  ". ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will not be able to find a solution for force equilibrium for the \
fully-nonlinear equations. Therefore, we assume that the atoms are only \
slightly displaced from equilibrium, and Taylor-expand the force about the \
equilibrium positions ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(\(i\)\(\ \)\)], TraditionalForm]]],
  " to obtain linear equations in the displacement from the force-free \
equilibrium. That is , we write ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], \(\(i\)\(\ \)\)], "=", " ", 
          RowBox[{
            SubscriptBox[
              StyleBox["R",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(i\)\(\ \)\)], "+", 
            "  ", \((\[CapitalDelta]x\_\(\(i\)\(\ \)\), \ \
\[CapitalDelta]y\_\(\(i\)\(\ \)\))\)}]}], TraditionalForm]]],
  ", and Taylor expand ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(i\)\(\ \)\)], "-", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "j"]}], ")"}], TraditionalForm]]],
  " for small ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\[CapitalDelta]x\_\(\(i\)\(\ \)\), \ \
\[CapitalDelta]y\_\(\(i\)\(\ \)\))\)\)\)]],
  ". This is accomplished below, and the result is called ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]], "(", \(i, j\), ")"}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(r[i_]\  = \ 
        R[i]\  + \ \[Lambda] {\[CapitalDelta]x[i], \[CapitalDelta]y[
                i]};\)\), "\n", 
    \(\(\[Delta]F[i_, j_]\  = \ 
        Simplify[
          Normal[Series[
                F[i, j, r[i] - r[j]], {\[Lambda], 0, 
                  1}]] /. \[Lambda] \[Rule] 1];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.168"],

Cell[TextData[{
  "The total force on the ",
  Cell[BoxData[
      \(TraditionalForm\`i\ th\)]],
  " atom ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Plain"], "tot"], "(", "i", ")"}], 
        TraditionalForm]]],
  " , assuming that this atom is not at the ends,  is due to its four nearest \
neighbors (one on each side in the same row, and the two nearest atoms along \
diagonals in the other row):"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SubscriptBox[
                StyleBox["F",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "tot"], "(", "i", ")"}], "=", 
            RowBox[{\((0, \(-m\)\ g)\), " ", "+", " ", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["F",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], " ", \((i, i - 2)\)}], "+", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["F",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], " ", \((i, i - 1)\)}], " ", "+",
               
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["F",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], "(", \(i, i + 1\), ")"}], " ", 
              "+", " ", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["F",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], " ", \((i, i + 2)\)}]}]}], " ", 
          ",", " "}], TraditionalForm]]],
  "for  ",
  Cell[BoxData[
      \(TraditionalForm\`3 \[LessEqual] \ i\  \[LessEqual] \ M - 2\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(Ftot[
        i_]\  := \ {0, \(-m\)\ g}\  + \ \ \ \[Delta]F[i, i - 2] + \[Delta]F[
            i, i - 1]\  + \[Delta]F[i, i + 1]\  + \ \[Delta]F[i, 
            i + 2]\ \  /; \ 
        3 \[LessEqual] \ i \[LessEqual] \ M - 2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.169"],

Cell["The masses on the ends are fixed to the walls, so ", "Text"],

Cell[BoxData[{
    \(\[CapitalDelta]x[i_] := 
      0\  /; \ i \[Equal] 1\  || i \[Equal] 2 || i \[Equal] M - 1 || 
          i \[Equal] M\), "\n", 
    \(\[CapitalDelta]y[i_] := 
      0\  /; \ i \[Equal] 1\  || i \[Equal] 2 || i \[Equal] M - 1 || 
          i \[Equal] M\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.170"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Solve the coupled equilibrium equations ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "tot"], "(", \(i, j\), ")"}], 
          "=", \({0, 0}\)}], TraditionalForm]]],
  " for the variables ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalDelta]x\_\(\(i\)\(\ \)\), \ \
\[CapitalDelta]y\_\(\(i\)\(\ \)\))\), \ i = 3,  ... , M - 2\)]],
  ", and plot the shape of the rod. (Hint: Create a table of the equations, \
and a list of variables. Apply ",
  StyleBox["Flatten",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the tables to remove internal brackets in the lists, so that the \
syntax matches that required in ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Assume that the ends of the rod are clamped, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalDelta]x, \[CapitalDelta]y)\) = \((0, 
          0)\)\)]],
  " for the end masses. ) Take ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(k\_\(i\ j\) = 1\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`g = 5. \ \[Cross]\ 10\^\(-5\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot the maximum vertical displacement of the rod,  ",
  Cell[BoxData[
      \(TraditionalForm\`max\ [\(|\)\(\[CapitalDelta]y\)\(|\)]\)]],
  ", vs. ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " by choosing five ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`g\)]]]], "-"}]}], TraditionalForm]]],
  "values in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ g \[LessEqual] \ 10\^\(-4\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Plot ",
  Cell[BoxData[
      \(TraditionalForm\`max\ [\(|\)\(\[CapitalDelta]y\)\(|\)]\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`g = 5. \ \[Cross]\ 10\^\(-5\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1/4\)]],
  ",  and ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1\)]],
  ". Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10, 20, 30, 40\)]],
  ". (This changes the length of the rod without affecting its intensive \
properties such as elasticity). How does the maximum sag scale with the \
length of the rod?"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Plot the shape of the rod for the same parameters as in part (a), but now \
assume that one of the springs has failed, so that"
}], "Text"],

Cell[TextData[{
  "\t(i) ",
  Cell[BoxData[
      \(TraditionalForm\`k\_\(\(10\)\(,\)\(\ \)\(11\)\(\ \)\) = \(k\_\(11, 10\
\) = 0\)\)]],
  " (break between atoms 10 and 11 in the top and bottom rows)."
}], "Text"],

Cell[TextData[{
  "\t(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`k\_\(\(10\)\(,\)\(\ \)\(12\)\(\ \)\) = \(k\_\(12, 10\
\) = 0\)\)]],
  " (break within the same row)."
}], "Text"],

Cell[TextData[{
  "The large difference between these two cases points out the importance to \
the shear strength of  the diagonal interactions between atoms in different \
layers . These interactions provide a ",
  StyleBox["cantilever",
    FontSlant->"Italic"],
  " effect : the diagonal springs are compressed or stretched as the rod \
sags, providing a restoring force that is  missing when there is only one \
row, or when a diagonal spring is broken.  [See Exercise (1), Sec. ",
  ButtonBox["1.5",
    ButtonData:>{"Chapter1.nb", "Ex. 1.5"},
    ButtonStyle->"Hyperlink"],
  ") for an analytic treatment of this problem.]"
}], "Text",
  CellTags->"i:112"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " Repeat Exercise (5) for a rod that is clamped horizontally to a wall only \
at the left end, with the other end free to sag in gravity. Plot the shape of \
the rod for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1, m = 1, \ a = 1/4, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g = \(\(5\[Cross]\ 10\^\(-6\)\)\(\ \)\)\)]],
  ", and determine how the maximum sag scales with the length of the rod for \
",
  Cell[BoxData[
      \(TraditionalForm\`M = 10, 20, 30, 40\)]],
  ". [See Exercise (7)(c), Sec. ",
  ButtonBox["4.2",
    ButtonData:>{"Chapter4.nb", "Ex. 4.2"},
    ButtonStyle->"Hyperlink"],
  ", for the analytic solution to this problem.]"
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " A  linear model of a solid two-dimensional pyramid consists of the \
following coupled mass-spring system. The masses have equilibrium  positions \
shown in Cell ",
  ButtonBox["9.171",
    ButtonData:>"Cell 9.171",
    ButtonStyle->"Hyperlink"],
  ", given by the equations ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["R",
                FontSlant->"Plain"], 
              StyleBox[\(i\ j\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["i",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "+", 
            RowBox[{"j", " ", 
              StyleBox["q",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2, \(\(...\) \(10\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0, 1, 2, \(\(...\) \(10\)\) - i\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((1, 0)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["q",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((1/2, \ \@\(3/2\))\)}], 
        TraditionalForm]]],
  ". However, they are subjected to gravity, and therefore the pyramid \
compresses under its own weight; see Fig. ",
  ButtonBox["9.6",
    ButtonData:>"Fig. 9.6",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:90"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p = {1, 0}; \ q = {1/2, \ Sqrt[3]/2};\), "\n", 
    \(\(R[i_, j_]\  = \ i\ p\  + \ j\ q;\)\), "\n", 
    \(\(ListPlot[
        Flatten[Table[Table[R[i, j], {j, 0, 10 - i}], {i, 0, 10}], 1], 
        PlotStyle \[Rule] PointSize[0.035], 
        PlotRange \[Rule] {{0, 10}, {0, 10}}, 
        AspectRatio \[Rule] 1];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.171"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0 0.1 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .2 -6 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -6 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -6 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -6 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.035 w
0 0 Mdot
.05 .0866 Mdot
.1 .17321 Mdot
.15 .25981 Mdot
.2 .34641 Mdot
.25 .43301 Mdot
.3 .51962 Mdot
.35 .60622 Mdot
.4 .69282 Mdot
.45 .77942 Mdot
.5 .86603 Mdot
.1 0 Mdot
.15 .0866 Mdot
.2 .17321 Mdot
.25 .25981 Mdot
.3 .34641 Mdot
.35 .43301 Mdot
.4 .51962 Mdot
.45 .60622 Mdot
.5 .69282 Mdot
.55 .77942 Mdot
.2 0 Mdot
.25 .0866 Mdot
.3 .17321 Mdot
.35 .25981 Mdot
.4 .34641 Mdot
.45 .43301 Mdot
.5 .51962 Mdot
.55 .60622 Mdot
.6 .69282 Mdot
.3 0 Mdot
.35 .0866 Mdot
.4 .17321 Mdot
.45 .25981 Mdot
.5 .34641 Mdot
.55 .43301 Mdot
.6 .51962 Mdot
.65 .60622 Mdot
.4 0 Mdot
.45 .0866 Mdot
.5 .17321 Mdot
.55 .25981 Mdot
.6 .34641 Mdot
.65 .43301 Mdot
.7 .51962 Mdot
.5 0 Mdot
.55 .0866 Mdot
.6 .17321 Mdot
.65 .25981 Mdot
.7 .34641 Mdot
.75 .43301 Mdot
.6 0 Mdot
.65 .0866 Mdot
.7 .17321 Mdot
.75 .25981 Mdot
.8 .34641 Mdot
.7 0 Mdot
.75 .0866 Mdot
.8 .17321 Mdot
.85 .25981 Mdot
.8 0 Mdot
.85 .0866 Mdot
.9 .17321 Mdot
.9 0 Mdot
.95 .0866 Mdot
1 0 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{209.5, 209.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004500011B000`400?l00000o`00003oooooool6
ooooo`00ooooool6ooooo`00ooooool6ooooo`00ooooool6ooooo`00ooooool6ooooo`00?_ooool5
o`0002cooooo0_l000000ol@413oooooooooo`0Xooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0:_oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Oooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0_ooool003kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00]ooooo`03o`000?oooooo
oooo02Wooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Zooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
:Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool003oooooo
00?oV9RHob4Q8Oo^k^h0:oooool5o`0002[ooooo00Go0000ooooooooooooooooo`00000Zooooo`05
o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool0043ooooo00?oV9RHob4Q8Oo^k^h0:_ooool01?m4A4CogMgMooooool0000[
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40:_ooool01Olb<S;oV9RHoooooonHV9So<S8b02Wooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0011ooooo`03ogMg
MomVIVKooooo02Wooooo00CogMgMoeEEEOoooooo0000:oooool01Ol0003oEEEEo`000?l@413oc<c<
02[ooooo00Goc<c<o`000?l0003o0000olc<c00Yooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000002ooooo`00@_ooool00ol0003oooooooooo`0Yooooo`03ogMgMoo<c<co
000002_ooooo00?oEEEEohN7Qoooool0;?ooool01Ol@413o^[Zjoooooonj^[[o410@02Wooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo000nooooo`05o`000?nj
^[[ooooooiRHV?l@4100:oooool00oo^k^koA4A4o`00000[ooooo`03omgMgOl@413oV9RH02cooooo
00Go0000okZj^_oooooo^[Zjo`00000Yooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02ooooo`00?_ooool01OnHV9So410@o`000?lQ8B7oc<c<02cooooo00?oMgMgo`00
0?ooool0:oooool01?o<c<coA4A4o`000?l@410Zooooo`05ojVYZOl@413o0000oa0@4?nYZJT09ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool0013ooooo1?l0
000Cooooo`Co00005?ooool4o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0001?ooooo1?l0
000Dooooo`Co00004oooool4o`0001Cooooo1?l0000Cooooo`Co00001_ooool000oooooo1_l0000A
ooooo`Ko00004_ooool6o`0001;ooooo1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0000B
ooooo`Ko00004Oooool6o`0001;ooooo1_l0000Aooooo`Ko00001Oooool000kooooo2?l0000?oooo
o`So00004?ooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@oooo
o`So00003oooool8o`00013ooooo2?l0000?ooooo`So00001?ooool000kooooo2?l0000?ooooo`So
00004?ooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So
00003oooool8o`00013ooooo2?l0000?ooooo`So00001?ooool000kooooolol00004ooooo`003_oo
ool8o`0000Oooooo00?o0000ooooooooool01Oooool8o`0000Sooooo00?o0000ooooooooool01Ooo
ool8o`0000Oooooo00?o0000ooooooooool01_ooool8o`0000Oooooo00?o0000ooooooooool01Ooo
ool8o`0000Oooooo00?o0000ooooooooool01_ooool8o`0000Oooooo00?o0000ooooooooool01Ooo
ool8o`0000Oooooo00?o0000ooooooooool01_ooool8o`0000Oooooo00?o0000ooooooooool01Ooo
ool8o`0000Sooooo00?o0000ooooooooool01Oooool8o`0000Oooooo00?o0000ooooooooool01Ooo
ool8o`0000Cooooo000?ooooo`Ko00004Oooool6o`0001;ooooo1_l0000Booooo`Ko00004Oooool6
o`0001;ooooo1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0000Booooo`Ko00004Oooool6
o`0000Gooooo000@ooooo`Co00004oooool4o`0001Cooooo1?l0000Dooooo`Co00004oooool4o`00
01Cooooo1?l0000Cooooo`Co00005?ooool4o`0001?ooooo1?l0000Dooooo`Co00004oooool4o`00
00Kooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo
000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aoooo
o`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`00
0?oooooooooo0?7ooooo000Aooooo`;o0000l_ooool0017ooooo00?o0000ooooooooool0lOooool0
017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo
00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000
ooooooooool02?ooool4o`0001?ooooo1?l0000Dooooo`Co00004oooool4o`0001Cooooo1?l0000C
ooooo`Co00005?ooool4o`0001?ooooo1?l0000Dooooo`Co00005?ooool4o`00017ooooo000Aoooo
o`03o`000?oooooooooo00Oooooo1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0000Boooo
o`Ko00004Oooool6o`0001;ooooo1_l0000Aooooo`Ko00004_ooool6o`0001;ooooo1_l0000@oooo
o`004Oooool00ol0003oooooooooo`06ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So
00004?ooool8o`0000oooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000@ooooo`So
00003oooool0017ooooo00?o0000ooooooooool01_ooool8o`0000oooooo2?l0000@ooooo`So0000
3oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So0000
4?ooool8o`0000oooooo000Aooooo`03o`000?oooooooooo00Kooooo2?l0000?ooooo`So00004?oo
ool8o`0000oooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?oo
ool8o`00013ooooo2?l0000?ooooo`004Oooool00ol0003oooooooooo`06ooooo`So00003oooool8
o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So00003oooool8
o`00013ooooo2?l0000@ooooo`So00003oooool0017ooooo0_l00008ooooo`Ko00004Oooool6o`00
01;ooooo1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0000Booooo`Ko00004Oooool6o`00
01;ooooo1_l0000Booooo`Ko00004?ooool0017ooooo00?o0000ooooooooool02?ooool4o`0001?o
oooo1?l0000Dooooo`Co00004oooool4o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0001?o
oooo1?l0000Dooooo`Co00005?ooool4o`00017ooooo000Aooooo`03o`000?oooooooooo0?7ooooo
000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aoooo
o`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`00
0?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooo
oooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7o
oooo000Aooooo`;o0000l_ooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000
ooooooooool04oooool4o`0001Cooooo1?l0000Dooooo`Co00004oooool4o`0001Cooooo1?l0000C
ooooo`Co00005?ooool4o`0001?ooooo1?l0000Dooooo`Co00007Oooool0017ooooo00?o0000oooo
ooooool04_ooool6o`0001;ooooo1_l0000Booooo`Ko00004Oooool6o`0001;ooooo1_l0000Aoooo
o`Ko00004_ooool6o`00017ooooo1_l0000Booooo`Ko00007?ooool0017ooooo00?o0000oooooooo
ool04Oooool8o`00013ooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So
00004?ooool8o`0000oooooo2?l0000@ooooo`So00006oooool0017ooooo00?o0000ooooooooool0
4Oooool8o`00013ooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So0000
4?ooool8o`0000oooooo2?l0000@ooooo`So00006oooool0017ooooo00?o0000ooooooooool04Ooo
ool8o`00013ooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?oo
ool8o`0000oooooo2?l0000@ooooo`So00006oooool0017ooooo00?o0000ooooooooool04Oooool8
o`00013ooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8
o`0000oooooo2?l0000@ooooo`So00006oooool0017ooooo00?o0000ooooooooool04_ooool6o`00
01;ooooo1_l0000Booooo`Ko00004Oooool6o`0001;ooooo1_l0000Aooooo`Ko00004_ooool6o`00
017ooooo1_l0000Booooo`Ko00007?ooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo01?o
oooo1?l0000Dooooo`Co00005?ooool4o`0001?ooooo1?l0000Dooooo`Co00004oooool4o`0001Co
oooo1?l0000Cooooo`Co00005?ooool4o`0001gooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01?ooool00ol0003oooooooooo`3aooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03o`00
0?oooooooooo0?7ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0ol0003aooooo`002oooool0
0omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo0?7ooooo000<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0lOooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4004oooo
o`03o`000?oooooooooo0?7ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003ooooo
ooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3a
ooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`0Oooooo`Co
00005?ooool4o`0001?ooooo1?l0000Dooooo`Co00004oooool4o`0001Cooooo1?l0000Cooooo`Co
00005?ooool4o`0002Wooooo000Aooooo`;o00007oooool6o`0001;ooooo1_l0000Aooooo`Ko0000
4_ooool6o`00017ooooo1_l0000Booooo`Ko00004Oooool6o`0001;ooooo1_l0000Xooooo`004Ooo
ool00ol0003oooooooooo`0Mooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So00003ooo
ool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0002Oooooo000Aooooo`03o`000?oooooo
oooo01gooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8
o`0000oooooo2?l0000@ooooo`So00009oooool0017ooooo00?o0000ooooooooool07Oooool8o`00
013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So00003oooool8o`00
013ooooo2?l0000Wooooo`004Oooool00ol0003oooooooooo`0Mooooo`So00004?ooool8o`0000oo
oooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0002Oo
oooo000Aooooo`03o`000?oooooooooo01kooooo1_l0000Booooo`Ko00004Oooool6o`0001;ooooo
1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0000Booooo`Ko0000:?ooool0017ooooo00?o
0000ooooooooool07oooool4o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0001?ooooo1?l0
000Dooooo`Co00004oooool4o`0001Cooooo1?l0000Yooooo`004Oooool00ol0003oooooooooo`3a
ooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`00
4Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool2
o`000?;ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7o
oooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000A
ooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03
o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo02_ooooo1?l0000Dooooo`Co0000
4oooool4o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0001?ooooo1?l0000eooooo`004Ooo
ool00ol0003oooooooooo`0Zooooo`Ko00004_ooool6o`00017ooooo1_l0000Booooo`Ko00004Ooo
ool6o`0001;ooooo1_l0000Aooooo`Ko0000=?ooool0017ooooo00?o0000ooooooooool0:Oooool8
o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So00003oooool8
o`0003?ooooo000Aooooo`03o`000?oooooooooo02Wooooo2?l0000@ooooo`So00003oooool8o`00
013ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000cooooo`004Oooool2o`0002[o
oooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0000oo
oooo2?l0000cooooo`004Oooool00ol0003oooooooooo`0Yooooo`So00004?ooool8o`0000oooooo
2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So0000<oooool0017ooooo00?o
0000ooooooooool0:_ooool6o`0001;ooooo1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0
000Booooo`Ko00004Oooool6o`0003Cooooo000Aooooo`03o`000?oooooooooo02_ooooo1?l0000D
ooooo`Co00004oooool4o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0001?ooooo1?l0000e
ooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`00
4Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool0
0ol0003oooooooooo`3aooooo`002_ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool0lOooool000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3aooooo`00
2?ooool5o`0000Cooooo00?o0000ooooooooool0lOooool000Sooooo00CoA4A4omgMgOoooooo0000
1Oooool3o`000?7ooooo0008ooooo`04omgMgOmEEEGoooooo`0000Gooooo00?o0000ooooooooool0
lOooool000Wooooo00?oMgMgolc<c?l000001Oooool00ol0003oooooooooo`3aooooo`002Oooool0
0oo^k^koA4A4o`000005ooooo`03o`000?oooooooooo0?7ooooo000:ooooo`03ogMgMol0003ooooo
00Cooooo00?o0000ooooooooool0=oooool4o`0001?ooooo1?l0000Dooooo`Co00004oooool4o`00
01Cooooo1?l0000Cooooo`Co0000@Oooool0017ooooo00?o0000ooooooooool0=_ooool6o`00017o
oooo1_l0000Booooo`Ko00004Oooool6o`0001;ooooo1_l0000Aooooo`Ko0000@?ooool0017ooooo
00?o0000ooooooooool0=Oooool8o`0000oooooo2?l0000@ooooo`So00003oooool8o`00013ooooo
2?l0000?ooooo`So0000?oooool0017ooooo00?o0000ooooooooool0=Oooool8o`0000oooooo2?l0
000@ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So0000?oooool0017ooooo00?o0000
ooooooooool0=Oooool8o`0000oooooo2?l0000@ooooo`So00003oooool8o`00013ooooo2?l0000?
ooooo`So0000?oooool0017ooooo00?o0000ooooooooool0=Oooool8o`0000oooooo2?l0000@oooo
o`So00003oooool8o`00013ooooo2?l0000?ooooo`So0000?oooool0017ooooo00?o0000oooooooo
ool0=_ooool6o`00017ooooo1_l0000Booooo`Ko00004Oooool6o`0001;ooooo1_l0000Aooooo`Ko
0000@?ooool0017ooooo00?o0000ooooooooool0=oooool4o`0001?ooooo1?l0000Dooooo`Co0000
4oooool4o`0001Cooooo1?l0000Cooooo`Co0000@Oooool0017ooooo0_l0003booooo`004Oooool0
0ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003o
ooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003ooooooooo
o`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aoooo
o`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Ooo
ool00ol0003oooooooooo`3aooooo`004Oooool2o`000?;ooooo000Aooooo`03o`000?oooooooooo
0?7ooooo000Aooooo`03o`000?oooooooooo04?ooooo1?l0000Cooooo`Co00005?ooool4o`0001?o
oooo1?l0000Dooooo`Co0000C?ooool0017ooooo00?o0000ooooooooool0@_ooool6o`00017ooooo
1_l0000Booooo`Ko00004Oooool6o`0001;ooooo1_l0001;ooooo`004Oooool00ol0003ooooooooo
o`11ooooo`So00003oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0004[ooooo000A
ooooo`03o`000?oooooooooo047ooooo2?l0000?ooooo`So00004?ooool8o`0000oooooo2?l0000@
ooooo`So0000B_ooool0017ooooo00?o0000ooooooooool0@Oooool8o`0000oooooo2?l0000@oooo
o`So00003oooool8o`00013ooooo2?l0001:ooooo`004Oooool00ol0003oooooooooo`11ooooo`So
00003oooool8o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0004[ooooo000Aooooo`03o`00
0?oooooooooo04;ooooo1_l0000Aooooo`Ko00004_ooool6o`00017ooooo1_l0000Booooo`Ko0000
Boooool0017ooooo00?o0000ooooooooool0@oooool4o`0001?ooooo1?l0000Dooooo`Co00004ooo
ool4o`0001Cooooo1?l0001<ooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0
003oooooooooo`3aooooo`004Oooool2o`000?;ooooo000Aooooo`03o`000?oooooooooo0?7ooooo
000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aoooo
o`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`00
0?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooo
oooo0?7ooooo0008ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01?ooool00ol0003oooooooooo`3a
ooooo`002?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Cooooo00?o0000ooooooooool0C_ooool4
o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0005Sooooo0008ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1=ooooo`Ko00004_ooool6o`00017ooooo1_l0000B
ooooo`Ko0000Eoooool000Sooooo00Go0000oiRHV?ooooooV9RHob4Q8@04ooooo`?o0000C?ooool8
o`00013ooooo2?l0000?ooooo`So00004?ooool8o`0005Kooooo0008ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01?ooool00ol0003oooooooooo`1<ooooo`So00004?ooool8o`0000oooooo2?l0000@
ooooo`So0000E_ooool000Sooooo00?oEEEEohN7Qoooool01_ooool00ol0003oooooooooo`1<oooo
o`So00004?ooool8o`0000oooooo2?l0000@ooooo`So0000E_ooool000Sooooo00?ogMgMoa0@4?nH
V9P01_ooool00ol0003oooooooooo`1<ooooo`So00004?ooool8o`0000oooooo2?l0000@ooooo`So
0000E_ooool000Wooooo00Coc<c<odA4A?l0003o410@1?ooool00ol0003oooooooooo`1=ooooo`Ko
00004_ooool6o`00017ooooo1_l0000Booooo`Ko0000Eoooool0017ooooo00?o0000ooooooooool0
C_ooool4o`0001Cooooo1?l0000Cooooo`Co00005?ooool4o`0005Sooooo000Aooooo`03o`000?oo
oooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo
0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo
000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`;o0000l_ooool0017ooooo00?o0000oooo
ooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0
lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0
017ooooo00?o0000ooooooooool0F_ooool4o`0001Cooooo1?l0000Cooooo`Co0000I?ooool0017o
oooo00?o0000ooooooooool0FOooool6o`0001;ooooo1_l0000Aooooo`Ko0000Hoooool0017ooooo
00?o0000ooooooooool0F?ooool8o`00013ooooo2?l0000?ooooo`So0000H_ooool0017ooooo00?o
0000ooooooooool0F?ooool8o`00013ooooo2?l0000?ooooo`So0000H_ooool0017ooooo00?o0000
ooooooooool0F?ooool8o`00013ooooo2?l0000?ooooo`So0000H_ooool0017ooooo0_l0001Ioooo
o`So00004?ooool8o`0000oooooo2?l0001Rooooo`004Oooool00ol0003oooooooooo`1Iooooo`Ko
00004_ooool6o`00017ooooo1_l0001Sooooo`004Oooool00ol0003oooooooooo`1Jooooo`Co0000
5?ooool4o`0001?ooooo1?l0001Tooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool0
0ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003o
ooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003ooooooooo
o`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aoooo
o`004Oooool00ol0003oooooooooo`3aooooo`004Oooool2o`000?;ooooo000Aooooo`03o`000?oo
oooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo
0?7ooooo000Aooooo`03o`000?oooooooooo06Kooooo1?l0000Cooooo`Co0000L?ooool0017ooooo
00?o0000ooooooooool0IOooool6o`00017ooooo1_l0001_ooooo`004Oooool00ol0003ooooooooo
o`1Tooooo`So00003oooool8o`0006kooooo000Aooooo`03o`000?oooooooooo06Cooooo2?l0000?
ooooo`So0000K_ooool0017ooooo00?o0000ooooooooool0I?ooool8o`0000oooooo2?l0001^oooo
o`002?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0I?ooool8o`00
00oooooo2?l0001^ooooo`002?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Cooooo00?o0000oooo
ooooool0IOooool6o`00017ooooo1_l0001_ooooo`002?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0I_ooool4o`0001?ooooo1?l0001`ooooo`002?ooool01Olb<S;o
V9RHoooooonHV9So<S8b00Cooooo0ol0003aooooo`002?ooool01Oo<c<co0000o`000?l0003oc<c<
00Cooooo00?o0000ooooooooool0lOooool000Sooooo00Go410@okZj^_oooooo^[Zjoa0@4004oooo
o`03o`000?oooooooooo0?7ooooo0008ooooo`05o`000?nj^[[ooooookZj^_l000001?ooool00ol0
003oooooooooo`3aooooo`002?ooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00?o0000oooo
ooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0
lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0
017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo
00?o0000ooooooooool0lOooool0017ooooo0_l0001cooooo`Co0000Noooool0017ooooo00?o0000
ooooooooool0LOooool6o`0007[ooooo000Aooooo`03o`000?oooooooooo073ooooo2?l0001ioooo
o`004Oooool00ol0003oooooooooo`1`ooooo`So0000NOooool0017ooooo00?o0000ooooooooool0
L?ooool8o`0007Wooooo000Aooooo`03o`000?oooooooooo073ooooo2?l0001iooooo`004Oooool0
0ol0003oooooooooo`1aooooo`Ko0000N_ooool0017ooooo00?o0000ooooooooool0L_ooool4o`00
07_ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo
000Aooooo`03o`000?oooooooooo0?7ooooo000Aooooo`03o`000?oooooooooo0?7ooooo000Aoooo
o`;o0000l_ooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0
lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0
017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo
00?o0000ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo00?o0000
ooooooooool0lOooool0017ooooo00?o0000ooooooooool0lOooool0017ooooo0_l0003booooo`00
4Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool0
0ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003o
ooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003ooooooooo
o`3aooooo`004Oooool00ol0003oooooooooo`3aooooo`004Oooool00ol0003oooooooooo`3aoooo
o`0000?oooooo`000?l000000_l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1?oo
ool00ol0003oooooooooo`3aooooo`000oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool00ol0003oooooooooo`3aooooo`000oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001?ooool3o`000?7ooooo0003ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00003hooooo`000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000n?ooool000?ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@0?Sooooo0003ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`3hooooo`0000CooooooeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^0?Sooooo003oooooo`Kooooo003oooooo`Kooooo003oooooo`Kooooo0000\
\>"],
  ImageRangeCache->{{{0, 260.875}, {260.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(k = 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g = 0.2\)]],
  " find the equilibrium shape, assuming that the masses in the base are \
fixed, by solving for the equilibrium position of the masses using the same \
spring force as in the previous problem with interior masses connected to \
their 6 nearest neighbors, and linearizing the equations in small \
displacements from equilibrium. (The solution is shown in Fig. ",
  ButtonBox["9.6",
    ButtonData:>"Fig. 9.6",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`g = 0.1\)]],
  ". )"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.1 0.000999001 0.0999001 [
[.2 -0.0115 -3 -9 ]
[.2 -0.0115 3 0 ]
[.4 -0.0115 -3 -9 ]
[.4 -0.0115 3 0 ]
[.6 -0.0115 -3 -9 ]
[.6 -0.0115 3 0 ]
[.8 -0.0115 -3 -9 ]
[.8 -0.0115 3 0 ]
[1 -0.0115 -6 -9 ]
[1 -0.0115 6 0 ]
[-0.0125 .2008 -6 -4.5 ]
[-0.0125 .2008 0 4.5 ]
[-0.0125 .4006 -6 -4.5 ]
[-0.0125 .4006 0 4.5 ]
[-0.0125 .6004 -6 -4.5 ]
[-0.0125 .6004 0 4.5 ]
[-0.0125 .8002 -6 -4.5 ]
[-0.0125 .8002 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .001 m
.2 .00725 L
s
[(2)] .2 -0.0115 0 1 Mshowa
.4 .001 m
.4 .00725 L
s
[(4)] .4 -0.0115 0 1 Mshowa
.6 .001 m
.6 .00725 L
s
[(6)] .6 -0.0115 0 1 Mshowa
.8 .001 m
.8 .00725 L
s
[(8)] .8 -0.0115 0 1 Mshowa
1 .001 m
1 .00725 L
s
[(10)] 1 -0.0115 0 1 Mshowa
.125 Mabswid
.05 .001 m
.05 .00475 L
s
.1 .001 m
.1 .00475 L
s
.15 .001 m
.15 .00475 L
s
.25 .001 m
.25 .00475 L
s
.3 .001 m
.3 .00475 L
s
.35 .001 m
.35 .00475 L
s
.45 .001 m
.45 .00475 L
s
.5 .001 m
.5 .00475 L
s
.55 .001 m
.55 .00475 L
s
.65 .001 m
.65 .00475 L
s
.7 .001 m
.7 .00475 L
s
.75 .001 m
.75 .00475 L
s
.85 .001 m
.85 .00475 L
s
.9 .001 m
.9 .00475 L
s
.95 .001 m
.95 .00475 L
s
.25 Mabswid
0 .001 m
1 .001 L
s
0 .2008 m
.00625 .2008 L
s
[(2)] -0.0125 .2008 1 0 Mshowa
0 .4006 m
.00625 .4006 L
s
[(4)] -0.0125 .4006 1 0 Mshowa
0 .6004 m
.00625 .6004 L
s
[(6)] -0.0125 .6004 1 0 Mshowa
0 .8002 m
.00625 .8002 L
s
[(8)] -0.0125 .8002 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05095 m
.00375 .05095 L
s
0 .1009 m
.00375 .1009 L
s
0 .15085 m
.00375 .15085 L
s
0 .25075 m
.00375 .25075 L
s
0 .3007 m
.00375 .3007 L
s
0 .35065 m
.00375 .35065 L
s
0 .45055 m
.00375 .45055 L
s
0 .5005 m
.00375 .5005 L
s
0 .55045 m
.00375 .55045 L
s
0 .65035 m
.00375 .65035 L
s
0 .7003 m
.00375 .7003 L
s
0 .75025 m
.00375 .75025 L
s
0 .85015 m
.00375 .85015 L
s
0 .9001 m
.00375 .9001 L
s
0 .95005 m
.00375 .95005 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.03 w
0 .001 Mdot
.02758 .06475 Mdot
.06968 .12362 Mdot
.12149 .17819 Mdot
.17823 .23042 Mdot
.23623 .28275 Mdot
.29302 .33766 Mdot
.34746 .39731 Mdot
.39951 .46322 Mdot
.45 .53612 Mdot
.5 .61598 Mdot
.1 .001 Mdot
.13033 .05528 Mdot
.17434 .10613 Mdot
.22682 .15558 Mdot
.28329 .20598 Mdot
.34036 .25956 Mdot
.39588 .31831 Mdot
.44899 .38363 Mdot
.5 .45625 Mdot
.55 .53612 Mdot
.2 .001 Mdot
.235 .04839 Mdot
.28173 .09448 Mdot
.33512 .14173 Mdot
.39106 .19246 Mdot
.44658 .24875 Mdot
.5 .31216 Mdot
.55101 .38363 Mdot
.60049 .46322 Mdot
.3 .001 Mdot
.34069 .04404 Mdot
.39056 .08792 Mdot
.44489 .13518 Mdot
.5 .18815 Mdot
.55342 .24875 Mdot
.60412 .31831 Mdot
.65254 .39731 Mdot
.4 .001 Mdot
.44685 .04196 Mdot
.5 .08581 Mdot
.55511 .13518 Mdot
.60894 .19246 Mdot
.65964 .25956 Mdot
.70698 .33766 Mdot
.5 .001 Mdot
.55315 .04196 Mdot
.60944 .08792 Mdot
.66488 .14173 Mdot
.71671 .20598 Mdot
.76377 .28275 Mdot
.6 .001 Mdot
.65931 .04404 Mdot
.71827 .09448 Mdot
.77318 .15558 Mdot
.82177 .23042 Mdot
.7 .001 Mdot
.765 .04839 Mdot
.82566 .10613 Mdot
.87851 .17819 Mdot
.8 .001 Mdot
.86967 .05528 Mdot
.93032 .12362 Mdot
.9 .001 Mdot
.97242 .06475 Mdot
1 .001 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{228.75, 228.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017B000`400?l00000o`00003ooooooolN
ooooo`00oooooolNooooo`00oooooolNooooo`00oooooolNooooo`00oooooolNooooo`00@oooool5
o`00033ooooo0_l000000ol@413oooooooooo`0]ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;ooo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^0_ooool004?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00aooooo`03o`000?oooooo
oooo02kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0_ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
;_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool004Cooooo
00?oV9RHob4Q8Oo^k^h0;oooool5o`0002oooooo00Go0000ooooooooooooooooo`00000_ooooo`05
o`000?ooooooooooooooool00000;_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000_ooool004Gooooo00?oV9RHob4Q8Oo^k^h0;_ooool01?m4A4CogMgMooooool0000`
ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;oooool01Olb<S;oV9RHoooooonHV9So<S8b02kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0016ooooo`03ogMg
MomVIVKooooo02gooooo00CogMgMoeEEEOoooooo0000<?ooool01Ol0003oEEEEo`000?l@413oc<c<
02oooooo00Goc<c<o`000?l0003o0000olc<c00^ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000002ooooo`00Aoooool00ol0003oooooooooo`0]ooooo`03ogMgMoo<c<co
0000033ooooo00?oEEEEohN7Qoooool0<Oooool01Ol@413o^[Zjoooooonj^[[o410@02kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00;ooooo0013ooooo`05o`000?nj
^[[ooooooiRHV?l@4100;oooool00oo^k^koA4A4o`00000`ooooo`03omgMgOl@413oV9RH037ooooo
00Go0000okZj^_oooooo^[Zjo`00000^ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`02ooooo`00@oooool01OnHV9So410@o`000?lQ8B7oc<c<033ooooo00?oMgMgo`00
0?ooool0<?ooool01?o<c<coA4A4o`000?l@410_ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00?oooooo7_oo
ool0013ooooo0ol0000Gooooo`?o00005oooool3o`0001Oooooo0ol0000Gooooo`?o00005oooool3
o`0001Oooooo0ol0000Gooooo`?o00005oooool3o`0001Oooooo0ol0000Gooooo`?o00001_ooool0
00oooooo1Ol0000Eooooo`Go00005Oooool5o`0001Gooooo1Ol0000Eooooo`Go00005Oooool5o`00
01Gooooo1Ol0000Eooooo`Go00005Oooool5o`0001Gooooo1Ol0000Eooooo`Go00001Oooool000ko
oooo1ol0000Cooooo`Oo00004oooool7o`0001?ooooo1ol0000Cooooo`Oo00004oooool7o`0001?o
oooo1ol0000Cooooo`Oo00004oooool7o`0001?ooooo1ol0000Cooooo`Oo00001?ooool000kooooo
ool0000<o`0000Cooooo000>ooooo`Oo00002_ooool00ol0003oooooooooo`06ooooo`Oo00002_oo
ool00ol0003oooooooooo`06ooooo`Oo00002_ooool00ol0003oooooooooo`06ooooo`Oo00002Ooo
ool00ol0003oooooooooo`07ooooo`Oo00002Oooool00ol0003oooooooooo`07ooooo`Oo00002Ooo
ool00ol0003oooooooooo`07ooooo`Oo00002Oooool00ol0003oooooooooo`07ooooo`Oo00002Ooo
ool00ol0003oooooooooo`07ooooo`Oo00002Oooool00ol0003oooooooooo`07ooooo`Oo00002Ooo
ool00ol0003oooooooooo`07ooooo`Oo00001?ooool000oooooo1Ol0000Eooooo`Go00005Oooool5
o`0001Gooooo1Ol0000Eooooo`Go00005Oooool5o`0001Gooooo1Ol0000Eooooo`Go00005Oooool5
o`0001Gooooo1Ol0000Eooooo`Go00001Oooool0013ooooo0ol0000Gooooo`?o00005oooool3o`00
01Oooooo0ol0000Gooooo`?o00005oooool3o`0001Oooooo0ol0000Gooooo`?o00005oooool3o`00
01Oooooo0ol0000Gooooo`?o00001_ooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`00
4_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Ooo
ool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`1_oooo
o`?o00006Oooool3o`0007[ooooo000Booooo`03o`000?oooooooooo05Cooooo0ol0000Gooooo`Go
00005oooool5o`0001Oooooo0ol0001Oooooo`004_ooool00ol0003oooooooooo`0hooooo`?o0000
6?ooool5o`0001Gooooo1ol0000Eooooo`Oo00005Oooool5o`0001Sooooo0ol00013ooooo`004_oo
ool00ol0003oooooooooo`0Mooooo`?o00005oooool5o`0001Kooooo1ol0000Dooooo`Oo00005Ooo
ool7o`0001Cooooo1ol0000Fooooo`Go00005oooool3o`0002Sooooo000Booooo`03o`000?oooooo
oooo01cooooo1Ol0000Eooooo`Oo00005Oooool7o`0001Cooooo1ol0000Eooooo`Oo00005?ooool7
o`0001Gooooo1ol0000Eooooo`Go00009oooool001;ooooo0_l0000Looooo`Oo00005?ooool7o`00
01Gooooo1ol0000Eooooo`Go00005oooool5o`0001Gooooo1ol0000Eooooo`Oo00005?ooool7o`00
02Kooooo000Booooo`03o`000?oooooooooo00?ooooo0ol0000Eooooo`Oo00005?ooool7o`0001Ko
oooo1Ol0000Gooooo`?o00006Oooool3o`0001Oooooo1Ol0000Fooooo`Oo00005?ooool7o`0001Go
oooo0ol0000>ooooo`004_ooool00ol0003oooooooooo`02ooooo`Go00005?ooool7o`0001Gooooo
1Ol0000Hooooo`?o0000Coooool3o`0001Sooooo1Ol0000Eooooo`Oo00005?ooool5o`0000gooooo
000Booooo`04o`000?ooooooooooooooo`Oo00005?ooool5o`0001Oooooo0ol00027ooooo`?o0000
5oooool5o`0001Cooooo1ol0000<ooooo`004_ooool01?l0003oooooooooooooool7o`0001Gooooo
0ol0002mooooo`?o00005Oooool7o`0000cooooo000Booooo`04o`000?ooooooooooooooo`Oo0000
kOooool7o`0000cooooo000Booooo`03o`000?oooooooooo00;ooooo1Ol0001fooooo`?o0000M_oo
ool5o`0000gooooo000Booooo`03o`000?oooooooooo00?ooooo0ol0001Kooooo`?o00006?ooool5
o`0001Sooooo0ol0001Kooooo`?o00003_ooool001;ooooo00?o0000ooooooooool0H?ooool5o`00
01Kooooo1ol0000Fooooo`Go0000Joooool001;ooooo00?o0000ooooooooool0A?ooool3o`0001So
oooo1ol0000Eooooo`Oo00005Oooool7o`0001Sooooo0ol0001?ooooo`004_ooool00ol0003ooooo
ooooo`13ooooo`Go00005oooool7o`0001Gooooo1ol0000Eooooo`Oo00005oooool5o`0004kooooo
000Booooo`03o`000?oooooooooo04;ooooo1ol0000Fooooo`Oo00005_ooool5o`0001Kooooo1ol0
000Fooooo`Oo0000COooool001;ooooo00?o0000ooooooooool0:Oooool3o`0001Kooooo1ol0000G
ooooo`Go00006?ooool3o`0001Sooooo1Ol0000Gooooo`Oo00005_ooool3o`0003Cooooo000Boooo
o`;o0000:Oooool5o`0001Gooooo1ol0000Hooooo`?o0000=Oooool3o`0001Sooooo1ol0000Eoooo
o`Go0000<oooool001;ooooo00?o0000ooooooooool09oooool7o`0001Gooooo1Ol0001]ooooo`Go
00005Oooool7o`0003;ooooo000Booooo`03o`000?oooooooooo02Oooooo1ol0000Fooooo`?o0000
Koooool3o`0001Kooooo1ol0000booooo`004_ooool00ol0003oooooooooo`0=ooooo`?o00005ooo
ool7o`000:7ooooo1ol0000Gooooo`?o00006?ooool001;ooooo00?o0000ooooooooool03?ooool5
o`0001Oooooo1Ol0002Sooooo`Go00005oooool5o`0001Oooooo000Booooo`03o`000?oooooooooo
00_ooooo1ol0000Gooooo`?o0000YOooool3o`0001Oooooo1ol0000Fooooo`004_ooool00ol0003o
ooooooooo`0;ooooo`Oo0000GOooool3o`0001Wooooo0ol0001Mooooo`Oo00005_ooool001;ooooo
00?o0000ooooooooool02oooool7o`0005cooooo1Ol0000Gooooo`Go0000G?ooool7o`0001Kooooo
000Booooo`03o`000?oooooooooo00cooooo1Ol00011ooooo`?o00006?ooool7o`0001Gooooo1ol0
000Hooooo`?o0000@Oooool5o`0001Oooooo000Booooo`03o`000?oooooooooo00gooooo0ol00011
ooooo`Go00005oooool7o`0001Gooooo1ol0000Gooooo`Go0000@Oooool3o`0001Sooooo000Boooo
o`03o`000?oooooooooo053ooooo1ol0000Fooooo`Oo00005Oooool7o`0001Kooooo1ol0001Koooo
o`004_ooool00ol0003oooooooooo`0fooooo`?o00005oooool7o`0001Oooooo1Ol0000Gooooo`Go
00005oooool7o`0001Oooooo0ol00011ooooo`004_ooool00ol0003oooooooooo`0eooooo`Go0000
5_ooool7o`0001Sooooo0ol0000Iooooo`?o00006?ooool7o`0001Kooooo1Ol00010ooooo`004_oo
ool2o`0003Gooooo1ol0000Fooooo`Go0000DOooool5o`0001Kooooo1ol0000oooooo`004_ooool0
0ol0003oooooooooo`0dooooo`Oo00005oooool3o`0005?ooooo0ol0000Gooooo`Oo0000?oooool0
01;ooooo00?o0000ooooooooool0=?ooool7o`0008Oooooo1ol0000oooooo`004_ooool00ol0003o
ooooooooo`0eooooo`Go0000ROooool5o`00043ooooo000Booooo`03o`000?oooooooooo01_ooooo
0ol0000Hooooo`?o0000Roooool3o`0001Sooooo0ol0000Vooooo`004_ooool00ol0003ooooooooo
o`0Jooooo`Go0000_oooool5o`0002Gooooo000Booooo`03o`000?oooooooooo01Wooooo1ol0002m
ooooo`Oo00009?ooool001;ooooo00?o0000ooooooooool06Oooool7o`0005gooooo0ol0001Moooo
o`Oo00009?ooool001;ooooo00?o0000ooooooooool06Oooool7o`00047ooooo0ol0000Hooooo`Go
00006?ooool3o`00047ooooo1ol0000Tooooo`004_ooool00ol0003oooooooooo`0Jooooo`Go0000
@Oooool5o`0001Kooooo1ol0000Fooooo`Go0000@Oooool5o`0002Gooooo0008ooooo`Go00001Ooo
ool00ol0003oooooooooo`0Kooooo`?o0000@Oooool7o`0001Gooooo1ol0000Eooooo`Oo0000@Ooo
ool3o`0002Kooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`15ooooo`?o00005oooool7o`0001Gooooo1ol0000Eooooo`Oo00005oooool3o`00053ooooo0009
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0A?ooool5o`0001Kooooo1ol0000F
ooooo`Go00005_ooool7o`0001Kooooo1Ol0001?ooooo`002_ooool00onHV9So8B4Qonk^kP05oooo
o`;o0000A?ooool7o`0001Kooooo1Ol0000Hooooo`?o00006?ooool5o`0001Kooooo1ol0001>oooo
o`002oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo04?ooooo1ol0000Gooooo`?o
0000=Oooool3o`0001Oooooo1ol0001>ooooo`003?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04?ooooo1ol0001Yooooo`Oo0000C_ooool000Sooooo00Go0000okZj^_ooooooV9RH
oa0@4005ooooo`03o`000?oooooooooo04Cooooo1Ol0001[ooooo`Go0000Coooool000Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo04Gooooo0ol0001]ooooo`?o0000
D?ooool001;ooooo00?o0000ooooooooool0:_ooool3o`000:?ooooo0ol0000eooooo`004_ooool0
0ol0003oooooooooo`0Yooooo`Go0000XOooool5o`0003Cooooo000Booooo`03o`000?oooooooooo
02Sooooo1ol0002Oooooo`Oo0000<oooool001;ooooo00?o0000ooooooooool0:?ooool7o`0009oo
oooo1ol0000cooooo`004_ooool00ol0003oooooooooo`0Xooooo`Oo0000Woooool7o`0003?ooooo
000Booooo`03o`000?oooooooooo02Wooooo1Ol00011ooooo`?o00006Oooool3o`00047ooooo1Ol0
000dooooo`004_ooool00ol0003oooooooooo`0Zooooo`?o0000@Oooool5o`0001Oooooo1Ol00011
ooooo`?o0000=Oooool001;ooooo00?o0000ooooooooool0E?ooool3o`0001Kooooo1ol0000Eoooo
o`Oo00005_ooool3o`0005oooooo000Booooo`;o0000E?ooool5o`0001Gooooo1ol0000Eooooo`Oo
00005Oooool5o`0005kooooo000Booooo`03o`000?oooooooooo05;ooooo1ol0000Dooooo`Oo0000
5Oooool7o`0001Cooooo1ol0001Mooooo`004_ooool00ol0003oooooooooo`1Booooo`Oo00005Ooo
ool5o`0001Oooooo1Ol0000Eooooo`Oo0000GOooool001;ooooo00?o0000ooooooooool0D_ooool7
o`0001Kooooo0ol0000Iooooo`?o00005_ooool7o`0005gooooo000Booooo`03o`000?oooooooooo
05?ooooo1Ol0001=ooooo`Go0000G_ooool001;ooooo00?o0000ooooooooool0>Oooool3o`0001So
oooo0ol0001?ooooo`?o00006?ooool3o`0004Cooooo000Booooo`03o`000?oooooooooo03Sooooo
1Ol00023ooooo`Go0000@oooool001;ooooo00?o0000ooooooooool0=oooool7o`00087ooooo1ol0
0012ooooo`004_ooool00ol0003oooooooooo`0gooooo`Oo0000POooool7o`0004;ooooo000Boooo
o`03o`000?oooooooooo03Oooooo1ol00021ooooo`Oo0000@_ooool001;ooooo00?o0000oooooooo
ool0>?ooool5o`0008?ooooo1Ol00013ooooo`004_ooool00ol0003oooooooooo`0iooooo`?o0000
QOooool3o`0004Cooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo0_l0001n
ooooo`?o0000R?ooool001;ooooo00?o0000ooooooooool0O?ooool5o`0008Oooooo000Booooo`03
o`000?oooooooooo06;ooooo0ol0000Fooooo`Oo00005_ooool3o`0006gooooo000Booooo`03o`00
0?oooooooooo067ooooo1Ol0000Eooooo`Oo00005Oooool5o`0006cooooo000Booooo`03o`000?oo
oooooooo063ooooo1ol0000Dooooo`Oo00005?ooool7o`0006_ooooo000Booooo`03o`000?oooooo
oooo063ooooo1ol0000Eooooo`Go00005Oooool7o`0006_ooooo000Booooo`03o`000?oooooooooo
063ooooo1ol0000Fooooo`?o00005_ooool7o`0006_ooooo000Booooo`03o`000?oooooooooo04Oo
oooo0ol0000Gooooo`Go0000<Oooool5o`0001Oooooo0ol0001Booooo`004_ooool00ol0003ooooo
ooooo`16ooooo`Go00005oooool3o`0003?ooooo0ol0000Gooooo`Go0000DOooool001;ooooo00?o
0000ooooooooool0AOooool7o`0006Gooooo1ol0001@ooooo`004_ooool00ol0003oooooooooo`15
ooooo`Oo0000IOooool7o`00053ooooo000Booooo`03o`000?oooooooooo04Gooooo1ol0001Uoooo
o`Oo0000D?ooool001;ooooo00?o0000ooooooooool0A_ooool5o`0006Oooooo1Ol0001Aooooo`00
4_ooool2o`0004Sooooo0ol0001Yooooo`?o0000D_ooool001;ooooo00?o0000ooooooooool0oooo
ool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo
0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003ooooo
ooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo073ooooo0ol0000Gooooo`?o0000Nooo
ool001;ooooo00?o0000ooooooooool0Koooool5o`0001Gooooo1Ol0001jooooo`004_ooool00ol0
003oooooooooo`1^ooooo`Oo00004oooool7o`0007Wooooo000Booooo`03o`000?oooooooooo05Go
oooo0ol0000Fooooo`Oo00004oooool7o`0001Kooooo0ol0001Pooooo`002_ooool2o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0E?ooool5o`0001Gooooo1ol0000Cooooo`Oo0000
5Oooool5o`0005oooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Dooo
ool7o`0001Gooooo1Ol0000Eooooo`Go00005Oooool7o`0005kooooo0008ooooo`Go00001Oooool0
0ol0003oooooooooo`1Cooooo`Oo00005_ooool3o`0001Oooooo0ol0000Fooooo`Oo0000G_ooool0
00Sooooo00CoA4A4omgMgOoooooo00001_ooool2o`0005Cooooo1ol00019ooooo`Oo0000G_ooool0
00Sooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`1Dooooo`Go0000Boooool5
o`0005oooooo0009ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0EOooool3o`00
04gooooo0ol0001Pooooo`002Oooool00oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo0?oo
oooo2Oooool000[ooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooo`Wooooo
000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oo
oooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003ooooooooo
o`3oooooo`Wooooo000Booooo`03o`000?oooooooooo07gooooo0ol00028ooooo`004_ooool00ol0
003oooooooooo`1looooo`Go0000Qoooool001;ooooo0_l0001Tooooo`?o00005Oooool7o`0001Go
oooo0ol0001^ooooo`004_ooool00ol0003oooooooooo`1Rooooo`Go00005?ooool7o`0001Cooooo
1Ol0001]ooooo`004_ooool00ol0003oooooooooo`1Qooooo`Oo00004oooool7o`0001?ooooo1ol0
001/ooooo`004_ooool00ol0003oooooooooo`1Qooooo`Oo00005?ooool5o`0001Cooooo1ol0001/
ooooo`004_ooool00ol0003oooooooooo`1Qooooo`Oo00005Oooool3o`0001Gooooo1ol0001/oooo
o`004_ooool00ol0003oooooooooo`1Rooooo`Go0000;oooool5o`0006gooooo000Booooo`03o`00
0?oooooooooo06?ooooo0ol0000aooooo`?o0000K_ooool001;ooooo00?o0000ooooooooool0oooo
ool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo
0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003ooooo
ooooo`3oooooo`Wooooo000Booooo`;o0000ooooool:ooooo`004_ooool00ol0003oooooooooo`3o
ooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000oooooooo
ool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oo
oooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0
003oooooooooo`1`ooooo`?o00005oooool3o`0007_ooooo000Booooo`03o`000?oooooooooo06oo
oooo1Ol0000Eooooo`Go0000N_ooool001;ooooo00?o0000ooooooooool0K_ooool7o`0001?ooooo
1ol0001iooooo`004_ooool00ol0003oooooooooo`1^ooooo`Oo00004oooool7o`0007Wooooo000B
ooooo`03o`000?oooooooooo06kooooo1ol0000Cooooo`Oo0000NOooool001;ooooo00?o0000oooo
ooooool0Koooool5o`0001Gooooo1Ol0001jooooo`004_ooool2o`00077ooooo0ol0000Gooooo`?o
0000Noooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003ooooooooo
o`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000oooo
ooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`00
0?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;o
oooo00?o0000ooooooooool0ooooool9ooooo`002?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0ooooool9ooooo`002?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Go
oooo00?o0000ooooooooool0ooooool9ooooo`002?ooool01Ol0003ooooooooooooooooo000000Go
oooo0_l0003oooooo`[ooooo0008ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003o
ooooooooo`3oooooo`Wooooo0008ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003o
ooooooooo`1mooooo`?o0000R?ooool000Sooooo00?oEEEEohN7Qoooool01oooool00ol0003ooooo
ooooo`1looooo`Go0000Qoooool000Sooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003ooooooooo
o`1kooooo`Oo0000Q_ooool000Wooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003ooooooooo
o`1kooooo`Oo0000Q_ooool001;ooooo00?o0000ooooooooool0Noooool7o`0008Kooooo000Boooo
o`03o`000?oooooooooo07cooooo1Ol00027ooooo`004_ooool00ol0003oooooooooo`1mooooo`?o
0000R?ooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003ooooooooo
o`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000oooo
ooooool0ooooool9ooooo`004_ooool2o`000?oooooo2_ooool001;ooooo00?o0000ooooooooool0
ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooo
oooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003o
ooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o
0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Boooo
o`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`00
4_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Ooo
ool001;ooooo0_l0003oooooo`[ooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;o
oooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo
000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oo
oooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003ooooooooo
o`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000oooo
ooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`;o0000
ooooool:ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooo
oooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003o
ooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o
0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Boooo
o`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`00
4_ooool00ol0003oooooooooo`3oooooo`Wooooo0008ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1Oooool00ol0003oooooooooo`3oooooo`Wooooo0008ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40
1Oooool00ol0003oooooooooo`3oooooo`Wooooo0008ooooo`05o`000?ooooooooooooooool00000
1Oooool2o`000?oooooo2_ooool000Sooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`03o`00
0?oooooooooo0?oooooo2Oooool000Sooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`00
0?oooooooooo0?oooooo2Oooool000Sooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`00
0?oooooooooo0?oooooo2Oooool000Sooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`00
0?oooooooooo0?oooooo2Oooool000Sooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`00
0?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;o
oooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo
000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9
ooooo`004_ooool2o`000?oooooo2_ooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`00
4_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Ooo
ool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0
ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooo
oooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003o
ooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo0_l0
003oooooo`[ooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000oooo
ooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`00
0?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool0
0ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;o
oooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo
000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9
ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`;o0000ooooool:ooooo`00
4_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Ooo
ool001;ooooo00?o0000ooooooooool0ooooool9ooooo`004_ooool00ol0003oooooooooo`3ooooo
o`Wooooo000Booooo`03o`000?oooooooooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0
ooooool9ooooo`004_ooool00ol0003oooooooooo`3oooooo`Wooooo000Booooo`03o`000?oooooo
oooo0?oooooo2Oooool001;ooooo00?o0000ooooooooool0ooooool9ooooo`0000?oooooo`000?l0
00000_l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool00ol0003ooooooooo
o`3oooooo`Wooooo0003ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03o`000?oooooooooo0?oooooo2Oooool000?ooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0ooooool9ooooo`000oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool2o`000?oooooo2_oo
ool000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000?oooooo4Ooo
ool000?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@0?oooooo4Ooo
ool000?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo4Ooo
ool00004oooooomEEEGoIVIVo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3ooooooa7ooooo
003ooooooakooooo003ooooooakooooo003ooooooakooooo003ooooooakooooo0000\
\>"],
  ImageRangeCache->{{{0, 284.938}, {284.938, 0}} -> {0, 0, 0, 0}}],

Cell["Fig. 9.6 Solution for g=0.1.", "Caption",
  CellTags->"Fig. 9.6"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot how the height of the pyramid depends on ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " over the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-0.2\) < g < 0.2\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(k = 1\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.11 Numerical Analysis", "Subtitle",
  CellTags->{"Sec. 9.11", "c:60"}],

Cell[TextData[{
  "In this section, we examine a few of the elementary numerical procedures \
commonly used by scientists and engineers: numerical solution of algebraic \
equations, numerical integration, interpolation, and fitting.  In university \
courses on numerical methods it was once ",
  StyleBox["de rigeur",
    FontSlant->"Italic"],
  " to spend a considerable amount of time discussing the theory behind these \
procedures. However, hardly anyone writes their own codes to perform these \
tasks anymore.   Here, we focus on the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " intrinsic functions that perform these operations. Some of the basic \
techniques, such as Newton's method and least-squares fitting, are considered \
in the exercises. "
}], "Text"],

Cell[CellGroupData[{

Cell["9.11.1 Numerical Solution of Algebraic Equations", "Subsubtitle",
  CellTags->"c:61"],

Cell[TextData[{
  " \tIn order to solve the equation ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ 0\)]],
  " numerically,  it is often a good idea to plot the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " in order to see whether solutions exist for real ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  Take, for example,  ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ cos(x)\  - \ \[ExponentialE]\^x\)]],
  ".  A plot of this function is shown in Cell ",
  ButtonBox["9.172",
    ButtonData:>"Cell 9.172",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:86"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Cos[x] - Exp[x], {x, \(-6\), 6}, 
        PlotRange \[Rule] {\(-1.1\), 1.1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.172"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.309017 0.280925 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .02809 -12 -4.5 ]
[.4875 .02809 0 4.5 ]
[.4875 .16855 -24 -4.5 ]
[.4875 .16855 0 4.5 ]
[.4875 .44948 -18 -4.5 ]
[.4875 .44948 0 4.5 ]
[.4875 .58994 -6 -4.5 ]
[.4875 .58994 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-6)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-4)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-2)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(2)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(4)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(6)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.06349 .30902 m
.06349 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.57937 .30902 m
.57937 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.77778 .30902 m
.77778 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .02809 m
.50625 .02809 L
s
[(-1)] .4875 .02809 1 0 Mshowa
.5 .16855 m
.50625 .16855 L
s
[(-0.5)] .4875 .16855 1 0 Mshowa
.5 .44948 m
.50625 .44948 L
s
[(0.5)] .4875 .44948 1 0 Mshowa
.5 .58994 m
.50625 .58994 L
s
[(1)] .4875 .58994 1 0 Mshowa
.125 Mabswid
.5 .05618 m
.50375 .05618 L
s
.5 .08428 m
.50375 .08428 L
s
.5 .11237 m
.50375 .11237 L
s
.5 .14046 m
.50375 .14046 L
s
.5 .19665 m
.50375 .19665 L
s
.5 .22474 m
.50375 .22474 L
s
.5 .25283 m
.50375 .25283 L
s
.5 .28092 m
.50375 .28092 L
s
.5 .33711 m
.50375 .33711 L
s
.5 .3652 m
.50375 .3652 L
s
.5 .39329 m
.50375 .39329 L
s
.5 .42139 m
.50375 .42139 L
s
.5 .47757 m
.50375 .47757 L
s
.5 .50566 m
.50375 .50566 L
s
.5 .53376 m
.50375 .53376 L
s
.5 .56185 m
.50375 .56185 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57806 m
.03279 .56739 L
.04262 .5519 L
.06244 .50956 L
.10458 .382 L
.14509 .23889 L
.18408 .11605 L
.1943 .09005 L
.20539 .06573 L
.21497 .04829 L
.22006 .04048 L
.22553 .03323 L
.23088 .02732 L
.23577 .02297 L
.23812 .02123 L
.24069 .0196 L
.2431 .01833 L
.24536 .01736 L
.24669 .0169 L
.24813 .01648 L
.24933 .0162 L
.25064 .01596 L
.25138 .01585 L
.25207 .01578 L
.25279 .01572 L
.25357 .01569 L
.2543 .01568 L
.25498 .01569 L
.25627 .01576 L
.25749 .0159 L
.25879 .01611 L
.2599 .01635 L
.26112 .01668 L
.26384 .01762 L
.26639 .01879 L
.27109 .02164 L
.27623 .02578 L
.28658 .03727 L
.29616 .05146 L
.30508 .06748 L
.34413 .16197 L
.38562 .27886 L
.40643 .32987 L
.41556 .34844 L
.42561 .36527 L
.43026 .37161 L
.43526 .37729 L
.43998 .38149 L
.44429 .3843 L
.44551 .3849 L
Mistroke
.44681 .38545 L
.44793 .38585 L
.44915 .3862 L
.44989 .38637 L
.45058 .3865 L
.45123 .38659 L
.45192 .38667 L
.45312 .38672 L
.45444 .38668 L
.4557 .38654 L
.45685 .38633 L
.45748 .38617 L
.45817 .38598 L
.45942 .38554 L
.46184 .3844 L
.46407 .383 L
.46872 .37898 L
.47372 .37294 L
.47845 .36553 L
.48277 .35724 L
.49282 .33216 L
.50339 .2965 L
.52317 .20188 L
.54155 .07811 L
Mfstroke
.54155 .07811 m
.55027 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0:00oooo002c0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0X03oool00;<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`2P0?ooo`00/`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0:00oooo
002c0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0X03oool00;<0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`2P0?ooo`00F03oool7000005@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`2Q0?ooo`00EP3oool2000000L0oooo0P00001B0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0X@3oool005@0oooo0P00000;0?ooo`800000
AP3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`2Q0?ooo`00E03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0:40oooo001C
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>@3oool6000000D0oooo00<00000
0?ooo`3oool01@3oool3000000h0oooo00<000000?ooo`3oool0X@3oool00580oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`2Q0?ooo`00D@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0:40oooo001A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
X@3oool00500oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2Q0?ooo`00C`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03h0oooo0P1EEED00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0XP3oool004h0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0XP3oool004d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0XP3oool004d0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
XP3oool004`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0XP3oool004`0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`160?ooo`8000003P3oool00`000000oooo0?ooo`2R0?ooo`00B`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`2R0?ooo`00BP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2R0?ooo`00BP3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`2R0?ooo`00B@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`2S0?ooo`00B@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2S
0?ooo`00B03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`2S0?ooo`00B03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2S0?ooo`00
B03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`2S0?ooo`00A`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2S0?ooo`00A`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0440oooo0P00000=0?ooo`030000003oool0
oooo0:<0oooo00170?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0:<0oooo00160?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:@0
oooo00160?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0:@0oooo00150?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:@0oooo0015
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0:@0oooo00150?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:@0oooo00140?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0:@0oooo00140?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:D0oooo00130?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0:D0oooo00130?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0?@3oool2
000000/0oooo00<000000?ooo`3oool0Y@3oool004<0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Y@3oool00480
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0Y@3oool00480oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Y@3oool00480oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0Y@3oool00440oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0YP3oool00440oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0YP3oool00440oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0YP3oool00400oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
YP3oool00400oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0YP3oool00400oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0h0?ooo`8000002P3oool00`000000oooo0?ooo`2V0?ooo`00?`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`2W0?ooo`00?`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2W0?ooo`00?`3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2W0?ooo`00?P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2W0?ooo`00?P3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2W
0?ooo`00?P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`2W0?ooo`00?@3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2X0?ooo`00
?@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo00D0k^k^03<c<`000000
<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`2X0?ooo`00?@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo01X0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1g
MgL0<c<c0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0Z03oool003`0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`H000000P3oool01@0A4A40
oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool00`3oool3000000L0oooo00<000000?oo
o`3oool0Z03oool003`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0I0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0Z03oool003`0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0
c<c<00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2X0?ooo`00>`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo01P0oooo00D04A4A0?ooo`3oool0oooo014A4@0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2X
0?ooo`00>`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01P0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2Y0?ooo`00>`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
01P0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000001P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0:T0oooo000k0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:T0oooo000j0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0:T0oooo000j0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:T0oooo000j0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0:T0oooo000i0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0:X0oooo000i0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0<@3oool2000000H0oooo00<000000?ooo`3oool0ZP3oool003T0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0ZP3oool003P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0ZP3oool003P0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0ZP3oool003P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Z`3oool003L0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0Z`3oool003L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0Z`3oool003L0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
Z`3oool003H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0Z`3oool003H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0[03oool0
03H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0]0?ooo`800000103oool00`00
0000oooo0?ooo`2/0?ooo`00=@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2/0?ooo`00=@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2/0?ooo`00=@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`2/0?ooo`00=03oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2]
0?ooo`00=03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`2]0?ooo`00=03oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2]0?ooo`00
=03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`2]0?ooo`00<`3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2]0?ooo`00<`3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02X0oooo00D000000?ooo`3oool0oooo0000
002`0?ooo`00<`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02T0oooo0P000002
0?ooo`030000003oool0oooo0:h0oooo000b0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0:@3oool01@000000oooo0?ooo`3oool000000;00oooo000b0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool000000;00oooo000b0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0
00000;00oooo000a0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0:03oool01000
0000oooo0?ooo`00002a0?ooo`00<@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
02P0oooo00@000000?ooo`3oool00000/@3oool000T0oooo00D0k^k^03<c<`0000004A4A0<c<c00S
0?ooo`030000003oool0oooo0100oooo0P0000000`0A4A40oooo0?ooo`0b0?ooo`D000002@3oool0
0`000000oooo0?ooo`0W0?ooo`040000003oool0oooo00000380oooo1@00000f0?ooo`80000000<0
4A4A0?ooo`3oool0<P3oool01@3^k^h0<c<c0000000A4A40c<c<00P0oooo00090?ooo`0505EEE@1g
MgL0oooo09VIV@0R8R808`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03<0oooo
00D0VIVI028R8P3^k^h0oooo04A4A0090?ooo`030000003oool0oooo02L0oooo00@000000?ooo`3o
ool00000<P3oool01@2IVIT08R8R0>k^kP3oool0A4A403L0oooo00<000000?ooo`3oool0<`3oool0
1@1EEED0MgMg0?ooo`2IVIT08R8R00P0oooo00000`3oool000000000000400000080oooo00D00000
0?ooo`3oool0oooo0000000R0?ooo`030000003oool0oooo00L0oooo1P0000020?ooo`D00000;03o
ool6000000<0oooo00<0VIVI028R8P3^k^h02P3oool00`000000oooo0?ooo`0W0?ooo`040000003o
ool0oooo000003<0oooo00<0VIVI028R8P3^k^h0=@3oool5000003@0oooo00D000000?ooo`3oool0
oooo000000080?ooo`002@3oool01@000000VIVI0?ooo`2IVIT08R8R0280oooo00<000000?ooo`3o
ool03`3oool01014A4@0gMgM0?ooo`00000g0?ooo`0309VIV@0R8R80k^k^00X0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0000000e0?ooo`0309VIV@0R8R80k^k^03@0oooo00@0A4A40=gM
g@3oool00000=@3oool01@000000VIVI0?ooo`2IVIT08R8R00P0oooo00090?ooo`050000001EEED0
0000014A4@3<c<`08P3oool00`000000oooo0?ooo`0?0?ooo`040=gMg@1EEED0oooo000003P0oooo
00<0MgMg06IVIP3oool02@3oool00`000000oooo0?ooo`0V0?ooo`<00000=P3oool00`1gMgL0IVIV
0?ooo`0c0?ooo`040=gMg@1EEED0oooo000003D0oooo00D0000005EEE@0000004A4A0<c<c0080?oo
o`002@3oool00`1EEED0R8R80?ooo`0S0?ooo`030000003oool0oooo0140oooo00<0MgMg0<c<c000
0000>@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<000000?ooo`00
0000=`3oool00`000000oooo0?ooo`0c0?ooo`0307MgM`3<c<`0000003D0oooo00<0EEEE08R8R03o
ool02P3oool000T0oooo00<0gMgM014A4@2IVIT08`3oool00`000000oooo0?ooo`0A0?ooo`030>k^
kP14A4@0000003D0oooo00D000000;^k^`3oool0VIVI014A4@0;0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`000000<`3oool01@000000^k^k0?ooo`2IVIT04A4A03D0oooo00<0k^k^04A4
A0000000=@3oool00`3MgMd04A4A09VIV@0:0?ooo`002P3oool0103<c<`0A4A40000000A4A4Q0?oo
o`030000003oool0oooo0180oooo00<0MgMg0000003oool0=03oool01@2IVIT04A4A0000000R8R80
c<c<00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0000000c0?ooo`0509VIV@0A4A40
0000028R8P3<c<`0=P3oool00`1gMgL000000?ooo`0e0?ooo`040<c<c014A4@00000014A4@P0oooo
000_0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0903oool200000;<0oooo000^
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0903oool200000;<0oooo000^0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool08`3oool200000;<0oooo000^0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool08`3oool200000;<0oooo000]0?ooo`030000
003oool0oooo05d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`2b0?ooo`00;@3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0/P3o
ool00?l00000J00000010?ooo`00203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0200
oooo0P00000h0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`070?ooo`00;03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0200oooo
0P00002d0?ooo`00;03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`000000]03oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool000000;@0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool07P3oool00`000000oooo0000002d0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo01`0oooo00@000000?ooo`3oool00000]03oool002X0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`0L0?ooo`040000003oool0oooo00000;@0oooo000Z0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00002d0?oo
o`00:P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3o
ool0oooo0P00002c0?ooo`00:P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo01T0
oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00:@3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00:@3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2b0?ooo`00:@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2b0?ooo`00:03oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2b0?ooo`00:03oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`00:03oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?oo
o`009`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2b0?ooo`009`3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2b0?ooo`009`3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool200000;<0oooo000W0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo000V0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0;80oooo000V0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0;80oooo000V0?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo
000U0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01`3oool2000000X0oooo00<0
00000?ooo`3oool0/P3oool002D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0/P3oool002D0oooo00<000000?oo
o`3oool0M`3oool300000080oooo0P00000=0?ooo`030000003oool0oooo0;80oooo000U0?ooo`03
0000003oool0oooo07T0oooo1000000>0?ooo`030000003oool0oooo0;80oooo000T0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<000000?ooo`3oool0S03o
ool200000;<0oooo000T0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/P3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`2b0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0;80oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0/P3oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`2b0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0;80oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0/P3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`2b0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0;80oooo000Q0?ooo`030000003oool0oooo08l0oooo0P00002c0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0;80oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0/P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`2b0?ooo`007`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0;80oooo
000O0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0/P3oool001l0oooo00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`2b0?ooo`007P3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0;80oooo000N0?ooo`030000003oool0oooo07L0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo00<00000
0?ooo`3oool0/P3oool001h0oooo00<000000?ooo`3oool0M`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0/P3oool0
01d0oooo00<000000?ooo`3oool0N03oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<00000
0?ooo`3oool00`3oool300000;80oooo000M0?ooo`030000003oool0oooo07P0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0/P3oool0
01d0oooo00<000000?ooo`3oool0N03oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000
028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0;80oooo000L0?ooo`030000003oool0
oooo07T0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0/P3oool001`0oooo00<000000?ooo`3oool0N@3oool01@1gMgL0VIVI0?ooo`2I
VIT0MgMg00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00703oool0
0`000000oooo0?ooo`1i0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000H0oooo00<0
00000?ooo`3oool0/P3oool001/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`2b
0?ooo`006`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo0;80oooo000K0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0/P3oool001X0oooo00<000000?ooo`3oool0
UP3oool00`000000oooo0?ooo`2b0?ooo`006P3oool00`000000oooo0?ooo`2F0?ooo`800000/`3o
ool001X0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`2b0?ooo`006@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo0;80oooo000I0?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0/P3oool001T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`2b0?ooo`00603oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0;80oooo000H
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0/P3oool001P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`2b0?ooo`005`3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo0;80oooo000G0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
/P3oool001L0oooo00<000000?ooo`3oool0V@3oool200000;<0oooo000F0?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0/P3oool001H0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`2b0?ooo`005P3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0;80
oooo000E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0/P3oool001D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`2b0?ooo`00503oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo0;80oooo000D0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0/P3oool001<0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`2b0?ooo`00
4`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo0;80oooo000B0?ooo`030000003o
ool0oooo09h0oooo0P00002c0?ooo`004P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo0;80oooo000B0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0/P3oool00140
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`2b0?ooo`004@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo0;80oooo000@0?ooo`030000003oool0oooo0:00oooo00<0
00000?ooo`3oool0/P3oool00100oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`2b
0?ooo`003`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo0;80oooo000?0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0/P3oool000h0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`2b0?ooo`003@3oool00`000000oooo0?ooo`2S0?ooo`800000/`3o
ool000d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`2b0?ooo`00303oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0;80oooo000;0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0/P3oool000X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`2b0?ooo`002@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo0;80oooo0008
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00:T0oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo0;80
oooo002[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool00:/0oooo00<0
00000?ooo`3oool01@3oool300000;80oooo002[0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0/P3oool00:/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?oo
o`00Z`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002[0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool00:T0oooo0P1EEED00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "You can see that there are in fact several solutions. One is at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", and there are others at ",
  Cell[BoxData[
      \(TraditionalForm\`x < 0\)]],
  ".  In order to find a numerical approximation to any one of these \
solutions, use the function ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This syntax for this function is \n",
  StyleBox["FindRoot[eqn,{var,guess}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",where ",
  StyleBox["eqn",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is the equation we are solving ( ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontWeight->"Bold"], 
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontWeight->"Bold"]}], 
          StyleBox["==",
            FontWeight->"Bold"], 
          StyleBox["0",
            FontWeight->"Bold"]}], TraditionalForm]],
    FontFamily->"Courier"],
  StyleBox[" ",
    FontFamily->"Courier"],
  "in this example),  ",
  StyleBox["var",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " is the variable we are solving for (",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in this case), and ",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["guess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is an initial guess for the value of ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that solves the equation. (Note the double equal sign syntax in the \
equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["x",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox["==",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["0",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " , just as in the intrinsic functions ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["NSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".) ",
  StyleBox["FindRoot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "will then attempt to find the solution closest to the given initial guess. \
 For example, if we choose for our initial guess ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-2\)\)]],
  ", we obtain the following result:"
}], "Text",
  CellTags->"i:84"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[Cos[x]\  - Exp[x] \[Equal] 0, {x, \(-2\)}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.173"],

Cell[BoxData[
    \({x \[Rule] \(-1.2926957194226605`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses ",
  ButtonBox["Newton's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Newton.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " method to quickly obtain the solution. It is not particularly important \
to understand how Newton's method works (some programming ideas are needed to \
explain it: see the Exercises).  However, it is important to know how well \
the solution works. We can find out by substituting it back into the function \
",
  Cell[BoxData[
      \(TraditionalForm\`cos\ x - \ exp\ x\)]],
  ":"
}], "Text",
  CellTags->"i:125"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cos[x]\  - \ Exp[x]\  /. %\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.174"],

Cell[BoxData[
    \(\(-3.3845481972605285`*^-11\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "There is a very small error, as expected in any numerical solution. But \
the accuracy is almost as high as one can expect to achieve in a computer \
system with 16-digit precision. One can attempt to improve ths accuracy by \
using the option ",
  StyleBox["AccuracyGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is an option that sets the wished-for number of digits of accuracy \
in the solution. For instance, "
}], "Text",
  CellTags->"i:102"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[Cos[x]\  - Exp[x] \[Equal] 0, {x, \(-2\)}, 
      AccuracyGoal \[Rule] 16]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.175"],

Cell[BoxData[
    \({x \[Rule] \(-1.2926957193733983`\)}\)], "Output"]
}, Open  ]],

Cell["This solution is more accurate than the previous solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cos[x] - Exp[x] /. %\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.176"],

Cell[BoxData[
    \(5.551115123125783`*^-17\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tTo find another solution, we must supply another guess. ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only finds one solution at a time:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[Cos[x] - Exp[x], {x, \(-5\)}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.177"],

Cell[BoxData[
    \({x \[Rule] \(-4.7212923566932625`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThere are also complex solutions to this equation, and ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will find them if an appropriate initial guess is supplied:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[Cos[x]\  - \ Exp[x], {x, 3\  + \ 3\ I}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.178"],

Cell[BoxData[
    \({x \[Rule] \(\(2.7950802199122182`\)\(\[InvisibleSpace]\)\) + 
          3.4875082071331542`\ \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["When using ",
    FontWeight->"Bold"],
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", it is important to remember that ",
    FontWeight->"Bold"],
  StyleBox["no unknown constants",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" can appear in the equation",
    FontWeight->"Bold"],
  " : after all, we are performing a ",
  StyleBox["numerical ",
    FontSlant->"Italic"],
  "solution so ",
  StyleBox["only",
    FontSlant->"Italic"],
  " numbers can appear in the equation."
}], "Text"],

Cell[TextData[{
  "\tFor example, the equation ",
  Cell[BoxData[
      \(TraditionalForm\`a\ x\  + \ b = 0\)]],
  "  has a perfectly good analytic solution ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-b\)/a\)]],
  ",  but ",
  StyleBox["FindRoot ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "will not work unless specific numerical values for ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are given:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[a\ x\  + \ b\  \[Equal] 0, {x, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.179"],

Cell[BoxData[
    \(FindRoot::"frnum" \(\(:\)\(\ \)\) 
      "Function \!\({\(\(1.`\\ a\)\) + b}\) is not a length \!\(1\) list of \
numbers at \!\({x}\) = \!\({1.`}\)."\)], "Message"],

Cell[BoxData[
    \(FindRoot[a\ x + b == 0, {x, 1}]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can also  find a numerical solution to coupled equations in several \
variables. For example, the coupled equations "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x\ y) + y\ \[ExponentialE]\^x = 0\)]],
  "\n ",
  Cell[BoxData[
      \(TraditionalForm\`y\^2 - y + x = 0\)]]
}], "NE5",
  CellTags->"(9.11.1)"],

Cell["have the following solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[{Cos[x\ y] + \ y\ Exp[x]\  \[Equal] 0, 
        y^2\  - \ y\  + \ x\  \[Equal] 0}, {x, 1}, {y, \(-1\)}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.180"],

Cell[BoxData[
    \({x \[Rule] \(-1.614808027121647`\), 
      y \[Rule] \(-0.8655797403375717`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThis is only one of several solutions. To find these other solutions, we \
need guesses that are nearby to the exact solutions. Such guesses can be made \
only if we know something about the functions. The following graphical method \
is useful in this regard: Plot the zero of each equation separately in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane using  a ",
  StyleBox["ContourPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; then superimpose the zeros to find solutions to the coupled system."
}], "Text",
  CellTags->"i:87"],

Cell[TextData[{
  "\tThe solution to ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x\ y) + y\ \[ExponentialE]\^x = 0\)]],
  " is a set of curves ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  "- plane, which can be determined by asking for the zero contour of the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x\ y) + y\ \[ExponentialE]\^x\)]],
  ", as shown in Cell ",
  ButtonBox["9.181",
    ButtonData:>"Cell 9.181",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[
        Cos[x\ y]\  + \ y\ Exp[x], {x, \(-3\), 3}, {y, \(-3\), 3}, 
        Contours \[Rule] {0}, PlotPoints \[Rule] 40, 
        ContourShading \[Rule] \ False];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.181"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.160256 0.5 0.160256 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -6 -9 ]
[.33974 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -12 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -6 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-3)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-2)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-1)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(1)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(2)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(3)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-3)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-2)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-1)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(1)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(2)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(3)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.01923 .41741 m
.04168 .41371 L
.04389 .41333 L
.06854 .40881 L
.0932 .40382 L
.11785 .39834 L
.1425 .39233 L
.15503 .38905 L
.16716 .3857 L
.19181 .37835 L
.21647 .37024 L
.23289 .3644 L
.24112 .36132 L
.26578 .3515 L
.29043 .34083 L
.29281 .33974 L
.31509 .32939 L
.33974 .31753 L
.34451 .31509 L
.3644 .30596 L
.38905 .29613 L
.41371 .29062 L
.43836 .29303 L
.46302 .30597 L
.47512 .31509 L
.48767 .32752 L
.50023 .33974 L
.51233 .35198 L
.52543 .3644 L
.53698 .37483 L
.5545 .38905 L
.56164 .3944 L
.58629 .41065 L
.59152 .41371 L
.61095 .42408 L
.6356 .43522 L
.64345 .43836 L
.66026 .44454 L
.68491 .45239 L
.70957 .45906 L
.72634 .46302 L
.73422 .46474 L
.75888 .46962 L
.78353 .47381 L
.80819 .47743 L
.83284 .48055 L
.8575 .48325 L
.88215 .48557 L
.9068 .48759 L
.90796 .48767 L
Mistroke
.93146 .48932 L
.95611 .49082 L
.98077 .49211 L
Mfstroke
.01923 .58534 m
.02427 .58629 L
.04389 .59024 L
.06854 .59588 L
.0932 .60235 L
.11785 .60981 L
.1213 .61095 L
.1425 .61853 L
.16716 .62899 L
.18061 .6356 L
.19181 .64167 L
.21647 .65753 L
.22017 .66026 L
.24112 .67789 L
.24821 .68491 L
.26578 .7053 L
.26897 .70957 L
.28485 .73422 L
.29043 .74461 L
.29725 .75888 L
.30713 .78353 L
.31488 .80819 L
.31509 .80892 L
.32122 .83284 L
.32632 .8575 L
.33043 .88215 L
.3342 .9068 L
.33247 .93146 L
.33077 .95611 L
.31871 .98077 L
s
.01923 .74767 m
.0417 .75888 L
.04389 .76002 L
.06854 .77366 L
.08522 .78353 L
.0932 .7885 L
.11785 .80489 L
.12255 .80819 L
.1425 .82291 L
.15512 .83284 L
.16716 .84272 L
.18406 .8575 L
.19181 .86449 L
.21014 .88215 L
.21647 .88831 L
.23396 .9068 L
.24112 .91403 L
.25553 .93146 L
.26578 .94092 L
.2801 .95611 L
.29043 .96608 L
.31131 .98077 L
s
.01923 .92664 m
.02443 .93146 L
.04389 .95146 L
.04819 .95611 L
.06854 .97957 L
.06946 .98077 L
s
.01923 .244 m
.02427 .24112 L
.04389 .22918 L
.06268 .21647 L
.06854 .21231 L
.0932 .19291 L
.09449 .19181 L
.11785 .17051 L
.12123 .16716 L
.1425 .14417 L
.14393 .1425 L
.16347 .11785 L
.16716 .11272 L
.1804 .0932 L
.19181 .0741 L
.19498 .06854 L
.20814 .04389 L
.21647 .02514 L
.21916 .01923 L
s
.01923 .0873 m
.04182 .06854 L
.04389 .06665 L
.06854 .04404 L
.06869 .04389 L
.0932 .01929 L
.09323 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`006_ooool0
1OnHV9So410@o`000?lb<S;oc<c<03;ooooo1Ol0000booooo`Co000000?o410@ooooooooool0:ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03;ooooo1?l000000ol@413oooooooooo`0^ooooo`Go0000
<_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S80<_ooool01OnHV9So8B4Qonk^k_ooooooA4A403Cooooo00?o0000ooooooooool0;Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg03Cooooo00?o0000ooooooooool0<?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A403;ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`004_ooool6o`0000Kooooo00?o
0000ooooooooool0:?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0:_ooool6o`0000Gooooo00?o
0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@03Cooooo00?o0000ooooooooool0
<Oooool00onHV9So8B4Qonk^kP0gooooo`03o`000?oooooooooo00Cooooo000Mooooo`03ojVYZOl@
413ooooo03?ooooo00?oV9RHob4Q8Oo^k^h0=?ooool00ol0003oooooooooo`0]ooooo`05o`000?oo
ooooooooooooool00000=?ooool00ol0003oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^03Gooooo
00?oZJVYoa0@4?ooool01Oooool001cooooo00?o410@o`000?nj^[X0=Oooool00omgMgOoIVIVoooo
o`0cooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000dooooo`03o`00
0?oooooooooo03?ooooo00?oMgMgofIVI_ooool0<oooool00ol@413o0000okZj^P06ooooo`007Ooo
ool00onj^[[o8B4Qooooo`0eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;Ooo
ool01Ol@413ooooooooooooooooo410@03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0cooooo`03okZj^_lQ8B7ooooo00Gooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l00000
<_ooool01Ol0003o^[ZjoooooonHV9So410@03Cooooo00?o0000ooooooooool0;Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Cooooo00?o0000ooooooooool0<?ooool01Ol0003o^[ZjoooooonHV9So
410@03;ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`006_ooool01OnYZJWo410@o`000?l@
413oZJVY03;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00booooo`03oeEEEOmVIVKo000002oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0booooo`03oeEEEOmVIVKo000003;ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00booooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?oooooool0001Eo`00
007ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo0008ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooomAooooo`7o00000Ooo
ool000Ko00001_ooool00ol0003oooooooooo`04ooooo`?o00007?ooool2o`0002Wooooo00?o0000
ooooooooool0ooooool5ooooo`?o00000Oooool000_ooooo00?oZJVYoa0@4?ooool01Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0ooooool7oooo
o`7o00000Oooool000[ooooo00?o410@o`000?nj^[X01_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0ooooool8ooooo`7o00000Oooool000_ooooo
00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0ooooool8ooooo`7o00000Oooool000Sooooo00Go410@oiRHV?oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo0Ol00001ooooo`002?ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0?oooooo
2Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`3oooooo`[ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0ooooool:ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
0?oooooo2_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`3oooooo`_ooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0ooooool;ooooo`7o0000
0Oooool001?ooooo0_l0000Cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0oooo
ool;ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo0?oooooo3?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0ooooool=ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo0?oooooo3_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3oooooo`kooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0:ooooo`?o0000<_ooool00ol0003oooooooooo`3o
ooooo`oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0ooooool?ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?oooooo4?ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`3ooooooa3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0oooooolAooooo`7o00000Oooool001?ooooo0_l00006
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0ooooool@ooooo`;o00000Oooool0
01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
0?oooooo4_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`3ooooooa?ooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0?oooooo4oooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0oooooolDooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`3ooooooaCooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo0?oooooo5Oooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0oooooolFooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3ooooooaKooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0?oooooo5oooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0oooooolHooooo`7o00000Oooool0
01?ooooo0_l0000fooooo`03o`000?oooooooooo0?oooooo6?ooool2o`00007ooooo000Cooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0oooooolJooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`3ooooooa[ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?oooooo6oooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3ooooooagooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo7Oooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0oooooolNooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3ooooooaoooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0?oooooo8?ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0oooooolQoooo
o`7o00000Oooool001?ooooo0_l0000^ooooo`03o`000?oooooooooo0?oooooo8?ooool2o`00007o
oooo000Cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0oooooolRooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3oooooob?ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0?oooooo9?ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0oooooolUoooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3oooooobKo
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0?oooooo
9oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0oooo
oolXooooo`7o00000Oooool000Sooooo1Ol00006ooooo`03o`000?oooooooooo02Cooooo0_l0003o
ooooob_ooooo0Ol00001ooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`3oooooob_ooooo0Ol00001ooooo`001_l00003oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3ooooo
obcooooo0Ol00001ooooo`002_ooool00onHV9So8B4Qonk^kP06ooooo`?o00008Oooool00ol0003o
ooooooooo`3oooooob_ooooo0ol00001ooooo`002oooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0ooooool^ooooo`7o00000Oooool000cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo;ooo
ool1o`00007ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo0?oooooo<?ooool1o`00007ooooo0008ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Kooooo`?o0000oooooolcooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3oooooocCooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo=Oooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0oooooolfooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3oooooocOooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo>?oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0ooooooli
ooooo`7o00000Oooool001?ooooo0_l0000Dooooo`;o0000oooooolkooooo`;o00000Oooool001?o
oooo00?o0000ooooooooool04Oooool2o`000?oooooo?_ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0oooooolnooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3oooooocoooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo@?ooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0oooooom1ooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool02oooool2o`000?ooooooA?ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo00Wooooo0_l0003oooooodKooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0?ooooooA_ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00Kooooo0_l0003oooooodWooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`04oooo
o`;o0000oooooom;ooooo`7o00000Oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo0?oo
ooooB_ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOoo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oo
ooooDOooool1o`00007ooooo000Cooooo`;o0000oooooomAooooo`;o00000Oooool001?ooooo00?o
0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomA
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
Qoooool=o`000;cooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`23ooooo`Co00003Ooo
ool00ol0003oooooooooo`2iooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0P?ooool3
o`0001;ooooo0_l0002iooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0OOooool3o`00
01Oooooo0_l0002gooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0N_ooool3o`0001co
oooo00?o0000ooooooooool0]?ooool1o`00007ooooo000Cooooo`;o0000N?ooool3o`00023ooooo
0_l0002cooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0MOooool2o`0002Gooooo00?o
0000ooooooooool0/Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo07?ooooo0_l0000X
ooooo`03o`000?oooooooooo0;3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1aoooo
o`;o0000:oooool00ol0003oooooooooo`2_ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool0Koooool2o`0002kooooo00?o0000ooooooooool0[_ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo06gooooo0_l0000aooooo`03o`000?oooooooooo0:gooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`1[ooooo`;o0000=?ooool00ol0003oooooooooo`2/ooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool0JOooool2o`0003Oooooo0_l0002/ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0Ioooool2o`0003_ooooo00?o0000ooooooooool0ZOooool1o`00
007ooooo0009ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`1Tooooo`?o
0000?_ooool00ol0003oooooooooo`2Xooooo`7o00000Oooool000_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Qooooo`?o0000@_ooool00ol0003oooooooooo`2Wooooo`7o0000
0Oooool000Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000H?ooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo0:Cooooo0ol00001ooooo`002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05kooooo0_l00018ooooo`03o`000?oooooooooo0:Gooooo0Ol00001
ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo0ol0001;oooo
o`03o`000?oooooooooo0:Cooooo0Ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo05Sooooo0ol0001?ooooo`03o`000?oooooooooo0:?ooooo0Ol00001ooooo`00
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo0_l0001Cooooo`03o`00
0?oooooooooo0:;ooooo0Ol00001ooooo`002Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oo
oooooooo05Cooooo0_l0001Eooooo`03o`000?oooooooooo0:;ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`1Booooo`;o0000F?ooool00ol0003oooooooooo`2Qooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0D?ooool2o`0005_ooooo00?o0000ooooooooool0X?ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo04kooooo0_l0001Nooooo`03o`000?oooooooooo09oo
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1;ooooo`?o0000HOooool2o`0009oooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`18ooooo`?o0000I_ooool00ol0003ooooooooo
o`2Looooo`7o00000Oooool001?ooooo0_l00015ooooo`Co0000J_ooool00ol0003oooooooooo`2J
ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0@?ooool4o`0006oooooo0_l0002Koooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0?Oooool3o`0007Gooooo00?o0000oooooooo
ool0V?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo03[ooooo0ol0001iooooo`03o`00
0?oooooooooo09Oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0gooooo`?o0000OOoo
ool00ol0003oooooooooo`2Fooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0=?ooool3
o`00087ooooo00?o0000ooooooooool0UOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
02oooooo1Ol00025ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0[ooooo`Co0000Roooool00ol0003oooooooooo`2Cooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool09oooool4o`00093ooooo0_l0002Cooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool08oooool4o`0009Kooooo0_l0002Aooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool07_ooool5o`0009cooooo0_l0002?ooooo`7o00000Oooool001?ooooo0_l0000Koooo
o`Co0000Xoooool00ol0003oooooooooo`2;ooooo`;o00000Oooool001?ooooo00?o0000oooooooo
ool05_ooool4o`000:Sooooo0_l0002<ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
4?ooool6o`000:kooooo0_l0002:ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool02Ooo
ool7o`000;Kooooo0_l00028ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Oooool4
o`000;oooooo00?o0000ooooooooool0QOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
00?ooooo0_l00034ooooo`;o0000QOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool0P_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0<cooooo
0_l00022ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0c_ooool2o`00083ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`3@ooooo`?o0000OOooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo0=?ooooo0_l0001kooooo`7o00000Oooool001?ooooo0_l0003Fooooo`;o
0000N?ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo0=Oooooo0ol0001fooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0f_ooool3o`0007?ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`3Mooooo`;o0000LOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
0=oooooo0ol0001^ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0h_ooool3o`0006_o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3Uooooo`?o0000J?ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo0>Sooooo1Ol0001Sooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0kOooool5o`0005kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3boooo
o`Co0000F_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?Kooooo1Ol0001Eooooo`7o
00000Oooool001?ooooo0_l0003looooo`Ko0000C_ooool2o`00007ooooo000Cooooo`03o`000?oo
oooooooo0?oooooo0_ooool5o`0004[ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3o
ooooo`Oooooo1_l00014ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0ooooool=oooo
o`Wo0000>oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oooooo5_ooool8o`0003?o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooakooooo2?l0000[ooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0oooooolVooooo`Wo00008_ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo0?oooooo;oooool@o`0001;ooooo0Ol00001ooooo`002?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0ooooooloooooo`go00001Oooool1
o`00007ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooe7ooooo0Ol00001ooooo`002?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0oooooomAooooo`7o00000Oooool000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`?o0000oooooom?ooooo`?o00000Oooool000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo0008ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool0
00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?ooooooDOooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oooooo
DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDOooool1o`00007ooooo000Cooooo`;o0000oooooomAooooo`;o00000Oooool001?ooooo
00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooo
oomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAoooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo
0_l0003ooooooe7ooooo0_l00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`03
ooooo`Oo0000oooooom7ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool02_ooool5o`00
0?oooooo@_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00oooooo1?l0003oooooocko
oooo0Ol00001ooooo`004oooool2o`0001Cooooo0ol0003ooooooc[ooooo0_l00001ooooo`004ooo
ool00ol0003oooooooooo`0Fooooo`?o0000oooooolhooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool06Oooool3o`000?oooooo=Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01cooooo0ol0003ooooooc;ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Oooooo`Go
0000ooooool]ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool09?ooool4o`000?oooooo
:Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo02Sooooo0ol0003oooooobKooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0[ooooo`;o0000oooooolTooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0;Oooool2o`000?oooooo8_ooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo02oooooo0_l0003oooooob3ooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`0aooooo`?o0000oooooolMooooo`7o00000Oooool001?ooooo0_l0000eooooo`;o0000oooo
oolJooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0=_ooool2o`000?oooooo6Oooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo03Sooooo0_l0003ooooooaOooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0jooooo`;o0000oooooolEooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0??ooool2o`000?oooooo4oooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo03kooooo0_l0003ooooooa7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo0?oooooo3_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
047ooooo0_l0003oooooo`kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`13ooooo`;o
0000ooooool<ooooo`7o00000Oooool000Wooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0ooooool9ooooo`7o00000Oooool000_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`16ooooo`;o0000ooooool9ooooo`7o00000Ooo
ool000_ooooo00?o0000ooooooooool01Oooool3o`0004Sooooo0_l0003oooooo`Gooooo0ol00001
ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0ooooool4ooooo`7o00000Oooool000_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo0?oooooo0oooool1o`00007ooooo000;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`3oooooo`;ooooo
0Ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool0ooooool1ooooo`7o00000Oooool000Wooooo00?oEEEEofIVI_l000001oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0?oooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo0?kooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo0?kooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo0?gooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo0?cooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo0?_ooooo0Ol00001ooooo`004oooool2o`0005Cooooo00?o0000oooo
ooooool0nOooool2o`00007ooooo000Cooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool0nOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
n?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0mooo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0m_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0m_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0mOooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0mOooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0m?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0loooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0loooool1o`00007ooooo000Cooooo`;o
0000G?ooool00ol0003oooooooooo`3aooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`3booooo`7o00000Oooool001?ooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`3aooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`3`ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`3`ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`3_ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`3_ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`3^ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool00oooool2o`0005[ooooo00?o0000
ooooooooool0k_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo0_l0001Ioooo
o`03o`000?oooooooooo0>gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`07ooooo`;o
0000F?ooool00ol0003oooooooooo`3/ooooo`7o00000Oooool001?ooooo0_l0000:ooooo`;o0000
E_ooool00ol0003oooooooooo`3[ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool02ooo
ool3o`0005Cooooo00?o0000ooooooooool0joooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`3[ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool03oooool2o`0005;ooooo00?o0000ooooooooool0j_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo017ooooo0_l0001@ooooo`03o`000?oooooooooo0>[o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0j_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01Cooooo0_l0
001>ooooo`03o`000?oooooooooo0>Wooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0F
ooooo`;o0000C?ooool00ol0003oooooooooo`3Yooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool06?ooool2o`0004[ooooo00?o0000ooooooooool0jOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`3Xooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo0>Sooooo0Ol00001ooooo`004oooool2o`0001gooooo0_l00018ooooo`03o`000?oo
oooooooo0>Kooooo0_l00001ooooo`004oooool00ol0003oooooooooo`0Nooooo`;o0000A_ooool0
0ol0003oooooooooo`3Wooooo`7o00000Oooool001?ooooo00?o0000ooooooooool08?ooool2o`00
04Cooooo00?o0000ooooooooool0ioooool1o`00007ooooo000Cooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`3Vooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool08oooool2o`0004;ooooo00?o0000ooooooooool0i_ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`3Vooooo`7o00000Oooool001?ooooo00?o0000ooooooooool09_ooool2o`00043ooooo00?o0000
ooooooooool0iOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`3Uooooo`7o00000Oooool000Sooooo1Ol00006ooooo`03
o`000?oooooooooo02Wooooo0_l0000mooooo`03o`000?oooooooooo0>Gooooo0Ol00001ooooo`00
2?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo0>Gooooo0Ol00001ooooo`002Oooool00onHV9So8B4Q
onk^kP07ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`3Tooooo`7o00000Oooool000[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`3Rooooo`?o00000Oooool000_ooooo00?oMgMg
ofIVI_ooool01Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0i?ooool1o`00007ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0>Cooooo0Ol00001oooo
o`002?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo0>?ooooo0Ol00001ooooo`002?ooool01OnHV9So
410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0<Oooool2o`0003Oooooo00?o0000oooo
ooooool0hoooool1o`00007ooooo000Cooooo`03o`000?oooooooooo03?ooooo0_l0000eooooo`03
o`000?oooooooooo0>?ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0hoooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`3Rooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo0>;ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0h_ooool1o`00007ooooo000Cooooo`;o0000>_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo0>7ooooo0_l00001ooooo`004oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0hOooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`3Qooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo0>7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0hOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3Qooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo0>7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0h?ooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3Pooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
0>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0h?ooool1o`00007ooooo000Cooooo`;o0000AOooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo0=oooooo0_l00001ooooo`004oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0h?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`3P
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo0>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0h?ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3Oooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo0=oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
04cooooo0_l0000Pooooo`03o`000?oooooooooo0=oooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0goooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`3Oooooo`7o00000Oooool001?ooooo0_l0001@ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0g_ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0=oooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00?ooooo0_l0001>ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0goooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo0=oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3Oooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0=oo
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0h?ooool1o`00007ooooo000Cooooo`;o00003?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0goooool2o`00007ooooo000Coooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3Pooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0h?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo0>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Qooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`;o00002oooool00ol0
003oooooooooo`3Qooooo`7o00000Oooool001?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0h_ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_ooool2o`0000Oooooo
00?o0000ooooooooool0h_ooool1o`00007ooooo0008ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
1_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3Sooooo`7o00000Oooool000Sooooo00Go410@okZj^_ooooooMgMg
oc8b<P06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0>?ooooo0Ol00001ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`?o00005?ooool00ol0003oooooooooo`1?ooooo`04o`000?ooooooooooo`000>Cooooo
0ol00001ooooo`002oooool00onYZJWo410@ooooo`05ooooo`03o`000?oooooooooo0?ooooooDOoo
ool1o`00007ooooo000:ooooo`03oa0@4?l0003o^[Zj00Kooooo00?o0000ooooooooool0oooooomA
ooooo`7o00000Oooool000_ooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`3ooooo
oe7ooooo0Ol00001ooooo`002?ooool01Ol@413oV9RHoooooonj^[[o000000Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool000Sooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool1o`00007o
oooo000Coooooooo0000EOl00001ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-3.47366, -3.44065, 0.0229686, \
0.0229686}}]
}, Open  ]],

Cell["\<\
We have turned off contour shading so that only the zero contour  \
is shown.\
\>", "Text"],

Cell[TextData[{
  "\t  We then plot the zero contour of the  function in the second equation, \
 ",
  Cell[BoxData[
      \(TraditionalForm\`x\  + \ y\^2\  - \ y\)]],
  "  (see Cell ",
  ButtonBox["9.182",
    ButtonData:>"Cell 9.182",
    ButtonStyle->"Hyperlink"],
  "; this time we plot the contour as a thick red line to distinguish it from \
the first set of curves):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[x + y^2\  - \ y, {x, \(-3\), 3}, {y, \(-3\), 3}, 
        Contours \[Rule] {0}, PlotPoints \[Rule] 40, 
        ContourShading \[Rule] \ False, 
        ContourStyle \[Rule] \ {RGBColor[1, 0, 0], 
            Thickness[0.012]}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.182"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.160256 0.5 0.160256 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -6 -9 ]
[.33974 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -3 -9 ]
[.66026 -0.0125 3 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -12 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -6 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-3)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-2)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-1)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(1)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(2)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(3)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-3)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-2)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-1)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(1)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(2)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(3)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.012 w
.01923 .86904 m
.04389 .86212 L
.06001 .8575 L
.06854 .85502 L
.0932 .84774 L
.11785 .84025 L
.14156 .83284 L
.1425 .83254 L
.16716 .8246 L
.19181 .81638 L
.21552 .80819 L
.21647 .80785 L
.24112 .79902 L
.26578 .78979 L
.2819 .78353 L
.29043 .78015 L
.31509 .77003 L
.33974 .7593 L
.34069 .75888 L
.3644 .74794 L
.38905 .7357 L
.3919 .73422 L
.41371 .72248 L
.43552 .70957 L
.43836 .70781 L
.46302 .69131 L
.47155 .68491 L
.48767 .67194 L
.5 .66026 L
.51233 .64728 L
.52086 .6356 L
.53414 .61095 L
.53698 .60235 L
.53983 .58629 L
.53793 .56164 L
.53698 .5579 L
.52845 .53698 L
.51233 .51328 L
.51138 .51233 L
.48767 .48846 L
.48672 .48767 L
.46302 .46892 L
.45448 .46302 L
.43836 .4524 L
.41466 .43836 L
.41371 .43783 L
.38905 .42453 L
.36724 .41371 L
.3644 .41234 L
.33974 .40093 L
Mistroke
.31509 .39025 L
.31224 .38905 L
.29043 .3801 L
.26578 .37046 L
.24966 .3644 L
.24112 .36125 L
.21647 .35239 L
.19181 .34388 L
.17949 .33974 L
.16716 .33566 L
.1425 .32771 L
.11785 .32 L
.10173 .31509 L
.0932 .31252 L
.06854 .30523 L
.04389 .29814 L
.01923 .29122 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`006_ooool0
1OnHV9So410@o`000?lb<S;oc<c<03;ooooo1Ol0000booooo`Co000000?o410@ooooooooool0:ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03;ooooo1?l000000ol@413oooooooooo`0^ooooo`Go0000
<_ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo000Jooooo`05oa0@4?nj^[[oooooogMgMolb
<S80<_ooool01OnHV9So8B4Qonk^k_ooooooA4A403Cooooo00?o0000ooooooooool0;Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg03Cooooo00?o0000ooooooooool0<?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A403;ooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`004_ooool6o`0000Kooooo00?o
0000ooooooooool0:?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0:_ooool6o`0000Gooooo00?o
0000ooooooooool0;Oooool01Ol@413ooooooooooooooooo410@03Cooooo00?o0000ooooooooool0
<Oooool00onHV9So8B4Qonk^kP0gooooo`03o`000?oooooooooo00Cooooo000Mooooo`03ojVYZOl@
413ooooo03?ooooo00?oV9RHob4Q8Oo^k^h0=?ooool00ol0003oooooooooo`0]ooooo`05o`000?oo
ooooooooooooool00000=?ooool00ol0003oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^03Gooooo
00?oZJVYoa0@4?ooool01Oooool001cooooo00?o410@o`000?nj^[X0=Oooool00omgMgOoIVIVoooo
o`0cooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000dooooo`03o`00
0?oooooooooo03?ooooo00?oMgMgofIVI_ooool0<oooool00ol@413o0000okZj^P06ooooo`007Ooo
ool00onj^[[o8B4Qooooo`0eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;Ooo
ool01Ol@413ooooooooooooooooo410@03Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0cooooo`03okZj^_lQ8B7ooooo00Gooooo000Jooooo`05oa0@4?nHV9SooooookZj^_l00000
<_ooool01Ol0003o^[ZjoooooonHV9So410@03Cooooo00?o0000ooooooooool0;Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Cooooo00?o0000ooooooooool0<?ooool01Ol0003o^[ZjoooooonHV9So
410@03;ooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`006_ooool01OnYZJWo410@o`000?l@
413oZJVY03;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00booooo`03oeEEEOmVIVKo000002oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0booooo`03oeEEEOmVIVKo000003;ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00booooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?oooooool0001Eo`00
007ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo0008ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002?ooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0oooooomAooooo`7o00000Ooo
ool000Ko00001_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom?ooooo`?o00000Oooool0
00_ooooo00?oZJVYoa0@4?ooool01Oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001oooo
o`002_ooool00ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007o
oooo000;ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000ooooooooool0oooooomAooooo`7o0000
0Oooool000Sooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo
DOooool1o`00007ooooo0008ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooo
ooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004ooo
ool2o`000?ooooooDOooool2o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oooooo
DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`;o0000oooooomAooooo`;o00000Oooool0
01?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAoooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooo
oomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool0
01?ooooo0_l0003ooooooe7ooooo0_l00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3o
oooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool2o`000?ooooooDOooool2o`00007o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oooooo
DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo0008
ooooo`Go00001_ooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool0
00Ko00000oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00
007ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodoooooo0ol00001ooooo`00
2oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo
000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooomAooooo`7o00000Ooo
ool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0?ooooooDOoo
ool1o`00007ooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool2o`000?ooooooDOooool2o`00
007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOoo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oo
ooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00
007ooooo000Cooooo`;o0000oooooomAooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0
oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomA
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo0_l0003ooooooe7ooooo
0_l00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooo
oe7ooooo0Ol00001ooooo`004oooool01?l0003oooooooooooooool6ool00?ooooooB_ooool1o`00
007ooooo000Cooooo`04o`000?ooooooooooooooo`_oo`00oooooom5ooooo`7o00000Oooool001?o
oooo00Co0000oooooooooooooooo3_oo003ooooood;ooooo0Ol00001ooooo`004oooool01?l0003o
oooooooooooooolAool00?oooooo?oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Co
oooo4Ooo003ooooooccooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`09ooooo`ooo`00
ooooooliooooo`7o00000Oooool001?ooooo0_l0000=oooooa3oo`00ooooooldooooo`;o00000Ooo
ool001?ooooo00?o0000ooooooooool03ooooolAool00?oooooo<Oooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo01;ooooo4Ooo003oooooobkooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0Eoooooa7oo`00ooooool[ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
6Oooool@ool00?oooooo:?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01gooooo4?oo
003oooooobCooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Poooooa7oo`00oooooolP
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool08ooooolAool00?oooooo7Oooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo02Kooooo4Ooo003ooooooa[ooooo0Ol00001ooooo`00
2Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool@ool00?oooooo
5oooool1o`00007ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_oo
ool?ool00?oooooo5?ooool1o`00007ooooo0006o`0000Gooooo00?o0000ooooooooool01Oooool3
o`00037ooooo3_oo003ooooooa3ooooo0ol00001ooooo`002oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Cooooo3Ooo003ooooooa3ooooo0Ol00001ooooo`002oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03Oooooo3Ooo003oooooo`gooooo0Ol00001ooooo`00
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03[ooooo3Ooo003oooooo`[ooooo
0Ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo3_oo
003oooooo`Oooooo0Ol00001ooooo`002Oooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo03kooooo3ooo003oooooo`Cooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`11oooo
o`ooo`00ooooool1ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0A?ooool?ool00?go
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`17ooooo`koo`00noooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo04[ooooo3_oo003hooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0COooool=ool00?Kooooo0Ol00001ooooo`004oooool2o`00057ooooo3Ooo003boooo
o`;o00000Oooool001?ooooo00?o0000ooooooooool0D_ooool>ool00?3ooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`1Eooooo`goo`00k_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo05Oooooo3_oo003[ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0F_ooool>
ool00>Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1Mooooo`koo`00iOooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo05oooooo3_oo003Sooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0H_ooool=ool00>7ooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`1Uooooo`coo`00goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo06Sooooo2ooo003M
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0J_ooool;ool00=_ooooo0Ol00001oooo
o`004oooool2o`0006gooooo2ooo003Hooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0
K_ooool;ool00=Oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1`ooooo`coo`00e?oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo07;ooooo3?oo003Booooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0M?ooool<ool00=3ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`1fooooo`coo`00c_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo07Wooooo
2ooo003<ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Noooool:ool00<_ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`1mooooo`[oo`00bOooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo07oooooo2_oo0037ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool0POooool9ool00<Kooooo0Ol00001ooooo`004oooool2o`0008?ooooo2ooo0032ooooo`;o0000
0Oooool001?ooooo00?o0000ooooooooool0Q?ooool:ool00<;ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`26ooooo`[oo`00`?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
08Oooooo2ooo002nooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0R_ooool9ool00;go
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2;ooooo`[oo`00^oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo08gooooo2_oo002iooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0Soooool9ool00;Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2@oooo
o`[oo`00]_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09;ooooo2Ooo002eooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool0U?ooool9ool00;?ooooo0Ol00001ooooo`004ooo
ool2o`0009Kooooo2Ooo002aooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0Uoooool8
ool00;7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2Hooooo`Soo`00/?ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo09[ooooo1ooo002_ooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0Voooool7ool00:kooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`2Looooo`Ooo`00[Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09gooooo1ooo002/
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0W_ooool7ool00:_ooooo0Ol00001oooo
o`002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0Woooool7ool0
0:[ooooo0Ol00001ooooo`002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool0X?ooool7ool00:Wooooo0Ol00001ooooo`002?ooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0XOooool7ool00:Sooooo0Ol00001ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol0002Rooooo`Ooo`00YOooool3o`00007ooooo0008ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2Sooooo`Ooo`00Y_ooool1o`00
007ooooo0008ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2Toooo
o`Ooo`00YOooool1o`00007ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`2Uooooo`Soo`00Xoooool1o`00007ooooo0008ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`2Vooooo`Ooo`00Xoooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo0:Oooooo1ooo002Rooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
Z?ooool7ool00:7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2Yooooo`Koo`00XOoo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:[ooooo1_oo002Pooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0Zoooool5ool00:3ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`2[ooooo`Koo`00Woooool1o`00007ooooo000Cooooo`;o0000[Oooool6ool009gooooo
0_l00001ooooo`004oooool00ol0003oooooooooo`2/ooooo`Koo`00W_ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo0:gooooo1_oo002Mooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0[_ooool5ool009gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2^ooooo`Ko
o`00W?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:oooooo1Ooo002Looooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0[oooool5ool009cooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`2`ooooo`Goo`00Voooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
0;3ooooo1Ooo002Kooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0/?ooool5ool009_o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2aooooo`Coo`00Voooool1o`00007ooooo
000Cooooo`;o0000/_ooool4ool009[ooooo0_l00001ooooo`004oooool00ol0003oooooooooo`2a
ooooo`Coo`00Voooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0;7ooooo1?oo002Koooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0/Oooool5ool009[ooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`2aooooo`Goo`00V_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo0;7ooooo1Ooo002Jooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0/_ooool4
ool009[ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2booooo`Coo`00V_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo0;;ooooo1?oo002Jooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0/_ooool4ool009[ooooo0Ol00001ooooo`004oooool2o`000;;ooooo1Ooo
002Iooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0/Oooool5ool009[ooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`2aooooo`Goo`00V_ooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo0;7ooooo1?oo002Kooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
/?ooool5ool009_ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2`ooooo`Goo`00Vooo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:oooooo1_oo002Kooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0[oooool5ool009cooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`2^ooooo`Koo`00W?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:kooooo
1Ooo002Mooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0[_ooool5ool009gooooo0Ol0
0001ooooo`004oooool2o`000:kooooo1Ooo002Mooooo`;o00000Oooool001?ooooo00?o0000oooo
ooooool0[Oooool5ool009kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2/ooooo`Ko
o`00W_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:cooooo1Ooo002Oooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0Zoooool6ool009oooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`2Zooooo`Koo`00X?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
0:Wooooo1ooo002Pooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Z?ooool7ool00:7o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2Wooooo`Ooo`00X_ooool1o`00007ooooo
0009ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`2Vooooo`Ooo`00Xooo
ool1o`00007ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Y?ooool8
ool00:Cooooo0Ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`?o0000Xoooool8ool0
0:?ooooo0ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;o
oooo2?oo002Vooooo`7o00000Oooool000_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Qooooo`Soo`00Yoooool1o`00007ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0X?ooool7ool00:Wooooo0Ol00001ooooo`002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09oooooo1ooo002Zooooo`7o00000Oooool000Wooooo00?oEEEEofIV
I_l000001oooool00ol0003oooooooooo`2Nooooo`Ooo`00Zoooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo09gooooo1ooo002/ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
W?ooool7ool00:gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2Jooooo`Soo`00[_oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo09Wooooo2?oo002_ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0Uoooool9ool00;3ooooo0Ol00001ooooo`004oooool2o`0009Oo
oooo2Ooo002`ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0U?ooool9ool00;?ooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`2Booooo`[oo`00]?ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo097ooooo2Ooo002fooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0T?ooool9ool00;Oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2>ooooo`Wo
o`00^Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo08cooooo2Ooo002kooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0R_ooool:ool00;cooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`28ooooo`_oo`00_Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
08Kooooo2ooo002oooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Q?ooool;ool00<7o
oooo0Ol00001ooooo`004oooool2o`0008Cooooo2_oo0032ooooo`;o00000Oooool001?ooooo00?o
0000ooooooooool0POooool:ool00<Gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`20
ooooo`Woo`00aoooool1o`00007ooooo000Cooooo`03o`000?oooooooooo07kooooo2Ooo0039oooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0O?ooool:ool00<[ooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`1iooooo`_oo`00c?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo07Oooooo3?oo003=ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0MOooool<
ool00<oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1cooooo`coo`00dOooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo077ooooo2ooo003Dooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0Koooool;ool00=Kooooo0Ol00001ooooo`004oooool2o`0006kooooo2ooo
003Gooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0J_ooool<ool00=[ooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`1Wooooo`goo`00g?ooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo06Gooooo3Ooo003Nooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
Hoooool=ool00>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1Pooooo`goo`00hooo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo05kooooo3?oo003Vooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0G?ooool<ool00>Sooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`1Iooooo`goo`00j_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo05Kooooo
3Ooo003]ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0E?ooool=ool00>oooooo0Ol0
0001ooooo`004oooool2o`0005;ooooo3_oo003`ooooo`;o00000Oooool001?ooooo00?o0000oooo
ooooool0C_ooool>ool00?Cooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1<ooooo`go
o`00moooool1o`00007ooooo000Cooooo`03o`000?oooooooooo04Wooooo3_oo003iooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0A_ooool>ool00?cooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`13ooooo`koo`00ooooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
043ooooo3ooo003oooooo`;ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0mooooo`oo
o`00ooooool5ooooo`7o00000Oooool000Sooooo1Ol00006ooooo`03o`000?oooooooooo03_ooooo
3_oo003oooooo`Sooooo0Ol00001ooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0>?ooool>ool00?oooooo2oooool1o`00007ooooo0009ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?o0000ooooooooool0=Oooool>ool00?oooooo3_ooool1o`00007ooooo000:
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000cooooo`goo`00ooooool?ooooo`?o00000Oooool0
00_ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0`ooooo`koo`00oooooolCoooo
o`7o00000Oooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`ko
o`00oooooolFooooo`7o00000Oooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo02Wooooo3ooo003ooooooaWooooo0Ol00001ooooo`002?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool09OoooolAool00?oooooo6oooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo02;ooooo4Ooo003ooooooakooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`0Ooooooa7oo`00oooooolQooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool07?ooool@ool00?oooooo9Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01Sooooo4?oo003oooooobWooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Doooooa7o
o`00ooooool/ooooo`7o00000Oooool001?ooooo0_l0000Boooooa7oo`00ooooool^ooooo`;o0000
0Oooool001?ooooo00?o0000ooooooooool03_oooolAool00?oooooo<_ooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo00_ooooo4?oo003oooooocKooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`08ooooo`ooo`00ooooooljooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool00ooooolAool00?oooooo?Oooool1o`00007ooooo000Cooooo`04o`000?oooooooooooooooa3o
o`00oooooom0ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooooooo3Ooo003ooooood?o
oooo0Ol00001ooooo`004oooool01?l0003oooooooooooooool:ool00?ooooooA_ooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooooooo`Goo`00oooooom;ooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooo
oomAooooo`7o00000Oooool001?ooooo0_l0003ooooooe7ooooo0_l00001ooooo`004oooool00ol0
003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3o
oooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool2o`00
0?ooooooDOooool2o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?oooooo
DOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDOooool1o`00007ooooo000Cooooo`;o0000oooooomAooooo`;o00000Oooool001?ooooo
00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooo
oomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0oooooomAooooo`7o00000Oooool000Sooooo00GoV9RHoa0@4?l0003o<S8bolc<c006
ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo0008ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S801_ooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`003?ooool00ol0
003oooooooooo`04ooooo`?o0000oooooom?ooooo`?o00000Oooool000_ooooo00?oZJVYoa0@4?oo
ool01Oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002_ooool00ol@413o0000
okZj^P06ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000;ooooo`03okZj^_lQ
8B7ooooo00Gooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool000Sooooo00Go410@
oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0008ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`004oooooooo`0005Go00000Oooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-3.47366, -3.44065, 0.0229686, \
0.0229686}}]
}, Open  ]],

Cell[TextData[{
  "Finally, by superimposing the two plots, we can find simultaneous \
solutions to both equations, as shown in Cell ",
  ButtonBox["9.183",
    ButtonData:>"Cell 9.183",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[%, %%];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.183"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.5 0.15873 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -3 -9 ]
[.81746 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -12 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .18254 -12 -4.5 ]
[-0.0125 .18254 0 4.5 ]
[-0.0125 .34127 -12 -4.5 ]
[-0.0125 .34127 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .65873 -6 -4.5 ]
[-0.0125 .65873 0 4.5 ]
[-0.0125 .81746 -6 -4.5 ]
[-0.0125 .81746 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-3)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-2)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(-1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(1)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(-3)] -0.0125 .02381 1 0 Mshowa
0 .18254 m
.00625 .18254 L
s
[(-2)] -0.0125 .18254 1 0 Mshowa
0 .34127 m
.00625 .34127 L
s
[(-1)] -0.0125 .34127 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .65873 m
.00625 .65873 L
s
[(1)] -0.0125 .65873 1 0 Mshowa
0 .81746 m
.00625 .81746 L
s
[(2)] -0.0125 .81746 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(3)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .05556 m
.00375 .05556 L
s
0 .0873 m
.00375 .0873 L
s
0 .11905 m
.00375 .11905 L
s
0 .15079 m
.00375 .15079 L
s
0 .21429 m
.00375 .21429 L
s
0 .24603 m
.00375 .24603 L
s
0 .27778 m
.00375 .27778 L
s
0 .30952 m
.00375 .30952 L
s
0 .37302 m
.00375 .37302 L
s
0 .40476 m
.00375 .40476 L
s
0 .43651 m
.00375 .43651 L
s
0 .46825 m
.00375 .46825 L
s
0 .53175 m
.00375 .53175 L
s
0 .56349 m
.00375 .56349 L
s
0 .59524 m
.00375 .59524 L
s
0 .62698 m
.00375 .62698 L
s
0 .69048 m
.00375 .69048 L
s
0 .72222 m
.00375 .72222 L
s
0 .75397 m
.00375 .75397 L
s
0 .78571 m
.00375 .78571 L
s
0 .84921 m
.00375 .84921 L
s
0 .88095 m
.00375 .88095 L
s
0 .9127 m
.00375 .9127 L
s
0 .94444 m
.00375 .94444 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.18254 .99375 m
.18254 1 L
s
.34127 .99375 m
.34127 1 L
s
.5 .99375 m
.5 1 L
s
.65873 .99375 m
.65873 1 L
s
.81746 .99375 m
.81746 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.05556 .99625 m
.05556 1 L
s
.0873 .99625 m
.0873 1 L
s
.11905 .99625 m
.11905 1 L
s
.15079 .99625 m
.15079 1 L
s
.21429 .99625 m
.21429 1 L
s
.24603 .99625 m
.24603 1 L
s
.27778 .99625 m
.27778 1 L
s
.30952 .99625 m
.30952 1 L
s
.37302 .99625 m
.37302 1 L
s
.40476 .99625 m
.40476 1 L
s
.43651 .99625 m
.43651 1 L
s
.46825 .99625 m
.46825 1 L
s
.53175 .99625 m
.53175 1 L
s
.56349 .99625 m
.56349 1 L
s
.59524 .99625 m
.59524 1 L
s
.62698 .99625 m
.62698 1 L
s
.69048 .99625 m
.69048 1 L
s
.72222 .99625 m
.72222 1 L
s
.75397 .99625 m
.75397 1 L
s
.78571 .99625 m
.78571 1 L
s
.84921 .99625 m
.84921 1 L
s
.88095 .99625 m
.88095 1 L
s
.9127 .99625 m
.9127 1 L
s
.94444 .99625 m
.94444 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .18254 m
1 .18254 L
s
.99375 .34127 m
1 .34127 L
s
.99375 .5 m
1 .5 L
s
.99375 .65873 m
1 .65873 L
s
.99375 .81746 m
1 .81746 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .05556 m
1 .05556 L
s
.99625 .0873 m
1 .0873 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .24603 m
1 .24603 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .37302 m
1 .37302 L
s
.99625 .40476 m
1 .40476 L
s
.99625 .43651 m
1 .43651 L
s
.99625 .46825 m
1 .46825 L
s
.99625 .53175 m
1 .53175 L
s
.99625 .56349 m
1 .56349 L
s
.99625 .59524 m
1 .59524 L
s
.99625 .62698 m
1 .62698 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .72222 m
1 .72222 L
s
.99625 .75397 m
1 .75397 L
s
.99625 .78571 m
1 .78571 L
s
.99625 .84921 m
1 .84921 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .9127 m
1 .9127 L
s
.99625 .94444 m
1 .94444 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.012 w
.02381 .86553 m
.04823 .85867 L
.0642 .85409 L
.07265 .85164 L
.09707 .84443 L
.12149 .83701 L
.14497 .82967 L
.14591 .82937 L
.17033 .8215 L
.19475 .81336 L
.21823 .80525 L
.21917 .80492 L
.24359 .79617 L
.26801 .78703 L
.28398 .78083 L
.29243 .77748 L
.31685 .76745 L
.34127 .75683 L
.34221 .75641 L
.36569 .74558 L
.39011 .73345 L
.39293 .73199 L
.41453 .72036 L
.43613 .70757 L
.43895 .70584 L
.46337 .68949 L
.47182 .68315 L
.48779 .6703 L
.5 .65873 L
.51221 .64588 L
.52066 .63431 L
.53381 .60989 L
.53663 .60138 L
.53945 .58547 L
.53757 .56105 L
.53663 .55735 L
.52818 .53663 L
.51221 .51316 L
.51127 .51221 L
.48779 .48857 L
.48685 .48779 L
.46337 .46922 L
.45492 .46337 L
.43895 .45286 L
.41547 .43895 L
.41453 .43842 L
.39011 .42525 L
.36851 .41453 L
.36569 .41317 L
.34127 .40188 L
Mistroke
.31685 .39129 L
.31403 .39011 L
.29243 .38124 L
.26801 .37169 L
.25204 .36569 L
.24359 .36257 L
.21917 .3538 L
.19475 .34537 L
.18254 .34127 L
.17033 .33723 L
.14591 .32935 L
.12149 .32172 L
.10552 .31685 L
.09707 .3143 L
.07265 .30709 L
.04823 .30006 L
.02381 .29321 L
Mfstroke
0 g
.5 Mabswid
.02381 .4182 m
.04605 .41453 L
.04823 .41415 L
.07265 .40968 L
.09707 .40474 L
.12149 .39931 L
.14591 .39335 L
.15831 .39011 L
.17033 .38679 L
.19475 .37951 L
.21917 .37148 L
.23543 .36569 L
.24359 .36264 L
.26801 .35291 L
.29243 .34234 L
.29479 .34127 L
.31685 .33101 L
.34127 .31927 L
.34599 .31685 L
.36569 .30781 L
.39011 .29807 L
.41453 .29261 L
.43895 .295 L
.46337 .30782 L
.47535 .31685 L
.48779 .32917 L
.50022 .34127 L
.51221 .35339 L
.52519 .36569 L
.53663 .37602 L
.55398 .39011 L
.56105 .3954 L
.58547 .4115 L
.59065 .41453 L
.60989 .4248 L
.63431 .43584 L
.64208 .43895 L
.65873 .44507 L
.68315 .45284 L
.70757 .45945 L
.72418 .46337 L
.73199 .46508 L
.75641 .46991 L
.78083 .47406 L
.80525 .47764 L
.82967 .48074 L
.85409 .48341 L
.87851 .48571 L
.90293 .4877 L
.90407 .48779 L
Mistroke
.92735 .48942 L
.95177 .49091 L
.97619 .49219 L
Mfstroke
.02381 .58453 m
.0288 .58547 L
.04823 .58938 L
.07265 .59497 L
.09707 .60138 L
.12149 .60877 L
.1249 .60989 L
.14591 .6174 L
.17033 .62776 L
.18366 .63431 L
.19475 .64032 L
.21917 .65603 L
.22284 .65873 L
.24359 .6762 L
.25061 .68315 L
.26801 .70334 L
.27117 .70757 L
.2869 .73199 L
.29243 .74228 L
.29918 .75641 L
.30897 .78083 L
.31664 .80525 L
.31685 .80598 L
.32292 .82967 L
.32797 .85409 L
.33204 .87851 L
.33577 .90293 L
.33406 .92735 L
.33238 .95177 L
.32044 .97619 L
s
.02381 .74531 m
.04607 .75641 L
.04823 .75754 L
.07265 .77106 L
.08917 .78083 L
.09707 .78575 L
.12149 .80199 L
.12614 .80525 L
.14591 .81984 L
.15841 .82967 L
.17033 .83946 L
.18707 .85409 L
.19475 .86102 L
.2129 .87851 L
.21917 .88461 L
.23649 .90293 L
.24359 .91009 L
.25786 .92735 L
.26801 .93672 L
.2822 .95177 L
.29243 .96164 L
.31311 .97619 L
s
.02381 .92258 m
.02896 .92735 L
.04823 .94716 L
.05249 .95177 L
.07265 .975 L
.07356 .97619 L
s
.02381 .24644 m
.0288 .24359 L
.04823 .23176 L
.06685 .21917 L
.07265 .21505 L
.09707 .19583 L
.09835 .19475 L
.12149 .17365 L
.12483 .17033 L
.14591 .14756 L
.14732 .14591 L
.16668 .12149 L
.17033 .11641 L
.18344 .09707 L
.19475 .07816 L
.19788 .07265 L
.21092 .04823 L
.21917 .02966 L
.22183 .02381 L
s
.02381 .09123 m
.04618 .07265 L
.04823 .07078 L
.07265 .04838 L
.0728 .04823 L
.09707 .02387 L
.0971 .02381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{7, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`007?ooool0
1OnHV9So410@o`000?lb<S;oc<c<037ooooo1Ol0000booooo`Co000000?o410@ooooooooool0:_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^037ooooo1?l000000ol@413oooooooooo`0^ooooo`Go0000
<Oooool01OnHV9So410@o`000?lb<S;oc<c<00Sooooo000Looooo`05oa0@4?nj^[[oooooogMgMolb
<S80<Oooool01OnHV9So8B4Qonk^k_ooooooA4A403Cooooo00?o0000ooooooooool0;?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg03?ooooo00?o0000ooooooooool0<?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A4037ooooo00Go410@okZj^_ooooooMgMgoc8b<P08ooooo`005?ooool6o`0000Kooooo00?o
0000ooooooooool09oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0:_ooool6o`0000Gooooo00?o
0000ooooooooool0;?ooool01Ol@413ooooooooooooooooo410@03?ooooo00?o0000ooooooooool0
<Oooool00onHV9So8B4Qonk^kP0fooooo`03o`000?oooooooooo00Kooooo000Oooooo`03ojVYZOl@
413ooooo03;ooooo00?oV9RHob4Q8Oo^k^h0=?ooool00ol0003oooooooooo`0/ooooo`05o`000?oo
ooooooooooooool00000<oooool00ol0003oooooooooo`0booooo`03oiRHV?lQ8B7ok^k^03Cooooo
00?oZJVYoa0@4?ooool01oooool001kooooo00?o410@o`000?nj^[X0=?ooool00omgMgOoIVIVoooo
o`0cooooo`03o`000?oooooooooo02cooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo03?ooooo00?oMgMgofIVI_ooool0<_ooool00ol@413o0000okZj^P08ooooo`007ooo
ool00onj^[[o8B4Qooooo`0dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;?oo
ool01Ol@413ooooooooooooooooo410@03?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0booooo`03okZj^_lQ8B7ooooo00Oooooo000Looooo`05oa0@4?nHV9SooooookZj^_l00000
<Oooool01Ol0003o^[ZjoooooonHV9So410@03Cooooo00?o0000ooooooooool0;?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg03?ooooo00?o0000ooooooooool0<?ooool01Ol0003o^[ZjoooooonHV9So
410@037ooooo00Go410@oiRHV?oooooo^[Zjo`000008ooooo`007?ooool01OnYZJWo410@o`000?l@
413oZJVY037ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00booooo`03oeEEEOmVIVKo000002kooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0aooooo`03oeEEEOmVIVKo000003;ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00aooooo`05ojVYZOl@413o0000oa0@4?nYZJT02?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool001?oooooool0001Eo`00
007ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo0?ooooooDOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0?ooooooDOooool1o`00
007ooooo0008ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3ooooo
oe7ooooo0Ol00001ooooo`002?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooo
ooooool0oooooomAooooo`7o00000Oooool000Ko00001_ooool00ol0003oooooooooo`04ooooo`?o
00007Oooool2o`0002Wooooo00?o0000ooooooooool0ooooool4ooooo`?o00000Oooool000_ooooo
00?oZJVYoa0@4?ooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0ooooool6ooooo`7o00000Oooool000[ooooo00?o410@o`000?nj^[X01_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0oooo
ool7ooooo`7o00000Oooool000_ooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0ooooool7ooooo`7o00000Oooool0
00Sooooo00Go410@oiRHV?oooooo^[Zjo`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`3oooooo`Sooooo0Ol00001ooooo`002?ooool01OnY
ZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo0?oooooo2?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3oooooo`Wooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0ooooool9ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo0?oooooo2_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3oooooo`[ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0ooooool;ooooo`7o00000Oooool001?ooooo0_l0000Cooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0ooooool:ooooo`;o00000Oooool001?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0?oooooo3?ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`3oooooo`cooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0ooooool<ooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0?oooooo3Oooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`3oooooo`gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0;ooooo`;o
0000<oooool00ol0003oooooooooo`3oooooo`kooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0ooooool?ooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo0?oooooo3oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`3ooooooa3ooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0ooooool@oooo
o`7o00000Oooool001?ooooo0_l00007ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0ooooool@ooooo`;o00000Oooool001?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo0?oooooo4_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0oooooolBooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`3ooooooa?ooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0?oooooo4oooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool0oooooolDooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`3ooooooaGooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0?oooooo5Oooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0oooooolFooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`3ooooooaOooooo0Ol00001oooo
o`004oooool2o`0003Oooooo00?o0000ooooooooool0oooooolGooooo`;o00000Oooool001?ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3ooooooaWooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0?oooooo6Oooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0oooooolJooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`3ooooooa_ooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3ooooooagooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0?oooooo7_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooooolOoooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3oooooob3o
oooo0Ol00001ooooo`004oooool2o`0002oooooo00?o0000ooooooooool0oooooolOooooo`;o0000
0Oooool001?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3oooooob7ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0?oooooo8_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0oooooolSoooo
o`7o00000Oooool001?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3oooooobCo
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0?oooooo
9Oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0oooo
oolVooooo`7o00000Oooool001?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3o
ooooobOooooo0Ol00001ooooo`002?ooool5o`0000Kooooo00?o0000ooooooooool09Oooool2o`00
0?oooooo:_ooool1o`00007ooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo:_ooool1o`00007ooooo0006o`0000?o
oooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0?oo
oooo:oooool1o`00007ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Rooooo`03o`00
0?oooooooooo0?oooooo:_ooool3o`00007ooooo000;ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`3oooooobgooooo0Ol00001ooooo`003?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0ooooool^
ooooo`7o00000Oooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0ooooool_ooooo`7o00000Oooool000Sooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01gooooo0_l0003ooooooc;ooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0?oooooo<_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0oooooolcooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool06Oooool2o`000?oooooo=_ooool1o`00007ooooo
000Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0oooooolfooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3oooooocOooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo>?ooool1o`00
007ooooo000Cooooo`;o00005Oooool2o`000?oooooo>_ooool2o`00007ooooo000Cooooo`03o`00
0?oooooooooo01;ooooo0_l0003oooooocgooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo0?oooooo?Oooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0oooooolnooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`3oooooocoooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo@?ooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo00cooooo0_l0003ooooood?ooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0?oooooo@oooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo00Wooooo0_l0003oooooodKooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0?ooooooA_ooool1o`00007ooooo000Cooooo`;o00001oooool2o`000?oo
ooooB?ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooom9ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomA
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool0oooooomAooooo`7o00000Oooool001?ooooo0_l0003ooooooe7ooooo
0_l00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooo
oe7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`03ooooo`Koo`00Ooooool7o`000<7ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`03ooooo`[oo`00M_ooool5o`0000Oooooo1Ol0002looooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool00oooool>ool006oooooo0ol0000Aooooo`;o0000^_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo00?ooooo4_oo001Xooooo`?o00005_ooool2o`00
0;Sooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`06oooooa?oo`00HOooool3o`0001_o
oooo0_l0002fooooo`7o00000Oooool001?ooooo00?o0000ooooooooool02_oooolBool005cooooo
0_l0000Pooooo`03o`000?oooooooooo0;?ooooo0Ol00001ooooo`004oooool2o`0000oooooo4Ooo
001Gooooo`;o00008oooool00ol0003oooooooooo`2aooooo`;o00000Oooool001?ooooo00?o0000
ooooooooool04_ooool@ool005?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2a
ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool05_ooool@ool004gooooo0_l0000Xoooo
o`03o`000?oooooooooo0;3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Ioooooa3o
o`00Aoooool3o`0002_ooooo00?o0000ooooooooool0[oooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo01cooooo4?oo0012ooooo`;o0000;oooool00ol0003oooooooooo`2^ooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool07oooool@ool003cooooo0ol0000booooo`03o`000?oo
oooooooo0:gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Sooooo`ooo`00=oooool2
o`0003Kooooo00?o0000ooooooooool0[?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
02Kooooo4Ooo000`ooooo`;o0000>Oooool2o`000:cooooo0Ol00001ooooo`002Oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0:OoooolAool002_ooooo0_l0000mooooo`03
o`000?oooooooooo0:Wooooo0Ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02cooooo4?oo000Xooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
Z?ooool1o`00007ooooo0006o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0_oooooa3oo`008oooool2o`0004;ooooo00?o0000ooooooooool0Yoooool1o`00007ooooo000;
ooooo`03o`000?oooooooooo00Gooooo0ol0000dooooo`koo`007Oooool3o`0004Gooooo00?o0000
ooooooooool0Y?ooool3o`00007ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=oooool>ool001Sooooo0_l00019ooooo`03o`000?oooooooooo0:Gooooo0Ol00001oooo
o`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo3ooo000Cooooo`;o
0000C?ooool00ol0003oooooooooo`2Tooooo`7o00000Oooool000_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0looooo`koo`003oooool2o`0004oooooo00?o0000ooooooooool0
Xoooool1o`00007ooooo0009ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0?ooo
ool>ool000[ooooo0_l0001Booooo`03o`000?oooooooooo0:;ooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`12ooooo`koo`001?ooool3o`0005Gooooo00?o0000ooooooooool0XOooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo04Gooooo3?oo0003o`0005Wooooo00?o0000oooo
ooooool0X?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo04Oooooo1ooo0003o`0000Go
o`00F?ooool00ol0003oooooooooo`2Oooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
B_ooool2ool000;o00002ooo001Fooooo`03o`000?oooooooooo09kooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`19ooooo`?o000000?oooooool00?oo00003?oo001Eooooo`03o`000?oo
oooooooo09gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`16ooooo`?o00001oooool>
ool005?ooooo00?o0000ooooooooool0W?ooool1o`00007ooooo000Cooooo`;o0000A?ooool3o`00
00gooooo3_oo001Aooooo`03o`000?oooooooooo09[ooooo0_l00001ooooo`004oooool00ol0003o
ooooooooo`10ooooo`?o00004oooool=ool0053ooooo0_l0002Kooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0?Oooool3o`0001Sooooo3_oo001?ooooo`03o`000?oooooooooo09Sooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0iooooo`Co00007_ooool=ool004kooooo0_l0
002Hooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0=Oooool4o`0002Gooooo2ooo001?
ooooo`03o`000?oooooooooo09Gooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0boooo
o`?o0000:oooool<ool004gooooo00?o0000ooooooooool0U?ooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo02oooooo0ol0000aooooo`coo`00Boooool00ol0003oooooooooo`2Cooooo`7o
00000Oooool001?ooooo00?o0000ooooooooool0;?ooool3o`0003Kooooo3Ooo0019ooooo`;o0000
Toooool1o`00007ooooo000Cooooo`03o`000?oooooooooo02Sooooo1?l0000jooooo`koo`00BOoo
ool00ol0003oooooooooo`2@ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool08_ooool6
o`00047ooooo3Ooo0018ooooo`;o0000T?ooool1o`00007ooooo000Cooooo`;o00007Oooool6o`00
04[ooooo3?oo0018ooooo`03o`000?oooooooooo08cooooo0_l00001ooooo`004oooool00ol0003o
ooooooooo`0Gooooo`Go0000Doooool;ool004Oooooo0_l0002=ooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool04oooool4o`0005[ooooo2_oo0018ooooo`03o`000?oooooooooo08[ooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0?ooooo`Co0000H?ooool:ool004Oooooo00?o
0000ooooooooool0ROooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Wooooo1_l0001V
ooooo`_oo`00AOooool2o`0008Wooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`05oooo
o`Co0000K_ooool;ool004Gooooo0ol00026ooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool0N?ooool<ool004Kooooo0_l00024ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
N_ooool<ool004Kooooo0_l00022ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0OOoo
ool;ool004Kooooo0_l00020ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Ooooool:
ool004Oooooo0_l0001nooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0POooool:ool0
04Oooooo0_l0001looooo`7o00000Oooool001?ooooo0_l00024ooooo`[oo`00Aoooool3o`0007So
oooo0_l00001ooooo`004oooool00ol0003oooooooooo`25ooooo`Woo`00BOooool2o`0007Oooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`26ooooo`[oo`00BOooool3o`0007Cooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`28ooooo`[oo`00B_ooool3o`00077ooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`2:ooooo`Woo`00C?ooool3o`0006kooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`2;ooooo`[oo`00COooool3o`0006_ooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`2=ooooo`[oo`00C_ooool3o`0006Sooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`2?ooooo`Woo`00D?ooool4o`0006Cooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`2@ooooo`[oo`00D_ooool5o`0005oooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`2Booooo`Woo`00E_ooool4o`0005_ooooo0Ol00001ooooo`004oooool00ol0003o
ooooooooo`2Dooooo`Woo`00F?ooool3o`0005Sooooo0Ol00001ooooo`004oooool2o`0009Kooooo
2Ooo001Jooooo`Go0000D_ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo09Oooooo2?oo
001Nooooo`Ko0000COooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09Sooooo2?oo001S
ooooo`So0000AOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09[ooooo1ooo001Zoooo
o`Wo0000??ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09_ooooo1ooo001booooo`So
0000=?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09cooooo1ooo001iooooo`So0000
;?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo09gooooo1ooo0020ooooo`So00009?oo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo09kooooo1ooo0027oooooa7o00004oooool1
o`00007ooooo0008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2O
ooooo`Ooo`00Uoooool<o`0000Oooooo0Ol00001ooooo`002?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0X?ooool7ool00:Wooooo0Ol00001ooooo`002?ooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0XOooool7ool00:Sooooo0Ol00001
ooooo`002?ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002Rooooo`Ooo`00YOooool3
o`00007ooooo0008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2S
ooooo`Ooo`00Y_ooool1o`00007ooooo0008ooooo`05oa0@4?ooooooooooooooool@41001_ooool0
0ol0003oooooooooo`2Tooooo`Ooo`00YOooool1o`00007ooooo0008ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`2Uooooo`Soo`00Xoooool1o`00007ooooo0008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`2Vooooo`Ooo`00Xoooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo0:Oooooo1ooo002Rooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool0Z?ooool7ool00:7ooooo0Ol00001ooooo`004oooool00ol0003ooooo
ooooo`2Yooooo`Koo`00XOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:[ooooo1_oo
002Pooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0Zoooool5ool00:3ooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`2[ooooo`Koo`00Woooool1o`00007ooooo000Cooooo`;o
0000[Oooool6ool009gooooo0_l00001ooooo`004oooool00ol0003oooooooooo`2/ooooo`Koo`00
W_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:gooooo1_oo002Mooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool0[_ooool5ool009gooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`2^ooooo`Koo`00W?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo0:oo
oooo1Ooo002Looooo`7o00000Oooool001?ooooo00?o0000ooooooooool0[oooool5ool009cooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`2`ooooo`Goo`00Voooool1o`00007ooooo000C
ooooo`03o`000?oooooooooo0;3ooooo1Ooo002Kooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0/?ooool5ool009_ooooo0Ol00001ooooo`004oooool2o`000;;ooooo1?oo002Jooooo`;o
00000Oooool001?ooooo00?o0000ooooooooool0/Oooool4ool009_ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`2aooooo`Coo`00Voooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo0;7ooooo1Ooo002Jooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0/Oooool5ool0
09[ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`2aooooo`Goo`00V_ooool1o`00007o
oooo000Cooooo`03o`000?oooooooooo0;;ooooo1?oo002Jooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool01Oooool2o`000:_ooooo1?oo002Jooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool01oooool4o`000:Oooooo1?oo002Jooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool02oooool5o`000:;ooooo1?oo002Jooooo`7o00000Oooool001?ooooo00?o0000oooooooo
ool04?ooool4o`0009gooooo1Ooo002Jooooo`7o00000Oooool001?ooooo0_l0000Eooooo`Co0000
VOooool5ool009Wooooo0_l00001ooooo`004oooool00ol0003oooooooooo`0Hooooo`Go0000U?oo
ool5ool009[ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Mooooo`?o0000TOooool4
ool009_ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Pooooo`?o0000SOooool5ool0
09_ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Sooooo`?o0000R_ooool5ool009_o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Vooooo`?o0000Qoooool5ool009_ooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`0Yooooo`?o0000Poooool5ool009cooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`0/ooooo`;o0000POooool5ool009cooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0^ooooo`?o0000OOooool6ool009cooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0aooooo`?o0000N_ooool5ool009gooooo0Ol00001ooooo`00
4oooool00ol0003oooooooooo`0dooooo`?o0000M_ooool6ool009gooooo0Ol00001ooooo`004ooo
ool2o`0003Sooooo0_l0001dooooo`Goo`00WOooool2o`00007ooooo000Cooooo`03o`000?oooooo
oooo03Wooooo0_l0001aooooo`Koo`00W_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
03_ooooo0_l0001_ooooo`Goo`00Woooool1o`00007ooooo000Cooooo`03o`000?oooooooooo03go
oooo0_l0001/ooooo`Koo`00Woooool1o`00007ooooo000Cooooo`03o`000?oooooooooo03oooooo
0_l0001Yooooo`Koo`00X?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0IOooool7ool00:3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo06Cooooo1_oo002Qooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0@oooool2o`0006?ooooo1_oo002Rooooo`7o00000Oooool000Wooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0Goooool6ool00:?o
oooo0Ol00001ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0GOooool7ool00:?ooooo0Ol00001ooooo`002oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0F_ooool8ool00:Cooooo0Ol0
0001ooooo`002oooool00ol0003oooooooooo`05ooooo`?o0000B?ooool2o`0005Wooooo2?oo002S
ooooo`?o00000Oooool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo05Gooooo2?oo002Vooooo`7o00000Oooool000_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo05?ooooo2?oo002Wooooo`7o
00000Oooool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo053ooooo2?oo002Yooooo`7o00000Oooool000Wooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04kooooo2?oo002Zooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1<ooooo`Soo`00Zoooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo04oooooo0_l0001;ooooo`Soo`00[?ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0A_ooool8ool00:ko
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo04Cooooo
2?oo002_ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`12ooooo`Woo`00/?ooool1o`00007ooooo000Cooooo`;o0000E?ooool00ol0003oooooooooo`10
ooooo`Woo`00/?ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0?_ooool8ool00;?ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo03_ooooo2Ooo002dooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`0iooooo`Soo`00]_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0=oooool8ool00;Oooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`1Hooooo`03o`000?oooooooooo03?ooooo2_oo002hooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0aooooo`Woo`00^_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0;oooool:ool00;_o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo02gooooo
2_oo002looooo`7o00000Oooool001?ooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`0/ooooo`Soo`00_oooool1o`00007ooooo000Cooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool0:Oooool9ool00<3ooooo0Ol00001ooooo`004oooool2o`0005gooooo00?o0000oooo
ooooool09_ooool9ool00<7ooooo0_l00001ooooo`004oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo02Cooooo2_oo0033ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Qooooo`_oo`00a?ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool07_ooool<ool00<Kooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01_ooooo3?oo0038ooooo`7o00000Oooool0
01?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Iooooo`coo`00b_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05_ooool<ool00<co
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01?ooooo
2ooo003?ooooo`7o00000Oooool001?ooooo00?o0000ooooooooool01Oooool2o`0005Wooooo00?o
0000ooooooooool04Oooool;ool00=7ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`07
ooooo`;o0000F?ooool00ol0003oooooooooo`0>ooooo`_oo`00doooool1o`00007ooooo000Coooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0<oooo
o`_oo`00eOooool1o`00007ooooo000Cooooo`;o00002oooool2o`0005Gooooo00?o0000oooooooo
ool02_ooool;ool00=Kooooo0_l00001ooooo`004oooool00ol0003oooooooooo`0<ooooo`?o0000
Doooool00ol0003oooooooooo`07ooooo`_oo`00fOooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`coo`00fooo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo013ooooo0_l0001Aooooo`04o`000?oooooo
ooooooooo`coo`00gOooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01;ooooo0_l0001?
ooooo`03o`000?ooooooo`0000_oo`00goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Boooool2ool00003o`000?oo003oo`0000Soo`00hOooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo01Gooooo0_l00018ooooo`Goo`0000?o0000ool00?oo
00001Ooo003Tooooo`7o00000Oooool001?ooooo00?o0000ooooooooool05oooool2o`0004Cooooo
2?oo00000ol0003oo`00ool00002ool00>Kooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0Iooooo`;o0000?oooool;ool00003o`000?oo003oo`000>Sooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`0Kooooo`;o0000>_ooool>ool00003ooooool0003ooooo0>Sooooo0Ol00001
ooooo`004oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Gooooo3Ooo0004oooo
o`03o`000?oooooooooo0>Oooooo0Ol00001ooooo`004oooool2o`0001oooooo0_l0000booooo`ko
o`001_ooool00ol0003oooooooooo`3Vooooo`;o00000Oooool001?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0/ooooo`koo`002_ooool00ol0003oooooooooo`3Vooooo`7o0000
0Oooool001?ooooo00?o0000ooooooooool08Oooool2o`0002Wooooo3_oo000=ooooo`03o`000?oo
oooooooo0>Kooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0Sooooo`;o00009?ooool?
ool000oooooo00?o0000ooooooooool0i_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool07_ooool?ool001;ooooo00?o0000ooooooooool0i_ooool1o`00
007ooooo000Cooooo`03o`000?oooooooooo02Kooooo0_l0000Looooo`koo`005_ooool00ol0003o
ooooooooo`3Uooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0:?ooool2o`0001Oooooo
3_oo000Iooooo`03o`000?oooooooooo0>Gooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo017ooooo3_oo000Looooo`03o`000?oooooooooo0>Gooooo0Ol0
0001ooooo`002?ooool5o`0000Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0>
ooooo`goo`007oooool00ol0003oooooooooo`3Uooooo`7o00000Oooool000Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02_ooool>
ool0027ooooo00?o0000ooooooooool0iOooool1o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06ooooo`koo`009Oooool00ol0
003oooooooooo`3Tooooo`7o00000Oooool000[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0002ko
oooo0_l00004ooooo`goo`00:?ooool00ol0003oooooooooo`3Rooooo`?o00000Oooool000_ooooo
00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo003oo`0000coo`00
:_ooool00ol0003oooooooooo`3Tooooo`7o00000Oooool000cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0^ooooo`?oo`0000?o0000ool00?oo00002?oo000]ooooo`03o`000?oo
oooooooo0>Cooooo0Ol00001ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o
0000ooooooooool0:_ooool8ool00003o`000?oo003oo`0000Coo`00<Oooool00ol0003ooooooooo
o`3Sooooo`7o00000Oooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo02Kooooo3Ooo0002o`0000;oo`00<oooool00ol0003oooooooooo`3Sooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool08ooooolAool00003ooooool0003ooooo03?ooooo00?o0000
ooooooooool0hoooool1o`00007ooooo000Cooooo`03o`000?oooooooooo023ooooo4Ooo0005oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0hoooool1o`00007ooooo000Cooooo`03
o`000?oooooooooo01gooooo4?oo000:ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0h_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01[ooooo3ooo000?ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0h_ooool1o`00007ooooo000Cooooo`03o`000?oo
oooooooo01Gooooo4Ooo000Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0h_oo
ool1o`00007ooooo000Cooooo`;o00004ooooolAool001Oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`3Qooooo`;o00000Oooool001?ooooo00?o0000ooooooooool04?ooool@ool0
01_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3Qooooo`7o00000Oooool001?o
oooo00?o0000ooooooooool03Oooool@ool001oooooo0_l0000^ooooo`03o`000?oooooooooo0>7o
oooo0Ol00001ooooo`004oooool00ol0003oooooooooo`09ooooo`ooo`009_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo0>7ooooo0Ol00001ooooo`004oooool00ol0003ooooooooo
o`05oooooa3oo`00:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0>7ooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`03oooooa3oo`00;Oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`03oooo
o`goo`00<Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0>3ooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`03ooooo`Woo`00=_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo0>3ooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`03ooooo`Goo`00
>oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0>3ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0gooo
ool1o`00007ooooo000Cooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo0_l00017ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0g_ooool2o`00007ooooo000Cooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0=oooooo
0Ol00001ooooo`004oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`3Nooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0=kooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0g_ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`3Nooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0=kooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0g_ooool1
o`00007ooooo000Cooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`3Nooooo`7o00000Oooool001?ooooo0_l0001@ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0gOooool2o`00007ooooo000Cooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`3Nooooo`7o00000Oooool001?ooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0=oooooo0Ol0
0001ooooo`004oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0B_ooool2o`0001Sooooo00?o0000ooooooooool0goooool1o`00007ooooo000Cooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo0=oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3Oooooo`7o00000Ooo
ool001?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0=oooooo0Ol00001ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo
0_l0000=ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`3Nooooo`;o00000Oooool001?ooooo00?o0000ooooooooool03Oooool2o`0004gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3Oooooo`7o00000Oooool001?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0goooool1o`00007ooooo000Cooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0=oooooo0Ol00001oooo
o`004oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3Pooooo`7o00000Oooool001?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
h?ooool1o`00007ooooo000Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Booo
ool2o`0000[ooooo00?o0000ooooooooool0hOooool1o`00007ooooo000Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0COooool2o`0000Sooooo00?o0000ooooooooool0hOooool1
o`00007ooooo0008ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3R
ooooo`7o00000Oooool000Sooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0C_ooool2o`0000Cooooo00?o0000ooooooooool0h_ooool1
o`00007ooooo000<ooooo`03o`000?oooooooooo00Cooooo0ol0000Eooooo`;o0000D?ooool01?l0
003oooooooooool0003Sooooo`?o00000Oooool000_ooooo00?oZJVYoa0@4?ooool01Oooool00ol0
003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`002_ooool00ol@413o0000okZj^P06ooooo`03
o`000?oooooooooo0?ooooooDOooool1o`00007ooooo000;ooooo`03okZj^_lQ8B7ooooo00Gooooo
00?o0000ooooooooool0oooooomAooooo`7o00000Oooool000Sooooo00Go410@oiRHV?oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0?ooooooDOooool1o`00007ooooo0008ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooe7ooooo0Ol00001ooooo`004ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`004oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`004oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`004oooooooo`0005Go
00000Oooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-3.50706, -3.47372, 0.0231894, \
0.0231894}}]
}, Open  ]],

Cell[TextData[{
  "The crossing points of the thin and thick curves show where both equations \
are satisfied, and are our solution points. The crossing point in the lower \
left quadrant is the one that was found by ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " previously.  Now that we know roughly where other solutions lie in the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-",
  StyleBox["y",
    FontSlant->"Italic"],
  " plane, we can choose initial guesses close to each one to find these \
solutions. For example:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[{Cos[x\ y] + \ y\ Exp[x]\  \[Equal] 0, 
        y^2\  - \ y\  + \ x\  \[Equal] 0}, {x, \(-2\)}, {y, 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.184"],

Cell[BoxData[
    \({x \[Rule] \(-2.1757789603973725`\), 
      y \[Rule] 2.0574912575300086`}\)], "Output"]
}, Open  ]],

Cell["\<\
\tUnfortunately, there is no general algorithm for finding all of \
the numerical solutions at once to general nonlinear equations. One needs to \
supply a guess for each solution, and this requires extra work, like the \
plotting we did in the above examples.   This is one of the reasons why \
complete analytic solutions of nonlinear systems (if such solutions are \
available) are superior to numerical solutions.\
\>", "Text"],

Cell[TextData[{
  "\tSyntax for the command ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is summarized in Table ",
  ButtonBox["9.22",
    ButtonData:>"Table 9.22",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table  
                9  .22\ Finding\ One\ Numerical\ Solution\ of\ an\ Equation\),
              
              FontSize->9], "\[IndentingNewLine]"}]},
        {GridBox[{
              {
                RowBox[{
                  RowBox[{
                    StyleBox["FindRoot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["lhs",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox["\[Equal]",
                          FontWeight->"Bold"], 
                        StyleBox["rhs",
                          FontFamily->"Times",
                          FontSlant->"Italic"]}], 
                      StyleBox[",",
                        FontFamily->"Times"], 
                      RowBox[{
                        StyleBox["{",
                          FontFamily->"Times"], 
                        RowBox[{
                          StyleBox["x",
                            FontFamily->"Times",
                            FontSlant->"Italic"], 
                          StyleBox[",",
                            FontFamily->"Times",
                            FontSlant->"Italic"], 
                          StyleBox[
                            FormBox[
                              StyleBox[\(x\_o\),
                                FontFamily->"Times"],
                              "TraditionalForm"],
                            FontFamily->"Times"]}], 
                        StyleBox["}",
                          FontFamily->"Times"]}]}], 
                    StyleBox["]",
                      FontWeight->"Bold"]}], 
                  StyleBox[" ",
                    FontFamily->"Times"]}], 
                RowBox[{
                  
                  StyleBox[\(Find\ a\ single\ numerical\ solution\ to\ an\ \
equation, \ given\ an\ initial\ guess\),
                    FontFamily->"Times"], 
                  StyleBox["\[IndentingNewLine]",
                    FontFamily->"Times"], 
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox["(",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["only",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["if",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["lhs",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["and",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["rhs",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["have",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["analytic",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["derivatives",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["wrt",
                        FontFamily->"Times"], 
                      StyleBox[" ",
                        FontFamily->"Times"], 
                      StyleBox["x",
                        FontFamily->"Times",
                        FontSlant->"Italic"], Cell[""]}], 
                    StyleBox[")",
                      FontFamily->"Times"]}]}]},
              {
                RowBox[{
                  StyleBox["FindRoot",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["lhs",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["\[Equal]",
                        FontWeight->"Bold"], 
                      StyleBox["rhs",
                        FontFamily->"Times",
                        FontSlant->"Italic"]}], 
                    StyleBox[",",
                      FontFamily->"Times"], 
                    RowBox[{
                      StyleBox["{",
                        FontFamily->"Times"], 
                      RowBox[{
                        StyleBox["x",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox[",",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox[
                          FormBox[
                            StyleBox[\(x\_o\),
                              FontFamily->"Times"],
                            "TraditionalForm"],
                          FontFamily->"Times"], 
                        StyleBox[",",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox[
                          FormBox[
                            StyleBox[\(x\_1\),
                              FontFamily->"Times"],
                            "TraditionalForm"],
                          FontFamily->"Times"]}], 
                      StyleBox["}",
                        FontFamily->"Times"]}]}], 
                  StyleBox["]",
                    FontFamily->"Times",
                    FontWeight->"Bold"]}], 
                StyleBox[
                  
                  RowBox[{\(Find\ a\ numerical\ solution\ to\ an\ equation, \ 
                    given\ two\ initial\ guesses\), " ", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(", 
                      RowBox[{"required", " ", "if", " ", 
                        StyleBox["lhs",
                          FontSlant->"Italic"], 
                        StyleBox[" ",
                          FontSlant->"Italic"], "and", " ", 
                        StyleBox["rhs",
                          FontSlant->"Italic"], 
                        StyleBox[" ",
                          FontSlant->"Italic"], "do", " ", "not", " ", "have",
                         " ", "analytic", " ", "derivatives"}], ")"}]}],
                  FontFamily->"Times"]}
              },
            ColumnSpacings->1.8,
            ColumnAlignments->{Left}]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 9.22"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.11.2 Numerical Integration", "Subsubtitle",
  CellTags->{"i:73", "c:62"}],

Cell[TextData[{
  "We saw in Sec. ",
  ButtonBox["9.9.3",
    ButtonData:>"c:51",
    ButtonStyle->"Hyperlink"],
  " that some definite integrals cannot be evaluated analytically. These \
integrals can be evaluated ",
  StyleBox["numerically",
    FontSlant->"Italic"],
  " using ",
  StyleBox["NIntegrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The syntax for this function is identical to that for a definite \
integral. For example, to numerically compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(-\
\[ExponentialE]\^\(x\^2\)\)\) \[DifferentialD]x\)]],
  " , one might type"
}], "Text",
  CellTags->"i:75"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[Exp[\(-Exp[x^2]\)], {x, 0, Infinity}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.185"],

Cell[BoxData[
    \(General::"unfl" \(\(:\)\(\ \)\) 
      "Underflow occurred in computation."\)], "Message"],

Cell[BoxData[
    \(General::"unfl" \(\(:\)\(\ \)\) 
      "Underflow occurred in computation."\)], "Message"],

Cell[BoxData[
    \(General::"unfl" \(\(:\)\(\ \)\) 
      "Underflow occurred in computation."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(General :: \"unfl\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    \(0.26330018327147453`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A number of error messages are given, but also an answer (to four \
significant figures). The reason for the errors is that we asked for an \
integral running all the way to infinity, which is not practical. The \
function goes to zero so rapidly at large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " that it is sufficient to ask for the integral from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 5\)]],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[Exp[\(-Exp[x^2]\)], {x, 0, 5}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.186"],

Cell[BoxData[
    \(0.26330018327243565`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since this is a numerical method, it is important to be able to test the \
accuracy. This can be accomplished by asking for more precision in the \
integral, via the ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. This option sets the number of digits of precision of the \
integral relative to the magnitude of the integral. By varying ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we can see the integral's value converge :"
}], "Text",
  CellTags->"i:103"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      InputForm[
        NIntegrate[Exp[\(-Exp[x^2]\)], {x, 0, 5}, PrecisionGoal \[Rule] n, 
          MaxRecursion \[Rule] 50]], {n, 3, 15}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.187"],

Cell[BoxData[
    \(NIntegrate::"ploss" \(\(:\)\(\ \)\) 
      "Numerical integration stopping due to loss of precision. Achieved \
neither the requested PrecisionGoal nor AccuracyGoal; suspect one of the \
following: highly oscillatory integrand or the true value of the integral is \
0. If your integrand is oscillatory try using the option Method->Oscillatory \
in NIntegrate."\)], "Message"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          StyleBox["0.2633001925783604",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.2633001925783604],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.2633001925783604",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.2633001925783604],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327243565",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327243565],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327243565",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327243565],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.2633001832720073",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327200733],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.2633001832720101",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.2633001832720101],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327201016",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327201016],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.2633001832720101",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.2633001832720101],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327201016",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327201016],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327201016",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327201016],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.2633001832720102",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327201021],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327201016",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327201016],
          Editable->True,
          AutoDelete->True], ",", 
        InterpretationBox[
          StyleBox["0.26330018327201016",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 0.26330018327201016],
          Editable->True,
          AutoDelete->True]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here the ",
  StyleBox["InputForm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  (see Sec. ",
  ButtonBox["9.2.6",
    ButtonData:>"c:9",
    ButtonStyle->"Hyperlink"],
  ")  is displayed in order to view the full precision of the numbers. Note \
that the integral's value is often of higher precision that what was \
requested. The option ",
  StyleBox["MaxRecursion ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "has  been set to 50 so that a sufficient number of bisections of the \
interval ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 5)\)\)]],
  " can be taken in order to achieve the requested accuracy. The  default \
setting for ",
  StyleBox["MaxRecursion",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is 7 and for ",
  StyleBox["PrecisionGoal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " it is ",
  Cell[BoxData[
      FormBox[
        StyleBox[\($MachinePrecision - 10\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ". The error occurs in the last integration because asking for a relative \
precision of 15 digits is impossible when the machine precision is only 16 \
digits. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.11.3 Interpolation", "Subsubtitle",
  CellTags->{"i:92", "c:63"}],

Cell[TextData[{
  "\tGiven a list of ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " data, it is often useful to be able to define a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " that goes through each point ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\((x, y)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " in a fashion that is as smooth as possible. One can then treat this \
function like any other function in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", taking its derivative or finding its zeros, for example."
}], "Text"],

Cell[TextData[{
  "\tTo create this function from a data set, use the ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. As an example, we will first create some ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " data, then apply ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the data. The data will be points taken from the function ",
  Cell[BoxData[
      \(TraditionalForm\`y = x\^5\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < x < 1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data = Table[{x, x^5}, {x, \(-1\), 1, 0.05}];\)\), "\n", 
    \(f = Interpolation[data]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.188"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-1.`\), 1.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of the interpolation is something called an",
  StyleBox[" InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which we have assigned to the variable ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ".  The first argument of this ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["{{-1.,1.}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is the range of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " values over which the function is defined (in this case from -1 to 1 , \
because this was the range of the data). The second argument ",
  StyleBox["<>",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " denotes an argument that is hidden from our view; it is a long list of \
numbers used to define this function, which need not concern us. "
}], "Text",
  CellTags->"i:100"],

Cell[TextData[{
  "\tHowever, there is no argument in the ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that allows us to evaluate the function at a given value of ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". This type of object is called a ",
  StyleBox["pure function",
    FontSlant->"Italic"],
  " in the nomenclature of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". To use it, we can add simply an argument to it. In other words, ",
  StyleBox["f",
    FontSlant->"Italic"],
  " is a function (a pure function), and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is the value of that function at position",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x\)\)\)]],
  ":"
}], "Text",
  CellTags->"i:101"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[0.7]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.189"],

Cell[BoxData[
    \(0.16806999999999994`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[\(-0.3\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.190"],

Cell[BoxData[
    \(\(-0.0024299999999999994`\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can plot ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " (Cell ",
  ButtonBox["9.191",
    ButtonData:>"Cell 9.191",
    ButtonStyle->"Hyperlink"],
  "), or take its derivative (Cell ",
  ButtonBox["9.192",
    ButtonData:>"Cell 9.192",
    ButtonStyle->"Hyperlink"],
  "), just as we would any other function (in its range of validity)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f[x], {x, \(-1\), 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.191"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.298833 218.948 [
[.02381 .28633 -6 -9 ]
[.02381 .28633 6 0 ]
[.2619 .28633 -12 -9 ]
[.2619 .28633 12 0 ]
[.7381 .28633 -9 -9 ]
[.7381 .28633 9 0 ]
[.97619 .28633 -3 -9 ]
[.97619 .28633 3 0 ]
[.4875 .07988 -36 -4.5 ]
[.4875 .07988 0 4.5 ]
[.4875 .18936 -42 -4.5 ]
[.4875 .18936 0 4.5 ]
[.4875 .40831 -36 -4.5 ]
[.4875 .40831 0 4.5 ]
[.4875 .51778 -30 -4.5 ]
[.4875 .51778 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .29883 m
.02381 .30508 L
s
[(-1)] .02381 .28633 0 1 Mshowa
.2619 .29883 m
.2619 .30508 L
s
[(-0.5)] .2619 .28633 0 1 Mshowa
.7381 .29883 m
.7381 .30508 L
s
[(0.5)] .7381 .28633 0 1 Mshowa
.97619 .29883 m
.97619 .30508 L
s
[(1)] .97619 .28633 0 1 Mshowa
.125 Mabswid
.07143 .29883 m
.07143 .30258 L
s
.11905 .29883 m
.11905 .30258 L
s
.16667 .29883 m
.16667 .30258 L
s
.21429 .29883 m
.21429 .30258 L
s
.30952 .29883 m
.30952 .30258 L
s
.35714 .29883 m
.35714 .30258 L
s
.40476 .29883 m
.40476 .30258 L
s
.45238 .29883 m
.45238 .30258 L
s
.54762 .29883 m
.54762 .30258 L
s
.59524 .29883 m
.59524 .30258 L
s
.64286 .29883 m
.64286 .30258 L
s
.69048 .29883 m
.69048 .30258 L
s
.78571 .29883 m
.78571 .30258 L
s
.83333 .29883 m
.83333 .30258 L
s
.88095 .29883 m
.88095 .30258 L
s
.92857 .29883 m
.92857 .30258 L
s
.25 Mabswid
0 .29883 m
1 .29883 L
s
.5 .07988 m
.50625 .07988 L
s
[(-0.001)] .4875 .07988 1 0 Mshowa
.5 .18936 m
.50625 .18936 L
s
[(-0.0005)] .4875 .18936 1 0 Mshowa
.5 .40831 m
.50625 .40831 L
s
[(0.0005)] .4875 .40831 1 0 Mshowa
.5 .51778 m
.50625 .51778 L
s
[(0.001)] .4875 .51778 1 0 Mshowa
.125 Mabswid
.5 .10178 m
.50375 .10178 L
s
.5 .12367 m
.50375 .12367 L
s
.5 .14557 m
.50375 .14557 L
s
.5 .16746 m
.50375 .16746 L
s
.5 .21125 m
.50375 .21125 L
s
.5 .23315 m
.50375 .23315 L
s
.5 .25504 m
.50375 .25504 L
s
.5 .27694 m
.50375 .27694 L
s
.5 .32073 m
.50375 .32073 L
s
.5 .34262 m
.50375 .34262 L
s
.5 .36452 m
.50375 .36452 L
s
.5 .38641 m
.50375 .38641 L
s
.5 .4302 m
.50375 .4302 L
s
.5 .4521 m
.50375 .4521 L
s
.5 .47399 m
.50375 .47399 L
s
.5 .49589 m
.50375 .49589 L
s
.5 .05799 m
.50375 .05799 L
s
.5 .0361 m
.50375 .0361 L
s
.5 .0142 m
.50375 .0142 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .56157 m
.50375 .56157 L
s
.5 .58347 m
.50375 .58347 L
s
.5 .60536 m
.50375 .60536 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.37294 0 m
.37723 .04991 L
.38725 .13655 L
.39647 .19326 L
.4013 .21547 L
.4066 .23544 L
.41209 .25245 L
.41729 .26489 L
.42218 .27382 L
.4275 .28102 L
.43192 .28598 L
.4368 .29025 L
.43952 .29208 L
.44207 .29347 L
.44476 .29464 L
.44767 .29561 L
.45022 .29624 L
.45291 .29679 L
.45522 .29734 L
.45772 .29783 L
.46029 .29821 L
.46147 .29835 L
.46272 .29847 L
.46384 .29857 L
.46508 .29865 L
.4662 .29872 L
.46726 .29876 L
.4679 .29878 L
.46859 .2988 L
.4698 .29882 L
.47049 .29883 L
.47122 .29883 L
.47253 .29883 L
.47317 .29882 L
.47386 .29881 L
.47512 .29879 L
.47634 .29877 L
.47746 .2988 L
.47966 .29885 L
.48172 .29889 L
.4829 .2989 L
.48398 .29891 L
.48522 .29892 L
.48639 .29893 L
.48753 .29893 L
.48874 .29893 L
.48978 .29892 L
.49091 .29892 L
.49213 .29891 L
.49345 .2989 L
Mistroke
.49582 .29888 L
.50047 .29883 L
.50542 .29877 L
.50689 .29876 L
.50827 .29875 L
.50951 .29875 L
.51021 .29874 L
.51085 .29874 L
.51202 .29874 L
.51331 .29874 L
.51396 .29874 L
.51465 .29874 L
.5159 .29875 L
.51722 .29876 L
.51862 .29878 L
.52015 .29881 L
.52157 .29884 L
.5228 .29887 L
.52349 .29889 L
.52412 .29889 L
.52483 .29888 L
.52558 .29886 L
.52629 .29885 L
.52694 .29884 L
.52815 .29883 L
.52943 .29884 L
.53063 .29885 L
.53175 .29887 L
.53307 .29892 L
.53428 .29897 L
.53561 .29906 L
.53702 .29917 L
.53954 .29944 L
.54194 .29978 L
.54409 .30018 L
.54644 .30071 L
.55134 .30179 L
.55408 .30261 L
.55657 .30357 L
.55892 .3047 L
.56146 .3062 L
.56606 .30975 L
.57065 .31452 L
.57487 .31956 L
.57958 .32677 L
.58462 .33696 L
.58937 .34933 L
.59371 .3633 L
.5988 .38259 L
.60433 .40854 L
Mistroke
.61438 .47336 L
.62379 .5581 L
Mfstroke
.62379 .5581 m
.62863 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oQOooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;;ooooo0025ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0/_ooool008Gooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`2booooo`00QOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0;;ooooo
0025ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0/_ooool008Kooooo00?o0000
ooooooooool0:_ooool2o`000;?ooooo0026ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0/_ooool008Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2booooo`00
Q_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;;ooooo0026ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0/_ooool008Kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`2booooo`00Q_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
0;;ooooo0026ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0/_ooool008Kooooo
00?o0000ooooooooool0:_ooool2o`000;?ooooo0027ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0/_ooool008Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2b
ooooo`00Qoooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0;;ooooo0027ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool008Oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`2booooo`00Qoooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo0;;ooooo0027ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0/_ooool0
08Oooooo00?o0000ooooooooool0:Oooool2o`000;?ooooo0027ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0/_ooool008Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`2booooo`00R?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;;ooooo0028
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0/_ooool008Sooooo00Go0000oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`2booooo`00R?ooool01Ol0003oV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2booooo`00P?ooool6o`0000;ooooo00Go0000oooooooo
oooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2booooo`00R?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`?o0000/_ooool008Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2b
ooooo`00R?ooool01Ol@413o0000oooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0;;ooooo0028ooooo`05ogMgMol0003ooooooiRHV?mgMgL02oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool008Sooooo00Gok^k^o`000?l0003o<S8bonk^kP0;oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`2booooo`00ROooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo0;;ooooo0029ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0/_ooool008Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2booooo`00
ROooool00ol0003oooooooooo`0Wooooo`;o0000/oooool008[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`2booooo`00R_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo0;;ooooo002:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/_ooool008[o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2booooo`00R_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo0;;ooooo002:ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0/_ooool008[ooooo00?o0000ooooooooool09_ooool2o`000;?ooooo002:oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0/_ooool008_ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`2booooo`00Roooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo0;;ooooo002;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0/_oo
ool008_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2booooo`00Roooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo0;;ooooo002;ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0/_ooool008_ooooo00?o0000ooooooooool09Oooool2o`000;?ooooo
002<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0/_ooool008cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`2booooo`00S?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo0;;ooooo002<ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0/_ooool008cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2booooo`00S?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0;;ooooo002<ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0/_ooool008gooooo00?o0000ooooooooool08oooool2o`00
0;?ooooo002=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0/_ooool008gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`2booooo`00SOooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0;;ooooo002=ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0/_ooool0083ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q00Wooooo
o`000?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`2booooo`00P?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B402Ooooooo0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`2booooo`00N?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
4009ooooo`03o`000?oooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0/_ooool0083ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`05ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0002b
ooooo`00P?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo0;;o
oooo0020ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol0003ooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;;ooooo0020oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/_ooool0083ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0:ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co00001_ooool00ol0003o
ooooooooo`2booooo`00Soooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0;;ooooo
002?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0/_ooool008oooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`2booooo`00T?ooool00ol0003oooooooooo`0Poooo
o`;o0000/oooool0093ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2booooo`00
T?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;;ooooo002@ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0/_ooool0097ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`2booooo`00TOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
0;;ooooo002Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0/_ooool009;ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`2booooo`00T_ooool00ol0003ooooooooo
o`0Nooooo`;o0000/oooool009;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2b
ooooo`00T_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;;ooooo002Cooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0/_ooool009?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`2booooo`00Toooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo0;;ooooo002Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0/_ooool0
09Cooooo00?o0000ooooooooool07?ooool2o`000;?ooooo002Dooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0/_ooool009Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`2booooo`002_ooool4o`000003oa0@4?oooooooooo04Kooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`17ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@19ooooo`Co000000?o410@ooooooooool01Oooool0
00cooooo00?o0000ooooooooool0B?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`17
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0B_oo
ool00ol0003oooooooooo`07ooooo`0000?oooooo`000?l000001?l00005ooooo`03o`000?oooooo
oooo043ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Aoooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`07ooooo`003?oo
ool00ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`0Xooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Aoooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool0B_ooool00ol0003oooooooooo`07ooooo`00
3?ooool00ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`17oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<04_ooooo00?o
0000ooooooooool01oooool000cooooo00?o0000ooooooooool0B?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`;o0000B?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`07ooooo`003?ooool00ol0003oooooooooo`18ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
Aoooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`07ooooo`002_ooool00omEEEGoIVIVo`00001:ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0002gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0004[ooooo00?oEEEEofIVI_l000002Oooool009[o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2booooo`00Voooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0;;ooooo002Looooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0/_ooool009gooooo0_l0000Dooooo`03o`000?oooooooooo0;;ooooo002Ooooo
o`Co00004?ooool00ol0003oooooooooo`2booooo`00ool0001Xo`00007ooooo0008ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool4o`0000oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000002o`0000cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo002c
ooooo`03o`000?oooooooooo01?ooooo0_l0002Mooooo`00/oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo09[ooooo002cooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0V_ooool00;?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Iooooo`00/ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo09Sooooo002cooooo`;o00006Oooool0
0ol0003oooooooooo`2Gooooo`00/oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
09Kooooo002cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0UOooool00;?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Eooooo`00/oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo09Gooooo002cooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0U?ooool00;?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2Doooo
o`00/oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Cooooo002cooooo`;o0000
7Oooool00ol0003oooooooooo`2Cooooo`00/oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo09?ooooo002cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0T_ooool0
0;?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Booooo`00/oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo097ooooo002cooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0TOooool00;?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`2Aooooo`00/oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo093ooooo002coooo
o`;o00008?ooool00ol0003oooooooooo`2@ooooo`00/oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo093ooooo002cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
T?ooool00;?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`2?ooooo`00/oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08oooooo002cooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0Soooool00;?ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`2?ooooo`00/oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo08oooooo
002cooooo`;o00008Oooool00ol0003oooooooooo`2?ooooo`00/oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo08kooooo002cooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0S_ooool00;?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2>ooooo`00
/oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo08kooooo0020ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0S_oo
ool0083ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0SOooool0083ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo00?ooooo0ol0000Rooooo`03o`000?oooooooooo08gooooo
0020ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0SOooool0
083ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
08gooooo0020ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
SOooool0083ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2<
ooooo`00P?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo1?l00006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0S?ooool00;?ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`2<ooooo`00/oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo08cooooo002cooooo`;o00009?ooool00ol0003oooooooooo`2<
ooooo`00/oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08cooooo002cooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0Roooool00;?ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`2;ooooo`00/oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo08_ooooo002cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Roooool0
0;?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2;ooooo`00/oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo08_ooooo002cooooo`;o00009_ooool00ol0003ooooo
ooooo`2:ooooo`00/oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08[ooooo002c
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0R_ooool00;?ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`2:ooooo`00/oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo08[ooooo002cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
R_ooool00;?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`29ooooo`00/oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08Wooooo002cooooo`;o00009oooool00ol0
003oooooooooo`29ooooo`00/oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08Wo
oooo002cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0ROooool00;?ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`29ooooo`00/oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo08Wooooo002cooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0ROooool00;?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`28ooooo`00
/oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08Sooooo002cooooo`;o0000:?oo
ool00ol0003oooooooooo`28ooooo`00/oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo08Sooooo002cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0R?ooool00;?o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`28ooooo`00/oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo08Sooooo0028ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`28ooooo`00R?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08Sooooo0028
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`28ooooo`00R?ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`05ooooo`?o0000:?ooool00ol0003oooooooooo`27ooooo`00R?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0Qoooool008Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oooooo0028ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`27ooooo`00R?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00omEEEGo
IVIVo`000007ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Qoooool00;?ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`27ooooo`00/oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo08Oooooo002cooooo`;o0000:Oooool00ol0003oooooooooo`27
ooooo`00/oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oooooo002cooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0Qoooool00;?ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`26ooooo`00/oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo08Kooooo002cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Q_ooool0
0;?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`26ooooo`00/oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo08Kooooo002cooooo`;o0000:_ooool00ol0003ooooo
ooooo`26ooooo`00/oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08Kooooo002c
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Q_ooool00;?ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`26ooooo`00/oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo08Kooooo002cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
QOooool00;?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`25ooooo`00/oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Gooooo002cooooo`;o0000:oooool00ol0
003oooooooooo`25ooooo`00/oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Go
oooo002cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0QOooool00;?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`25ooooo`00/oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo08Gooooo002cooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0QOooool00;?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`25ooooo`00
/oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Gooooo002cooooo`;o0000;?oo
ool00ol0003oooooooooo`24ooooo`00/oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo08Cooooo002cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q?ooool00;?o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`24ooooo`00/oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo08Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, 0, 0, 0}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(f'\)[0.2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.192"],

Cell[BoxData[
    \(0.008225000000000001`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe interpolating function is guaranteed to equal the original data at \
the given data points, and connects the data points \"as smoothly as possible\
\".  In more detail, what this means is that the interpolating function \
consists of a set of cubic polynomials. Each polynomial in the set is applied \
only between two corresponding consecutive data points.  The polynomials are \
\"spliced together\" at each data point  to form a function that  is \
continuous and has continuous first and second derivatives. (The  hidden \
argument in the interpolating function is a list of the coefficients in this \
set of polynomials.) This type of interpolation is commonly called a ",
  StyleBox["cubic spline ",
    FontSlant->"Italic"],
  "interpolation. General spline fits can allow the fitting function to be \
multi-valued (i.e. several values of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " are possible for a given value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", as in a circle), but the implementation used in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  assumes a single-valued function. For this reason, the data must be such \
that no two ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " values are the same. (If you need to fit data to a multi-valued function, \
read about the function ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the add-on package ",
  StyleBox["NumericalMath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".)"
}], "Text",
  CellTags->"i:127"],

Cell[TextData[{
  "\tIn a cubic spline interpolation the third derivative will not be \
continuous in general, as one can see in Cell ",
  ButtonBox["9.193",
    ButtonData:>"Cell 9.193",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[\(f'''\)[x]], {x, \(-1\), 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.193"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.011457 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .12929 -12 -4.5 ]
[.4875 .12929 0 4.5 ]
[.4875 .24386 -12 -4.5 ]
[.4875 .24386 0 4.5 ]
[.4875 .35843 -12 -4.5 ]
[.4875 .35843 0 4.5 ]
[.4875 .473 -12 -4.5 ]
[.4875 .473 0 4.5 ]
[.4875 .58757 -12 -4.5 ]
[.4875 .58757 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12929 m
.50625 .12929 L
s
[(10)] .4875 .12929 1 0 Mshowa
.5 .24386 m
.50625 .24386 L
s
[(20)] .4875 .24386 1 0 Mshowa
.5 .35843 m
.50625 .35843 L
s
[(30)] .4875 .35843 1 0 Mshowa
.5 .473 m
.50625 .473 L
s
[(40)] .4875 .473 1 0 Mshowa
.5 .58757 m
.50625 .58757 L
s
[(50)] .4875 .58757 1 0 Mshowa
.125 Mabswid
.5 .03763 m
.50375 .03763 L
s
.5 .06054 m
.50375 .06054 L
s
.5 .08346 m
.50375 .08346 L
s
.5 .10637 m
.50375 .10637 L
s
.5 .1522 m
.50375 .1522 L
s
.5 .17511 m
.50375 .17511 L
s
.5 .19803 m
.50375 .19803 L
s
.5 .22094 m
.50375 .22094 L
s
.5 .26677 m
.50375 .26677 L
s
.5 .28968 m
.50375 .28968 L
s
.5 .3126 m
.50375 .3126 L
s
.5 .33551 m
.50375 .33551 L
s
.5 .38134 m
.50375 .38134 L
s
.5 .40425 m
.50375 .40425 L
s
.5 .42717 m
.50375 .42717 L
s
.5 .45008 m
.50375 .45008 L
s
.5 .49591 m
.50375 .49591 L
s
.5 .51882 m
.50375 .51882 L
s
.5 .54174 m
.50375 .54174 L
s
.5 .56465 m
.50375 .56465 L
s
.5 .61048 m
.50375 .61048 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .60332 L
.04262 .60332 L
.04517 .60332 L
.04642 .60332 L
.04758 .60332 L
.04822 .60332 L
.04891 .60332 L
.05035 .60332 L
.05288 .60332 L
.06244 .60332 L
.06743 .60332 L
.06887 .60332 L
.06958 .60332 L
.07023 .60332 L
.07146 .54145 L
.07211 .54145 L
.0728 .54145 L
.0825 .54145 L
.08846 .54145 L
.09139 .54145 L
.09267 .54145 L
.09335 .54145 L
.09408 .54145 L
.09535 .48302 L
.09653 .48302 L
.09912 .48302 L
.10458 .48302 L
.10951 .48302 L
.11475 .48302 L
.11749 .48302 L
.11823 .48302 L
.11904 .48302 L
.1198 .42803 L
.1205 .42803 L
.12582 .42803 L
.13562 .42803 L
.138 .42803 L
.14055 .42803 L
.1413 .42803 L
.14201 .42803 L
.14265 .42803 L
.14334 .37647 L
.144 .37647 L
.14469 .37647 L
.14594 .37647 L
.15538 .37647 L
.16058 .37647 L
.16314 .37647 L
.16439 .37647 L
Mistroke
.16551 .37647 L
.16666 .37647 L
.16773 .32835 L
.16887 .32835 L
.17009 .32835 L
.17508 .32835 L
.18383 .32835 L
.18621 .32835 L
.18752 .32835 L
.18876 .32835 L
.18991 .32835 L
.19117 .28367 L
.19231 .28367 L
.19336 .28367 L
.20381 .28367 L
.20908 .28367 L
.21167 .28367 L
.2128 .28367 L
.21403 .28367 L
.21524 .24242 L
.21652 .24242 L
.21919 .24242 L
.22488 .24242 L
.23019 .24242 L
.23279 .24242 L
.23518 .24242 L
.23631 .24242 L
.23737 .24242 L
.23847 .20462 L
.23967 .20462 L
.24453 .20462 L
.25465 .20462 L
.25756 .20462 L
.25899 .20462 L
.26032 .20462 L
.26152 .20462 L
.2628 .17024 L
.26408 .17024 L
.2655 .17024 L
.27491 .17024 L
.28004 .17024 L
.28254 .17024 L
.28364 .17024 L
.28482 .17024 L
.28611 .13931 L
.28733 .13931 L
.29001 .13931 L
.29569 .13931 L
.30084 .13931 L
.30336 .13931 L
Mistroke
.30567 .13931 L
.30678 .13931 L
.308 .13931 L
.30915 .13931 L
.31022 .11181 L
.31146 .11181 L
.31259 .11181 L
.31512 .11181 L
.32552 .11181 L
.32805 .11181 L
.33073 .11181 L
.33212 .11181 L
.33292 .11181 L
.33366 .08775 L
.33496 .08775 L
.33635 .08775 L
.34655 .08775 L
.35149 .08775 L
.3542 .08775 L
.35552 .08775 L
.35674 .08775 L
.35805 .06713 L
.35875 .06713 L
.35947 .06713 L
.36249 .06713 L
.36781 .06713 L
.37246 .06713 L
.37742 .06713 L
.37889 .06713 L
.37961 .06713 L
.38028 .06713 L
.38152 .04995 L
.38218 .04995 L
.38287 .04995 L
.38794 .04995 L
.39738 .04995 L
.4001 .04995 L
.40144 .04995 L
.40268 .04995 L
.40381 .04995 L
.405 .0362 L
.40568 .0362 L
.40632 .0362 L
.40752 .0362 L
.41627 .0362 L
.42089 .0362 L
.42584 .0362 L
.42721 .0362 L
.4285 .0362 L
.42966 .02589 L
Mistroke
.43091 .02589 L
.43564 .02589 L
.44066 .02589 L
.44598 .02589 L
.44818 .02589 L
.45055 .02589 L
.45125 .02589 L
.45191 .02589 L
.45315 .01901 L
.45432 .01901 L
.45559 .01901 L
.46447 .01901 L
.46702 .01901 L
.46977 .01901 L
.47104 .01901 L
.47173 .01901 L
.47238 .01901 L
.47352 .01901 L
.47478 .01901 L
.47599 .01901 L
.47714 .01557 L
.47817 .01557 L
.47929 .01557 L
.48051 .01557 L
.4818 .01557 L
.48291 .01557 L
.48413 .01557 L
.48545 .01557 L
.48612 .01557 L
.48684 .01557 L
.48813 .01557 L
.48933 .01557 L
.49006 .01557 L
.49075 .01557 L
.49204 .01557 L
.49272 .01557 L
.49344 .01557 L
.49422 .01557 L
.49494 .01557 L
.49615 .01557 L
.49744 .01557 L
.49866 .01557 L
.49978 .01557 L
.50108 .01557 L
.50182 .01557 L
.50251 .01557 L
.50376 .01557 L
.50446 .01557 L
.5051 .01557 L
.5063 .01557 L
Mistroke
.50743 .01557 L
.50999 .01557 L
.51514 .01557 L
.5196 .01557 L
.52088 .01557 L
.5221 .01557 L
.52319 .01557 L
.52437 .01901 L
.52566 .01901 L
.52687 .01901 L
.52963 .01901 L
.5352 .01901 L
.53998 .01901 L
.54251 .01901 L
.5439 .01901 L
.5452 .01901 L
.54649 .01901 L
.54721 .01901 L
.54788 .02589 L
.54906 .02589 L
.55031 .02589 L
.55506 .02589 L
.56041 .02589 L
.56542 .02589 L
.5676 .02589 L
.56967 .02589 L
.57082 .02589 L
.57206 .0362 L
.57319 .0362 L
.57424 .0362 L
.58393 .0362 L
.58855 .0362 L
.59098 .0362 L
.5923 .0362 L
.59354 .0362 L
.59462 .0362 L
.59578 .04995 L
.59707 .04995 L
.59824 .04995 L
.60256 .04995 L
.60764 .04995 L
.61315 .04995 L
.61567 .04995 L
.61706 .04995 L
.61835 .04995 L
.61945 .06713 L
.62064 .06713 L
.62315 .06713 L
.63326 .06713 L
.63603 .06713 L
Mistroke
.63898 .06713 L
.64042 .06713 L
.64112 .06713 L
.64177 .06713 L
.64298 .08775 L
.64429 .08775 L
.65469 .08775 L
.65976 .08775 L
.66439 .08775 L
.66547 .08775 L
.66662 .08775 L
.66788 .11181 L
.66905 .11181 L
.67347 .11181 L
.68322 .11181 L
.68565 .11181 L
.68694 .11181 L
.68828 .11181 L
.68947 .11181 L
.69076 .13931 L
.69194 .13931 L
.69304 .13931 L
.69824 .13931 L
.70388 .13931 L
.70654 .13931 L
.70936 .13931 L
.71176 .13931 L
.71242 .13931 L
.71313 .13931 L
.71441 .17024 L
.71568 .17024 L
.71707 .17024 L
.7196 .17024 L
.72434 .17024 L
.72902 .17024 L
.73158 .17024 L
.73399 .17024 L
.73625 .17024 L
.73752 .17024 L
.73868 .20462 L
.73967 .20462 L
.74075 .20462 L
.74293 .20462 L
.74819 .20462 L
.75317 .20462 L
.75764 .20462 L
.75886 .20462 L
.76016 .20462 L
.76127 .20462 L
.76249 .24242 L
Mistroke
.76315 .24242 L
.76388 .24242 L
.7652 .24242 L
.76769 .24242 L
.77329 .24242 L
.77815 .24242 L
.78071 .24242 L
.78342 .24242 L
.78473 .24242 L
.78548 .24242 L
.78618 .28367 L
.78741 .28367 L
.78872 .28367 L
.79372 .28367 L
.80307 .28367 L
.80577 .28367 L
.80719 .28367 L
.80797 .28367 L
.8087 .28367 L
.81002 .32835 L
.81072 .32835 L
.81147 .32835 L
.81404 .32835 L
.81922 .32835 L
.82404 .32835 L
.82866 .32835 L
.82999 .32835 L
.83125 .32835 L
.83237 .32835 L
.8336 .37647 L
.83486 .37647 L
.83624 .37647 L
.83904 .37647 L
.84406 .37647 L
.84931 .37647 L
.85221 .37647 L
.85363 .37647 L
.85495 .37647 L
.85619 .37647 L
.8575 .42803 L
.85825 .42803 L
.85896 .42803 L
.86028 .42803 L
.86515 .42803 L
.87493 .42803 L
.87731 .42803 L
.87862 .42803 L
.87985 .42803 L
.88055 .42803 L
.88132 .48302 L
Mistroke
.88201 .48302 L
.88265 .48302 L
.88525 .48302 L
.89415 .48302 L
.89882 .48302 L
.90136 .48302 L
.90261 .48302 L
.90373 .48302 L
.90489 .54145 L
.90614 .54145 L
.90876 .54145 L
.91337 .54145 L
.92242 .54145 L
.92489 .54145 L
.92624 .54145 L
.92751 .54145 L
.92817 .54145 L
.92887 .60332 L
.92966 .60332 L
.93038 .60332 L
.93302 .60332 L
.94303 .60332 L
.94702 .60332 L
.94921 .60332 L
.95028 .60332 L
.95127 .60332 L
.9522 .60332 L
.95319 .60332 L
.95419 .60332 L
.95527 .60332 L
.9589 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`004oooool4o`000003oa0@4?oooooooooo047ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM08Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM04Cooooo
1?l000000ol@413oooooooooo`0>ooooo`005Oooool00ol0003oooooooooo`13ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Qoooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo04Gooooo00?o0000oooooooo
ool04?ooool000[ooooo1_l00005ooooo`03o`000?oooooooooo03_ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`26ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo000Eooooo`03
o`000?oooooooooo04?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
08Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo04Gooooo00?o0000
ooooooooool04?ooool001Gooooo00?o0000ooooooooool0@oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c028ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<04Kooooo00?o0000ooooooooool04?ooool001Gooooo
00?o0000ooooooooool0@oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool0R_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0@ooooo`005Oooool00ol0003oooooooooo`13ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`2:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo013ooooo000Cooooo`03oeEEEOmVIVKo0000
04Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00015ooooo`03oeEEEOmVIVKo000001;ooooo003oooooofWooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo0008oooooooo0000F?l00009ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool9o`0000Oooooo00?o0000oooooooo
ool01Oooool9o`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo013ooooo002Kooooo`Wo00003ooo
ool00ol0003oooooooooo`0=ooooo`Wo0000W?ooool009_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09[ooooo002Kooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Jooooo`00Voooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0VOooool009?ooooo
2Ol0000Gooooo`;o00005oooool8o`0009Cooooo002Cooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`2Booooo`00Toooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0T_ooool009;ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo097ooooo002Booooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Aooooo`00
Roooool8o`00023ooooo00?o0000ooooooooool07_ooool8o`0008cooooo002;ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`2:ooooo`00Roooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0R_ooool0
08_ooooo00?o0000ooooooooool09Oooool2o`0002Kooooo00?o0000ooooooooool0R_ooool008[o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08Wo
oooo002:ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`29ooooo`00Poooool8o`0002Sooooo00?o0000ooooooooool09_ooool8o`0008Cooooo0023
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`22
ooooo`00Poooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0P_ooool008?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo08;ooooo0022ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`21ooooo`00P_ooool00ol0003oooooooooo`0^ooooo`;o0000;ooo
ool00ol0003oooooooooo`21ooooo`00P_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0POooool007[ooooo2Ol0000`ooooo`03o`000?oooooooooo
02kooooo2Ol0001kooooo`00N_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0NOooool007[ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo07Wooooo001jooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1iooooo`00N_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0NOooool007[ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Wooooo001jooooo`03
o`000?oooooooooo03Kooooo0_l0000gooooo`03o`000?oooooooooo07Wooooo001jooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1iooooo`00L_oo
ool9o`0003Sooooo00?o0000ooooooooool0=_ooool9o`0007?ooooo001booooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1aooooo`00L_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0LOooool007;o
oooo00?o0000ooooooooool0;?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h6ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0LOooool007;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo077ooooo001booooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`1aooooo`00L_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000?_oo
ool00ol0003oooooooooo`1aooooo`00L_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0LOooool007;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo077ooooo001Zooooo`Wo0000<?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0nooooo`Wo0000Joooool006[ooooo00?o0000
ooooooooool0=?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo06Wooooo001Zooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Yooooo`00J_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0JOooool006[o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo06Wo
oooo001Zooooo`03o`000?oooooooooo04Kooooo0_l00017ooooo`03o`000?oooooooooo06Wooooo
001Zooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`1Yooooo`00J_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0JOooool006[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo06Wooooo001Zooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1Yooooo`00J_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0JOooool006;ooooo2Ol00018ooooo`03o`000?oo
oooooooo04Kooooo2Ol0001Sooooo`00H_ooool00ol0003oooooooooo`1>ooooo`;o0000Coooool0
0ol0003oooooooooo`1Qooooo`00H_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0HOooool006;ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Rooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qooooo`00H_ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool006;ooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Roooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Qoooo
o`00H_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0HOooool006;ooooo00?o0000ooooooooool0C_ooool2o`0004oooooo00?o0000ooooooooool0
HOooool006;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo067ooooo001Jooooo`Wo0000D?ooool00ol0003oooooooooo`1>ooooo`Wo0000Foooool0
05[ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
05Wooooo001Jooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`1Iooooo`00F_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool0FOooool005[ooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo05Wooooo001Jooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool0E_ooool00ol0003oooooooooo`1Iooooo`00F_ooool00ol0003oooooooooo`1Foooo
o`;o0000Eoooool00ol0003oooooooooo`1Iooooo`00FOooool00ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool005Wooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05Sooooo001Iooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`1Hooooo`00FOooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool0
05Wooooo00?o0000ooooooooool0A?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool005Wooooo00?o0000oooo
ooooool0A?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0F?ooool005;ooooo2?l00017
ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo05Oooooo2?l0001Cooooo`00D_ooool00ol0003oooooooooo`1=ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000G_ooool00ol0003ooooooooo
o`1Aooooo`00D_ooool00ol0003oooooooooo`1>ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0DOoo
ool005;ooooo00?o0000ooooooooool0Coooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool01?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo057ooooo001B
ooooo`03o`000?oooooooooo04_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo057ooooo
001Booooo`03o`000?oooooooooo04_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo057o
oooo001Booooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0G_ooool00ol0003ooooo
ooooo`1Aooooo`00D_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0DOooool0057ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo053ooooo001Aooooo`03o`000?oooooooooo05oooooo0_l0001Poooo
o`03o`000?oooooooooo053ooooo001Aooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`1@ooooo`00DOooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0D?ooool0057ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo053ooooo001Aooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1@ooooo`00B_ooool8o`00
067ooooo00?o0000ooooooooool0Goooool8o`0004_ooooo001:ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003ooooo
ooooo`1Vooooo`;o0000Ioooool00ol0003oooooooooo`19ooooo`00B_ooool00ol0003ooooooooo
o`1Vooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0BOooool004[ooooo00?o0000
ooooooooool0I_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo04Wooooo001:oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`19oooo
o`00B_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0BOooool004[ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo04Wooooo001:ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`19ooooo`00BOooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0Ioooool2o`00
06Sooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo04Sooooo0019ooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`18ooooo`00BOooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0B?ooool004Wooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo04Sooooo0019oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`18oooo
o`00@_ooool8o`0006Wooooo00?o0000ooooooooool0Ioooool8o`0004?ooooo0012ooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`11ooooo`00@_oo
ool00ol0003oooooooooo`1^ooooo`;o0000Koooool00ol0003oooooooooo`11ooooo`00@_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0@Oooool0
04;ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo
047ooooo0012ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`11ooooo`00@_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo06kooooo
00?o0000ooooooooool0@Oooool004;ooooo00?o0000ooooooooool0Foooool01OnHV9So410@o`00
0?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool0@Oooool004;ooooo00?o0000ooooooooool0Foooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool0@Oooool0047ooooo00?o0000ooooooooool0H?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo043ooooo0011ooooo`03o`000?oooooooooo05oooooo00?oZJVYoa0@4?oo
ool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0001_ooooo`03o`000?oooooooooo
043ooooo0011ooooo`03o`000?oooooooooo05kooooo00?o410@o`000?nj^[X00oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`10oooo
o`00@Oooool00ol0003oooooooooo`1Oooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0@?ooool0047o
oooo00?o0000ooooooooool0G?ooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0@?ooool0
047ooooo00?o0000ooooooooool0G?ooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0@?oo
ool0047ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo043ooooo000iooooo`Wo0000LOooool00ol0003oooooooooo`1_ooooo`Wo0000>_ooool003Wo
oooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03So
oooo000iooooo`03o`000?oooooooooo07Oooooo0_l0001hooooo`03o`000?oooooooooo03Sooooo
000iooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`0hooooo`00>Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0>?ooool003Wooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo03Sooooo000iooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`0hooooo`00>Oooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooooooool0>?ooool003Wooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Sooooo000iooooo`03o`000?oooooo
oooo07Oooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0hooooo`00>Oooool00ol0
003oooooooooo`1gooooo`;o0000N?ooool00ol0003oooooooooo`0hooooo`00>Oooool00ol0003o
ooooooooo`1gooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0>?ooool003Wooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Sooooo
000iooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`0hooooo`00>Oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo07Oooooo00?o0000
ooooooooool0>?ooool003Wooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo03Sooooo000iooooo`03o`000?oooooooooo07Oooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`0hooooo`00>Oooool00ol0003oooooooooo`1gooooo`;o0000
N?ooool00ol0003oooooooooo`0hooooo`00<Oooool9o`0007Wooooo00?o0000ooooooooool0Mooo
ool9o`0003;ooooo000aooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0<?ooool0037ooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo033ooooo000aooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0<?ooool0037ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo033ooooo000aoooo
o`03o`000?oooooooooo07oooooo0_l00020ooooo`03o`000?oooooooooo033ooooo000aooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0`ooooo`00
<Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
<?ooool0037ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo033ooooo000aooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0<?ooool0037ooooo00?o0000ooooooooool0K_ooool2o`000009
oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0`ooooo`00<Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0<?ooool0037ooooo00?o0000ooooooooool0K?ooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`?o0000Ooooool00ol0003oooooooooo`0`ooooo`00<Oooool0
0ol0003oooooooooo`1/ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0<?ooool0037ooooo00?o
0000ooooooooool0K?ooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo033ooooo000Yooooo`Wo0000
Koooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`1oooooo`Wo0000:_ooool002Wooooo00?o0000ooooooooool0MOooool00oo^k^koA4A4
o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo07Kooooo00?oMgMgo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo08Oooooo0_l00028
ooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo08Oooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Xooooo`00:Oooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0:?ooool0
02Sooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
02Sooooo000Xooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`0Xooooo`00:?ooool00ol0003oooooooooo`28ooooo`;o0000R?ooool00ol0003ooooo
ooooo`0Xooooo`00:?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool0:?ooool002Sooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`27
ooooo`03o`000?oooooooooo02Sooooo000Xooooo`03o`000?oooooooooo08Sooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`0Xooooo`00:?ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0:?ooool002Sooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo02Sooooo000Xooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Xooooo`008Oooool8
o`0008[ooooo0_l00028ooooo`Wo00008_ooool0027ooooo00?o0000ooooooooool0Soooool00ol0
003oooooooooo`2?ooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo08oo
oooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003ooooo
ooooo`2?ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0027ooooo00?o
0000ooooooooool0Soooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo023ooooo000Q
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0P
ooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo08oooooo00?o0000oooo
ooooool08?ooool0027ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo08oooooo0_l0002@ooooo`03o`00
0?oooooooooo023ooooo000Qooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0Sooo
ool00ol0003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo08oooooo00?o0000ooooooooool08?ooool0023ooooo00?o0000ooooooooool0T?ooool00ol0
003oooooooooo`2?ooooo`03o`000?oooooooooo023ooooo000Pooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0Pooooo`008?ooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0023ooooo00?o
0000ooooooooool0O_ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0023ooooo
00?o0000ooooooooool0POooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool08?ooool0023ooooo00?o0000oooo
ooooool0P_ooool01?l0003oooooooooool@4103ooooo`03oa0@4?oooooooooo00Cooooo0ol0002?
ooooo`03o`000?oooooooooo023ooooo000Pooooo`03o`000?oooooooooo087ooooo00GoMgMgoc8b
<_ooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Soooool0
0ol0003oooooooooo`0Pooooo`008?ooool00ol0003oooooooooo`1nooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0Sooo
ool00ol0003oooooooooo`0Pooooo`008?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo08oooooo00?o
0000ooooooooool08?ooool0023ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`04
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2?ooooo`03o`000?oo
oooooooo023ooooo000Aoooooa3o0000P?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo08oooooo4Ol0000Booooo`00/oooool00ol0003oooooooooo`2b
ooooo`00/oooool00ol0003oooooooooo`2booooo`00/oooool2o`000;?ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -3, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "One can ask that higher-order (or lower-order) polynomials be used in the \
fitting, by choosing the option ",
  StyleBox["InterpolationOrder-> n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox[" ",
    FontWeight->"Bold"],
  "where ",
  StyleBox["n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the order of the polynomials. This is necessary if  third or \
higher-order derivatives of the interpolated data are required. An example is \
given in Cell ",
  ButtonBox["9.194",
    ButtonData:>"Cell 9.194",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:93"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f = Interpolation[data, InterpolationOrder \[Rule] 5];\)\), "\n", 
    \(\(Plot[\(f'''\)[x], {x, \(-1\), 1}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.194"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.0147151 0.00981006 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -12 -9 ]
[.2619 .00222 12 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .11282 -12 -4.5 ]
[.4875 .11282 0 4.5 ]
[.4875 .21092 -12 -4.5 ]
[.4875 .21092 0 4.5 ]
[.4875 .30902 -12 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .40712 -12 -4.5 ]
[.4875 .40712 0 4.5 ]
[.4875 .50522 -12 -4.5 ]
[.4875 .50522 0 4.5 ]
[.4875 .60332 -12 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-0.5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(0.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .11282 m
.50625 .11282 L
s
[(10)] .4875 .11282 1 0 Mshowa
.5 .21092 m
.50625 .21092 L
s
[(20)] .4875 .21092 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(30)] .4875 .30902 1 0 Mshowa
.5 .40712 m
.50625 .40712 L
s
[(40)] .4875 .40712 1 0 Mshowa
.5 .50522 m
.50625 .50522 L
s
[(50)] .4875 .50522 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(60)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .03434 m
.50375 .03434 L
s
.5 .05396 m
.50375 .05396 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .0932 m
.50375 .0932 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .15206 m
.50375 .15206 L
s
.5 .17168 m
.50375 .17168 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .23054 m
.50375 .23054 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .26978 m
.50375 .26978 L
s
.5 .2894 m
.50375 .2894 L
s
.5 .32864 m
.50375 .32864 L
s
.5 .34826 m
.50375 .34826 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .3875 m
.50375 .3875 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .44636 m
.50375 .44636 L
s
.5 .46598 m
.50375 .46598 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .52484 m
.50375 .52484 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .56408 m
.50375 .56408 L
s
.5 .5837 m
.50375 .5837 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .51168 L
.10458 .42058 L
.14415 .34341 L
.18221 .27686 L
.22272 .21429 L
.26171 .16211 L
.30316 .11529 L
.34309 .07863 L
.3815 .05117 L
.40095 .04018 L
.42237 .03036 L
.44268 .02324 L
.45178 .02075 L
.46172 .01852 L
.4671 .01752 L
.4721 .01674 L
.47727 .01606 L
.48196 .01556 L
.48658 .01518 L
.4887 .01505 L
.49093 .01493 L
.49332 .01483 L
.49438 .0148 L
.49552 .01477 L
.49675 .01474 L
.49789 .01473 L
.49859 .01472 L
.49925 .01472 L
.50049 .01472 L
.50163 .01472 L
.50286 .01474 L
.50401 .01476 L
.50508 .01478 L
.50754 .01486 L
.51014 .01498 L
.51268 .01513 L
.51504 .0153 L
.5204 .0158 L
.5293 .01694 L
.53882 .01863 L
.54906 .02096 L
.56016 .02411 L
.58032 .03146 L
.60019 .04077 L
.62123 .05287 L
.65912 .08044 L
.69946 .11799 L
.73829 .1621 L
.77956 .21759 L
Mistroke
.81932 .2794 L
.85757 .34659 L
.89827 .42644 L
.93745 .51144 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`004oooool4o`000003oa0@4?oooooooooo047ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM08Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM04Cooooo
1?l000000ol@413oooooooooo`0>ooooo`005Oooool00ol0003oooooooooo`13ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Qoooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo04Gooooo00?o0000oooooooo
ool04?ooool000[ooooo1_l00005ooooo`03o`000?oooooooooo03_ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`26ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo000Eooooo`03
o`000?oooooooooo04?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
08Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo04Gooooo00?o0000
ooooooooool04?ooool001Gooooo00?o0000ooooooooool0@oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c028ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<04Kooooo00?o0000ooooooooool04?ooool001Gooooo
00?o0000ooooooooool0@oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool0R_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0@ooooo`005Oooool00ol0003oooooooooo`13ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`2:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo013ooooo000Cooooo`03oeEEEOmVIVKo0000
04Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000ROooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00015ooooo`03oeEEEOmVIVKo000001;ooooo003oooooofWooooo002coooo
o`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`00
0?oooooooooo0;;ooooo002cooooo`03o`000?oooooooooo0;;ooooo002cooooo`03o`000?oooooo
oooo0;;ooooo0009oooooooo0000E_l0000:ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooo`000003o`0000[o
oooo00?o0000ooooooooool02_ooool4o`0000oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0?Oooool3o`0000kooooo00?o0000ooooooooool03Oooool4o`0003gooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`00W_ooool4o`00017ooooo00?o
0000ooooooooool04Oooool3o`0009kooooo002Kooooo`?o00005Oooool00ol0003oooooooooo`0D
ooooo`?o0000Voooool009Sooooo0ol0000Hooooo`03o`000?oooooooooo01Oooooo0ol0002Hoooo
o`00UOooool3o`0001_ooooo0_l0000Kooooo`?o0000UOooool009;ooooo0ol0000Nooooo`03o`00
0?oooooooooo01gooooo0_l0002Cooooo`00T?ooool2o`00027ooooo00?o0000ooooooooool07ooo
ool2o`00097ooooo002?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`2>ooooo`00SOooool2o`0002Cooooo00?o0000ooooooooool08_ooool2o`00
08kooooo002<ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`2;ooooo`00R_ooool2o`0002Oooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`2:ooooo`00ROooool00ol0003oooooooooo`0Wooooo`;o00009oooool2o`0008[ooooo0027
ooooo`;o0000:_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Oooooo0026oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:Oooool2o`0008Oooooo0024ooooo`;o
0000;Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Cooooo0023ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0;?ooool2o`0008Cooooo0022ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`21ooooo`00P?ooool2
o`00037ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`20ooooo`00Ooooool00ol0
003oooooooooo`0aooooo`;o0000<Oooool2o`00083ooooo001mooooo`;o0000=?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo07gooooo001looooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0<oooool2o`0007gooooo001kooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1jooooo`00N_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0NOooool007Wooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Sooooo001hooooo`03
o`000?oooooooooo03Sooooo0_l0000iooooo`03o`000?oooooooooo07Oooooo001gooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1fooooo`00M_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0MOoo
ool007Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo07Cooooo001dooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`1cooooo`00Loooool00ol0003oooooooooo`0[ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`1booooo`00L_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0LOoo
ool0077ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool3o`0003oooooo00?o0000ooooooooool0L?ooool0073ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo06oooooo001`ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`1^ooooo`00Koooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool0K_ooool006kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo06gooooo001]ooooo`03o`000?oooooooooo037ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`1/ooooo`00K?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0Joooool006_ooooo00?o0000ooooooooool0AOooool2o`00
04Kooooo00?o0000ooooooooool0J_ooool006[ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo06Wooooo001Yooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Xooooo`00JOooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Ioooool006Sooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo06Oooooo001Woooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1Voooo
o`00I_ooool00ol0003oooooooooo`1:ooooo`;o0000Boooool00ol0003oooooooooo`1Uooooo`00
IOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
I?ooool006Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo06?ooooo001Sooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1Rooooo`00H_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0HOooool006;ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo067ooooo001Qooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`1Pooooo`00H?ooool00ol0003ooooooooo
o`1@ooooo`;o0000DOooool00ol0003oooooooooo`1Oooooo`00Goooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0G_ooool005oooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo05kooooo001Nooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Mooooo`00
GOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
G?ooool005gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo05_ooooo001Looooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`1Kooooo`00Foooool00ol0003oooooooooo`1Eooooo`;o0000E_ooool00ol0
003oooooooooo`1Jooooo`00F_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Ko
oooo00?o0000ooooooooool0FOooool005[ooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo05Wooooo001Iooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool0Eoooool00ol0003oooooooooo`1Hooooo`00F?ooool00ol0003oooooooooo`15
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooooooo`1Gooooo`00F?ooool00ol0003oooooooooo`15ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`1Fooooo`00Eoooool00ol0003oooooooooo`17ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000FOooool00ol0003ooooo
ooooo`1Fooooo`00E_ooool00ol0003oooooooooo`19ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
EOooool005Gooooo00?o0000ooooooooool0Boooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05Cooooo
001Eooooo`03o`000?oooooooooo04cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Cooooo`00E?oo
ool00ol0003oooooooooo`19ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Cooooo`00
Doooool00ol0003oooooooooo`1:ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Boooo
o`00Doooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0DOooool005;ooooo00?o0000ooooooooool0G_ooool2o`0005oooooo00?o0000ooooooooool0
DOooool0057ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo053ooooo001Aooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`1?ooooo`00D?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0Coooool004oooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo04kooooo001?ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1=ooooo`00C_ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0COooool004gooooo00?o0000
ooooooooool0Hoooool2o`0006Cooooo00?o0000ooooooooool0C?ooool004gooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo04_ooooo001<ooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1;ooooo`00
Boooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
B_ooool004_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo04Wooooo001:ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooooooo`19ooooo`00BOooool00ol0003oooooooooo`1Wooooo`;o0000J?ooool00ol0
003oooooooooo`18ooooo`00BOooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool0Aoooool004Sooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo04Oooooo0017ooooo`03o`000?oooooooooo06Wooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`16ooooo`00Aoooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0AOooool004Kooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04Gooooo0016ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`14ooooo`00
AOooool00ol0003oooooooooo`1[ooooo`;o0000K?ooool00ol0003oooooooooo`14ooooo`00A?oo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0@ooo
ool004Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo04;ooooo0013ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`12ooooo`00@oooool00ol0003oooooooooo`1Jooooo`05oiRHV?l@413o0000oc8b
<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`11ooooo`00@_ooool00ol0003oooooooooo`1Kooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`11ooooo`00@Oooool00ol0003oooooooooo`1Pooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool0@?ooool0047ooooo00?o0000ooooooooool0Goooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0006oooooo00?o0000ooooooooool0@?oo
ool0043ooooo00?o0000ooooooooool0Goooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo03oooooo0010
ooooo`03o`000?oooooooooo063ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0nooooo`00?oooool0
0ol0003oooooooooo`1Nooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0nooooo`00?_oo
ool00ol0003oooooooooo`1Oooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0mooooo`00
?_ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0
?Oooool003gooooo00?o0000ooooooooool0Loooool2o`0007Cooooo00?o0000ooooooooool0??oo
ool003gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo03cooooo000looooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0kooooo`00>oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool0>oooool003_ooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo03[ooooo000jooooo`03o`000?oooooooooo07Kooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`0iooooo`00>_ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool0>Oooool003Wooooo00?o0000oooo
ooooool0Moooool2o`0007Sooooo00?o0000ooooooooool0>?ooool003Wooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo03Sooooo000hooooo`03o`00
0?oooooooooo07Sooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0gooooo`00>?oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0=ooo
ool003Oooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo03Kooooo000gooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0NOooool00ol0
003oooooooooo`0fooooo`00=_ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooooooool0=Oooool003Kooooo00?o0000ooooooooool0N_ooool2o`0007_ooooo
00?o0000ooooooooool0=Oooool003Gooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo03Cooooo000eooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`0dooooo`00=?ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool0<oooool003Cooooo00?o0000oooooooo
ool0O?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo03?ooooo000cooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0booooo`00<_oo
ool00ol0003oooooooooo`1nooooo`;o0000O_ooool00ol0003oooooooooo`0booooo`00<_ooool0
0ol0003oooooooooo`1nooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0<Oooool0
037ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
037ooooo000aooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`0aooooo`00<?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0<?ooool0033ooooo00?o0000ooooooooool0Koooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`0`ooooo`00;oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0;oooool002oooooo00?o0000ooooooooool0K_ooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`?o0000P?ooool00ol0003oooooooooo`0_ooooo`00;_ooool00ol0003o
ooooooooo`1_ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0;_ooool002kooooo00?o0000oooo
ooooool0Koooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo02kooooo000]ooooo`03o`000?oooooo
oooo077ooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`0]ooooo`00;Oooool00ol0003oooooooooo`1a
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0;Oooool002cooooo00?o0000ooooooooool0Loooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`23ooooo`03o`000?oooooooooo02cooooo000/ooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool0Poooool00ol0003oooooooooo`0/ooooo`00:oooool00ol0003oooooooooo`25oooo
o`;o0000QOooool00ol0003oooooooooo`0[ooooo`00:oooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool0:oooool002[ooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo02[ooooo000Zooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Zooooo`00:_ooool0
0ol0003oooooooooo`26ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0:Oooool0
02Wooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo
02Wooooo000Yooooo`03o`000?oooooooooo08Oooooo0_l00028ooooo`03o`000?oooooooooo02So
oooo000Xooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0Qoooool00ol0003ooooo
ooooo`0Xooooo`00:?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool09oooool002Oooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo02Oooooo000Wooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`0Vooooo`009_ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool09_ooool002Kooooo00?o0000ooooooooool0
R_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo02Gooooo000Uooooo`03o`000?oo
oooooooo08_ooooo0_l0002;ooooo`03o`000?oooooooooo02Gooooo000Uooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Tooooo`009Oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool09?ooool002Co
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo02Co
oooo000Tooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Sooooo`008oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool08oooool002?ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`2=
ooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo08kooooo0_l0002>oooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool0S_ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`2?ooooo`03o`00
0?oooooooooo08kooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000ooooooooool0Sooo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo023ooooo000Pooooo`03o`000?oooooo
oooo07kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo023ooooo000Pooooo`03o`000?oo
oooooooo087ooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo01oooooo000Pooooo`03o`000?oooooooooo08;o
oooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`04ooooo`?o0000T?ooool00ol0
003oooooooooo`0Oooooo`007oooool00ol0003oooooooooo`22ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool07_ooool001oooooo00?o0000ooooooooool0Ooooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo097ooooo00?o0000
ooooooooool07_ooool001kooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo
oooo01gooooo000Nooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`0M
ooooo`007Oooool00ol0003oooooooooo`21ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0Looooo`007Oooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool07?ooool001go
oooo00?o0000ooooooooool0Toooool2o`0009Cooooo00?o0000ooooooooool07?ooool001cooooo
00?o0000ooooooooool0U?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo01_ooooo
000Looooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0U?ooool00ol0003ooooooooo
o`0Kooooo`006oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo09Gooooo00?o0000
ooooooooool06_ooool001_ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`2Eoooo
o`03o`000?oooooooooo01[ooooo000Jooooo`03o`000?oooooooooo09Kooooo00?o0000oooooooo
ool0U_ooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2Fooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0U_oo
ool2o`0009Oooooo00?o0000ooooooooool06Oooool001Wooooo00?o0000ooooooooool0Uoooool0
0ol0003oooooooooo`2Gooooo`03o`000?oooooooooo01Sooooo000Iooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Hooooo`006?ooool00ol0003o
ooooooooo`2Hooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool05oooool001Sooooo
00?o0000ooooooooool0V?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo01Oooooo
000Gooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0Fooooo`005oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool05_ooool001Oooooo00?o0000ooooooooool0VOooool2o`0009[ooooo00?o0000oooo
ooooool05_ooool001Kooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`2Jooooo`03
o`000?oooooooooo01Gooooo000Fooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0Eooooo`005Oooool00ol0003oooooooooo`2Kooooo`03o`000?oo
oooooooo09_ooooo00?o0000ooooooooool05?ooool001Gooooo00?o0000ooooooooool0Voooool0
0ol0003oooooooooo`2Kooooo`03o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0Dooooo`005?ooool00ol0003o
ooooooooo`2Looooo`;o0000WOooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool04oooool001?ooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo01;ooooo000C
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0B
ooooo`004_ooool00ol0003oooooooooo`2;ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`0Aooooo`004_ooool00ol0003oooooooooo`2;ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B400ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`0Aooooo`004_ooool00ol0003oooooooooo`2;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0Aooooo`004Oooool00ol0003oooooooooo`2<ooooo`05o`000?nHV9SooooooiRHV?lQ
8B400oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0002Oooooo`03o`000?oooooooooo
013ooooo002Pooooo`05o`000?mEEEGo0000oa0@4?o<c<`00oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0/_ooool00:3ooooo00?oEEEEohN7Qoooool01Oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0/_ooool00:3ooooo00?ogMgMoa0@
4?nHV9P01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0/_ooool0
0:7ooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0/_ooool00;?ooooo00?o0000ooooooooool0/_ooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -4, 0, 0}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.11.4 Fitting", "Subsubtitle",
  CellTags->{"i:95", "c:64"}],

Cell[TextData[{
  "It is sometimes necessary to find an analytic function that fits given \
data as closely as possible. This can be accomplished with ",
  StyleBox["Mathematic",
    FontSlant->"Italic"],
  "a's ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The ",
  StyleBox["Fit ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function will fit a particular functional form to the data. The functional \
form is taken from  a list of functions provided by the user, such as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["{",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[
            RowBox[{
              StyleBox["1",
                FontFamily->"Courier"], 
              StyleBox[",",
                FontFamily->"Courier"], 
              StyleBox["x",
                FontFamily->"Courier",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier"], 
              StyleBox[
                SuperscriptBox[
                  StyleBox["x",
                    FontSlant->"Plain"], "2"],
                FontFamily->"Courier"], 
              StyleBox[",",
                FontFamily->"Courier"], 
              StyleBox[
                SuperscriptBox[
                  StyleBox["x",
                    FontSlant->"Plain"], "3"],
                FontFamily->"Courier"]}],
            FontWeight->"Bold"], 
          StyleBox["}",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the data itself as its first argument, and this list of functions \
as the second argument. The third argument is the variables used in the fit. \
In other words,  the proper syntax is ",
  StyleBox["Fit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["data",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["function list",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vars",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " then finds the best linear combination of functions appearing in ",
  StyleBox["function list ",
    FontSlant->"Italic"],
  "in order to fit the data.  For example, ",
  StyleBox["Fit[data,",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"1", ",", 
            StyleBox["x",
              FontSlant->"Plain"], ",", 
            SuperscriptBox[
              StyleBox["x",
                FontSlant->"Plain"], "2"], ",", 
            SuperscriptBox[
              StyleBox["x",
                FontSlant->"Plain"], "3"]}], "}"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",x] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "tries fits of the form ",
  Cell[BoxData[
      \(TraditionalForm\`a\  + \ b\ x\  + \ 
        c\ x\^\(\(2\)\(\ \)\)\  + \ \(\(d\)\(\ \)\(x\^3\)\(\ \)\)\)]],
  ". Here\[CloseCurlyQuote]s an example using the data created in Cell ",
  ButtonBox["9.188",
    ButtonData:>"Cell 9.188",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fit[data, {1, x, x^2, x^3, x^4, x^5}, x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.195"],

Cell[BoxData[
    \(\(-5.551115123125783`*^-17\) - 4.440892098500626`*^-16\ x + 
      4.440892098500626`*^-16\ x\^2 + 0.`\ x\^3 - 
      3.3306690738754696`*^-16\ x\^4 + 1.`\ x\^5\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Fit ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "has done a very good job reproducing the original function, ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5\)]],
  ", from the data set. All the terms except for the ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5\)]],
  " term have negligibly small coefficients."
}], "Text"],

Cell[TextData[{
  "\tFits to functional forms that do not involve simple linear combinations \
of functions can also be performed. The function ",
  StyleBox["NonlinearFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["Statistics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " add-on package can make such fits: see the help browser for more \
information."
}], "Text",
  CellTags->"i:132"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          RowBox[{
            
            StyleBox[\(Table  9  .23\ Numerical\ Operations\ on\ Data\ Sets\),
              
              FontSize->9], "\[IndentingNewLine]"}]},
        {
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Interpolation",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["data",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(Create\ a\ numerical\ interpolating\ \
function\ that\[IndentingNewLine]
                  
                  interpolates\ a\ data\ set\ by\ trying\ to\ smoothly\ go\ \
\[IndentingNewLine]
                  through\ each\ data\ point\)},
                {
                  
                  StyleBox[\(\(InterpolatingFunction[{xmin, xmax},  <> ]\)[
                      x]\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  
                  RowBox[{\(Evaluate\ an\ interpolating\ function\ at\), 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      RowBox[{"position", " ", 
                        StyleBox["x",
                          FontSlant->"Italic"]}], ",", 
                      RowBox[{
                        StyleBox["xmin",
                          FontSlant->"Italic"], 
                        StyleBox[" ",
                          FontSlant->"Italic"], "<", 
                        StyleBox["x",
                          FontSlant->"Italic"], " ", "<", 
                        StyleBox["xmax",
                          FontSlant->"Italic"]}]}]}]},
                {
                  RowBox[{
                    StyleBox["Fit",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["data",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[\(function\ list\),
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["vars",
                        FontSlant->"Italic"]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  
                  RowBox[{\(\(Fit\ data\ with\ a\ linear\ combination\)\
\[IndentingNewLine]\(of\ functions\), \(each\ function\ taken\)\), 
                    "\[IndentingNewLine]", 
                    RowBox[{"from", " ", 
                      StyleBox["function",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], 
                      StyleBox["list",
                        FontSlant->"Italic"], 
                      StyleBox["     ",
                        FontSlant->"Italic"]}]}]}
                },
              ColumnSpacings->1.8,
              ColumnAlignments->{Left}],
            FontFamily->"Times"]}
        }]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell["Reading Data from External Files", "Section",
  CellTags->"c:82"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has several intrinsic functions that can be used to import data.  First, \
you must place a file containing the data in one of the directories on your \
computer where ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " looks for files. The list of these directories is held in the variable ",
  StyleBox["$Path",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The current working directory is a member of this list, and it can be \
determined using the command "
}], "Text",
  CellTags->"i:128"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Directory[]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.196"],

Cell[BoxData[
    \("/Users/dubin"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "(In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " versions previous to 4.1, the  directory is specified using colons to \
denote subdirectories rather than the above backslash notation.) You can \
change the current working directory using the ",
  StyleBox["SetDirectory",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command.  For instance, to access files on my computer in a subdirectory \
named ",
  StyleBox["Documents",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the command is"
}], "Text",
  CellTags->"i:129"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\</Users/dubin/Documents\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.197"],

Cell[BoxData[
    \("/Users/dubin/Documents"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Within this directory, there is a file named ",
  StyleBox["datafile.dat",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that contains a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  list of the form ",
  StyleBox["data={{1.,3.},{Exp[-4x],5.*10^2},...};",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". (This file can also be found on the CD that came with the book.) The \
data in this file is read with the command"
}], "Text"],

Cell[BoxData[
    \(Get["\<datafile.dat\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.198"],

Cell[TextData[{
  "(This command is equivalent to ",
  StyleBox["<<datafile.dat",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".) The data within the file has now been defined:"
}], "Text",
  CellTags->"i:130"],

Cell[CellGroupData[{

Cell[BoxData[
    \(data\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.199"],

Cell[BoxData[
    \({{1.`, 3.`}, {\[ExponentialE]\^\(\(-4\)\ x\), 500.`}, {2.`, 
        2\ x + Sin[3\ y]}, {9.`, 12.`}, {6.`, 4.`}, {3.`, 2.`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the data can be in the form of general ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expressions as well as numbers. The ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command can be used to read in any definitions contained in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks, and in fact this is the  method used to load add-on packages \
(see Sec. ",
  ButtonBox["9.6.8",
    ButtonData:>"c:34",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellTags->"i:131"],

Cell[TextData[{
  "\tIt is not always convenient to format data in terms of a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " list. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can also read data in many other formats using the ",
  StyleBox["Import",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. For example, in order to read a simple tab- or space-delimited \
set of data of the form\n\t\t-2.\t3.\t1.\n\t\t4.\t6.\t-5.2\n\t\t2.\t-2.e-5\t\
6.e12\nthat is contained in a file named ",
  StyleBox["tabdata.dat",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the syntax is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Import["\<tabdata.dat\>", \ "\<Table\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.200"],

Cell[BoxData[
    \({{\(-2.`\), 3.`, 1.`}, {4.`, 6.`, \(-5.2`\)}, {2.`, \(-0.00002`\), 
        6.`*^12}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here, ",
  StyleBox["\"Table\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the format of the data.  Other possible formats include \
standard binary, sound, and even image data formats: see ",
  ButtonBox["Cell 2.68",
    ButtonData:>{"Chapter2.nb", "Cell 2.68"},
    ButtonStyle->"Hyperlink"],
  " in Chapter 2 for an example involving a sound file. Allowed formats \
depend on the computer system. This information can be found in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  help browser. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 9.11", "Subsubtitle",
  CellTags->{"Ex. 9.11", "c:65"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Solve the following equation numerically, finding all real roots:  ",
  Cell[BoxData[
      \(TraditionalForm\`\(log\^2\) x + 2 = x\)]],
  ". (Hint: Use a plot to pick out locations of the roots)."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Find numerical values for all complex solutions to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-3\)\ z\) = z + 2\)]],
  "  in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-4\) < x < 4, \ \(-4\) < y < 4\)]],
  ",  where ",
  Cell[BoxData[
      \(TraditionalForm\`z = x + \[ImaginaryI]\ y\)]],
  ". (Hint: Use contour plots to plot the real and imaginary parts of the \
equation vs. ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " to find approximate locations of roots.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Find numerical values for the following definite integrals that are \
accurate to at least six significant figures. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(2\ \[Pi]\)\(sin(\@x\ \(cos(
                x)\))\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\( \
\[ExponentialE]\^\(-x\)\/\(log\ x\)\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(2\ \[Pi]\)\(sin(
            cos(x\^3))\) \[DifferentialD]x\)]],
  ". (Be careful with this one: take a look at a plot of the function!)"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " The following table produces some data:"
}], "Text"],

Cell[BoxData[
    \(data\  = \ Table[{x, f[x]}, {x, 0, 10,  .01}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.201"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ sin\ x\)]],
  ", interpolate the data. Plot the difference between the resulting \
interpolating function and ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ x\)]],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 10\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "Repeat the problem for a more rapidly varying function, ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \ sin(10\ x)\)]],
  ". What does one learn from this exercise?"
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " The following table produces some data with noise added:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["data",
        FontFamily->"Courier",
        FontWeight->"Bold"], 
      StyleBox["=",
        FontFamily->"Courier",
        FontWeight->"Bold"], 
      RowBox[{
        StyleBox["Table",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        StyleBox["[",
          FontFamily->"Courier",
          FontWeight->"Bold"], 
        RowBox[{
          RowBox[{
            StyleBox["{",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["x",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                RowBox[{
                  StyleBox["Tanh",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["x",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["]",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], 
                StyleBox[" ",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["+",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox[" ",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox[\(0.1*\((Random[] - 0.5)\)\),
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}]}], 
            StyleBox["}",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], 
          StyleBox[",",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["{",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["x",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox[\(-3\),
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox[",",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["0.1",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            StyleBox["}",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], 
        StyleBox["]",
          FontFamily->"Courier",
          FontWeight->"Bold"]}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.202"],

Cell[TextData[{
  "(The ",
  Cell[BoxData[
      \(TraditionalForm\`Random[]\)],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function produces a pseudo-random number in the interval [0,1].) Fit this \
data to a  sixth order polynomial, and plot the fitted function and the data \
on the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < x < 3\)]],
  ". "
}], "Text",
  CellTags->"i:97"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " In this exercise we will design our own numerical root finder using \
Newton's method. We will solve the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(x)\  = \ 0\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is some general function, depicted in Fig. ",
  ButtonBox["9.7",
    ButtonData:>"Fig. 9.7",
    ButtonStyle->"Hyperlink"],
  ". We are given an initial guess, ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\(x\_o\)\(.\)\)\)]],
  " This is not a solution to the equation; instead, ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " takes on a value ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_o)\  \[NotEqual] \ 0\)]],
  ". In Newton's method we obtain an improved estimate for the solution by \
replacing ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " by its Taylor expansion to linear order, about ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ x\_o\)]],
  ":"
}], "Text",
  CellTags->"i:124"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  \[TildeEqual] \ 
        f(x\_o)\  + \ \(\(f\^\[Prime]\)(x\_o)\) \((x - x\_o)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Using this approximation, we can then solve the equation ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = 0\)]],
  ", obtaining "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ 
        x\_o - \(f(x\_o)\)/\(\(f\^\[Prime]\)(x\_o)\)\)]],
  ". "
}], "NE5",
  CellTags->"(9.11.2)"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007k0001LB000`400?l00000o`00003ooooooool
ooooo`00ooooooolooooo`00ooooooolooooo`00ooooooolooooo`00ooooooolooooo`00oooooool
ooooo`00ooooooolooooo`00ooooooolooooo`00ooooooolooooo`003?oooolH0?ooo`030<30`020
P800`<300?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=
ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`03
0820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooo
b03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH
0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P820
0?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`00
3?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P000
0000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=
ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`03
0820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooo
b03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH
0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P820
0?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`00
3?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P000
0000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=
ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`03
0820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooo
b03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH
0?ooo`030820P0000000P8200?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P820
0?l0oooob03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200300oooo1`0000070820P?l0
ooooRP3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200300oooo4@0000001010@400P820
0820P030`<3o0?oooh<0oooo3Oooool000cooooo603oool00`20P80000000820P00g0?ooo`L0P820
2P0000030820P0030<30`03oool0oooo0?l0ooooNP3oool=ooooo`003?oooolH0?ooo`030820P000
0000P8200440oooo00@0`<300820P020P800@410200000000`10@400P8200<30`03o0?ooogP0oooo
3Oooool000cooooo603oool00`20P80000000820P0180?ooo`<0P8201`0000020820P?l0ooooM03o
ool=ooooo`003?oooolH0?ooo`030820P0000000P82004d0oooo0P20P80700000080P820o`3ooom`
0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800D@3oool00`30`<00P8200410@0050000
00030410@020P800`<300?l0ooooK03oool=ooooo`003?oooolH0?ooo`030820P0000000P82005D0
oooo00<0`<300820P010@4001@0000020820P0030<30`03oool0oooo0?l0ooooIP3oool=ooooo`00
3?oooolH0?ooo`030820P0000000P82005T0oooo0P20P80600000080P820o`3ooomU0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800G03oool00`30`<00P8200820P005000000030410@020
P800oooo0?l0ooooH@3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200600oooo00<0`<30
0820P010@400100000000`10@400P8200?ooo`3o0?oooeh0oooo3Oooool000cooooo603oool00`20
P80000000820P01T0?ooo`030820P010@400000000<0000000<0@4100<30`03oool0o`3ooomK0?oo
o`gooooo000<oooooaP0oooo00<0P82000000020P800I`3oool00`20P80000000000000300000003
0820P030`<00oooo0?l0ooooF03oool=ooooo`003?oooolH0?ooo`030820P0000000P82006T0oooo
00<0`<300820P0000000100000000`20P800`<300?ooo`3o0?oooeD0oooo3Oooool000cooooo603o
ool00`20P80000000820P01/0?ooo`030<30`010@400000000@0000000<0P8200?ooo`3oool0o`3o
oomB0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800K`3oool600000?l0ooooD`3oool=
ooooo`003?oooolH0?ooo`030820P0000000P8200700oooo0P20P804000000030410@030`<00oooo
0?l0ooooC`3oool=ooooo`003?oooolH0?ooo`030820P0000000P82007<0oooo00<0P8200410@000
00000P0000000`10@400P8200?ooo`3o0?ooodd0oooo3Oooool000cooooo603oool00`20P8000000
0820P01e0?ooo`030<30`020P800000000<0000000<0P8200?ooo`3oool0o`3ooom:0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800N03oool00`20P800@41000000002000000030820P03o
ool0oooo0?l0ooooB03oool=ooooo`003?oooolH0?ooo`030820P0000000P82007X0oooo00<0P820
0000000000000P0000000`20P800`<300?ooo`3o0?ooodH0oooo3Oooool000cooooo603oool00`20
P80000000820P01l0?ooo`030820P000000000000080000000<0@4100820P03oool0o`3ooom40?oo
o`gooooo000<oooooaP0oooo00<0P82000000020P800OP3oool00`20P800@4100000000300000003
0820P03oool0oooo0?l0oooo@@3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200800oooo
00<0`<300410@00000000`0000000`20P800oooo0?ooo`3o0?ooocl0oooo3Oooool000cooooo603o
ool00`20P80000000820P0230?ooo`060820P0000000000000000010@400`<30o`3ooolo0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800Q@3oool01@20P8000000000000000000P8200?l0
oooo?P3oool=ooooo`003?oooolH0?ooo`030820P0000000P82008H0oooo00<0`<300410@0000000
0P0000000`30`<00oooo0?ooo`3o0?ooocX0oooo3Oooool000cooooo603oool00`20P80000000820
P0280?ooo`050<30`010@400000000000010@400o`3ooolk0?ooo`gooooo000<oooooaP0oooo00<0
P82000000020P800RP3oool01@20P8000000000000000000`<300?l0oooo>@3oool=ooooo`003?oo
oolH0?ooo`030820P0000000P82008`0oooo00D0P820000000000000@4100<30`03o0?ooocL0oooo
3Oooool000cooooo603oool00`20P80000000820P02=0?ooo`050<30`010@400000000000010@400
o`3ooolf0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800S`3oool01@20P80000000000
00000000`<300?l0oooo=03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200900oooo00D0
`<300410@000000000000410@03o0?oooc<0oooo3Oooool000cooooo603oool00`20P80000000820
P02B0?ooo`@0000000<0P8200?ooo`3oool0o`3oool_0?ooo`gooooo000<oooooaP0oooo00<0P820
00000020P800T`3oool01@10@4000000000000000000`<300?l0oooo<03oool=ooooo`003?oooolH
0?ooo`030820P0000000P82009@0oooo00D0`<3000000000000000000410@03o0?ooobl0oooo3Ooo
ool000cooooo603oool00`20P80000000820P02F0?ooo`050<30`0000000000000000030`<00o`3o
ool]0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800V03oool01010@400000000000010
@43o0?ooob`0oooo3Oooool000cooooo603oool00`20P80000000820P02I0?ooo`050<30`0000000
00000410@030`<00o`3ooolZ0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800V`3oool0
1010@400000000000020P83o0?ooobT0oooo3Oooool000cooooo603oool00`20P80000000820P02L
0?ooo`050<30`000000000000410@030`<00o`3ooolW0?ooo`gooooo000<oooooaP0oooo00<0P820
00000020P800WP3oool01010@400000000000020P83o0?ooobH0oooo3Oooool000cooooo603oool0
0`20P80000000820P02O0?ooo`040<30`000000000000410@?l0oooo9@3oool=ooooo`003?oooolH
0?ooo`030820P0000000P8200:40oooo0P0000000`10@400`<300?ooo`3o0?ooob80oooo3Oooool0
00cooooo603oool00`20P80000000820P02Q0?ooo`050<30`0000000000000000030`<00o`3ooolR
0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800XP3oool01@30`<00@410000000000000
`<300?l0oooo8@3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200:@0oooo00D0@4100000
00000000P8200<30`03o0?oooal0oooo3Oooool000cooooo603oool00`20P80000000820P02U0?oo
o`050410@0000000000000000030`<00o`3ooolN0?ooo`gooooo000<oooooaP0oooo00<0P8200000
0020P800YP3oool01@10@4000000000000000000`<300?l0oooo7@3oool=ooooo`003?oooolH0?oo
o`030820P0000000P8200:P0oooo00@0@410000000000000@410o`3ooolL0?ooo`gooooo000<oooo
oaP0oooo00<0P82000000020P800Z@3oool01010@400000000000010@43o0?oooa/0oooo3Oooool0
00cooooo603oool00`20P80000000820P02Z0?ooo`<0000000<0P8200?ooo`3oool0o`3ooolH0?oo
o`gooooo000<oooooaP0oooo00<0P82000000020P800ZP3oool01@30`<000000000000000000P820
0?l0oooo6@3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200:/0oooo00D0`<300410@000
000000000410@03o0?oooaP0oooo3Oooool000cooooo603oool00`20P80000000820P02]0?ooo`04
0410@000000000000410@?l0oooo5`3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200:h0
oooo00D0@410000000000000@4100<30`03o0?oooaD0oooo3Oooool000cooooo603oool00`20P800
00000820P02_0?ooo`050410@0000000000000000030`<00o`3ooolD0?ooo`gooooo000<oooooaP0
oooo00<0P82000000020P800/03oool01030`<00000000000010@43o0?oooa@0oooo3Oooool000co
oooo603oool00`20P80000000820P02a0?ooo`040<30`010@40000000410@?l0oooo4`3oool=oooo
o`003?oooolH0?ooo`030820P0000000P8200;<0oooo00<0@41000000010@400o`3ooolB0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800]03oool00`10@40000000410@03o0?oooa40oooo
3Oooool000cooooo603oool00`20P80000000820P02e0?ooo`030410@0000000@4100?l0oooo403o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200;H0oooo00<0@41000000010@400o`3oool?
0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800]`3oool00`10@40000000410@03o0?oo
o`h0oooo3Oooool000cooooo603oool00`20P80000000820P02h0?ooo`040410@000000000000<30
`?l0oooo303oool=ooooo`003?oooolH0?ooo`030820P0000000P8200;T0oooo00@0@41000000000
0000`<30o`3oool;0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800^@3oool01@30`<00
0000000000000000`<300?l0oooo2P3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200;/0
oooo00@0@410000000000000`<30o`3oool90?ooo`gooooo000<oooooaP0oooo00<0P82000000020
P800_03oool300000?l0oooo2@3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200;`0oooo
00@0`<30000000000000@410o`3oool80?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
_@3oool01030`<00000000000010@43o0?ooo`L0oooo3Oooool000cooooo603oool00`20P8000000
0820P02n0?ooo`040<30`000000000000410@?l0oooo1P3oool=ooooo`003?oooolH0?ooo`030820
P0000000P8200;l0oooo00@0`<30000000000000@410o`3oool50?ooo`gooooo000<oooooaP0oooo
00<0P82000000020P800`03oool01030`<00000000000010@43o0?ooo`@0oooo3Oooool000cooooo
603oool00`20P80000000820P0310?ooo`040<30`000000000000<30`?l0oooo0`3oool=ooooo`00
3?oooolH0?ooo`030820P0000000P8200<80oooo00@0`<30000000000000`<30o`3oool20?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800``3oool01010@400000000000030`<3o0?ooo`40
oooo3Oooool000cooooo603oool00`20P80000000820P0340?ooo`030410@0000000@4100?l0oooo
0@3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200<D0oooo00<0@41000000010@400o`3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200<D0oooo00@0`<30000000000000P820oP3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200<H0oooo00@0`<30000000000000`<30o@3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200<L0oooo00@0`<30000000000000`<30o03o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200<P0oooo00<0P820000000000000o03oool=
ooooo`003?oooolH0?ooo`030820P0000000P8200<T0oooo00<0@41000000010@400n`3oool=oooo
o`003?oooolH0?ooo`030820P0000000P8200<X0oooo00@0@410000000000000`<30n@3oool=oooo
o`003?oooolH0?ooo`030820P0000000P8200</0oooo0P0000000`10@400oooo0?ooo`3g0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800b`3oool01020P800000000000020P83h0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800c03oool01020P800000000000030`<3g0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800c@3oool00`30`<0000000000003g0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800O`3oool20<30`4d0oooo00<0@41000000010@400mP3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P82007h0oooo00@0`<30000000000000`<30C@3o
ool2000000030820P03oool0oooo0?<0oooo3Oooool000cooooo603oool00`20P80000000820P01o
0?ooo`050820P0000000000000000030`<00B`3oool01020P800000000000030`<3d0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800P03oool01@30`<000000000000000000`<3004/0oooo
00<0@410000000000000m03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200840oooo00@0
`<300820P00000000000C03oool2000000030410@03oool0oooo0?40oooo3Oooool000cooooo603o
ool00`20P80000000820P0230?ooo`80`<30C03oool01030`<00000000000020P83b0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800dP3oool01020P800000000000030`<3a0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800d`3oool00`10@40000000410@03a0?ooo`gooooo000<
oooooaP0oooo00<0P82000000020P800e03oool2000000030410@03oool0oooo0>h0oooo3Oooool0
00cooooo603oool00`20P80000000820P03D0?ooo`040<30`000000000000<30`>l0oooo3Oooool0
00cooooo603oool00`20P80000000820P03E0?ooo`040820P000000000000<30`>h0oooo3Oooool0
00cooooo603oool00`20P80000000820P02<0?ooo`030<30`010@400`<3004L0oooo00<0@4100000
0010@400I@3oool01P20P800@4100820P020P800@4100820P8<0oooo3Oooool000cooooo603oool0
0`20P80000000820P02<0?ooo`040410@000000000000<30`4H0oooo00@0`<30000000000000P820
H`3oool00`10@40000000<30`0030?ooo`030<30`010@400P8200840oooo3Oooool000cooooo603o
ool00`20P80000000820P02=0?ooo`040410@000000000000820P4H0oooo00@0`<30000000000000
`<30H@3oool00`20P80000000410@0060?ooo`0300000010@400oooo07l0oooo3Oooool000cooooo
603oool00`20P80000000820P02>0?ooo`040820P000000000000820P4H0oooo0`00001Q0?ooo`03
0820P0000000P82000H0oooo00<0P82000000020P800O`3oool=ooooo`003?oooolH0?ooo`030820
P0000000P82008l0oooo00<0@41000000010@400AP3oool01030`<00000000000030`<1P0?ooo`80
000000<0P8200?ooo`3oool01@3oool2000000030<30`03oool0oooo07`0oooo3Oooool000cooooo
603oool00`20P80000000820P02@0?ooo`030820P03oool0oooo04H0oooo00@0P820000000000000
`<30G`3oool2000000030820P03oool0oooo00D0oooo00<0`<30000000000000OP3oool=ooooo`00
3?oooolH0?ooo`030820P0000000P8200=X0oooo00<0@41000000010@400G`3oool2000000030820
P03oool0oooo00H0oooo0P0000000`10@400oooo0?ooo`1k0?ooo`gooooo000<oooooaP0oooo00<0
P82000000020P800f`3oool2000000030820P03oool0oooo05`0oooo0`0000080?ooo`030820P000
0000000007d0oooo3Oooool000cooooo603oool00`20P80000000820P03L0?ooo`80000000<0`<30
0?ooo`3oool0F`3oool01020P800000000000030`<080?ooo`80000000<0P8200?ooo`3oool0NP3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200=`0oooo00<0`<3000000010@400BP3oool3
0820P0P0oooo0P20P8060?ooo`040<30`000000000000820P0P0oooo0P0000000`10@400oooo0?oo
o`1j0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800g@3oool00`10@400000000000019
0?ooo`<0000000<0@4100?ooo`3oool0103oool01020P800000000000010@4060?ooo`030410@000
0000000000P0oooo00<0P820000000000000O03oool=ooooo`003?oooolH0?ooo`030820P0000000
P82009X0oooo00<000000820P03oool0@@3oool2000000030820P03oool0oooo04H0oooo10000000
0`10@400oooo0?ooo`030?ooo`<0000000<0P8200410@03oool01@3oool2000000030820P03oool0
oooo00D0oooo00<0P820000000000000O03oool=ooooo`003?oooolH0?ooo`030820P0000000P820
09T0oooo00@0@410000000000000@410@@3oool01020P800000000000030`<170?ooo`80P8200P3o
ool20820P0<0oooo00L0`<30000000000000@4100?ooo`30`<00@41000D0oooo00@0`<3000000000
0000`<301P3oool00`20P80000000000001l0?ooo`gooooo000<oooooaP0oooo00<0P82000000020
P800V@3oool01P30`<00@410000000000000@4100<30`400oooo00<0P82000000010@400C03oool0
1@10@400`<300?ooo`3oool0P8200080000000D0P8200?ooo`3oool0P8200<30`0050?ooo`030<30
`0000000@41000H0oooo00<0P82000000020P800O03oool=ooooo`003?oooolH0?ooo`030820P000
0000P82009/0oooo00D0@41000000000000000000<30`0100?ooo`030410@0000000P82004`0oooo
00@000000?ooo`3oool0P8200P0000000`30`<00oooo0?ooo`080?ooo`030<30`0000000@41000D0
oooo0P0000000`30`<00oooo0?ooo`1j0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
W03oool00`20P8000000000000120?ooo`80000000<0`<300?ooo`3oool0B@3oool00`30`<00@410
0?ooo`03000000`0oooo00@0`<300410@010@400`<300P3oool00`10@40000000<30`01m0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800W@3oool20<30`480oooo00<0`<3000000010@400
C03oool01@10@400P820000000000000@41000l0oooo1020P81o0?ooo`gooooo000<oooooaP0oooo
00<0P82000000020P800hP3oool00`10@40000000820P01<0?ooo`<0000000<0P8200?ooo`3oool0
T03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200><0oooo0P0000000`30`<00oooo0?oo
o`190?ooo`040820P000000000000820P980oooo3Oooool000cooooo603oool00`20P80000000820
P03S0?ooo`030<30`0000000@41004/0oooo00<0@410000000000000T`3oool=ooooo`003?oooolH
0?ooo`030820P0000000P8200>@0oooo00<0@41000000030`<00BP3oool3000000030<30`03oool0
oooo0900oooo3Oooool000cooooo603oool00`20P80000000820P03T0?ooo`030820P00000000000
04X0oooo0`0000000`20P800oooo0?ooo`2@0?ooo`gooooo000<oooooaP0oooo00<0P82000000020
P800Y`3oool00`20P800`<300?ooo`0k0?ooo`030410@0000000`<3004P0oooo00<0P82000000000
00000P10@4000`30`<00oooo0?ooo`2?0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
YP3oool01010@400000000000030`<0k0?ooo`030<30`0000000000004P0oooo00H0P82000000000
0000P8200<30`000002A0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800YP3oool01@30
`<00P820000000000000@41003/0oooo00<0P82000000010@400A`3oool3000000080<30`03oool0
P8200410@020P800@41000000030`<2<0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
Z03oool01030`<00000000000010@40k0?ooo`030410@0000000`<300480oooo0P30`<000`3oool0
`<3000000002000000<0oooo00D0@41000000000000000000820P02<0?ooo`gooooo000<oooooaP0
oooo00<0P82000000020P800Z@3oool01030`<00@41000000020P80j0?ooo`030<30`0000000@410
04<0oooo00<0`<300820P010@4000P0000000`30`<00oooo0?ooo`020?ooo`040820P00000000000
0<30`8`0oooo3Oooool000cooooo603oool00`20P80000000820P02[0?ooo`030820P03oool0oooo
03X0oooo00<0@41000000020P800g03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200>T0
oooo0P00003L0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800j@3oool00`20P8000000
0410@03K0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800jP3oool00`10@40000000<30
`03J0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800jP3oool00`30`<0000000410@03J
0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800j`3oool00`10@40000000820P03I0?oo
o`gooooo000<oooooaP0oooo00<0P82000000020P800]03oool00`10@400P8200?ooo`0e0?ooo`80
000000<0`<300?ooo`3oool0eP3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200;<0oooo
00@0`<30000000000000@410=@3oool00`30`<0000000410@03H0?ooo`gooooo000<ooooool00000
c`0000000`20P800oooo0?ooo`0A0?ooo`gooooo000<ooooool00000c`0000000`20P800oooo0?oo
o`0A0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800]`3oool20410@3D0oooo00<0P820
00000020P800eP3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200>l0oooo0P0000000`20
P800oooo0?ooo`3C0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800k`3oool00`20P800
00000000003E0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800l03oool2000000030820
P03oool0oooo0=80oooo3Oooool000cooooo603oool00`20P80000000820P02]0?ooo`030<30`020
P800oooo0400oooo00@0P820000000000000`<30d`3oool=ooooo`003?oooolH0?ooo`030820P000
0000P8200:`0oooo00<0P8200000003oool0@P3oool00`20P80000000410@03C0?ooo`gooooo000<
oooooaP0oooo00<0P82000000020P800Z`3oool00`10@4000000000000140?ooo`030410@0000000
`<300=80oooo3Oooool000cooooo603oool00`20P80000000820P02Y0?ooo`050<30`00000000000
00000020P8004`3oool00`30`<00@4100<30`00^0?ooo`030<30`0000000@4100=80oooo3Oooool0
00cooooo603oool00`20P80000000820P02X0?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool04@3oool01010@400000000000030`<0^0?ooo`030410@0000000P8200=40oooo3Oooool0
00cooooo603oool00`20P80000000820P02V0?ooo`030<30`020P800000000@000005@3oool01010
@400000000000020P80]0?ooo`030<30`0000000000003`0oooo00<0`<300820P020P800TP3oool=
ooooo`003?oooolH0?ooo`030820P0000000P8200:D0oooo00<0`<300000000000001@00000F0?oo
o`040<30`000000000000410@2d0oooo00<0@41000000020P800>`3oool00`20P80000000000002B
0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800Y03oool00`10@4000000000000050000
00030410@03oool0oooo01D0oooo00<0`<3000000030`<00;P3oool2000000030<30`03oool0oooo
03P0oooo00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200:80
oooo00<0`<300410@00000001`0000000`20P800oooo0?ooo`160?ooo`030820P0000000@41003X0
oooo00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000P8200:40oooo
00<0`<30000000000000200000000`30`<00oooo0?ooo`170?ooo`80000000<0`<300?ooo`3oool0
=`3oool00`20P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800X03o
ool00`20P800000000000009000004X0oooo00<0P820000000000000>@3oool00`20P80000000000
002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800W`3oool00`10@40000000000000:
000004/0oooo0P0000000`20P800oooo0?ooo`0f0?ooo`030820P000000000000980oooo3Oooool0
00cooooo603oool00`20P80000000820P02M0?ooo`030<30`0000000000000/0000000<0P8200?oo
o`3oool0B@3oool00`30`<0000000000003=0?ooo`gooooo000<oooooaP0oooo00<0P82000000020
P800W03oool00`10@40000000000000<000000030820P03oool0oooo0240oooo00<0P8200?ooo`3o
ool09P3oool00`10@40000000410@03<0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
V`3oool00`10@40000000000000=000002<0oooo00@0@410000000000000`<309P3oool01030`<00
000000000030`<3;0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800VP3oool00`20P800
00000000000>000002<0oooo00@0P82000000000000000009`3oool2000000030820P03oool0oooo
0<T0oooo3Oooool000cooooo603oool00`20P80000000820P02K0?ooo`030410@0000000000000`0
000000<0@4100?ooo`3oool08P3oool01@30`<00000000000010@400`<3002D0oooo00<0P8200000
00000000b`3oool=ooooo`003?oooolH0?ooo`030820P0000000P82009/0oooo00<0`<3000000000
0000300000000`20P800oooo0?ooo`0S0?ooo`050<30`0000000000000000030`<009@3oool20000
00030410@03oool0oooo0<P0oooo3Oooool000cooooo603oool00`20P80000000820P02L0?ooo`03
0<30`0000000000000/0000000<0P8200?ooo`3oool09@3oool20410@2H0oooo00@0`<3000000000
0000`<30b@3oool=ooooo`003?oooolH0?ooo`030820P0000000P82009h0oooo00<0@41000000000
00002@00001A0?ooo`030410@0000000@4100<T0oooo3Oooool000cooooo603oool00`20P8000000
0820P02O0?ooo`030410@0000000000000P00000D@3oool01030`<00000000000030`<380?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800W`3oool00`10@400000000000007000000030820
P03oool0oooo0500oooo00<0@410000000000000b03oool=ooooo`003?oooolH0?ooo`030820P000
0000P82009h0oooo00<0P8200000000000000P30`<000`10@400000000000003000000030820P03o
ool0oooo0540oooo0P0000000`20P800oooo0?ooo`0`0?ooo`030<30`020P800P8200980oooo3Ooo
ool000cooooo603oool00`20P80000000820P02N0?ooo`80000000H0P8200?ooo`3oool0oooo0<30
`010@403000005@0oooo00<0P820000000000000<P3oool00`20P80000000000002B0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800W@3oool00`10@40000000410@0070?ooo`80P820<`3o
ool00`20P800oooo0?ooo`0O0?ooo`80000000<0@4100?ooo`3oool0;`3oool00`20P80000000000
002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800W03oool01030`<00000000000030
`<0k0?ooo`030<30`0000000@4100200oooo00@0`<30000000000000`<30<03oool00`20P8000000
0000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800W03oool2000000030820P03o
ool0oooo03X0oooo00D0@41000000000000000000820P00O0?ooo`030410@0000000@4100300oooo
00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000P82009/0oooo00<0
P820000000000000?P3oool01@30`<000000000000000000@41001h0oooo00@0`<30000000000000
`<30;`3oool00`20P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
VP3oool01030`<00000000000030`<100?ooo`040410@000000000000820P1h0oooo00<0@4100000
0010@400;`3oool00`20P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020
P800VP3oool00`10@40000000410@0130?ooo`030820P03oool0oooo01d0oooo00@0`<3000000000
0000P820``3oool=ooooo`003?oooolH0?ooo`030820P0000000P82009T0oooo00<0P82000000000
0000I@3oool00`20P8000000000000330?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
V03oool01030`<00000000000030`<1V0?ooo`<00000`P3oool=ooooo`003?oooolH0?ooo`030820
P0000000P82009P0oooo00<0@41000000010@400I`3oool01020P800000000000010@4310?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800V03oool2000000030820P03oool0oooo06H0oooo
0`0000310?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800U`3oool00`10@40000000410
@01Y0?ooo`040820P000000000000820P<00oooo3Oooool000cooooo603oool00`20P80000000820
P02F0?ooo`040<30`000000000000<30`4l0oooo00<0`<300?ooo`3oool0603oool300000<00oooo
3Oooool000cooooo603oool00`20P80000000820P02F0?ooo`80000000<0P8200?ooo`3oool0CP3o
ool2000000030<30`03oool0oooo01L0oooo0P0000000`20P800oooo0?ooo`2m0?ooo`gooooo000<
oooooaP0oooo00<0P82000000020P800U@3oool2000000030410@03oool0oooo04h0oooo00D0`<30
00000000000000000<30`00H0?ooo`040820P000000000000<30`;h0oooo3Oooool000cooooo603o
ool00`20P80000000820P02D0?ooo`040410@000000000000<30`540oooo00D0`<30000000000000
00000410@00H0?ooo`030410@0000000@4100;h0oooo3Oooool000cooooo603oool00`20P8000000
0820P02C0?ooo`040<30`000000000000410@5@0oooo00@0@410000000000000`<305`3oool01030
`<00000000000030`<2m0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800T`3oool30000
05H0oooo0P10@40I0?ooo`030410@0000000@41002P0oooo00<0P820000000000000TP3oool=oooo
o`003?oooolH0?ooo`030820P0000000P8200980oooo00<0P82000000010@400LP3oool01030`<00
000000000030`<0W0?ooo`030820P000000000000980oooo3Oooool000cooooo603oool00`20P800
00000820P02A0?ooo`040<30`000000000000<30`7<0oooo00<0@41000000010@4009`3oool00`20
P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800T@3oool00`10@400
00000820P01d0?ooo`040<30`000000000000820P2H0oooo00<0P820000000000000TP3oool=oooo
o`003?oooolH0?ooo`030820P0000000P8200900oooo00<0P820000000000000MP3oool00`20P800
00000000000V0?ooo`030820P000000000000980oooo3Oooool000cooooo603oool00`20P8000000
0820P02?0?ooo`040<30`000000000000<30`7L0oooo0P0000000`20P800oooo0?ooo`0S0?ooo`03
0820P000000000000980oooo3Oooool000cooooo603oool00`20P80000000820P02?0?ooo`030410
@0000000@41006D0oooo00<0`<300?ooo`3oool0403oool00`20P80000000000002j0?ooo`gooooo
000<oooooaP0oooo00<0P82000000020P800SP3oool00`30`<0000000000001U0?ooo`030410@000
0000@4100180oooo0P0000000`10@400oooo0?ooo`2g0?ooo`gooooo000<oooooaP0oooo00<0P820
00000020P800SP3oool2000000030<30`03oool0oooo06<0oooo00@0`<30000000000000@4104@3o
ool01030`<00000000000030`<2h0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800S@3o
ool00`10@40000000410@01W0?ooo`050<30`010@400000000000030`<00403oool00`10@4000000
0410@02h0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800S@3oool2000000030820P03o
ool0oooo06L0oooo0`00000@0?ooo`040820P000000000000820P;L0oooo3Oooool000cooooo603o
ool00`20P80000000820P02<0?ooo`030820P0000000@41006X0oooo00<0`<3000000030`<004@3o
ool00`10@40000000410@02g0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800R`3oool0
1030`<00000000000030`<1n0?ooo`040<30`000000000000<30`;H0oooo3Oooool000cooooo603o
ool00`20P80000000820P02;0?ooo`030410@0000000P8200800oooo00<0@410000000000000]P3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P82008X0oooo00<0P820000000000000PP3oool2
000000030820P03oool0oooo0;<0oooo3Oooool000cooooo603oool00`20P80000000820P02:0?oo
o`80000000<0`<300?ooo`3oool0P03oool01020P800000000000030`<2d0?ooo`gooooo000<oooo
oaP0oooo00<0P82000000020P800R@3oool00`10@40000000410@0240?ooo`030410@0000000@410
0;@0oooo3Oooool000cooooo603oool00`20P80000000820P0280?ooo`030<30`0000000000007P0
oooo00<0`<300820P03oool02P3oool01030`<00000000000030`<0N0?ooo`030820P00000000000
0980oooo3Oooool000cooooo603oool00`20P80000000820P0280?ooo`80000000<0`<300?ooo`3o
ool0M@3oool01@30`<000000000000000000`<3000X0oooo00<0@4100000000000007P3oool00`20
P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800Q`3oool00`10@400
00000410@01i0?ooo`050820P0000000000000000030`<002P3oool2000000030820P03oool0oooo
01/0oooo00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000P82008H0
oooo00@0`<30000000000000`<30N`3oool01010@400000000000010@4090?ooo`040820P0000000
00000<30`1`0oooo00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000
P82008H0oooo00<0@41000000020P800O@3oool01020P800000000000030`<090?ooo`030820P000
0000@41001`0oooo00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000
P82008D0oooo00<0P82000000010@400O`3oool20<30`0/0oooo00@0@410000000000000`<306P3o
ool00`20P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800Q03oool0
1030`<00000000000030`<2=0?ooo`80000000<0@4100?ooo`3oool0603oool00`30`<00P8200820
P02B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800Q03oool00`10@40000000820P02>
0?ooo`040820P000000000000820P:h0oooo3Oooool000cooooo603oool00`20P80000000820P023
0?ooo`030<30`000000000000900oooo00@0P820000000000000`<30[@3oool=ooooo`003?oooolH
0?ooo`030820P0000000P82008<0oooo0P0000000`30`<00oooo0?ooo`2?0?ooo`030410@0000000
00000:d0oooo3Oooool000cooooo603oool00`20P80000000820P0210?ooo`040<30`00000000000
0410@9<0oooo0P0000000`10@400oooo0?ooo`2Z0?ooo`gooooo000<oooooaP0oooo00<0P8200000
0020P800P@3oool00`20P80000000000002=0?ooo`030000003oool0oooo00@0oooo00<0P8200000
00000000[03oool=ooooo`003?oooolH0?ooo`030820P0000000P8200840oooo0P0000000`10@400
oooo0?ooo`2:0?ooo`030410@0000000@41000H0oooo0P0000000`10@400oooo0?ooo`2Y0?ooo`go
oooo000<oooooaP0oooo00<0P82000000020P800P03oool00`10@40000000000002=0?ooo`050<30
`010@400000000000030`<00103oool01020P800000000000020P82Z0?ooo`gooooo000<oooooaP0
oooo00<0P82000000020P800O`3oool00`30`<0000000000002@0?ooo`040410@000000000000<30
`0@0oooo00@0@410000000000000`<30Z@3oool=ooooo`003?oooolH0?ooo`030820P0000000P820
07l0oooo0P0000000`30`<00oooo0?ooo`2?0?ooo`030820P0000000000000@0oooo00D0`<300000
0000000000000<30`02X0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800OP3oool00`10
@40000000410@02C0?ooo`80`<301@3oool01030`<00000000000010@42X0?ooo`gooooo000<oooo
oaP0oooo00<0P82000000020P800O@3oool00`30`<0000000000002L0?ooo`040820P00000000000
0410@180oooo00<0P820000000000000TP3oool=ooooo`003?oooolH0?ooo`030820P0000000P820
07d0oooo00<0@41000000030`<00W@3oool01010@400000000000010@40A0?ooo`030820P0000000
00000980oooo3Oooool000cooooo603oool00`20P80000000820P01l0?ooo`030820P0000000@410
09l0oooo00@0@410000000000000`<30403oool00`20P80000000000002B0?ooo`gooooo000<oooo
oaP0oooo00<0P82000000020P800N`3oool01030`<00000000000030`<2P0?ooo`<00000403oool0
0`20P80000000000002B0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800N`3oool00`10
@40000000820P02Q0?ooo`040<30`000000000000410@0l0oooo00<0P820000000000000TP3oool=
ooooo`003?oooolH0?ooo`030820P0000000P82007X0oooo00<0`<3000000010@400X@3oool01P10
@400P8200?ooo`10@40000000410@0h0oooo00<0P820000000000000TP3oool=ooooo`003?oooolH
0?ooo`030820P0000000P82007X0oooo0P0000000`30`<00oooo0?ooo`2N0?ooo`060<30`0000000
00000410@03oool0@4100P0000000`30`<00oooo0?ooo`0:0?ooo`030<30`020P800P8200980oooo
3Oooool000cooooo603oool00`20P80000000820P01i0?ooo`030410@0000000P8200:80oooo00H0
`<30000000000000@4100<30`010@402000000030<30`03oool0oooo09h0oooo3Oooool000cooooo
603oool00`20P80000000820P01h0?ooo`030<30`000000000000:D0oooo00D0@410000000000000
`<300410@002000000030<30`03oool0oooo09d0oooo3Oooool000cooooo603oool00`20P8000000
0820P01h0?ooo`030410@0000000`<300:H0oooo0P10@4020?ooo`040410@000000000000<30`9h0
oooo3Oooool000cooooo603oool00`20P80000000820P01g0?ooo`030820P0000000@4100:`0oooo
00D0@410000000000000P8200<30`02L0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
MP3oool00`30`<0000000000002^0?ooo`050410@0000000000000000030`<00V`3oool=ooooo`00
3?oooolH0?ooo`030820P0000000P82007H0oooo00<0P82000000020P800[`3oool4000009/0oooo
3Oooool000cooooo603oool00`20P80000000820P01e0?ooo`040<30`000000000000<30`:l0oooo
00D0`<3000000000000000000410@02J0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800
M@3oool00`10@40000000820P02b0?ooo`050820P0000000000000000030`<00V03oool=ooooo`00
3?oooolH0?ooo`030820P0000000P82007@0oooo00<0`<3000000010@400]03oool01@30`<000000
000000000000`<3009L0oooo3Oooool000cooooo603oool00`20P80000000820P01d0?ooo`800000
00<0`<300?ooo`3oool0/P3oool00`20P800000000000002000000030<30`03oool0oooo09@0oooo
3Oooool000cooooo603oool00`20P80000000820P01c0?ooo`030410@0000000P8200;@0oooo00<0
`<30000000000000100000001010@400`<300820P020P82B0?ooo`gooooo000<oooooaP0oooo00<0
P82000000020P800LP3oool00`30`<0000000000002f0?ooo`030820P0000000000000L00000TP3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P8200780oooo00<0@41000000030`<00]`3oool0
0`30`<0000000000000600000980oooo3Oooool000cooooo603oool00`20P80000000820P01a0?oo
o`030820P0000000@4100;T0oooo00D0`<300410@0000000P8200<30`003000000030<30`03oool0
oooo08l0oooo3Oooool000cooooo603oool00`20P80000000820P01`0?ooo`030820P00000000000
0;`0oooo00@0P8200?ooo`3oool0P8200`0000000`10@400oooo0?ooo`2>0?ooo`gooooo000<oooo
oaP0oooo00<0P82000000020P800K`3oool01030`<00000000000030`<2o0?ooo`030820P0000000
00000080000000<0@4100?ooo`3oool0S@3oool=ooooo`003?oooolH0?ooo`030820P0000000P820
06l0oooo00<0@41000000010@400`03oool01030`<00P8200820P030`<03000000030<30`03oool0
oooo08/0oooo3Oooool000cooooo603oool00`20P80000000820P01^0?ooo`040820P00000000000
0<30`<D0oooo00@0@410000000000000@410S03oool=ooooo`003?oooolH0?ooo`030820P0000000
P82006h0oooo00<0P8200000003oool0a`3oool01@30`<000000000000000000@41008X0oooo3Ooo
ool000cooooo603oool00`20P80000000820P03o0?oooc/0oooo00D0@410000000000000@4100<30
`0280?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800o`3oooli0?ooo`80@4100P3oool0
1010@400000000000020P8270?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800o`3ooolh
0?ooo`070<30`000000000000410@020P800oooo0<30`002000000030410@030`<00oooo04h0oooo
0P30`<0d0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800o`3ooolj0?ooo`<0000000<0
P8200?ooo`3oool00`00001?0?ooo`030820P0000000oooo0180oooo00<0P8200?ooo`3oool04`3o
ool00`000000oooo0?ooo`080?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800o`3ooolj
0?ooo`070<30`0000000000000000030`<00oooo0<30`003000000030<30`03oool0oooo04/0oooo
00<0P82000000010@4004@3oool00`30`<00@4100<30`00D0?ooo`030410@0000000`<3000P0oooo
3Oooool000cooooo603oool00`20P80000000820P01B0?ooo`<0P82000<0`<300?ooo`3oool0DP3o
ool30820P0030<30`03oool0oooo06D0oooo1020P80Q0?ooo`040<30`020P8000000000000<0oooo
00D0@410000000000000@4100<30`01<0?ooo`030410@0000000P82000l0oooo0P10@40H0?ooo`03
0410@030`<00oooo00H0oooo3Oooool000cooooo603oool00`20P80000000820P01@0?ooo`030410
@0000000`<300080oooo00<0P8200410@030`<00D03oool00`10@40000000<30`0020?ooo`030820
P010@400`<3006<0oooo00<0@41000000030`<000P3oool00`30`<00@4100820P00Q0?ooo`80`<30
103oool01@30`<000000000000000000P82004/0oooo00<0P8200000000000003P3oool00`30`<00
00000?ooo`0I0?ooo`0300000020P800oooo00D0oooo3Oooool000cooooo603oool00`20P8000000
0820P01?0?ooo`030410@0000000P82000D0oooo0P10@41=0?ooo`040<30`000000000000820P0D0
oooo0P10@41Q0?ooo`030410@0000000P82000D0oooo00<0`<3000000030`<009P3oool01P30`<00
@410000000000000@4100<30`4X0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`030<30`0000000
`<3001X0oooo00<0`<3000000030`<001@3oool=ooooo`003?oooolH0?ooo`030820P0000000P820
04l0oooo0P0000060?ooo`030<30`0000000@41002<0oooo0P20P80W0?ooo`030820P00000000000
00H0oooo00<0`<3000000010@400903oool20820P3X0oooo0P0000070?ooo`030410@0000000`<30
02L0oooo00D0@41000000000000000000820P0190?ooo`<00000303oool00`000000@4100?ooo`0K
0?ooo`030410@0000000`<3000@0oooo3Oooool000cooooo603oool00`20P80000000820P01>0?oo
o`030820P0000000000000L0oooo00<0P82000000010@4008P3oool00`30`<0000000820P00A0?oo
o`030410@030`<00oooo0180oooo0`0000070?ooo`030820P0000000@41000D0oooo00<0P8200410
@03oool06`3oool00`30`<0000000820P00S0?ooo`030<30`010@400oooo0180oooo00<0P8200000
00000000203oool2000000030<30`03oool0oooo0080oooo00<0P8200410@03oool0803oool00`30
`<00000000000002000000030<30`03oool0oooo04D0oooo00@0P820000000000000P8202P3oool0
0`10@40000000<30`0050?ooo`<0P820203oool20820P0X0oooo00<0`<3000000010@400103oool=
ooooo`003?oooolH0?ooo`030820P0000000P82004h0oooo00<0P820000000000000203oool00`10
@40000000820P00R0?ooo`030410@0000000`<3000h0oooo00<0`<3000000030`<00503oool30000
00P0oooo00<0@41000000020P8001@3oool00`30`<0000000820P00K0?ooo`030410@0000000`<30
0240oooo0P10@40D0?ooo`030820P0000000000000P0oooo00<0`<300000000000001@3oool00`30
`<00@4100<30`00Q0?ooo`050410@0000000000000000010@400AP3oool01020P800000000000010
@4090?ooo`030<30`0000000@41000H0oooo0`0000000`10@400oooo0?ooo`040?ooo`040820P000
000000000410@0X0oooo00<0@41000000030`<000`3oool=ooooo`003?oooolH0?ooo`030820P000
0000P82004h0oooo00<0P820000000000000203oool01020P800000000000030`<0Q0?ooo`030820
P0000000@41000d0oooo00<0`<3000000030`<005@3oool3000000P0oooo00@0P820000000000000
`<301P3oool20410@1X0oooo00<0P82000000010@400803oool20410@1D0oooo00<0P82000000000
00002@3oool2000000030410@03oool0oooo00<0oooo00<0`<3000000030`<008@3oool00`30`<00
@41000000002000000030820P030`<00oooo04<0oooo0`0000090?ooo`030410@0000000P82000H0
oooo100000000`10@400oooo0?ooo`030?ooo`<0000000<0P8200410@03oool0203oool00`20P800
00000410@0030?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800CP3oool01020P8000000
00000020P8080?ooo`80000000<0P8200?ooo`3oool0803oool2000000030<30`03oool0oooo00T0
oooo00<0`<3000000020P8005P3oool3000000030820P03oool0oooo00H0oooo0P0000000`20P800
oooo0?ooo`050?ooo`0300000010@400oooo01T0oooo0P0000000`30`<00oooo0?ooo`0L0?ooo`03
0410@0000000oooo01D0oooo00@0P820000000000000P820203oool00`20P8000000000000060?oo
o`030820P0000000`<3001`0oooo00<0`<3000000030`<000`3oool00`20P8000000000000020000
00030820P03oool0oooo0440oooo00@0@410000000000000`<301`3oool01030`<00000000000030
`<060?ooo`040820P030`<00oooo0?ooo`80P8200`3oool01`30`<00000000000010@400oooo0<30
`010@4002@3oool2000000030<30`03oool0oooo00gooooo000<oooooaP0oooo00<0P82000000020
P800C`3oool2000000030410@03oool0oooo00H0oooo00<0P8200000000000008P3oool200000003
0820P03oool0oooo00T0oooo0P10@40G0?ooo`040820P000000000000410@0P0oooo00<0P8200000
000000001`3oool00`30`<0000000820P00I0?ooo`80000000<0P8200?ooo`3oool06`3oool00`30
`<0000000<30`00G0?ooo`80000000<0@4100?ooo`3oool01`3oool2000000030820P03oool0oooo
00@0oooo00<0@4100000003oool06`3oool01010@400000000000020P8040?ooo`060820P0000000
000000000010@400`<30@@3oool01020P800000000000020P8070?ooo`030820P0000000000000`0
oooo00D0@4100<30`03oool0oooo0820P002000000050820P03oool0oooo0820P030`<00203oool2
000000030820P03oool0oooo00gooooo000<oooooaP0oooo00<0P82000000020P8005@3oool20820
P0030<30`03oool0oooo00D0oooo00<0`<300820P030`<006P3oool20820P0030<30`03oool0oooo
00D0oooo00<0`<300820P030`<001P3oool00`10@4000000000000080?ooo`040820P00000000000
0820P240oooo00<0P8200000000000002P3oool00`10@40000000<30`0040?ooo`040<30`020P800
P8200<30`0L0oooo00<0`<300820P030`<001@3oool01030`<0000000000000000080?ooo`040820
P000000000000<30`0L0oooo00<0@41000000030`<00603oool00`20P80000000000000L0?ooo`03
0<30`0000000@41000@0oooo00<0`<300820P020P800203oool00`30`<00P8200<30`0060?ooo`03
0410@0000000000000T0oooo0P0000000`10@400oooo0?ooo`040?ooo`040<30`000000000000<30
`1/0oooo00@0`<30000000000000@4101@3oool01@30`<00@410000000000000P8200400oooo00@0
`<3000000000000000001`3oool3000000d0oooo00@000000?ooo`3oool0P8200P0000000`30`<00
oooo0?ooo`0:0?ooo`<000000P3oool=ooooo`003?oooolH0?ooo`030820P0000000P82001D0oooo
0`0000000`30`<00oooo0?ooo`040?ooo`<0000000<0`<300?ooo`3oool05`3oool3000000030<30
`03oool0oooo00@0oooo0`0000000`30`<00oooo0?ooo`030?ooo`040<30`000000000000820P0P0
oooo0`00000Q0?ooo`040820P000000000000820P0P0oooo00<0`<3000000010@4001@3oool01@20
P8000000000000000000`<3000H0oooo0`0000000`30`<00oooo0?ooo`030?ooo`040820P0000000
00000820P0P0oooo0P0000000`20P800oooo0?ooo`050?ooo`030<30`0000000@41000@0oooo00<0
00000820P03oool04@3oool01020P800000000000030`<0K0?ooo`030410@0000000`<3000@0oooo
00@0P820000000000000@4101`3oool3000000030<30`03oool0oooo00<0oooo00@0`<3000000000
0000P820203oool00`20P8000000000000070?ooo`030410@0000000@41001`0oooo00@0`<300000
00000000@4101P3oool01@20P8000000000000000000P82003l0oooo0`0000070?ooo`80000000<0
P8200?ooo`3oool02`3oool00`30`<00@4100?ooo`03000000d0oooo00<0P8200000000000000P3o
ool=ooooo`003?oooolH0?ooo`030820P0000000P82001D0oooo100000000`30`<00oooo0?ooo`02
0?ooo`030820P000000000000080@41000<0`<300?ooo`3oool05P3oool4000000030<30`03oool0
oooo0080oooo00<0P8200000000000000P10@4000`20P800oooo0?ooo`030?ooo`030820P0000000
000000P0oooo0`00000R0?ooo`<00000203oool00`10@40000000820P0050?ooo`030820P0000000
00000080000000<0`<300?ooo`3oool00P3oool00`20P8000000000000020410@0030<30`03oool0
oooo00<0oooo00<0P820000000000000203oool2000000030820P03oool0oooo00H0oooo0P000000
1030`<00oooo0?ooo`3oool20410@1<0oooo0P0000000`20P800oooo0?ooo`0H0?ooo`030<30`000
0000000000D0oooo00D0P82000000000000000000410@0050?ooo`030820P000000000000080@410
00<0`<300?ooo`3oool00`3oool00`20P8000000000000080?ooo`030820P0000000000000L0oooo
00@0P820000000000000`<307@3oool20410@0P0oooo00D0P820000000000000@4100<30`00m0?oo
o`040820P00000000000000000D0oooo00@0`<30000000000000P8203P3oool01@10@400P8200000
00000000@41000d0oooo00D0P820000000000000P8200?ooo`0=ooooo`003?oooolH0?ooo`030820
P0000000P82001D0oooo00D0P8200<30`03oool0oooo000000040?ooo`070410@000000000000<30
`03oool0@4100<30`00G0?ooo`050820P030`<00oooo0?ooo`000000103oool01`10@40000000000
0030`<00oooo0820P010@4001@3oool00`10@40000000410@0070?ooo`<000008P3oool01010@400
000000000030`<060?ooo`040<30`000000000000<30`0D0oooo00<0`<300820P03oool00P3oool0
0`000000oooo0?ooo`020?ooo`070410@000000000000<30`03oool0@4100<30`0050?ooo`030410
@0000000@41000L0oooo0P0000000`20P800oooo0?ooo`060?ooo`030820P0000000@41000<0oooo
00<0P8200000003oool04P3oool00`10@40000000410@00J0?ooo`030410@0000000@41000D0oooo
00@0`<300820P03oool0oooo0P20P8040?ooo`070410@000000000000<30`03oool0@4100<30`005
0?ooo`040410@000000000000<30`0H0oooo00<0P820000000000000203oool2000000030410@03o
ool0oooo02L0oooo00D0@410000000000000@4100<30`00k0?ooo`050820P0000000000000000030
`<00103oool01020P800000000000020P80?0?ooo`<0000000<0P8200?ooo`3oool02`3oool01@20
P800000000000020P800oooo00gooooo000<oooooaP0oooo00<0P82000000020P8006@3oool00`30
`<00@4100?ooo`020?ooo`<000000`3oool00`10@400oooo0?ooo`0I0?ooo`030<30`010@400oooo
0080oooo0`0000030?ooo`030820P030`<00oooo00@0oooo00<0@41000000030`<001P3oool20000
02<0oooo00@0P820000000000000P8201P3oool00`20P80000000000000;0?ooo`030<30`010@400
oooo0080oooo0`0000030?ooo`030410@03oool0oooo00@0oooo00<0@41000000030`<001P3oool2
000000T0oooo00<0P8200000000000000`3oool00`30`<0000000820P00B0?ooo`030820P0000000
000001X0oooo0P0000000`20P800oooo0?ooo`080?ooo`030410@020P800oooo0080oooo0`000003
0?ooo`030410@03oool0oooo00@0oooo00<0@41000000010@4001P3oool00`20P80000000820P008
0?ooo`<00000:P3oool01P30`<00@410000000000000@4100<30`3X0oooo0`0000000`20P800oooo
0?ooo`020?ooo`040820P000000000000820P0l0oooo00@0P820000000000000P8203@3oool01@20
P800000000000020P800oooo00gooooo000<oooooaP0oooo00<0P82000000020P8006P3oool20820
P080oooo0P0000000`10@400oooo0?ooo`050?oooa<0P82000<0`<300?ooo`3oool00`3oool20820
P080oooo0P0000000`10@400oooo0?ooo`090?ooo`030410@0000000`<3000@0oooo00<0P8200000
0010@4008`3oool01030`<0000000000000000060?ooo`<00000303oool20820P080oooo0P000000
0`10@400oooo0?ooo`090?ooo`030410@0000000`<3000@0oooo00<0P82000000010@4002@3oool0
1030`<00000000000020P8030?ooo`0300000010@400oooo0140oooo00@0`<30000000000000P820
603oool01020P800000000000020P80;0?ooo`0400000020P800oooo0?ooo`80000000<0@4100?oo
o`3oool02@3oool00`20P80000000410@0050?ooo`80000000<0`<300?ooo`3oool01P3oool01020
P800000000000020P80[0?ooo`050<30`010@400000000000020P800>@3oool01010@40000000000
0010@4040?ooo`040820P000000000000820P0l0oooo00<0@4100000000000003P3oool01@20P800
000000000020P800oooo00gooooo000<oooooaP0oooo00<0P82000000020P8006`3oool00`10@400
`<300820P002000000030820P03oool0oooo00D0oooo4`0000000`20P800oooo0?ooo`040?ooo`03
0410@030`<00P8200080000000<0P8200?ooo`3oool02P3oool00`20P80000000820P0020?ooo`03
0<30`0000000@41002D0oooo0`0000060?ooo`80000000<0P8200?ooo`3oool02`3oool00`10@400
`<300820P002000000030820P03oool0oooo00X0oooo00<0P82000000020P8000P3oool00`30`<00
00000410@00;0?ooo`80000000H0P8200?ooo`3oool0oooo0820P000000C0?ooo`80000000<0P820
0?ooo`3oool05P3oool00`20P80000000000000=0?ooo`030410@030`<00P8200080000000<0P820
0?ooo`3oool02P3oool01030`<00@4100410@030`<020?ooo`030410@0000000`<3000X0oooo0P00
00000`20P800oooo0?ooo`0[0?ooo`050<30`0000000000000000020P800=`3oool01020P8000000
0000000000040?ooo`040820P000000000000820P0l0oooo0`0000000`30`<00oooo0?ooo`0;0?oo
o`050820P000000000000820P03oool03Oooool000cooooo603oool00`20P80000000820P00K0?oo
o`030820P0000000P8200080000000<0P8200?ooo`3oool01@3ooolC000000030820P03oool0oooo
00@0oooo00<0P82000000020P8000P0000000`20P800oooo0?ooo`0<0?ooo`050820P00000000000
00000020P8009P3oool01020P800000000000020P8040?ooo`040820P000000000000820P0d0oooo
00<0P82000000020P8000P0000000`20P800oooo0?ooo`0<0?ooo`050820P0000000000000000020
P800303oool3000000<0oooo00<0P8200000003oool04P3oool00`20P80000000000000H0?ooo`<0
00003@3oool00`20P80000000820P002000000030820P03oool0oooo00d0oooo1000000<0?ooo`<0
0000;`3oool4000003H0oooo00D0P82000000000000000000820P0030?ooo`040820P00000000000
0820P0l0oooo0`0000000`20P800oooo0?ooo`0;0?ooo`050820P000000000000820P03oool03Ooo
ool000cooooo603oool00`20P80000000820P00L0?ooo`80@4100P00000S0?ooo`80@4100P00000S
0?ooo`030820P0000000000000D0000000<0P8200?ooo`3oool0303oool01020P800000000000020
P8040?ooo`040820P000000000000820P0h0oooo0P10@40200000200oooo0`0000040?ooo`030000
0020P800oooo0140oooo00<0P820000000000000603oool3000000h0oooo0P10@40200000200oooo
0`00000`0?ooo`060820P0000000000000000020P800`<30=03oool3000000050820P03oool0oooo
0?ooo`20P8000P0000000`20P800oooo0?ooo`0<0?ooo`030820P000000000000080@41000<0`<30
0?ooo`3oool02P3oool01@20P800000000000020P800oooo00gooooo000<oooooaP0oooo00<0P820
00000020P800703oool01030`<00000000000000000S0?ooo`040<30`00000000000000002<0oooo
00<0`<300820P020P8001@20P8000`30`<00oooo0?ooo`0<0?ooo`040<30`00000000000000000@0
oooo00@0P820000000000000P8203P3oool01030`<00000000000000000P0?ooo`<00000103oool2
0410@180oooo00@0`<30000000000000P8205`3oool3000000h0oooo00@0`<300000000000000000
803oool3000002H0oooo00<0@4100820P03oool02@3oool01P10@4000000000000000000@4100<30
`380oooo00@0@410000000000000@4100`3oool01030`<00000000000020P80>0?ooo`060820P000
000000000820P030`<000000303oool00`20P8000000000000020?ooo`gooooo000<oooooaP0oooo
00<0P82000000020P8007@3oool2000000030410@03oool0oooo0280oooo0P0000000`10@400oooo
0?ooo`0i0?ooo`<00000103oool01020P800000000000020P80?0?ooo`80000000<0@4100?ooo`3o
ool07P3oool3000000@0oooo00<0P8200000003oool04P3oool2000000030820P03oool0oooo01D0
oooo0`00000?0?ooo`80000000<0@4100?ooo`3oool07P3oool3000002D0oooo00@0`<3000000000
0000@4102P3oool00`30`<00P82000000002000000030410@030`<00oooo02l0oooo00@0P8200000
000000000000103oool2000000030410@03oool0oooo00`0oooo0`0000002030`<00oooo0820P010
@400P8200410@0000000`<301`3oool300000080oooo3Oooool000cooooo603oool00`20P8000000
0820P00L0?ooo`040820P000000000000820P2<0oooo00@0P820000000000000P820?03oool20000
00050820P03oool0oooo0?ooo`20P8000P0000000`20P800oooo0?ooo`0<0?ooo`040820P0000000
00000820P200oooo0`0000050?ooo`0300000020P800oooo0140oooo00<0P8200000000000005`3o
ool3000000h0oooo00@0P820000000000000P820803oool3000002H0oooo00D0`<30000000000000
@4100<30`00;0?ooo`060820P0000000000000000010@400`<30:`3oool00`20P80000000000000;
000000X0oooo0P30`<000`3oool0`<3000000002000000<0oooo00D0@41000000000000000000820
P0070?ooo`80000000<0@4100?ooo`3oool03Oooool000cooooo603oool00`20P80000000820P00L
0?ooo`040820P00000000000000002<0oooo00@0P8200000000000000000?03oool2000000050410
@03oool0oooo0?ooo`20P8000P0000000`20P800oooo0?ooo`0<0?ooo`040820P000000000000000
0200oooo0`0000050?ooo`0300000010@400oooo0140oooo00@0P820000000000000`<305P3oool3
000000h0oooo00@0P8200000000000000000803oool3000002P0oooo00@0@410000000000000`<30
303oool01P10@4000000000000000000@4100<30`2T0oooo00@0`<300820P020P800P8200`000000
1@10@400P8200820P020P800@410008000002`3oool00`30`<00P8200410@002000000030<30`03o
ool0oooo0080oooo00@0P820000000000000`<301`3oool2000000030820P03oool0oooo00gooooo
000<oooooaP0oooo00<0P82000000020P800703oool3000000030820P010@400oooo0240oooo0`00
00000`20P800@4100?ooo`0j0?ooo`030820P0000000000000<0oooo00@0`<30000000000000P820
3P3oool3000000030820P010@400oooo01h0oooo0P0000000`10@400oooo0?ooo`030?ooo`030820
P0000000oooo0180oooo0P0000000`20P800oooo0?ooo`0D0?ooo`030410@0000000000000h0oooo
0`0000000`20P800@4100?ooo`0N0?ooo`80000000<0@4100?ooo`3oool09`3oool20410@0h0oooo
00<0`<300410@00000000P0000000`10@400`<300?ooo`0[0?ooo`<00000103oool2000000030<30
`03oool0oooo01`0oooo00<0P8200000000000000`3oool=ooooo`003?oooolH0?ooo`030820P000
0000P82001`0oooo0`0000000`3oool0@4100820P0060?oooa<0000000<0P8200?ooo`3oool01@3o
ool3000000030?ooo`10@400P82003X0oooo00@0P820000000000000`<300`3oool2000000030820
P03oool0oooo00`0oooo0`0000000`3oool0@4100820P00M0?ooo`040<30`000000000000820P0D0
oooo00<0`<3000000020P8004P3oool2000000030410@03oool0oooo01@0oooo00<0P82000000000
00003P3oool3000000030?ooo`10@400P82001d0oooo00@0P820000000000000P820>`3oool00`30
`<00@41000000002000000030410@030`<00oooo02T0oooo0`0000040?ooo`030820P0000000P820
01h0oooo00<0P82000000020P8000`3oool=ooooo`003?oooolH0?ooo`030820P0000000P82001/0
oooo00@0P820000000000000@4100P3oool00`000000P8200820P002000000030<30`03oool00000
0180000000<0P8200?ooo`3oool0103oool01020P800000000000010@4020?ooo`0600000020P800
P8200410@0000000`<30=P3oool2000000050820P03oool0oooo0?ooo`10@4000P00000=0?ooo`04
0820P000000000000410@080oooo00D000000820P020P80000000410@00I0?ooo`040820P0000000
00000<30`0H0oooo00<000000820P03oool04@3oool00`20P80000000000000F0?ooo`040<30`000
000000000820P0`0oooo00@0P820000000000000@4100P3oool01@000000P8200820P0000000@410
01T0oooo0`0000000`30`<00oooo0?ooo`0l0?ooo`060820P0000000000000000010@400`<30:03o
ool00`20P8000000000000050?ooo`8000007P3oool2000000@0oooo3Oooool000cooooo603oool0
0`20P80000000820P00H0?ooo`040820P03oool0oooo0410@080000000@0P8200?ooo`3oool0`<30
100000000`20P800oooo0?ooo`0F0?ooo`040820P03oool0oooo0410@080000000@0P8200?ooo`3o
ool0`<30100000000`20P800oooo0?ooo`0`0?ooo`040<30`020P800P8200820P080000000D0@410
0820P020P800P8200410@002000000X0oooo00@0P8200?ooo`3oool0@4100P0000001020P800oooo
0?ooo`30`<04000001T0oooo00<0P8200000000000001`3oool00`20P80000000?ooo`0>0?ooo`04
0<30`020P800P8200410@08000001020P8000`30`<00oooo0?ooo`0@0?ooo`80000000<0P8200?oo
o`3oool01P3oool20<30`080oooo00@0@410000000000000P8200P3oool00`30`<00000000000002
000001T0oooo0`0000110?ooo`060820P0000000000000000010@400`<309P3oool01030`<000000
00000020P8040?ooo`030820P0000000P82001`0oooo00<0P82000000030`<00103oool=ooooo`00
3?oooolH0?ooo`030820P0000000P82001T0oooo0P20P802000000030410@03oool0oooo0080oooo
00D0`<300410@000000000000<30`00I0?ooo`80P8200P0000000`10@400oooo0?ooo`020?ooo`05
0<30`020P800000000000030`<00<`3oool30820P0030410@0000000000000@0P8200P0000000`30
`<00oooo0?ooo`080?ooo`80P8200P0000000`10@400oooo0?ooo`020?ooo`040<30`010@4000000
0410@1T0oooo0P0000000`20P800oooo0?ooo`050?ooo`030<30`0000000`<3000l0oooo0`20P803
000000@0P8204P3oool00`20P80000000410@0090?ooo`030<30`020P800P8200080000000<0@410
0?ooo`3oool00P3oool01030`<00@41000000010@40H0?ooo`040820P000000000000820P4<0oooo
00<0`<300410@00000000P0000000`20P800`<300?ooo`0S0?ooo`030410@0000000P82000D0oooo
00<0@4100000003oool06`3oool00`000000@4100?ooo`040?ooo`gooooo000<oooooaP0oooo00<0
P82000000020P800Q@3oool2000000070<30`03oool0oooo0?ooo`20P80000000820P00_0?ooo`03
0<30`0000000000000T0oooo00<000000820P03oool04@3oool01020P800000000000030`<0F0?oo
o`800000;`3oool00`10@4000000000000160?ooo`030<30`010@40000000080000000<0@4100820
P03oool08@3oool00`30`<000000000000020?ooo`040<30`000000000000?ooo`80@4106P3oool2
0410@0H0oooo3Oooool000cooooo603oool00`20P80000000820P0250?ooo`80000000<0P8200?oo
o`3oool00P3oool2000002l0oooo00<0P82000000020P8002@3oool00`10@40000000?ooo`0A0?oo
o`040820P000000000000820P1H0oooo00<0P82000000020P800;P3oool2000000030820P03oool0
oooo03<0oooo00<0P8200?ooo`3oool04@3oool00`20P800@41000000002000000030820P03oool0
oooo01l0oooo00D0@41000000020P800oooo0820P002000000040820P03oool000000410@1P0oooo
00<0`<300410@03oool01P3oool=ooooo`003?oooolH0?ooo`030820P0000000P82008D0oooo00<0
P82000000020P800103oool00`30`<0000000820P00^0?ooo`0300000010@400oooo00T0oooo00<0
P82000000030`<004P3oool2000000030820P03oool0oooo01D0oooo00<0@4100000003oool0;03o
ool00`20P80000000820P00e0?ooo`040410@000000000000410@1<0oooo00<0`<300410@0000000
0P0000000`10@400`<300?ooo`0N0?ooo`040410@0000000`<300<30`080000000D0`<300?ooo`3o
ool0@4100820P00F0?ooo`030820P010@400oooo00L0oooo3Oooool000cooooo603oool00`20P800
00000820P0260?ooo`8000001@3oool00`10@40000000<30`00/0?ooo`030410@0000000oooo00/0
oooo00<000000820P03oool04@3oool00`20P80000000000000G0?ooo`030<30`0000000@41002/0
oooo00<0`<3000000020P800=P3oool01@30`<00@410000000000000@41001@0oooo00<0`<300820
P00000000P0000000`10@400P8200?ooo`0M0?ooo`050820P0000000000000000030`<00103oool2
0820P1@0oooo00<0@4100820P03oool0203oool=ooooo`003?oooolH0?ooo`030820P0000000P820
08H0oooo00P0@4100000003oool0oooo0<30`0000000@4100?ooo`80@410:`3oool00`30`<000000
0<30`00<0?ooo`80@4104P3oool00`30`<000000000000020?ooo`030<30`0000000@41001<0oooo
00<0`<3000000030`<00:P3oool20410@3T0oooo00D0P82000000000000000000<30`00E0?ooo`03
0820P000000000000080000000<0P8200<30`03oool0A03oool=ooooo`003?oooolH0?ooo`030820
P0000000P82008L0oooo00@000000820P03oool0P8200P0000020?ooo`80@410:@3oool00`20P800
00000<30`00=0?ooo`030820P0000000oooo01<0oooo00@000000820P03oool0P8200P00000D0?oo
o`030<30`0000000`<3002P0oooo0P10@40k0?ooo`040<30`010@40000000410@1L0oooo00<0P820
0410@00000000P0000000`10@400`<300?ooo`120?ooo`gooooo000<oooooaP0oooo00<0P8200000
0020P800Q`3oool01020P80000000?ooo`3oool2000000<0oooo0P20P80W0?ooo`030820P0000000
P82000l0oooo0P00000C0?ooo`040820P0000000oooo0?ooo`8000005P3oool00`000000oooo0?oo
o`0U0?ooo`030820P0000000oooo03d0oooo00<000000?ooo`3oool0603oool00`20P80000000000
000300000480oooo3Oooool000cooooo603oool00`20P80000000820P0280?ooo`050820P010@400
@4100410@030`<00103oool20820P2D0oooo00<0P8200410@03oool0403oool2000001@0oooo00D0
P8200410@010@400@4100<30`00F0?ooo`030<30`010@400oooo02@0oooo00<0P8200410@03oool0
F`3oool00`20P80000000000000200000080P820?`3oool=ooooo`003?oooolH0?ooo`030820P000
0000P8200?l0ooooQ03oool00`20P800@41000000003000000030410@020P800oooo03/0oooo3Ooo
ool000cooooo603oool00`20P80000000820P03[0?ooo`030<30`010@400@41009L0oooo00<0`<30
0820P010@400100000000`10@400P8200?ooo`0h0?ooo`gooooo000<oooooaP0oooo00<0P8200000
0020P800k03oool2000000030<30`03oool0oooo09P0oooo00<0P8200410@00000000`0000000`10
@400P8200?ooo`0e0?ooo`gooooo000<oooooaP0oooo00<0P82000000020P800k03oool01030`<00
000000000030`<2L0?ooo`030820P010@400000000@0000000<0P8200<30`03oool0<@3oool=oooo
o`003?oooolH0?ooo`030820P0000000P8200>d0oooo00<0P820000000000000O@3oool20<30`200
oooo00<0P8200410@0000000100000000`10@400P8200?ooo`0^0?ooo`gooooo000<oooooaP0oooo
00<0P82000000020P800kP3oool00`10@40000000410@01l0?ooo`030410@0000000`<300280oooo
00<0`<300820P00000001@0000000`10@400P8200<30`00Z0?ooo`gooooo000<oooooaP0oooo00<0
P82000000020P800kP3oool01030`<00000000000000001j0?ooo`050<30`0000000000000000010
@4009@3oool00`20P800@4100000000500000080P8209`3oool=ooooo`003?oooolH0?ooo`030820
P0000000P8200>l0oooo00@0P820000000000000@410N`3oool01010@400000000000010@40X0?oo
o`80P8201`0000001010@400P8200820P030`<0P0?ooo`gooooo000<oooooaP0oooo00<0P8200000
0020P800l03oool01010@400000000000010@41k0?ooo`040<30`000000000000820P2X0oooo00<0
`<300820P010@4001P0000000`20P800oooo0?ooo`0N0?ooo`gooooo000<oooooaP0oooo00<0P820
00000020P800l@3oool3000000030<30`03oool0oooo07X0oooo00<0P8200?ooo`3oool0;`3oool3
0820P0030<30`03oool0oooo01h0oooo3Oooool000cooooo603oool00`20P80000000820P03b0?oo
o`030410@0000000@4100=80oooo3Oooool000cooooo603oool00`30`<00P8200<30`03b0?ooo`03
0<30`020P800oooo0=80oooo3Oooool000coooooo`3ooooS0?ooo`gooooo000<ooooool0ooooh`3o
ool=ooooo`003?oooooo0?ooon<0oooo3Oooool000coooooo`3ooonG0?ooo`0300000030`<00oooo
04T0oooo3Oooool000coooooo`3ooonF0?ooo`030820P0000000000004X0oooo3Oooool000cooooo
o`3ooonF0?ooo`050410@0000000000000000030`<00B03oool=ooooo`003?oooooo0?oooiL0oooo
00D0`<3000000000000000000<30`0170?ooo`gooooo000<ooooool0ooooV03oool01030`<000000
0000000000170?ooo`gooooo000<ooooool0ooooVP3oool00`10@400P8200?ooo`160?ooo`gooooo
000<ooooool0ooooh`3oool=ooooo`003?oooooo0?ooon<0oooo3Oooool000coooooo`3ooooS0?oo
o`gooooo000<ooooool0ooooh`3oool=ooooo`003?oooooo0?ooon<0oooo3Oooool000coooooo`3o
oonT0?ooo`030<30`03oool0oooo03`0oooo3Oooool000coooooo`3ooonS0?ooo`040<30`0000000
00000<30`3`0oooo3Oooool000coooooo`3ooonT0?ooo`040410@000000000000<30`3/0oooo3Ooo
ool000coooooo`3ooonU0?ooo`040820P000000000000410@3X0oooo3Oooool000coooooo`3ooonV
0?ooo`040<30`000000000000<30`3T0oooo3Oooool000coooooo`3ooonW0?ooo`80`<30>P3oool=
ooooo`003?oooooo0?ooon<0oooo3Oooool000coooooo`3ooooS0?ooo`gooooo000<ooooool0oooo
h`3oool=ooooo`003?oooooo0?ooon<0oooo3Oooool000coooooo`3ooooS0?ooo`gooooo000<oooo
ool0oooo/@3oool00`20P800oooo0?ooo`0_0?ooo`gooooo000<ooooool0oooo/03oool01010@400
000000000030`<0_0?ooo`gooooo000<ooooool0oooo/03oool01@30`<00@410000000000000P820
02h0oooo3Oooool000coooooo`3ooonb0?ooo`050410@0000000000000000030`<00;03oool=oooo
o`003?oooooo0?oook<0oooo00@0P820000000000000@410;03oool=ooooo`003?oooooo0?oookD0
oooo00<0P8200?ooo`3oool0:`3oool=ooooo`00ooooooolooooo`00ooooooolooooo`00oooooool
ooooo`00ooooooolooooo`00ooooooolooooo`00ooooooolooooo`00ooooooolooooo`00oooooool
ooooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{169.125, 123.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 9.7 One iteration of Newton's method.", "Caption",
  CellTags->"Fig. 9.7"],

Cell[TextData[{
  "This solution is shown in Fig. ",
  ButtonBox["9.7",
    ButtonData:>"Fig. 9.7",
    ButtonStyle->"Hyperlink"],
  ".  Of course, this Taylor expansion is only valid for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " close to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ", which implies that the solution must be close to our initial guess ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " in order for Eq. ",
  ButtonBox["(9.11.2)",
    ButtonData:>"(9.11.2)",
    ButtonStyle->"Hyperlink"],
  "  to be accurate.\n\tEven so, there will still be some error, so we now \
iterate this expression, using ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " as our new initial guess, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\  = \ x\)]],
  ", and then reevaluating Eq. ",
  ButtonBox["(9.11.2)",
    ButtonData:>"(9.11.2)",
    ButtonStyle->"Hyperlink"],
  ".  The hope is that with each iteration of Eq. ",
  ButtonBox["(9.11.2)",
    ButtonData:>"(9.11.2)",
    ButtonStyle->"Hyperlink"],
  ", the result for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " will be closer to the actual solution of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = 0\)]],
  ". One can show that this will be true if ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " is sufficiently close to the actual solution, and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is a smooth function. We will perform similar recursive procedures in \
many other contexts throughout this book."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Write a sequence of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands, separated by semicolons and placed in a single cell, that \
performs a single iteration of this process, evaluating Eq. ",
  ButtonBox["(9.11.2)",
    ButtonData:>"(9.11.2)",
    ButtonStyle->"Hyperlink"],
  " for a given initial guess ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and then replacing ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  After defining the initial guess ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = \(-2.0\)\)]],
  " and the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ e\^x\  - \ cos(x)\)]],
  ", evaluate this cell several times until the displayed value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " no-longer changes.  What is the value of the root that you have found, to \
5 significant figures? "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Read about the ",
  StyleBox["While",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " help browser (or see  Cell ",
  ButtonBox["8.14",
    ButtonData:>{"Chapter8.nb", "Cell 8.14"},
    ButtonStyle->"Hyperlink"],
  " in Chapter 8 for an example of its use), and use this statement to \
automatically iterate the sequence of commands derived in part (a) until ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(f(
          x)\)\(|\)\(\(\[LessEqual]\)\(\ \)\(\[Epsilon]\)\)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 10\^\(-10\)\)]],
  "is the accuracy goal. Evaluating this ",
  StyleBox["While",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement once should produce the same result as the multiple evaluations \
performed in part (a)."
}], "Text",
  CellTags->"i:126"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " In this exercise we will develop our own numerical algorithm to fit  a \
data list ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_i, \ y\_i}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1,  ... , M\)]],
  ", to a sum of given functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_n\)(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1,  .. , P\)]],
  ". That is, we look for a function ",
  Cell[BoxData[
      \(TraditionalForm\`g(
          x)\  = \ \[Sum]\+\(n = 1\)\%P\( c\_n\) \(\(f\_n\)(x)\)\)]],
  " that provides the best fit to the data, where the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  "'s are fitting coefficients. The problem is to find the best values for \
these coefficients. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " If ",
  Cell[BoxData[
      \(TraditionalForm\`M = P\)]],
  ", then one can simply solve ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  " equations in the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " unknowns ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " in order to determine a functional form that passes through each data \
point:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\_i\  = \[Sum]\+\(n = 1\)\%M\( 
                c\_n\) \(\(f\_n\)(x\_i)\)\)\(,\)\(\ \ \ \)\(i = 
        1\)\(,\)\(...\)\(,\)\(M\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Using the ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, solve these equations for the following data, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_n\)(x)\  = \ x\^\(n - 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`P = 4\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(data\  = \ {{1. , 2. }, {0. , 5. }, {3. , \(-1. \)}, {2. , 
          0. }}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.203"],

Cell[TextData[{
  "Compare your result to that obtained using ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " When ",
  Cell[BoxData[
      \(TraditionalForm\`P < M\)]],
  " there are too many data points for the fitting function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " to go through every point. However, we can minimize the error between the \
function and the data. If we define the error as"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`error\  = \ \[Sum]\+\(j = 1\)\%M\((g(x\_j) - y\_j)\)\
\^2\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "show that the error is extremized when the ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " fitting coefficients satisfy the following set of ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " linear equations:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Sum]\+\(j = 1\)\%M\(\( f\_k\)(
            x\_j)\) \((\[Sum]\+\(n = 1\)\%P\( c\_n\) \(\(f\_n\)(x\_j)\) - 
              y\_j)\) = 0, \ \ k = 1,  ... , P\)]]], "NE5",
  CellTags->"(9.11.3)"],

Cell[TextData[{
  "(Hint: take the derivative of the error with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  ".) Note that since there is a unique solution for the extremum, and since \
the error becomes large and positive as any one of the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  "'s become large, the extremum must be a minimum. The solution to Eqs. ",
  ButtonBox["(9.11.3",
    ButtonData:>"(9.11.3)",
    ButtonStyle->"Hyperlink"],
  ") is called the ",
  StyleBox["least-squares fit",
    FontSlant->"Italic"],
  " to the data."
}], "Text",
  CellTags->"i:138"],

Cell[TextData[{
  "(c) Using the ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, set up and solve these equations for the following data, taking \
",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_n\)(x)\  = \ x\^\(n - 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`P = 4\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(data\  = \ 
        Table[s = Random[]; {s, \ 
            Exp[\(-3\) s] +  .1 \((Random[] -  .5)\)}, {40}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.204"],

Cell[TextData[{
  "Plot the data together with the function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  ". Compare this function to that found using ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " In this exercise we will develop our own numerical integration scheme, in \
order to compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( f(t)\) \[DifferentialD]t\)]],
  " for some given function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and given integration bounds ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". The simplest method is to cut the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  " into a grid of ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " values,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), "=", " ", 
            RowBox[{"a", " ", "+", " ", 
              RowBox[{"n", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]}]}], ",", " ", \(n = 0\), ",",
           "1", ",", "2", ",", \(\(...\) \(M\)\)}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontSlant->"Plain"], \(\((b - a)\)/M\)}], TraditionalForm]]],
  ". Then the integral can be expressed as a sum of integrals:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( f(
              t)\) \[DifferentialD]t = \[Sum]\+\(n = 0\)\%\(M - \
1\)\[Integral]\_\(t\_n\)\%\(t\_\(n + 1\)\)\(f(t)\) \[DifferentialD]t\)]],
  "."
}], "NE5",
  CellTags->"(9.11.4)"],

Cell[TextData[{
  "Now, if the grid is sufficiently fine, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " varies little in each integral, so that we can replace it by its initial \
value in each integral:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(t\_n\)\%\(t\_\(n + 1\)\)\(f(
                  t)\) \[DifferentialD]t\  \[TildeEqual] \
\[Integral]\_\(t\_n\)\%\(t\_\(n + 1\)\)\(f(t\_n)\) \[DifferentialD]t\), "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", \(f(t\_n)\)}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "This approximation, together with Eq. ",
  ButtonBox["(9.11.4)",
    ButtonData:>"(9.11.4)",
    ButtonStyle->"Hyperlink"],
  ", is called a ",
  StyleBox["Reimann sum",
    FontSlant->"Italic"],
  " approximation to the integral, and is the approximation used to \
numerically integrate differential equations in Eulers method (see Sec. ",
  ButtonBox["1.4.3",
    ButtonData:>{"Chapter1.nb", "c:24"},
    ButtonStyle->"Hyperlink"],
  "). However, it is not a particularly accurate approximation: we might just \
as well have used the final value as the initial value, obtaining the \
slightly different result "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(t\_n\)\%\(t\_\(n + 1\)\)\(f(
                t\_n)\) \[DifferentialD]t\), " ", "\[TildeEqual]", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", \(f(t\_\(n + 1\))\)}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
It is better to split the difference, and take the average of these \
two extremes:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_\(t\_n\)\%\(t\_\(n + 1\)\)\(f(
              t\_n)\) \[DifferentialD]t\), "\[TildeEqual]", 
        RowBox[{
          FractionBox[
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " "}], "2"], 
          "[", \(f(t\_n) + f(t\_\(n + 1\))\), "]"}], " "}], 
      TraditionalForm]]]], "NE5",
  CellTags->{"(9.11.5)", "i:134"}],

Cell[TextData[{
  "This approximation is called the ",
  StyleBox["trapezoidal rule",
    FontSlant->"Italic"],
  ", and is used in the second-order predictor-corrector method (Sec. ",
  ButtonBox["1.4.4",
    ButtonData:>{"Chapter1.nb", "c:25"},
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text"],

Cell[TextData[{
  "\tUsing Eqs.",
  ButtonBox[" (9.11.4)",
    ButtonData:>"(9.11.4)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(9.11.5)",
    ButtonData:>"(9.11.5)",
    ButtonStyle->"Hyperlink"],
  ", evaluate the following integrals numerically, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10, 20, 40\)]],
  ". (Use the intrinsic function ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".) For each value of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " determine the error in the result by comparing to the exact result. Show \
that the error scales roughly as ",
  Cell[BoxData[
      \(TraditionalForm\`1/M\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Pi] sin\ t \[DifferentialD]t\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-5\)\%5\( \
\[ExponentialE]\^\(-t\^2\)\) \[DifferentialD]t\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%1\( x\^3\) \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "[A proof that the error obeys this ",
  Cell[BoxData[
      \(TraditionalForm\`1/M\^2\)]],
  " scaling is discusssed in Sec. ",
  ButtonBox["1.4.4",
    ButtonData:>{"Chapter1.nb", "c:25"},
    ButtonStyle->"Hyperlink"],
  ", and Exercise ",
  ButtonBox["(13)",
    ButtonData:>{"Chapter1.nb", "ex 13"},
    ButtonStyle->"Hyperlink"],
  " of that section. See also the next exercise.]"
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Higher-order integration schemes",
    FontSlant->"Italic"],
  ". There are several ways to improve on the trapezoidal rule. In one \
approach, the integrals in Eq. ",
  ButtonBox["(9.11.4)",
    ButtonData:>"(9.11.4)",
    ButtonStyle->"Hyperlink"],
  " are performed over larger sets of data. For instance, we can keep three \
adjacent grid points in each integral:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_a\%b\( f(t)\) \[DifferentialD]t\), "=", 
          RowBox[{
            UnderoverscriptBox[
              StyleBox["\[CapitalSigma]",
                FontSize->18], GridBox[{
                  {\(n = 0\)},
                  {\((n\ even)\)}
                  }], \(M - 
                2\)], \(\[Integral]\_\(t\_n\)\%\(t\_\(n + \ 2\)\)\(f(
                  t)\) \[DifferentialD]t\)}]}], TraditionalForm]]],
  "."
}], "NE5",
  CellTags->"(9.11.6)"],

Cell[TextData[{
  "With three grid points included in each integral, we can fit these points \
to a polynomial in order to obtain an approximate description of the \
function, and then perform the integration over this polynomial analytically. \
With only three grid points, the highest-order polynomial that can be \
uniquely defined by the fit is a parabola. We can perform this fit using the \
function ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and we do so in Cell ",
  ButtonBox["9.205",
    ButtonData:>"Cell 9.205",
    ButtonStyle->"Hyperlink"],
  " on the three data points corresponding to ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(data\  = \ {{0, f[0]}, {\[CapitalDelta]t, 
          f[\[CapitalDelta]t]}, {2  \[CapitalDelta]t, 
          f[2\ \[CapitalDelta]t]}}; \), "\[IndentingNewLine]", 
    \(Chop[
      Simplify[Fit[data, {1, t, t^2}, t], \[CapitalDelta]t > 0]]\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 9.205"],

Cell[BoxData[
    \(1.`\ f[0] + 0.`\ f[\[CapitalDelta]t] + 0.`\ f[2\ \[CapitalDelta]t] + 
      t\^2\ \((\(0.5`\ f[0]\)\/\[CapitalDelta]t\^2 - \(1.`\ \
f[\[CapitalDelta]t]\)\/\[CapitalDelta]t\^2 + \(0.5`\ f[2\ \[CapitalDelta]t]\)\
\/\[CapitalDelta]t\^2)\) + 
      t\ \((\(-\(\(1.5`\ f[
                      0]\)\/\[CapitalDelta]t\)\) + \(2.`\ f[\[CapitalDelta]t]\
\)\/\[CapitalDelta]t - \(0.5`\ f[2\ \
\[CapitalDelta]t]\)\/\[CapitalDelta]t)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " ",
  StyleBox["Fit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only provides numerical approximations for the coefficients in the \
fitting function, but one can see that the coefficients in this expression \
are simple fractions or integers. [One could, if one wished, obtain exact \
expressions for the coefficients by using the fitting procedure outlined in \
Exercise (7)(a).] With this fit, one can now analytically integrate over the \
interval from 0 to 2\[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[%, {t, 0, 2  \[CapitalDelta]t}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.206"],

Cell[BoxData[
    \(0.33333333333333326`\ \[CapitalDelta]t\ f[0] + 
      1.3333333333333335`\ \[CapitalDelta]t\ f[\[CapitalDelta]t] + 
      0.33333333333333326`\ \[CapitalDelta]t\ f[
          2\ \[CapitalDelta]t]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This expression is known as ",
  StyleBox["Simpson's rule",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_\(t\_n\)\%\(t\_\(n + \ 2\)\)\(f(
              t)\) \[DifferentialD]t\), "=", 
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            " ", \((\(1\/3\) \(f(t\_n)\) + \(4\/3\) \(f(
                    t\_\(n + 1\))\) + \(1\/3\) \(f(t\_\(n + 2\))\))\)}], "+", 
          
          RowBox[{"O", "(", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "5"], ")"}]}]}], 
      TraditionalForm]]]], "NE5",
  CellTags->"i:135"],

Cell[TextData[{
  "The fact that the error in this integral scales as ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "5"], TraditionalForm]]],
  "  can be proven by Taylor-expanding the equation around ",
  Cell[BoxData[
      \(TraditionalForm\`f(t\_n)\)]],
  " (to simplify the notation, we take the case ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  "):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Series[
      Integrate[
          f[t], {t, 0, 
            2  \[CapitalDelta]t}]\  - \ \[CapitalDelta]t \((1/3\ f[0]\  + \ 
              4/3\ f[\[CapitalDelta]t]\  + 
              1/3\ f[2\ \[CapitalDelta]t])\), {\[CapitalDelta]t, 0, 
        5}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.207"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        RowBox[{"-", 
          RowBox[{\(1\/90\), " ", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((4)\),
                  Derivative],
                MultilineFunction->None], "[", "0", "]"}], 
            " ", \(\[CapitalDelta]t\^5\)}]}], "+", 
        InterpretationBox[\(O[\[CapitalDelta]t]\^6\),
          SeriesData[ \[CapitalDelta]t, 0, {}, 5, 6, 1]]}],
      SeriesData[ \[CapitalDelta]t, 0, {
        Times[ 
          Rational[ -1, 90], 
          Derivative[ 4][ f][ 0]]}, 5, 6, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Simpson's rule, for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10, 20, \ and\ 40\)]],
  ", evaluate the integrals and the errors in (i) Exercise (8)(a); (ii) \
Exercise (8)(b); (iii) Exercise (8)(c). How do the errors scale with ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "? "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show using this approach that the trapezoidal rule, Eq. ",
  ButtonBox["(9.11.5)",
    ButtonData:>"(9.11.5)",
    ButtonStyle->"Hyperlink"],
  ",  stems from a ",
  StyleBox["linear ",
    FontSlant->"Italic"],
  "fit  to ",
  Cell[BoxData[
      \(TraditionalForm\`f(t\_n)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f(t\_\(n + 1\))\)]],
  ", and find the error in the equation. "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use this analysis to prove ",
  StyleBox["Bode's rule",
    FontSlant->"Italic"],
  " (whereby 4th-order polynomials are fitted to 5 adjacent grid points):"
}], "Text",
  CellTags->"i:136"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_\(t\_n\)\%\(t\_\(n + \ 4\)\)\(f(
              t)\) \[DifferentialD]t\), "=", 
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            " ", \((\(14\/45\) \(f(t\_n)\) + \(64\/45\) \(f(
                    t\_\(n + 1\))\) + \(24\/45\) \(f(
                    t\_\(n + 2\))\) + \(64\/45\) \(f(
                    t\_\(n + 3\))\) + \(14\/45\) \(f(t\_\(n + 4\))\))\)}], 
          "+", 
          RowBox[{"O", "(", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "6"], ")"}]}]}], 
      TraditionalForm]]]], "NE5"],

Cell[TextData[{
  "[Note that all of the integration rules considered here break the interval \
",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  " into a ",
  StyleBox["uniform",
    FontSlant->"Italic"],
  " grid of points, resulting in rules of the form"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( f(
              t)\) \[DifferentialD]t \[TildeEqual] \ \[Sum]\+\(n = 0\)\%M\( 
                w\_n\) \(f(t\_n)\)\)]],
  ",    ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), " ", "=", " ", 
          RowBox[{"a", " ", "+", " ", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where the weighting coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)]],
  " depend on the method used. We have seen that one obtains approximations \
with different accuracies depending on the choice of the ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)]],
  "'s. However, even more accuracy can be achieved if we allow the grid to be \
",
  StyleBox["nonuniform",
    FontSlant->"Italic"],
  ", and determine the grid point locations that provide the best accuracy. \
For broad classes of smooth functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " the best grid point locations can be shown to be at the zeros of certain \
well-known ",
  StyleBox["orthogonal polynomials",
    FontSlant->"Italic"],
  ". This is the general idea behind ",
  StyleBox["Gaussian quadrature",
    FontSlant->"Italic"],
  ",  the default method used for one-dimensional integrals by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s intrinsic function ",
  StyleBox["NIntegrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". A detailed discussion of the method can be found in ",
  ButtonBox["Conte and de Boor (1980)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". ] "
}], "Text",
  CellTags->"i:137"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Use Bode's rule to evaluate the integrals in (i) Exercise (8)(a); (ii) \
Exercise (8)(b); ",
  " (iii) Exercise (8)(c). Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 8, 16, \ and\ 32\)]],
  ", and determine how the error scales with ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " In this exercise we will derive our own cubic spline interpolation \
algorithm. As described in Sec. ",
  ButtonBox["9.11.3",
    ButtonData:>"c:63",
    ButtonStyle->"Hyperlink"],
  ", we require a sequence of  third-order polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_j\)(
          x)\  = \ \[Sum]\+\(i = 0\)\%3\( c\_\(n\ i\)\) x\^i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, \(\(...\) \(M\)\) - 1\)]],
  ", chosen to pass through a set of data ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_j, \ y\_j}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1,  ... , M\)]],
  ", where the ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "'s are ordered consecutively from lowest to highest values as ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " increases. Each polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_j\)(x)\)]],
  " in the set is used only between grid points ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(j + 1\)\)]],
  ", and is chosen so that the first and second derivatives match those of \
neighboring polynomials at their common grid points, so that the \
interpolating function is continuous and has continuous first and second \
derivatives. Thus, the polynomials satisfy the following linear equations:"
}], "Text",
  CellTags->"i:139"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(p\_j\)(x\_j) = y\_j, \ 
      j = 1, \(\(...\) \(M\)\) - 
        1, \[IndentingNewLine]\(p\_j\)(x\_\(j + 1\)) = y\_\(j + 1\), \ 
      j = 1, \(\(...\) \(M\)\) - 
        1, \[IndentingNewLine]\(p\_j\^\[Prime]\)(
          x\_\(j + 1\)) = \(p\_\(j + 1\)\^\[Prime]\)(x\_\(j + 1\)), \ 
      j = 1, \(\(...\) \(M\)\) - 
        2, \[IndentingNewLine]\(p\_j\^\[DoublePrime]\)(
          x\_\(j + 1\)) = \(p\_\(j + 1\)\^\[DoublePrime]\)(x\_\(j + 1\)), \ 
      j = 1, \(\(...\) \(M\)\) - 2. \)]],
  " "
}], "NE5"],

Cell[TextData[{
  "These ",
  Cell[BoxData[
      \(TraditionalForm\`4  M - 6\)]],
  " equations are almost enough to uniquely specify the ",
  Cell[BoxData[
      \(TraditionalForm\`4 \((M - 1)\)\)]],
  " coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(n\ i\)\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`M - 1\)]],
  " polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_n\)(x)\)]],
  ", but we need two more equations. Typically, one chooses that the second \
derivative vanish at each end, providing the equations"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(p\_1\^\[DoublePrime]\)(
          x\_1) = \(\(p\_M\^\[DoublePrime]\)(x\_M) = 0\)\)]],
  "."
}], "NE5"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", set up and solve these coupled linear equations for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(n\ i\)\)]],
  ", given the data defined in Cell ",
  ButtonBox["9.188",
    ButtonData:>"Cell 9.188",
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The following interpolation function will evaluate the spline for any \
value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " chosen between ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_M\)]],
  ", given that each polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_j\)(x)\)]],
  " has been defined as a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["p[j,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Here, the solution from ",
  StyleBox["Solve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is assumed to be a simple list of substitution commands for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(n\ i\)\)]],
  "'s called ",
  StyleBox["sol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text"],

Cell[BoxData[
    \(finterp[x_, 
        data_]\  := \ \((M = Length[data]; \ j1\  = \ 1; \ jM = M; \ 
          While[jM - j1 > 1, jav = Floor[\((jM + j1)\)/2]; 
            If[data[\([jav, 1]\)] > x, \ jM = jav, j1 = jav]]; \ 
          p[j1, x])\)\  /. sol\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.208"],

Cell[TextData[{
  "This interpolation function must find the correct polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`p\_j\)]],
  " associated with a given ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ": it corresponds to the ",
  Cell[BoxData[
      \(TraditionalForm\`x\_j\)]],
  " value in the data set nearest to but less than ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". We use a division method, recursively dividing the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([x\_1, \ x\_M]\)\)]],
  " in half until ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " falls between consecutive grid points. (A faster method is possible if \
the grid points are evenly spaced, with spacing ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". Then ",
  Cell[BoxData[
      FormBox[
        RowBox[{"j", "=", " ", 
          RowBox[{"Min", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"Floor", "[", 
                  RowBox[{\((x - x\_1)\), "/", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]]}], 
                  StyleBox["]",
                    FontSlant->"Italic"]}], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["+",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["1",
                  FontSlant->"Plain"]}], 
              StyleBox[",",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontSlant->"Plain"], 
              StyleBox["M",
                FontSlant->"Italic"]}], 
            StyleBox["]",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ". )\nUse this function to plot the spline interpolation found in part (a) \
in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) \[LessEqual] \ x \[LessEqual] \ 1\)]],
  ". "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "9.12 Summary of Basic",
  StyleBox[" Mathematica",
    FontSlant->"Italic"],
  " Commands"
}], "Subtitle",
  CellTags->"c:67"],

Cell["", "Text"],

Cell["\<\
This section summarizes some of the commands learned in the \
previous sections. For quick reference, you may want to print it out and keep \
it beside the computer as you work.\
\>", "Text"],

Cell[TextData[{
  "Many of the following tables are adapted from similar tables in ",
  StyleBox[ButtonBox["The Mathematica Book",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ". More information can be found there, or by using the online help \
function (see Sec. ",
  ButtonBox["9.7",
    ButtonData:>"c:36",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell["9.12.1 Elementary Functions", "Subsubtitle",
  CellTags->"c:68"],

Cell["", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {\(x + y\), "add"},
                {\(-x\), "minus"},
                {\(x/y\), "divide"},
                {\(\(x\)\(\ \)\(y\)\(\ \ \ \)\(or\)\(\ \)\(x\)\(*\)\(y\)\(\ \
\)\), "multiply"},
                {\(x^y\), "power"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Arithmetic operations", "Caption"],

Cell[TextData[{
  "The arguments of all ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions are enclosed with square brackets.\nThe names of all intrinsic \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions begin with capital letters."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell["Two important rules about functions.", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Sqrt",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "x", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(square\ root\ \((\@x)\)\)},
                {
                  RowBox[{
                    StyleBox["Abs",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "x", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(absolute\ value\)},
                {
                  RowBox[{
                    StyleBox["Mod",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], \(x, n\), 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(x\ modulo\ n\)},
                {
                  RowBox[{"n", 
                    StyleBox["!",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(factorial\ function\)},
                {
                  RowBox[{
                    StyleBox["Exp",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "x", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(exponential\ \
\((\[ExponentialE]\^x)\)\)},
                {
                  RowBox[{
                    StyleBox["Log",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "x", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(natural\ logarithm\ \((\(log\_\
\[ExponentialE]\) x)\)\)},
                {
                  RowBox[{
                    StyleBox["Log",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], \(b, x\), 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(log\ to\ the\ base\ b\ \((\(log\_b\) 
                        x)\)\)},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["Sin",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "x", 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], ",", 
                    RowBox[{
                      StyleBox["Cos",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "x", 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], ",", 
                    RowBox[{
                      StyleBox["Tan",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "x", 
                      StyleBox["]",
                        FontFamily->"Courier",
                        
                        FontWeight->
                          "Bold"]}]}], \(trigonometric\ functions\ \
\((arguments\ in\ radians)\)\)},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ArcSin",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "x", 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], ",", 
                    RowBox[{
                      StyleBox["ArcCos",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "x", 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], ",", 
                    RowBox[{
                      StyleBox["ArcTan",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], "x", 
                      StyleBox["]",
                        FontFamily->"Courier",
                        
                        FontWeight->
                          "Bold"]}]}], \(inverse\ trigonometric\ \
functions\)},
                {
                  StyleBox[\(Random[]\),
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(random\ real\ number\ in\ the\ range\ from\ \
0\ to\ 1\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some elementary mathematical functions. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  StyleBox["I",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(\[ImaginaryI]\  = \ \@\(-1\)\)},
                {
                  StyleBox["Pi",
                    FontFamily->"Courier",
                    
                    FontWeight->"Bold"], \(\[DoubledPi] \[TildeEqual] \ 
                      3.14159 ... \)},
                {
                  StyleBox["E",
                    FontFamily->"Courier",
                    FontWeight->"Bold",
                    
                    FontSlant->"Plain"], \(\[ExponentialE]\  \[TildeEqual] \ 
                      2.71828 ... \)},
                {
                  StyleBox["Degree",
                    FontFamily->"Courier",
                    
                    FontWeight->"Bold"], \(\[DoubledPi]/
                      180\ \((degree\ to\ radian\ conversion\ factor)\)\)},
                {
                  StyleBox["Infinity",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], "\[Infinity]"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some common mathematical constants. ", "Caption"],

Cell[TextData[Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{"x", " ", 
                    StyleBox["//",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    RowBox[{
                      StyleBox["N",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "  ", "or", "  ", 
                      RowBox[{
                        StyleBox["N",
                          FontFamily->"Courier",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["[",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], "x", 
                        StyleBox["]",
                          FontFamily->"Courier",
                          
                          FontWeight->
                            "Bold"]}]}]}], \(numerical\ value\ of\ x\)},
                {
                  RowBox[{
                    StyleBox["N",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], \(x, n\), 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(numerical\ value\ of\ x\ calculated\ to\ \
n - digit\ precision\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->"4.3"]], "Text"],

Cell["Numerical evaluation functions", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["NIntegrate",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"f", ",", 
                        RowBox[{"{", 
                          RowBox[{"x", ",", 
                            StyleBox["xmin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["xmax",
                              FontSlant->"Italic"]}], "}"}]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"\<\"numerical approximation to \"\>", 
                    StyleBox[
                      RowBox[{
                        
                        SubsuperscriptBox[
                          "\[Integral]", \
"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"xmin\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", "\<\
\"\\!\\(\\*StyleBox[\\\"\\\\\\\"xmax\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>"], 
                        " ", \(f\ d  x\)}],
                      "InlineFormula"]}]},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["NSum",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"f", ",", 
                        RowBox[{"{", 
                          RowBox[{"i", ",", 
                            StyleBox["imin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["Infinity",
                              FontFamily->"Courier",
                              FontWeight->"Bold"]}], "}"}]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"\<\"numerical approximation to \"\>", 
                    StyleBox[
                      RowBox[{
                        
                        UnderoverscriptBox[
                          "\[Sum]", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"imin\\\
\\\\\"\\\", \\\"TI\\\"]\\)\"\>", "\[Infinity]",
                          LimitsPositioning->True], " ", "f"}],
                      "InlineFormula"], "\<\" \"\>"}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"NSolve[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"lhs\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"==\\\\\\\"\\\", \\\"MB\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\"rhs\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MB\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"numerical solutions to some simple equations (eg. polynomials) \"\
\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["FindRoot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], \(f, {x, x\_0}\), 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(search\ for\ one\ numerical\ solution\ \
to\ an\ equation, \ starting\ at\ x\  = \ x\_0\)},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["FindMinimum",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], \(f, {x, x\_0}\), 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{
                    RowBox[{"search", " ", "for", " ", 
                      StyleBox["a",
                        FontSlant->"Plain"], " ", "local", " ", "minimum", 
                      " ", "of", " ", "f", " ", "starting", " ", "at", " ", 
                      "x"}], " ", "=", " ", \(x\_0\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some numerical operations. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{"x", "+", 
                    RowBox[{
                      StyleBox["I",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], " ", 
                      "y"}]}], \(the\ complex\ number\ x + \[ImaginaryI]\ \
y\)},
                {
                  RowBox[{
                    StyleBox["Re",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "z", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(real\ part\)},
                {
                  RowBox[{
                    StyleBox["Im",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "z", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(real\ part\)},
                {
                  RowBox[{
                    StyleBox["Conjugate",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "z", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(complex\ conjugate\ \(z\^*\)\)},
                {
                  RowBox[{
                    StyleBox["Abs",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "z", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(absolute\ value\  | z | \)},
                {
                  RowBox[{
                    StyleBox["Arg",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "z", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->"Bold"]}], \(phase\ \[Phi]\ \ of\ \(z : \ 
                        z\) = \(\(|\)\(z\)\(|\)\(\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Phi]\)\)\)\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some complex number operations. ", "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
9.12.2 Using Previous Results; Substitution and Defining \
Variables\
\>", "Subsubtitle",
  CellTags->"c:69"],

Cell["", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  StyleBox["%",
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(\(previous\)\(\ \)\(result\)\(\ \)\)},
                {
                  StyleBox["%%",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], \(next - 
                    to - \(\(last\)\(\ \ \)\(result\)\(\ \)\)\)},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["%%",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], " ", "..."}], 
                    StyleBox["%",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], \((k\ times)\)}], 
                  RowBox[{
                    StyleBox[
                      RowBox[{
                        StyleBox["k",
                          FontSlant->"Italic"], "th"}]], " ", "previous", " ",
                     "result", "  "}]},
                {
                  RowBox[{
                    StyleBox["%",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "n", " "}], 
                  RowBox[{
                  "result", " ", "from", " ", "output", " ", "line", " ", 
                    RowBox[{
                      RowBox[{
                        StyleBox["Out",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["[",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], "n", 
                        StyleBox["]",
                          FontFamily->"Courier",
                          FontWeight->"Bold"]}], ".", " "}]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["\<\
A few of the ways to refer to results in previously-evaluated \
cells. \
\>", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{"x", 
                    StyleBox["=",
                      "MB"], 
                    StyleBox["value",
                      FontSlant->"Italic"], 
                    StyleBox["  ",
                      FontSlant->"Italic"]}], 
                  RowBox[{"assign", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "value", " ", "to", " ", 
                    "the", " ", "variable", " ", "x"}]},
                {
                  RowBox[{"x", 
                    StyleBox["=",
                      "MB"], 
                    RowBox[{"y", 
                      StyleBox["=",
                        "MB"], 
                      StyleBox["value",
                        FontSlant->"Italic"], 
                      StyleBox["  ",
                        FontSlant->"Italic"]}]}], 
                  RowBox[{"assign", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "value", " ", "to", " ", 
                    "both", " ", "x", " ", "and", " ", "y"}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"=.\\\\\\\"\\\", \\\"MB\\\"]\\) \
\[ThinSpace]or \[ThinSpace]\\!\\(\\*StyleBox[\\\"\\\\\\\"Clear[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", 
                  RowBox[{
                  "clear", "  ", "the", " ", "value", " ", "of", " ", 
                    StyleBox["\<\"x\"\>",
                      "TI"]}]},
                {
                  StyleBox[\(\(Clear["\"Global`*\""]\)\(\ \)\),
                    "MB"], \(clear\ all\ user - 
                    defined\ variables\ \((all\ variables\ in\ the\ Global\ \
context)\)\)},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["Remove",
                        "MB"], 
                      StyleBox["[",
                        "MB"], 
                      RowBox[{"x", 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}], 
                      StyleBox["]",
                        "MB"]}], 
                    StyleBox[" ",
                      
                      "MB"]}], \(clear\ the\ value\ of\ x\ and\ remove\ it\ \
from\ the\ set\ of\ user - defined\ variables\)},
                {
                  RowBox[{
                    StyleBox["?",
                      "MB"], 
                    RowBox[{"x", 
                      StyleBox["\<\"\"\>",
                        
                        "\n\"TI\""]}]}], \(provide\ the\ definition\ of\ \
x\)},
                {
                  RowBox[{
                    StyleBox["?",
                      "MB"], 
                    RowBox[{
                      StyleBox["Global`",
                        "MB"], 
                      StyleBox["*",
                        "MB"], 
                      StyleBox["\<\"\"\>",
                        "\n\"TI\""]}]}], \(list\ \ all\ user - 
                    defined\ variables\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Assigning, removing,  and checking values. ", "Caption"],

Cell[TextData[{
  StyleBox["x y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " means ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " times ",
  StyleBox["y",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["xy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with no space means a variable named ",
  StyleBox["xy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["3x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " means ",
  StyleBox["3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " times ",
  StyleBox["x",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "Some points to watch when using variables in ",
  StyleBox["Mathematica", "SO"],
  ". "
}], "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["expr",
                      FontSlant->"Italic"], 
                    StyleBox["/.",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", 
                    RowBox[{"x", "\[Rule]", 
                      StyleBox["value",
                        FontSlant->"Italic"]}]}], 
                  RowBox[{"replace", " ", "x", " ", "by", " ", 
                    StyleBox["value",
                      FontSlant->"Italic"], " ", "in", " ", 
                    StyleBox["expr",
                      FontSlant->"Italic"]}]},
                {
                  RowBox[{
                    StyleBox["expr",
                      FontSlant->"Italic"], 
                    StyleBox["/.",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", 
                    RowBox[{"{", 
                      RowBox[{
                        RowBox[{"x", "\[Rule]", 
                          StyleBox[\(value\_1\),
                            FontSlant->"Italic"]}], 
                        StyleBox[",",
                          FontSlant->"Italic"], 
                        StyleBox[" ",
                          FontSlant->"Italic"], 
                        StyleBox[\(y \[Rule] value\_2\),
                          FontSlant->"Italic"], 
                        StyleBox[",",
                          FontSlant->"Italic"], 
                        StyleBox["...",
                          FontSlant->"Italic"]}], 
                      StyleBox["}",
                        FontSlant->"Italic"]}], 
                    StyleBox[" ",
                      
                      FontSlant->
                        "Italic"]}], \(perform\ several\ replacements\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Ways to replace symbols in expressions", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[GridBox[{
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Expand[\\\\\\\"\\\", \\\"MB\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"multiply out products and powers \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ExpandAll[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"apply \\!\\(\\*StyleBox[\\\"\\\\\\\"Expand\\\\\\\"\\\", \
\\\"MB\\\"]\\) everywhere \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Factor[\\\\\\\"\\\", \\\"MB\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"reduce to a product of factors \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Together[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"put all terms over a common denominator \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Apart[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"separate into terms with simple denominators \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Cancel[\\\\\\\"\\\", \\\"MB\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"cancel common factors between numerators and denominators \"\>"},
              {
                RowBox[{
                "                             ", \
"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Simplify[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>"}], "\<\"try a sequence of algebraic transformations and give the \
smallest form of \\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\) found \"\>"},
              {
                RowBox[{
                  RowBox[{
                    StyleBox["Collect",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["\<\"\"\>",
                          "\n\"MB\""], 
                        StyleBox["expr",
                          "TI"]}], 
                      StyleBox[",",
                        "TI"], 
                      RowBox[{
                        StyleBox["x",
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      "MB"]}], 
                  StyleBox["\<\"\"\>",
                    "\n\"MB\""]}], "\<\"group together powers of \!\(\*
StyleBox[\\\"x\\\",\\nFontSlant->\\\"Italic\\\"]\) \"\>"},
              {
                RowBox[{
                  RowBox[{
                    StyleBox["TrigExpand",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["\<\"\"\>",
                        "\n\"MB\""], 
                      StyleBox["expr",
                        "TI"], 
                      StyleBox["\<\"\"\>",
                        "\n\"TI\""]}], 
                    StyleBox["]",
                      "MB"]}], 
                  StyleBox["\<\"\"\>",
                    
                    "\n\"MB\""]}], "\<\"expand out trigonometric expressions \
into a sum of terms \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"TrigFactor[\\\\\\\"\\\", \\\
\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", "\<\"factor \
trigonometric expressions into products of terms \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"TrigReduce[\\\\\\\"\\\", \\\
\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", "\<\"reduce \
trigonometric expressions using multiple angles \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"TrigToExp[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"convert trigonometric functions to exponentials \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ExpToTrig[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"convert exponentials to trigonometric functions \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"FunctionExpand[\\\\\\\"\\\",\
 \\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", \
"\<\"expand out special and other functions \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ComplexExpand[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"perform expansions assuming that all variables are real \"\>"},
              {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PowerExpand[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", 
                RowBox[{"\<\"transform \"\>", 
                  StyleBox[\(\((x  y)\)\^p\),
                    "InlineFormula"], "\<\" into \"\>", 
                  StyleBox[\(\(x\^p\) y\^p\),
                    "InlineFormula"], "\<\", etc. \"\>"}]}
              },
            ColumnAlignments->{Right, Left}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some functions for transforming algebraic expressions. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["Coefficient",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[\(expr, form\),
                        FontSlant->"Italic"], 
                      StyleBox["]",
                        FontWeight->"Bold",
                        FontSlant->"Italic"]}], "\n", "                ", 
                    RowBox[{
                      StyleBox["Numerator",
                        "MB"], 
                      StyleBox["[",
                        "MB"], 
                      RowBox[{
                        StyleBox["\<\"\"\>",
                          "\n\"MB\""], 
                        StyleBox["expr",
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}], 
                      StyleBox["]",
                        "MB"]}], 
                    StyleBox[" ",
                      "MB"]}], 
                  RowBox[{
                    RowBox[{"coefficient", " ", "of", " ", 
                      StyleBox["form",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["in",
                        FontSlant->"Plain"], 
                      StyleBox["  ",
                        FontSlant->"Plain"], 
                      StyleBox["expr",
                        FontSlant->"Italic"]}], 
                    "\n", "\<\"numerator of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Denominator[\\\\\\\"\\\", \
\\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"denominator of \\!\\(\\*StyleBox[\\\"\\\\\\\"expr\\\\\\\"\\\", \\\
\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Functions to pick out pieces of rational expressions. ", "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.12.3 Lists,Tables,Vectors and Matrices", "Subsubtitle",
  CellTags->"c:70"],

Cell[TextData[{
  "  \n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FrameBox[
            StyleBox[GridBox[{
                  {\({a, b, c}\), 
                    RowBox[{
                      StyleBox["a",
                        FontSlant->"Plain"], " ", "list"}]},
                  {
                    RowBox[{
                      RowBox[{
                        StyleBox["Part",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["[",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        RowBox[{
                          StyleBox["list",
                            FontFamily->"Times",
                            FontSlant->"Italic"], ",", "i"}], 
                        StyleBox["]",
                          FontFamily->"Courier",
                          FontWeight->"Bold"]}], "  ", 
                      StyleBox["or",
                        FontFamily->"Times",
                        FontSlant->"Plain"], 
                      StyleBox[
                        RowBox[{
                          StyleBox[" ",
                            FontFamily->"Times",
                            FontSlant->"Plain"], 
                          StyleBox[" ",
                            FontFamily->"Times",
                            FontSlant->"Italic"]}]], 
                      RowBox[{
                        StyleBox["list",
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox["[",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        RowBox[{
                          StyleBox["[",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], "i", 
                          StyleBox["]",
                            FontFamily->"Courier",
                            FontWeight->"Bold"]}], 
                        StyleBox["]",
                          FontFamily->"Courier",
                          FontWeight->"Bold"]}]}], 
                    RowBox[{
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Italic"], "th", " ", "element", " ", "of",
                       " ", 
                      StyleBox["list",
                        FontSlant->"Italic"]}]}
                  },
                ColumnAlignments->{Right, Left}],
              GridBoxOptions->{RowLines->False}]],
          "2ColumnBox"], TraditionalForm]], "Text",
    CellTags->"4.3"]
}], "Text"],

Cell["Operations on list elements. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[GridBox[{
              {
                RowBox[{
                  StyleBox["Join",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[\(list\_1\),
                      FontFamily->"Times",
                      FontSlant->"Italic"], ",", 
                    StyleBox[\(list\_2\),
                      FontFamily->"Times",
                      FontSlant->"Italic"]}], 
                  StyleBox["]",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], 
                StyleBox[\(join\ two\ lists\),
                  FontFamily->"Times"]},
              {
                RowBox[{
                  StyleBox["Delete",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["list",
                      FontSlant->"Italic"], ",", "n"}], 
                  StyleBox["]",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], 
                RowBox[{"delete", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["n",
                        FontSlant->"Italic"], "th"}]], " ", "element", " ", 
                  "from", " ", 
                  StyleBox["list",
                    FontSlant->"Italic"]}]},
              {
                RowBox[{
                  StyleBox["Append",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["list",
                      FontSlant->"Italic"], ",", 
                    StyleBox["element",
                      FontSlant->"Italic"]}], 
                  StyleBox["]",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], 
                RowBox[{"add", " ", 
                  StyleBox["element",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["to",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["the",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["end",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["of",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["list",
                    FontSlant->"Italic"]}]},
              {
                RowBox[{
                  StyleBox["Prepend",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["list",
                      FontSlant->"Italic"], ",", 
                    StyleBox["element",
                      FontSlant->"Italic"]}], 
                  StyleBox["]",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], 
                RowBox[{"add", " ", 
                  StyleBox["element",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["to",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["the",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["beginning",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["of",
                    FontSlant->"Plain"], 
                  StyleBox[" ",
                    FontSlant->"Plain"], 
                  StyleBox["list",
                    FontSlant->"Italic"]}]},
              {
                RowBox[{
                  StyleBox["Insert",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["list",
                      FontSlant->"Italic"], ",", 
                    StyleBox["element",
                      FontSlant->"Italic"], ",", "n"}], 
                  StyleBox["]",
                    FontFamily->"Courier",
                    FontWeight->"Bold"]}], 
                RowBox[{"place", " ", 
                  StyleBox["element",
                    FontSlant->"Italic"], " ", "at", " ", "the", " ", 
                  StyleBox[
                    RowBox[{
                      StyleBox["n",
                        FontSlant->"Italic"], "th"}]], " ", "position", " ", 
                  "in", " ", 
                  StyleBox["list",
                    FontSlant->"Italic"]}]}
              },
            ColumnAlignments->{Right, Left}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Operations on lists. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Table",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        "TI"], 
                      RowBox[{
                        StyleBox[\({imax}\),
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      
                      "MB"]}], "\<\"give a list of \\!\\(\\*StyleBox[\\\"\\\\\
\\\"imax\\\\\\\"\\\", \\\"TI\\\"]\\) values of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
                {
                  RowBox[{
                    StyleBox["Table",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        "TI"], 
                      RowBox[{
                        StyleBox[\({i, imax}\),
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      
                      "MB"]}], "\<\"give a list of the values of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) as \
\\!\\(\\*StyleBox[\\\"\\\\\\\"i\\\\\\\"\\\", \\\"TI\\\"]\\) runs from \
\\!\\(\\*StyleBox[\\\"\\\\\\\"1\\\\\\\"\\\", \\\"MB\\\"]\\) to \
\\!\\(\\*StyleBox[\\\"\\\\\\\"imax\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
                {
                  RowBox[{
                    StyleBox["Table",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        "TI"], 
                      RowBox[{
                        StyleBox[\({i, imin, imax}\),
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      
                      "MB"]}], "\<\"give a list of values with \
\\!\\(\\*StyleBox[\\\"\\\\\\\"i\\\\\\\"\\\", \\\"TI\\\"]\\) running from \
\\!\\(\\*StyleBox[\\\"\\\\\\\"imin\\\\\\\"\\\", \\\"TI\\\"]\\) to \
\\!\\(\\*StyleBox[\\\"\\\\\\\"imax\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
                {
                  RowBox[{
                    StyleBox["Table",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        "TI"], 
                      RowBox[{
                        StyleBox[\({i, imin, imax, di}\),
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      "MB"]}], 
                  RowBox[{"use", " ", "steps", " ", "of", " ", "size", " ", 
                    StyleBox["di",
                      FontSlant->"Italic"]}]},
                {
                  RowBox[{
                    StyleBox["Table",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        "TI"], 
                      StyleBox[\({j, jmin, jmax}\),
                        "TI"], 
                      StyleBox[",",
                        "TI"], 
                      RowBox[{
                        StyleBox[\({i, imin, imax}\),
                          "TI"], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      "MB"]}], "\<\"generate a multidimensional table \"\>"},
                {
                  RowBox[{
                    StyleBox["TableForm",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["list",
                        FontSlant->"Italic"], 
                      StyleBox["\<\"\"\>",
                        "\n\"TI\""]}], 
                    StyleBox["]",
                      "MB"]}], 
                  RowBox[{"display", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], "list", " ", "in", " ", "tabular", 
                    " ", "form"}]},
                {
                  RowBox[{
                    StyleBox["MatrixForm",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      StyleBox["list",
                        FontSlant->"Italic"], 
                      StyleBox["\<\"\"\>",
                        "\n\"TI\""]}], 
                    StyleBox["]",
                      "MB"]}], 
                  RowBox[{"display", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "list", " ", "as", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "matrix"}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{
            RowLines->{False, False, False, False, True, False}}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Functions for generating and displaying lists. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[GridBox[{
              {\({a, b, c}\), \(vector\ \((a, b, c)\)\)},
              {\({{a, b}, {c, d}}\), 
                RowBox[{"matrix", "  ", 
                  RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                        {"a", "b"},
                        {"c", "d"}
                        },
                      ColumnWidths->0.012], "\[NegativeThinSpace]", ")"}]}]}
              },
            ColumnAlignments->{Right, Left}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["The representation of vectors and matrices by lists. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{" ", 
                    RowBox[{"c", " ", 
                      StyleBox["m",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]}], 
                  RowBox[{"multiply", " ", "the", " ", "matrix", " ", 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], " ", "by", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], "scalar", " ", "c"}]},
                {
                  RowBox[{
                    StyleBox["a",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[".",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["b",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      
                      FontSlant->
                        "Plain"]}], \(dot\ product\ of\ two\ vectors\)},
                {
                  RowBox[{
                    StyleBox["Inverse",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(matrix\ inverse\)},
                {
                  RowBox[{
                    StyleBox["Det",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "determinant"},
                {
                  RowBox[{
                    StyleBox["Tr",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "trace"},
                {
                  RowBox[{
                    StyleBox["Transpose",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "transpose"},
                {
                  RowBox[{
                    StyleBox["Eigenvalues",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "eigenvalues"},
                {
                  RowBox[{
                    StyleBox["Eigenvectors",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["m",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "eigenvectors"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some mathematical operations on vectors and matrices. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["(",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[\(x + y\),
                        FontSlant->"Italic"], 
                      StyleBox[")",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox["z",
                      
                      FontSlant->
                        "Italic"]}], \(parentheses\ are\ used\ for\ grouping\ \
terms\)},
                {
                  RowBox[{
                    StyleBox["f",
                      FontSlant->"Italic"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(square\ brackets\ enclose\ the\ \
arguments\ of\ functions\)},
                {\({a, b, c}\), \(curley\ brackets\ denote\ lists\)},
                {
                  RowBox[{
                    StyleBox["list",
                      FontSlant->"Italic"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["i",
                        FontSlant->"Italic"], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(double\ square\ brackets\ extract\ list\ \
elements\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell[TextData[{
  "The four uses of brackets in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["9.12.4 Graphics", "Subsubtitle",
  CellTags->"c:72"],

Cell[CellGroupData[{

Cell["Basic Plotting", "Section",
  CellTags->"c:73"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Plot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"f", ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", 
                          StyleBox["xmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["xmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"plot", " ", "f", " ", "as", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "function", " ", "of", " ", 
                    "x", " ", "from", " ", 
                    StyleBox["xmin",
                      FontSlant->"Italic"], " ", "to", " ", 
                    StyleBox["xmax",
                      FontSlant->"Italic"]}]},
                {
                  RowBox[{
                    StyleBox["Plot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{\({f\_1, f\_2,  ... }\), ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", 
                          StyleBox["xmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["xmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(plot\ several\ functions\ at\ once\ on\ \
one\ graph\)},
                {
                  RowBox[{
                    StyleBox["Plot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"f", ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", 
                          StyleBox["xmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["xmax",
                            FontSlant->"Italic"]}], "}"}], ",", " ", 
                      RowBox[{
                        StyleBox["PlotStyle",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["\[RightArrow]",
                          FontSlant->"Italic"], 
                        StyleBox["values",
                          FontSlant->"Italic"]}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{
                  "plot", " ", "f", " ", "with", " ", "the", " ", "option", 
                    " ", 
                    StyleBox["PlotStyle",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "  ", "to", " ", "change", " ", 
                    "to", " ", "style", " ", "of", " ", "the", " ", "plot"}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Basic plotting functions. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Show",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["plot",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"redraw", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["plot",
                      FontSlant->"Plain"]}]},
                {
                  RowBox[{
                    StyleBox["Show",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[\(plot, \ options\  \[RightArrow] values\),
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"redraw", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["plot",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["with",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["options",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    StyleBox["changed",
                      FontSlant->"Plain"]}]},
                {
                  RowBox[{
                    StyleBox["Show",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[\(plot\_1, \ plot\_2,  ... \),
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], \(combine\ several\ plots\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["The show function", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {\(option\ name\), \(default\ value\), "\[Null]"},
                {
                  StyleBox["AspectRatio",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox[\(1/GoldenRatio\),
                    FontFamily->"Courier",
                    FontWeight->"Bold"], \(the\ height - to\  - 
                    width\ ratio\)},
                {
                  StyleBox["Axes",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["Automatic",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], \(whether\ to\ include\ axes\)},
                {
                  StyleBox["AxesLabel",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["None",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{"values", " ", "for", " ", 
                      RowBox[{"labels", ".", " ", 
                        StyleBox["ylabel",
                          FontSlant->"Italic"]}], 
                      StyleBox[" ",
                        FontSlant->"Italic"], 
                      StyleBox["specifies",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["a",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["label",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["for",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["the",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["y",
                        FontSlant->"Italic"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["axis",
                        FontSlant->"Plain"]}], 
                    StyleBox[";",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["{",
                          FontSlant->"Plain"], 
                        RowBox[{
                          StyleBox["xlabel",
                            FontSlant->"Italic"], 
                          StyleBox[",",
                            FontSlant->"Plain"], 
                          StyleBox[" ",
                            FontSlant->"Plain"], 
                          StyleBox["ylabel",
                            FontSlant->"Italic"]}], 
                        StyleBox["}",
                          FontSlant->"Plain"]}], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["specifies",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["values",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["for",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["both",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["axes",
                        FontSlant->"Plain"]}]}]},
                {
                  StyleBox["AxesOrigin",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["Automatic",
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(the\ point\ where\ the\ axes\ cross\)},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"DisplayFunction\\\\\\\"\\\
\", \\\"MB\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"$DisplayFunction\
\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", "\<\"how to display graphics; \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Identity\\\\\\\"\\\", \\\"MB\\\"]\\) causes no \
display \"\>"},
                {
                  StyleBox["Frame",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["False",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{"whether", " ", "to", " ", "draw", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "frame", " ", "around", " ", 
                    "the", " ", "plot"}]},
                {
                  StyleBox["FrameLabel",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["None",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[\(a\ single\ label\),
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontSlant->"Plain"], 
                    StyleBox[" ",
                      FontSlant->"Plain"], 
                    RowBox[{
                      StyleBox["or",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["a",
                        FontSlant->"Plain"], 
                      StyleBox[
                        RowBox[{
                          StyleBox[" ",
                            FontSlant->"Plain"], " "}]], "list", " ", "of", 
                      " ", "up", " ", "to", " ", "four", " ", "labels", " ", 
                      "for", " ", "each", " ", "side", " ", "of", " ", "the", 
                      " ", "frame"}]}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"FrameTicks\\\\\\\"\\\", \
\\\"MB\\\"]\\) \"\>", \
"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Automatic\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"what tick marks to draw if there is a frame; \\!\\(\\*StyleBox[\\\
\"\\\\\\\"None\\\\\\\"\\\", \\\"MB\\\"]\\) gives no tick marks \"\>"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"GridLines\\\\\\\"\\\", \\\
\"MB\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"None\\\\\\\"\\\", \
\\\"MB\\\"]\\) \"\>", "\<\"what grid lines to include; \\!\\(\\*StyleBox[\\\"\
\\\\\\\"Automatic\\\\\\\"\\\", \\\"MB\\\"]\\) includes a grid line for every \
major tick mark \"\>"},
                {
                  StyleBox["PlotLabel",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["None",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "label", " ", "for", " ", 
                    "the", " ", "plot"}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PlotRange\\\\\\\"\\\", \\\
\"MB\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Automatic\\\\\\\"\\\", \
\\\"MB\\\"]\\) \"\>", "\<\"the range of coordinates to include in the plot; \
\\!\\(\\*StyleBox[\\\"\\\\\\\"All\\\\\\\"\\\", \\\"MB\\\"]\\) includes all \
points \"\>"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Ticks\\\\\\\"\\\", \\\"MB\
\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Automatic\\\\\\\"\\\", \
\\\"MB\\\"]\\) \"\>", "\<\"what tick marks to draw if there are axes; \
\\!\\(\\*StyleBox[\\\"\\\\\\\"None\\\\\\\"\\\", \\\"MB\\\"]\\) gives no tick \
marks \"\>"}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text"],

Cell[TextData[{
  "Some of the options for ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These options can also be used in ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Contour and Density Plots", "Section",
  CellTags->"c:74"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["ContourPlot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"f", ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", 
                          StyleBox["xmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["xmax",
                            FontSlant->"Italic"]}], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{"y", ",", 
                          StyleBox["ymin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["ymax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"make a contour plot of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) as a function of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) and \
\\!\\(\\*StyleBox[\\\"\\\\\\\"y\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
                {
                  RowBox[{
                    StyleBox["DensityPlot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"f", ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", 
                          StyleBox["xmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["xmax",
                            FontSlant->"Italic"]}], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{"y", ",", 
                          StyleBox["ymin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["ymax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"make a density plot of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Contour and density plots. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"SO10\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"SO10\\\"]\\) \"\>", "\[Null]"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ColorFunction\\\\\\\"\\\",\
 \\\"MB\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Automatic\\\\\\\"\\\
\", \\\"MB\\\"]\\) \"\>", "\<\"what colors to use for shading; \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Hue\\\\\\\"\\\", \\\"MB\\\"]\\) uses a sequence \
of hues \"\>"},
                {
                  StyleBox["Contours",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["10",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  
                  RowBox[{\(the\ total\ number\ of\ contours\ to\ be\ \
includes\), ",", " ", 
                    RowBox[{"or", " ", 
                      StyleBox["a",
                        FontSlant->"Plain"], " ", "list", " ", "of", " ", "z",
                       " ", "values"}]}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PlotRange\\\\\\\"\\\", \\\
\"MB\\\"]\\) \"\>", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Automatic\\\\\\\"\\\", \
\\\"MB\\\"]\\) \"\>", 
                  
                  RowBox[{"\<\"the range of values to be included; you can \
specify {\!\(\*
StyleBox[\\\"zmin\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\"zmax\\\",\\nFontSlant->\\\"Italic\\\"]\)}\"\>", ",", " ", 
                    RowBox[{
                      StyleBox["\<\"All\"\>",
                        "MB"], " ", "or", " ", 
                      StyleBox["\<\"Automatic\"\>",
                        "MB"]}]}]},
                {
                  StyleBox["ContourShading",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["True",
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(whether\ to\ shade\ in\ between\ the\ \
contours\)},
                {
                  StyleBox["PlotPoints",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  StyleBox["15",
                    FontFamily->"Courier",
                    
                    FontWeight->
                      "Bold"], \(number\ of\ evaluation\ points\ in\ each\ \
direction\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{
            RowLines->{True, False, False, False, True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text"],

Cell[TextData[{
  "Some options for ",
  StyleBox["ContourPlot", "MB"],
  ". The first set can also be used in ",
  StyleBox["Show", "MB"],
  ". "
}], "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Three\[Hyphen]Dimensional Surface Plots", "Section",
  CellTags->"c:75"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Plot3D",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"f", ",", 
                      RowBox[{"{", 
                        RowBox[{"x", ",", 
                          StyleBox["xmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["xmax",
                            FontSlant->"Italic"]}], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{"y", ",", 
                          StyleBox["ymin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["ymax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"make a three\[Hyphen]dimensional plot \
of \\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \\\"TI\\\"]\\) as a function \
of the variables \\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) \
and \\!\\(\\*StyleBox[\\\"\\\\\\\"y\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Basic 3D plotting function. ", "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting Lists of Data", "Section",
  CellTags->"c:76"],

Cell["", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ListPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], \({y\_1, y\_2,  ... }\), 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"\<\"plot \"\>", 
                    StyleBox[\(y\_1\),
                      "InlineFormula"], "\<\", \"\>", 
                    StyleBox[\(y\_2\),
                      "InlineFormula"], "\<\", \"\>", 
                    StyleBox["...",
                      "InlineFormula"], "\<\" at \"\>", 
                    StyleBox["x",
                      "InlineFormula"], "\<\" values \"\>", 
                    StyleBox["1",
                      "InlineFormula"], "\<\", \"\>", 
                    StyleBox["2",
                      "InlineFormula"], "\<\", \"\>", 
                    StyleBox["...",
                      "InlineFormula"], "\<\" \"\>"}]},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ListPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        
                        FontWeight->"Bold"], \({{x\_1, 
                          y\_1}, {\(x\_\(\(2\)\(,\)\)\) y\_2},  ... }\), 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"\<\"plot points \"\>", 
                    StyleBox[\((x\_1, y\_1)\),
                      "InlineFormula"], "\<\", \"\>", 
                    StyleBox["...",
                      "InlineFormula"], "\<\" \"\>"}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ListPlot[\\\\\\\"\\\", \\\
\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"list\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MB\\\"]\\) \\!\\(\\*StyleBox[\\\
\"\\\\\\\"PlotJoined\\\\\\\"\\\", \\\"MB\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\
\"->\\\\\\\"\\\", \\\"MB\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"True]\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", \
"\<\"join the points with lines \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ListPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        
                        FontWeight->"Bold"], \({{z\_11, 
                          z\_12,  ... }, {\(z\_\(\(21\)\(,\)\)\) 
                            z\_22,  ... },  ... }\), 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  
                  RowBox[{"\<\"make a three\[Hyphen]dimensional plot of the \
array of heights \"\>", 
                    StyleBox[\(z\_\(y  x\)\),
                      "InlineFormula"], "\<\" \"\>"}]},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ListContourPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["array",
                        FontSlant->"Italic"], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"make", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "contour", " ", "plot", " ", 
                    "from", " ", "an", " ", "array", " ", "of", " ", 
                    "heights"}]},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ListDensityPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["array",
                        FontSlant->"Italic"], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], "\<\"make a density plot \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->{False, False, True, False}}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Functions for plotting lists of data. ", "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parametric Plots", "Section",
  CellTags->"c:77"],

Cell["  ", "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["ParametricPlot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{\({f\_x, f\_y}\), ",", 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          StyleBox["tmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["tmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"make a parametric plot \"\>"},
                {
                  RowBox[{
                    StyleBox["ParametricPlot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{\({{f\_x, f\_y}, {g\_x, g\_y},  ... }\), ",", 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          StyleBox["tmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["tmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"plot several parametric curves \
together \"\>"},
                {
                  RowBox[{
                    StyleBox["ParametricPlot",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{\({f\_x, f\_y}\), ",", 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          StyleBox["tmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["tmax",
                            FontSlant->"Italic"]}], "}"}], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[\(AspectRatio -> Automatic\),
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"attempt to preserve the shapes of \
curves \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Functions for generating parametric plots. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["ParametricPlot3D",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{\({f\_x, f\_y, f\_z}\), ",", 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          StyleBox["tmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["tmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"make a parametric plot of a three\
\[Hyphen]dimensional curve \"\>"},
                {
                  RowBox[{
                    StyleBox["ParametricPlot3D",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{\({f\_x, f\_y, f\_z}\), ",", " ", 
                      RowBox[{"{", 
                        RowBox[{"s", ",", 
                          StyleBox["smin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["smax",
                            FontSlant->"Italic"]}], "}"}], ",", 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          StyleBox["tmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["tmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"make a parametric plot of a three\
\[Hyphen]dimensional surface \"\>"},
                {
                  RowBox[{
                    StyleBox["ParametricPlot3D",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    
                    RowBox[{\({{f\_x, f\_y, f\_z}, {g\_x, g\_y, 
                          g\_z},  ... }\), 
                      RowBox[{"{", 
                        RowBox[{"t", ",", 
                          StyleBox["tmin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["tmax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"plot several objects together \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Three\[Hyphen]dimensional parametric plots. ", "Caption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Other Plots", "Section",
  CellTags->"c:78"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"<<Graphics`\\\\\\\"\\\", \
\\\"MB\\\"]\\) \"\>", 
                  RowBox[{
                    RowBox[{"load", " ", 
                      StyleBox["an",
                        FontSlant->"Plain"], 
                      StyleBox[" ",
                        FontSlant->"Plain"], 
                      StyleBox["add",
                        FontSlant->"Plain"]}], 
                    StyleBox["-",
                      FontSlant->"Plain"], 
                    RowBox[{
                      StyleBox["on",
                        FontSlant->"Plain"], 
                      StyleBox[
                        RowBox[{
                          StyleBox[" ",
                            FontSlant->"Plain"], " "}]], "package", " ", 
                      "for", " ", "setting", " ", "up", " ", "additional", 
                      " ", "plotting", " ", "functions"}]}]},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["LogPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"f", ",", 
                        RowBox[{"{", 
                          RowBox[{"x", ",", 
                            StyleBox["xmin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["xmax",
                              FontSlant->"Italic"]}], "}"}]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->
                        "Bold"]}], "\<\"generate a log\[Hyphen]linear plot \"\
\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["LogLogPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"f", ",", 
                        RowBox[{"{", 
                          RowBox[{"x", ",", 
                            StyleBox["xmin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["xmax",
                              FontSlant->"Italic"]}], "}"}]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"generate a log\[Hyphen]log plot \
\"\>"},
                {
                  RowBox[{"\<\"\!\(\*
StyleBox[\\\"\\\\\\\"LogListPlot[\\\\\\\"\\\",\\n\\\"MB\\\"]\)\!\(\* \
StyleBox[\\\"\\\\\\\"list\\\\\\\"\\\",\\n\\\"TI\\\"]\)\!\(\* \
StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\",\\n\\\"MB\\\"]\)\"\>", 
                    " "}], "\<\"generate a log\[Hyphen]linear plot from a \
list of data \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["LogLogListPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["list",
                        FontSlant->"Italic"], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"generate a log\[Hyphen]log plot from \
a list of data \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["PolarPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"r", ",", 
                        RowBox[{"{", 
                          RowBox[{"\[Theta]", ",", 
                            StyleBox[
                              RowBox[{
                                StyleBox["\[Theta]",
                                  FontSlant->"Plain"], 
                                StyleBox["min",
                                  FontSlant->"Italic"]}]], ",", 
                            StyleBox[
                              RowBox[{"\[Theta]", 
                                StyleBox["max",
                                  FontSlant->"Italic"]}]]}], "}"}]}], 
                      StyleBox["]",
                        FontWeight->"Bold"]}], 
                    StyleBox["  ",
                      
                      FontWeight->
                        "Bold"]}], "\<\"generate a polar plot of the radius \
\\!\\(\\* StyleBox[\\\"\\\\\\\"r\\\\\\\"\\\",\\n\\\"TI\\\"]\\) as a function \
of angle \\!\\(\[Theta] \\* \
StyleBox[\\\"\\\\\\\"\\\\\\\"\\\",\\n\\\"TI\\\"]\\) \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["ErrorListPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"{", 
                        RowBox[{
                          RowBox[{"{", 
                            RowBox[{\(x\_1\), ",", \(y\_1\), ",", " ", 
                              SubscriptBox[
                                StyleBox["dy",
                                  FontSlant->"Italic"], "1"]}], "}"}], ",", 
                          "..."}], "}"}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"generate a plot of data with error \
bars \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["TextListPlot",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        
                        FontWeight->"Bold"], \({{x\_1, y\_1, \ 
                          s\_1},  ... }\), 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  
                  RowBox[{"\<\"plot a list of data with each point given by \
the text string \"\>", 
                    StyleBox[
                      
                      SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"s\\\\\\\
\"\\\", \\\"TI\\\"]\\)\"\>", "i"],
                      "InlineFormula"], "\<\" \"\>"}]},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BarChart[\\\\\\\"\\\", \\\
\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"list\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", "\<\"plot a \
list of data as a bar chart \"\>"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PieChart[\\\\\\\"\\\", \\\
\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"list\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \"\>", "\<\"plot a \
list of data as a pie chart \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["PlotVectorField",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{\({f\_x, f\_y}\), ",", " ", 
                        RowBox[{"{", 
                          RowBox[{"x", ",", 
                            StyleBox["xmin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["xmax",
                              FontSlant->"Italic"]}], "}"}], ",", 
                        RowBox[{"{", 
                          RowBox[{"y", ",", 
                            StyleBox["ymin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["ymax",
                              FontSlant->"Italic"]}], "}"}]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], "\<\"plot the vector field corresponding \
to the vector function \\!\\(\\*StyleBox[\\\"\\\\\\\"f\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ListPlotVectorField[\\\\\\\
\"\\\", \\\"MB\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"list\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MB\\\"]\\) \
\"\>", "\<\"plot the vector field corresponding to the \
two\[Hyphen]dimensional array of vectors in \
\\!\\(\\*StyleBox[\\\"\\\\\\\"list\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["SphericalPlot3D",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{"r", ",", 
                        RowBox[{"{", 
                          RowBox[{"\[Theta]", ",", 
                            StyleBox[
                              RowBox[{
                                StyleBox["\[Theta]",
                                  FontSlant->"Plain"], 
                                StyleBox["min",
                                  FontSlant->"Italic"]}]], ",", 
                            StyleBox[
                              RowBox[{"\[Theta]", 
                                StyleBox["max",
                                  FontSlant->"Italic"]}]]}], "}"}], ",", 
                        RowBox[{"{", 
                          RowBox[{"\[Phi]", ",", 
                            StyleBox[
                              RowBox[{"\[Phi]", 
                                StyleBox["min",
                                  FontSlant->"Italic"]}]], ",", 
                            StyleBox[
                              RowBox[{"\[Phi]", 
                                StyleBox["max",
                                  FontSlant->"Italic"]}]]}], "}"}]}], 
                      StyleBox["]",
                        FontWeight->"Bold"]}], 
                    StyleBox["  ",
                      
                      FontWeight->
                        
                        "Bold"]}], "\<\"generate a three\[Hyphen]dimensional \
spherical plot \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell[TextData[{
  "Some special plotting functions defined in standard ",
  StyleBox["Mathematica", "SO"],
  " packages. "
}], "Caption"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["9.12.5 Symbolic Mathematics", "Subsubtitle",
  CellTags->"c:79"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[":=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["^",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["2",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}]}], 
                  RowBox[{"define", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "function", " ", "f"}]},
                {
                  RowBox[{
                    StyleBox["?",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["f",
                      
                      FontSlant->
                        "Italic"]}], \(show\ the\ definition\ of\ f\)},
                {
                  RowBox[{
                    StyleBox["Clear",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "f", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(clear\ the\ definition\ of\ f\)},
                {
                  RowBox[{
                    StyleBox["Remove",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "f", 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(clear\ the\ definition\ of\ f\ and\ \
remove\ it\ from\ the\ list\ of\ user - defined\ symbols\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Defining a function.", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[",",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["@",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}], 
                    StyleBox[",",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox[" ",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["//",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        
                        FontSlant->
                          "Plain"]}]}], \(all\ mean\ \ evaluate\ the\ \
function\ f\ at\ x\)},
                {
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["[",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{
                        StyleBox["x",
                          FontFamily->"Courier",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox[",",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["y",
                          FontFamily->"Courier",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}], 
                      StyleBox["]",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox[",",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["~",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["f",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["~",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["y",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]}], 
                  RowBox[{"evaluate", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "function", " ", "of", " ", 
                    "2", " ", "variables", " ", "at", " ", "x", " ", "and", 
                    " ", "y"}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Different ways to evaluate functions. ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["D",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], \(f, x\), 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(\((partial)\)\ derivative\ of\ f\ with\ \
respect\ to\ x\)},
                {
                  RowBox[{
                    StyleBox["Integrate",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], \(f, x\), 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(indefinite\ integral\ of\ f\ with\ \
respect\ to\ x\)},
                {
                  RowBox[{
                    StyleBox["Sum",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{"f", ",", 
                      RowBox[{"{", 
                        RowBox[{"i", ",", 
                          StyleBox["imin",
                            FontSlant->"Italic"], ",", 
                          StyleBox["imax",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"the", " ", "sum", "  ", 
                    RowBox[{
                      UnderoverscriptBox[
                        StyleBox["\[Sum]",
                          FontSize->14], 
                        RowBox[{"i", "=", 
                          StyleBox["imin",
                            FontSlant->"Italic"]}], 
                        StyleBox["imax",
                          FontSlant->"Italic"]], "f"}]}]},
                {
                  RowBox[{
                    StyleBox["Solve",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["lhs",
                          FontSlant->"Italic"], 
                        StyleBox["\[Equal]",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["rhs",
                          FontSlant->"Italic"]}], ",", "x"}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(solution\ to\ an\ equation\ for\ x\)},
                {
                  RowBox[{
                    StyleBox["Series",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        FontSlant->"Italic"], 
                      RowBox[{"{", 
                        RowBox[{"x", ",", \(x\_0\), ",", 
                          StyleBox["order",
                            FontSlant->"Italic"]}], "}"}]}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(series\ expansion\ of\ f\ about\ the\ \
point\ x\_0\)},
                {
                  RowBox[{
                    StyleBox["Normal",
                      FontFamily->"Courier",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["series",
                      FontSlant->"Italic"], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{
                  "normal", " ", "Mathematica", " ", "expression", " ", 
                    "derived", " ", "from", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "series", " ", 
                    "expression"}]},
                {
                  RowBox[{
                    StyleBox["Limit",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["f",
                        FontSlant->"Italic"], 
                      StyleBox[",",
                        FontSlant->"Italic"], 
                      RowBox[{
                        StyleBox["x",
                          FontSlant->"Italic"], "\[RightArrow]", \(x\_0\)}]}],
                     
                    StyleBox["]",
                      FontFamily->"Courier",
                      
                      FontWeight->
                        "Bold"]}], \(limit\ of\ f\ as\ x\ approaches\ x\_0\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Some symbolic mathematical operations. ", "Caption"],

Cell[CellGroupData[{

Cell[" Algebraic Equations", "Section",
  CellTags->"c:80"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{"x", 
                    StyleBox["=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    "y"}], \(immediately\ evaluates\ y\ and\ assigns\ the\ \
result\ to\ x\)},
                {
                  RowBox[{"x", 
                    StyleBox[":=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    "y"}], \(assigns\ y\ to\ x\ without\ evaluating\ y\ \
immediately\)},
                {
                  RowBox[{"x", 
                    StyleBox["==",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    "y"}], \(tests\ whether\ x\ and\ y\ are\ equal\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Three types of equal signs", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{"x", 
                    StyleBox["==",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "y"}], "equal"},
                {
                  RowBox[{"x", 
                    StyleBox["!=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "y"}], "unequal"},
                {
                  RowBox[{"x", 
                    StyleBox[">",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "y"}], \(greater\ than\)},
                {
                  RowBox[{"x", 
                    StyleBox[">=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    "y"}], \(greater\ than\ or\ equal\ to\)},
                {
                  RowBox[{"x", 
                    StyleBox["<",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "y"}], \(less\ than\)},
                {
                  RowBox[{"x", 
                    StyleBox["<=",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    "y"}], \(less\ than\ or\ equal\ to\)},
                {
                  RowBox[{"x", 
                    StyleBox["\[Element]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], "y"}], 
                  RowBox[{"x", " ", "is", " ", 
                    StyleBox["an",
                      FontSlant->"Plain"], " ", "element", " ", "of", " ", 
                    "the", " ", "set", " ", "y"}]},
                {
                  RowBox[{
                    StyleBox[\(statement\ 1\),
                      FontSlant->"Italic"], " ", 
                    StyleBox["||",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", 
                    StyleBox[\(statement\ 2\),
                      FontSlant->"Italic"]}], 
                  RowBox[{"either", " ", 
                    StyleBox["statement",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox["1",
                      FontSlant->"Italic"], " ", "or", " ", 
                    StyleBox["statement",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox["2",
                      FontSlant->"Italic"], " ", "is", " ", "true"}]},
                {
                  RowBox[{
                    StyleBox[\(statement\ 1\),
                      FontSlant->"Italic"], " ", 
                    StyleBox["&&",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], " ", 
                    StyleBox[\(statement\ 2\),
                      FontSlant->"Italic"]}], 
                  RowBox[{"both", " ", 
                    StyleBox["statement",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox["1",
                      FontSlant->"Italic"], " ", "and", " ", 
                    StyleBox["statement",
                      FontSlant->"Italic"], 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox["2",
                      FontSlant->"Italic"], " ", "are", " ", "true"}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{
            RowLines->{
              False, False, False, False, False, False, True, False}}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Logical statements ", "Caption"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["Solve",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["lhs",
                          FontSlant->"Italic"], 
                        StyleBox["\[Equal]",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        StyleBox["rhs",
                          FontSlant->"Italic"]}], ",", "x"}], 
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{\(solve\ an\ equation\), ",", " ", 
                    RowBox[{"giving", " ", 
                      StyleBox["a",
                        FontSlant->"Plain"], " ", "list", " ", "of", " ", 
                      "replacement", " ", "rules", " ", "for", " ", "x"}]}]},
                {
                  RowBox[{
                    StyleBox["x",
                      FontSlant->"Italic"], 
                    StyleBox["/.",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["solution",
                      
                      FontSlant->
                        "Italic"]}], \(use\ the\ list\ of\ rules\ to\ get\ \
values\ for\ x\)},
                {
                  RowBox[{
                    StyleBox["expr",
                      FontSlant->"Italic"], 
                    StyleBox["/.",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["solution",
                      FontSlant->
                        "Italic"]}], \(use\ the\ list\ of\ rules\ to\ get\ \
values\ for\ an\ expression\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Finding and using solutions to equations. ", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{x\^2\  + \ y\^2\  \[Equal] 2, y + x - 1 \[Equal] 0}, {x, 
        y}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.209"],

Cell[BoxData[
    \({{x \[Rule] 1\/2 - \@3\/2, 
        y \[Rule] 1\/2\ \((1 + \@3)\)}, {x \[Rule] 1\/2\ \((1 + \@3)\), 
        y \[Rule] 1\/2\ \((1 - \@3)\)}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Differential Equations", "Section",
  CellTags->"c:81"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["DSolve",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    StyleBox["[",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["eqn",
                        FontSlant->"Italic"], ",", " ", \(y(x)\), ",", "x"}], 
                    
                    StyleBox["]",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  RowBox[{"solve", " ", 
                    StyleBox["a",
                      FontSlant->"Plain"], " ", "differential", " ", 
                    "equation", " ", "for", " ", \(y(x)\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["DSolve",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["{",
                          FontSlant->"Italic"], 
                        RowBox[{
                          StyleBox[\(eqn\_1\),
                            FontSlant->"Italic"], 
                          StyleBox[",",
                            "TI"], 
                          StyleBox[\(eqn\_2\),
                            "TI"], 
                          StyleBox[",",
                            "TI"], 
                          StyleBox["...",
                            "TI"]}], 
                        StyleBox["}",
                          "TI"]}], ",", \({y\_1, y\_2,  ... }\), ",", 
                      RowBox[{"x", 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      
                      "MB"]}], "\<\"solve a list of differential equations \
for functions \!\(y\_1\), \!\(y\_2\),...\"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["Solving ordinary differential equations analytically. ", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(DSolve[\(y''\)[x] + \ 3\ y[x] \[Equal] 0, y[x], 
      x]\)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.210"],

Cell[BoxData[
    \({{y[x] \[Rule] C[1]\ Cos[\@3\ x] + C[2]\ Sin[\@3\ x]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[{\(y''\)[x] + \ 3\ y[x] \[Equal] 0, 
        y[0] \[Equal] 2, \(y'\)[0] == 0}, y[x], x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.211"],

Cell[BoxData[
    \({{y[x] \[Rule] 2\ Cos[\@3\ x]}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                    StyleBox["NDSolve",
                      "MB"], 
                    StyleBox["[",
                      "MB"], 
                    RowBox[{
                      RowBox[{
                        StyleBox["{",
                          FontSlant->"Italic"], 
                        RowBox[{
                          StyleBox[\(eqn\_1\),
                            FontSlant->"Italic"], 
                          StyleBox[",",
                            "TI"], 
                          StyleBox[\(eqn\_2\),
                            "TI"], 
                          StyleBox[",",
                            "TI"], 
                          StyleBox["...",
                            "TI"]}], 
                        StyleBox["}",
                          "TI"]}], ",", "  ", "y", " ", ",", 
                      RowBox[{
                        RowBox[{"{", 
                          RowBox[{"x", ",", 
                            StyleBox["xmin",
                              FontSlant->"Italic"], ",", 
                            StyleBox["xmax",
                              FontSlant->"Italic"]}], "}"}], 
                        StyleBox["\<\"\"\>",
                          "\n\"TI\""]}]}], 
                    StyleBox["]",
                      
                      "MB"]}], "\<\"find a numerical solution for the \
function \\!\\(\\*StyleBox[\\\"\\\\\\\"y\\\\\\\"\\\", \\\"TI\\\"]\\) with \\!\
\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\\) in the range \
\\!\\(\\*StyleBox[\\\"\\\\\\\"xmin\\\\\\\"\\\", \\\"TI\\\"]\\) to \
\\!\\(\\*StyleBox[\\\"\\\\\\\"xmax\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text"],

Cell["\<\
Finding numerical solutions to ordinary differential equations. \
\
\>", "Caption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NDSolve[\ {\(y''\)[x] + Re[x\^\((1/3)\)]\ y[x] \[Equal] 0, 
        y[0] == 0, \(y'\)[0] \[Equal] 1}, y[x], {x, \(-20\), 20}]\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 9.212"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(y[x]\), "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{\(-20.`\), 20.`}}, "<>"]\),
              False,
              Editable->False], "[", "x", "]"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(y[x] /. %[\([\)\(1\)\(]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.213"],

Cell[BoxData[
    RowBox[{
      TagBox[\(InterpolatingFunction[{{\(-20.`\), 20.`}}, "<>"]\),
        False,
        Editable->False], "[", "x", "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[%, {x, \(-20\), 20}]; \)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 9.214"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.320414 0.216053 [
[.02381 .30791 -9 -9 ]
[.02381 .30791 9 0 ]
[.2619 .30791 -9 -9 ]
[.2619 .30791 9 0 ]
[.7381 .30791 -6 -9 ]
[.7381 .30791 6 0 ]
[.97619 .30791 -6 -9 ]
[.97619 .30791 6 0 ]
[.4875 .10436 -12 -4.5 ]
[.4875 .10436 0 4.5 ]
[.4875 .21239 -24 -4.5 ]
[.4875 .21239 0 4.5 ]
[.4875 .42844 -18 -4.5 ]
[.4875 .42844 0 4.5 ]
[.4875 .53647 -6 -4.5 ]
[.4875 .53647 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .32041 m
.02381 .32666 L
s
[(-20)] .02381 .30791 0 1 Mshowa
.2619 .32041 m
.2619 .32666 L
s
[(-10)] .2619 .30791 0 1 Mshowa
.7381 .32041 m
.7381 .32666 L
s
[(10)] .7381 .30791 0 1 Mshowa
.97619 .32041 m
.97619 .32666 L
s
[(20)] .97619 .30791 0 1 Mshowa
.125 Mabswid
.07143 .32041 m
.07143 .32416 L
s
.11905 .32041 m
.11905 .32416 L
s
.16667 .32041 m
.16667 .32416 L
s
.21429 .32041 m
.21429 .32416 L
s
.30952 .32041 m
.30952 .32416 L
s
.35714 .32041 m
.35714 .32416 L
s
.40476 .32041 m
.40476 .32416 L
s
.45238 .32041 m
.45238 .32416 L
s
.54762 .32041 m
.54762 .32416 L
s
.59524 .32041 m
.59524 .32416 L
s
.64286 .32041 m
.64286 .32416 L
s
.69048 .32041 m
.69048 .32416 L
s
.78571 .32041 m
.78571 .32416 L
s
.83333 .32041 m
.83333 .32416 L
s
.88095 .32041 m
.88095 .32416 L
s
.92857 .32041 m
.92857 .32416 L
s
.25 Mabswid
0 .32041 m
1 .32041 L
s
.5 .10436 m
.50625 .10436 L
s
[(-1)] .4875 .10436 1 0 Mshowa
.5 .21239 m
.50625 .21239 L
s
[(-0.5)] .4875 .21239 1 0 Mshowa
.5 .42844 m
.50625 .42844 L
s
[(0.5)] .4875 .42844 1 0 Mshowa
.5 .53647 m
.50625 .53647 L
s
[(1)] .4875 .53647 1 0 Mshowa
.125 Mabswid
.5 .01794 m
.50375 .01794 L
s
.5 .03954 m
.50375 .03954 L
s
.5 .06115 m
.50375 .06115 L
s
.5 .08276 m
.50375 .08276 L
s
.5 .12597 m
.50375 .12597 L
s
.5 .14757 m
.50375 .14757 L
s
.5 .16918 m
.50375 .16918 L
s
.5 .19078 m
.50375 .19078 L
s
.5 .23399 m
.50375 .23399 L
s
.5 .2556 m
.50375 .2556 L
s
.5 .2772 m
.50375 .2772 L
s
.5 .29881 m
.50375 .29881 L
s
.5 .34202 m
.50375 .34202 L
s
.5 .36362 m
.50375 .36362 L
s
.5 .38523 m
.50375 .38523 L
s
.5 .40684 m
.50375 .40684 L
s
.5 .45005 m
.50375 .45005 L
s
.5 .47165 m
.50375 .47165 L
s
.5 .49326 m
.50375 .49326 L
s
.5 .51486 m
.50375 .51486 L
s
.5 .55807 m
.50375 .55807 L
s
.5 .57968 m
.50375 .57968 L
s
.5 .60128 m
.50375 .60128 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07993 m
.04262 .24115 L
.0522 .35865 L
.06244 .4748 L
.0679 .523 L
.07047 .54113 L
.07286 .55486 L
.07525 .56557 L
.07651 .56992 L
.07784 .57353 L
.079 .57583 L
.08008 .57727 L
.08127 .57805 L
.08255 .57795 L
.08326 .57749 L
.08402 .57666 L
.08473 .57558 L
.08537 .57434 L
.08696 .57028 L
.08845 .56514 L
.09114 .55276 L
.09406 .53506 L
.09954 .4909 L
.10458 .44002 L
.11444 .32393 L
.125 .19929 L
.13012 .14775 L
.13497 .10803 L
.13933 .08162 L
.14052 .07606 L
.14179 .071 L
.14288 .06734 L
.14407 .06409 L
.14521 .06172 L
.1464 .06001 L
.14751 .05915 L
.14855 .05897 L
.14977 .05954 L
.15088 .06079 L
.15217 .0631 L
.15338 .06611 L
.15556 .07356 L
.15757 .08266 L
.16212 .11067 L
.16672 .14847 L
.17179 .19891 L
.18204 .3177 L
.19202 .4342 L
.19693 .48445 L
.20149 .52383 L
Mistroke
.20671 .55829 L
.20947 .57126 L
.21101 .57684 L
.2124 .58082 L
.21369 .58358 L
.21487 .58535 L
.21617 .58642 L
.21683 .58662 L
.21754 .58658 L
.21875 .58588 L
.22005 .58427 L
.22127 .58194 L
.22238 .57914 L
.22467 .57135 L
.2272 .55971 L
.23232 .52708 L
.23706 .4873 L
.2415 .4433 L
.25163 .3284 L
.26228 .20628 L
.27194 .11569 L
.27459 .09651 L
.27741 .07929 L
.27986 .06727 L
.28114 .06206 L
.2825 .0574 L
.28374 .05394 L
.2844 .05241 L
.2851 .051 L
.28634 .04913 L
.2875 .04806 L
.28876 .04766 L
.28996 .04802 L
.29104 .04895 L
.29221 .05061 L
.29326 .05268 L
.29442 .05558 L
.29678 .06345 L
.29896 .07304 L
.30102 .08398 L
.3057 .11547 L
.31083 .15903 L
.32117 .26703 L
.33967 .4706 L
.34495 .51784 L
.34993 .55422 L
.3544 .57889 L
.35693 .58917 L
.35926 .59622 L
.36046 .59894 L
Mistroke
.36176 .60114 L
.36298 .60253 L
.3641 .60322 L
.3654 .60332 L
.36614 .60304 L
.36683 .60256 L
.36809 .60115 L
.36879 .60006 L
.36943 .59889 L
.37209 .59208 L
.37359 .58692 L
.37497 .58137 L
.3802 .55362 L
.3849 .52039 L
.38995 .47752 L
.39904 .38663 L
.41971 .16898 L
.42989 .0855 L
.43268 .06762 L
.43564 .05132 L
.4382 .03957 L
.44096 .0294 L
.44222 .02565 L
.44354 .0223 L
.44476 .01973 L
.4459 .01782 L
.44697 .01644 L
.44811 .01541 L
.44938 .01479 L
.45053 .01472 L
.45119 .01488 L
.45189 .01521 L
.45314 .01622 L
.45383 .01701 L
.45448 .0179 L
.45596 .02043 L
.45843 .02624 L
.46109 .0346 L
.46635 .05725 L
.47123 .08469 L
.48228 .16474 L
.50238 .34204 L
.51299 .43464 L
.51819 .47437 L
.52296 .50501 L
.52732 .52663 L
.52951 .53484 L
.53192 .54159 L
.53318 .54416 L
.53434 .54588 L
Mistroke
.53497 .54658 L
.53567 .54713 L
.53692 .54756 L
.5381 .54731 L
.53935 .54633 L
.54041 .54491 L
.54159 .54272 L
.54287 .53958 L
.54407 .53597 L
.54678 .52532 L
.54917 .51316 L
.55172 .49749 L
.56099 .4202 L
.57186 .30527 L
.58186 .20285 L
.58686 .16171 L
.58941 .14469 L
.59214 .12992 L
.59357 .12372 L
.59488 .11905 L
.5962 .11533 L
.59744 .11272 L
.59814 .11164 L
.59889 .11083 L
.59953 .11039 L
.60023 .11018 L
.60098 .11029 L
.60179 .1108 L
.60256 .11163 L
.60326 .11271 L
.60444 .11516 L
.60569 .11869 L
.60795 .12735 L
.61064 .14139 L
.61309 .15746 L
.62343 .25327 L
.63274 .3587 L
.64261 .45857 L
.64509 .47809 L
.64776 .49558 L
.64929 .50381 L
.65069 .51011 L
.65211 .51528 L
.65342 .51893 L
.65461 .52124 L
.65587 .52268 L
.65659 .52302 L
.65727 .52303 L
.65854 .52222 L
.65976 .52042 L
Mistroke
.66088 .5179 L
.66211 .51419 L
.6634 .50921 L
.66595 .49633 L
.66837 .48057 L
.6729 .44283 L
.68307 .33184 L
.69179 .23196 L
.69643 .18688 L
.69886 .16709 L
.70141 .14978 L
.70266 .14278 L
.70402 .13626 L
.70527 .13135 L
.7064 .12781 L
.70758 .12511 L
.70883 .1233 L
.70999 .12263 L
.71109 .12288 L
.71233 .12422 L
.71365 .12686 L
.71478 .13008 L
.71602 .13465 L
.71877 .14854 L
.72135 .1659 L
.726 .20645 L
.73024 .25153 L
.73978 .36473 L
.74458 .41829 L
.74967 .46577 L
.75177 .4813 L
.75403 .495 L
.75532 .5013 L
.7565 .50605 L
.75764 .50964 L
.75883 .51239 L
.76013 .51417 L
.76131 .51468 L
.76197 .5145 L
.76267 .51395 L
.76396 .51196 L
.76517 .50897 L
.76645 .50462 L
.76874 .49386 L
.7714 .47685 L
.7739 .45692 L
.77958 .39983 L
.78997 .27539 L
.79509 .21785 L
.79984 .17405 L
Mistroke
.80204 .15807 L
.80412 .14599 L
.80528 .14062 L
.80652 .13592 L
.80765 .13268 L
.80869 .13057 L
.80985 .12924 L
.81094 .12895 L
.81212 .1297 L
.8134 .13175 L
.81404 .13326 L
.81473 .13526 L
.81599 .13986 L
.81836 .15168 L
.8207 .16721 L
.82321 .18785 L
.82777 .23372 L
.83814 .35902 L
.84348 .42031 L
.8464 .44906 L
.8491 .47162 L
.85142 .48717 L
.85261 .49365 L
.8539 .49948 L
.85464 .50224 L
.85532 .50439 L
.85595 .50608 L
.85665 .50756 L
.85787 .50919 L
.85915 .50959 L
.86045 .50862 L
.86165 .50648 L
.86297 .5028 L
.86437 .49735 L
.86697 .48329 L
.86932 .46638 L
.8741 .42158 L
.87861 .37007 L
.88877 .24515 L
.89146 .21568 L
.89433 .18788 L
.89698 .16647 L
.89829 .1577 L
.8995 .15072 L
.90065 .14512 L
.90191 .14016 L
.90318 .13648 L
.90387 .13504 L
.90453 .13405 L
.90568 .13318 L
Mistroke
.90673 .13338 L
.90794 .13477 L
.9091 .13726 L
.91036 .14123 L
.91171 .14691 L
.91413 .1607 L
.91701 .18262 L
.91962 .20704 L
.92925 .32062 L
.93811 .42623 L
.94235 .46539 L
.94475 .48243 L
.947 .49439 L
.94822 .49917 L
.94937 .50256 L
.95041 .50463 L
.95153 .50583 L
.95276 .50587 L
.95406 .50449 L
.95517 .50214 L
.9564 .49832 L
.95764 .49315 L
.95896 .48632 L
.96131 .47079 L
.9666 .42216 L
.97619 .30557 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{245.625, 151.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004c0000_B000`400?l00000o`00003ooooooold
ooooo`00V_ooool00ol0003oooooooooo`2Fooooo`00V_ooool00ol0003oooooooooo`2Fooooo`00
V_ooool00ol0003oooooooooo`2Fooooo`00V_ooool00ol0003oooooooooo`2Fooooo`00Roooool2
o`0000gooooo00?o0000ooooooooool0U_ooool008[ooooo1?l0000<ooooo`?o0000U_ooool008[o
oooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`2Fooooo`00ROooool01Ol0003o
oooooooooooooooo000000cooooo00?o0000ooooooooool0U_ooool008Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo09Kooooo0029ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Fooooo`00ROoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0U_oo
ool008Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo09Kooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool3o`00
09Kooooo0028ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2Fooooo`00F_ooool2o`0002_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo09Kooooo001Jooooo`?o0000:_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0U_ooool005Wooooo00Co0000
oooooooooooo0000:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0U_ooool005Wooooo00Co0000oooooooooooo0000:_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0U_ooool0033ooooo0_l0000W
ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`?o0000U_ooool002oooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo09Kooooo000_ooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Fooooo`00;_ooool01Ol0003ooooooooooooooooo
000002Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Fooooo`00;_ooool01Ol0
003ooooooooooooooooo000002Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2F
ooooo`00;_ooool01Ol0003ooooooooooooooooo000002Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`2Fooooo`002oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
09Kooooo000;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo0ol0002Fooooo`002oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo09Kooooo000;ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0U_ooool000_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2F
ooooo`002oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0U_ooool000co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Fooooo`003?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooooooo1_l00005ooooo`03
o`000?oooooooooo00Cooooo0ol0002Fooooo`003?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo09Kooooo000<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06ooo
ool2o`0007Wooooo000<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool3
o`0007Sooooo000<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool01?l0
003oooooooooool0001hooooo`003?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo
01[ooooo00Co0000oooooooooooo0000N?ooool000cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Jooooo`04o`000?ooooooooooo`0001kooooo0_l0001Hooooo`003?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`?o00006_ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000
ooooool00000Eoooool000cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooo`00000Koooo
o`?o0000>Oooool000gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Koooo
o`03o`000?oooooo000001[ooooo0_l0000Mooooo`003Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`05
o`000?ooooooooooooooool000006_ooool00ol0003oooooo`00000Jooooo`?o00007?ooool000go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000001Wooooo00Go0000oooo
ooooooooooooo`00000Iooooo`03o`000?oooooo000001cooooo000=ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Wooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000006Ooo
ool00ol0003oooooo`00000Looooo`003Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`?o00006?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
000Iooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo000001_o
oooo000=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo0000
01_ooooo000=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Gooooo`05o`000?ooooooooooooooool000006?ooool01Ol0003ooooooooooooooooo
000001_ooooo000=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool01Ol0
003ooooooooooooooooo000001_ooooo000=ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool01Ol0003ooooooooooooooooo000001_ooooo000>ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001_ooooo000>oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Wooooo000>ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo0ol0000Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool000kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool000kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06?ooool000kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool0
00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
017ooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06?ooool000kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06?ooool000kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo0ol0000G
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool000kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool0
00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01;ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05oooool000oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05oooool000oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000H
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool000oooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Kooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00KoA4A4o`000?l0003o<S8bomgMgOl00003ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`003oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01_ooooo00GoMgMgo`000?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8bo`000003ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Gooooo`003oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01?ooooo1_l00002ooooo`05oa0@4?l0003oooooooooool@41004?ooool00ol0003ooooo
o`000002ooooo`?o00005_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo
000?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool2o`0000;ooooo00?o
0000ooooooooool03Oooool01?mgMgOo<S8booooool00002ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`003oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01[ooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00Oo
0000ob4Q8Ol0003o<S8bolc<c?oooooo000000;ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Oooooo000?ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool06_ooool01Ol@413o0000oooooooooooo410@00cooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05oooool000oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`05
o`000?nHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`004?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00Go0000oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00000_ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05_ooool0013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00005oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Kooooo000@ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o00005Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000@ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`04o`000?oooooooooo
o`0001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`004?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooo`00000Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0013o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooool000005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Ko
oooo000@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Fooooo`004?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05_ooool0013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool000000_l0000Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05_ooool0013ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool000005_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo000@ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000001Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`004Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
o`00000Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool0017ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooool000005_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo000A
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0G
ooooo`;o00005_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo000Aoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Goooo
o`;o00005_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo0008ooooo`Go
00000oooool01Oo^k^ko0000o`000?lb<S;ok^k^01;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Eooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPOooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`Co00005?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool4o`000008oa0@
4?l0003oooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05ogMgMol0003ooooooiRHV?mgMgL04_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`;o00005_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool02_l0003o
ooooooooool0003oooooogMgMonHV9SooooooiRHV?mgMgL:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool000Ko
00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?l0003oooooooooool@41004_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo1_l00002ooooo`04o`000?oooooooooo
o`0000Cooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05oooool2o`0001Kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Sooooo00Ko0000oooooooooooo0000ooooool@4103ooooo`03
oa0@4?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP04ooooo`05
oa0@4?ooooooooooooooool@41000oooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Co
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Gooooo`;o00005_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`002oooool00omgMgOoIVIV
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05?ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo0_l0000Eoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
000<ooooo`06o`000?ooooooooooooooool@413o00000_ooool00ol@413oooooooooo`0@ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool00004oooo
o`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Oooooo0_l0000Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo410@0oooool00ol@413ooooo
ooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo007ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
0000oooooonHV9SoMgMg01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Doooo
o`04o`000?ooooooooooo`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool06?ooool4o`0001?ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00[o0000oooooooooooo0000
oooooomgMgOoV9RHoooooonHV9SoMgMg2Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0008ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Cooooo`04o`000?mEEEGoIVIVo`0000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`03oeEEEOmVIVKo000000;ooooo00Oo0000ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`004_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`00
4_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`004_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`001?ooooooo`0002oo
00000Oooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo0_l0000>ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool2o`0000gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`06ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`004_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool2o`0001?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oo
oooo000Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Jooooo`;o00004oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01oooool001;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo0_l0000Cooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool3o`0001;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000Coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Joooo
o`;o00004oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01[ooooo0_l0000Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool06_ooool2o`0001?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000Cooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`;o00004ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01[ooooo0_l0000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooo`00000Booooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`004oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool3o`00017o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Cooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo0000017ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000C
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000Cooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo0000017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo000Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Kooooo`?o00004Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool001Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool000004Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool001Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00004?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool001Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00004?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool001Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool001Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01cooooo1?l0000?ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`005?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool01?l0
003oooooooooool0000?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`09ooooo`005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`005Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07?ooool01?l0
003oooooooooool0000?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`005Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
000Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo000Eooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?ooool03Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool001Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool001Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Wooooo000Eooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`005Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo000Eooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`?o00000_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo000F
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool001Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool001Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01kooooo0ol00003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool001Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000000gooooo000Fooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`05
o`000?ooooooooooooooool000003Oooool001Kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000=oooo
o`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool01Ol0
003ooooooooooooooooo000000gooooo000Gooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Nooooo`?o00001?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool0000Hooooo`04o`000?oo
ooooooooo`0000kooooo000Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool01Ol0003ooooooooooooooooo000001Wooooo00Co0000oooooooooooo00006?ooool01?l0003o
ooooooooool0000>ooooo`005oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01So
oooo00Go0000ooooooooooooooooo`00000Iooooo`04o`000?ooooooooooo`0001Wooooo00?o0000
ooooool000003_ooool001Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hoooo
o`05o`000?ooooooooooooooool000006_ooool00ol0003oooooo`00000Iooooo`;o00003oooool0
01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo0000
01_ooooo0_l0000Kooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`05o`000?oooooooooooooo
ool000006oooool00ol0003oooooo`00000Kooooo`;o0000:oooool001Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo0ol00005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Moooo
o`;o0000B?ooool001Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooool00000Ioooool001Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo0ol0001Wooooo`006?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_oo
ool2o`0006Sooooo000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool001Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0R?ooool001Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool001Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1?ooool3o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`28ooooo`006Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000
Roooool001Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooo`0008_ooooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool2o`0008cooooo000Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0U_ooool0
01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0U_ooool001[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo027ooooo0ol0002Fooooo`006_ooool01Ol0003ooooo
oooooooooooo000002?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`2Fooooo`00
6_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`2Fooooo`006_ooool01Ol0003ooooooooooooooooo000002Cooooo00Go0000oooooooo
ooooooooo`00000Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`2Fooooo`006oooool01?l0003oooooooooool0000Tooooo`05o`000?oooooooooo
ooooool000009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0U_ooool001_ooooo00?o0000ooooool000009Oooool01Ol0003ooooooooooooooooo
000002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo09Kooooo000Kooooo`?o00009Oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo09Kooooo0014oooo
o`04o`000?oooooo0000o`0002Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0R
ooooo`?o0000U_ooool004Cooooo00?o0000ooooool000009oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0U_ooool004Gooooo0_l0000Xooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`2Fooooo`00
Koooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
U_ooool006oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo09Kooooo001`ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003ooooooooo
o`2Fooooo`00L?ooool2o`000003ooooool0003ooooo02Gooooo0ol0002Fooooo`00LOooool2o`00
02Oooooo00?o0000ooooooooool0U_ooool009[ooooo00?o0000ooooooooool0U_ooool009[ooooo
00?o0000ooooooooool0U_ooool009[ooooo00?o0000ooooooooool0U_ooool009[ooooo00?o0000
ooooooooool0U_ooool00?oooooo=?ooool00001\
\>"],
  ImageRangeCache->{{{0, 306}, {188.688, 0}} -> {-21, -1, 0, 0}}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->"refs"],

Cell[TextData[{
  "Samuel D. Conte and Carl de Boor, ",
  StyleBox["Elementary Numerical Analysis",
    FontSlant->"Italic"],
  ", 3rd ed. (McGraw-Hill, New York, 1980).",
  "\nStephen Wolfram, ",
  StyleBox["The Mathematica Book, ",
    FontSlant->"Italic"],
  "4th ed.  (Cambridge University Press, Cambridge, 1999)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 9, Section 9.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
ShowSelection->True,
TaggingRules:>{"NextIndexingNumber" -> 140, "IndexEntries" -> {{"i:102", 
  StyleBox[ "AccuracyGoal", FontWeight -> "Bold"]}, {"i:103", 
  StyleBox[ 
  "PrecisionGoal", FontWeight -> 
    "Bold"]}, {"i:106", "Heaviside step function"}, {"i:11", "Keyboard \
equivalents"}, {"i:111", "Logical statements"}, {"i:112", "Cantilever"}, \
{"i:113", "<<"}, {"i:114", "ExtendGraphics packages"}, {"i:115", "( ) \
(brackets used to determine order in a calulation)"}, {"i:116", "Taylor, \
Brook"}, {"i:117", "radius of convergence"}, {"i:118", "Work-kinetic-energy \
theorem"}, {"i:119", "Lissajous figure"}, {"i:12", "Palettes"}, {"i:12", \
"Special characters"}, {"i:120", "Shadowing"}, {"i:121", "* (wildcard)"}, \
{"i:122", "? (determine definition)"}, {"i:123", "Heaviside, Oliver"}, \
{"i:124", "Newton's method"}, {"i:125", "Newtons' method"}, {"i:126", \
"While"}, {"i:127", "splines"}, {"i:128", "Directory"}, {"i:129", \
"SetDirectory"}, {"i:13", {
  StyleBox[ "Abort", FontWeight -> "Bold"], " ", 
  StyleBox[ "Evaluation", FontWeight -> "Bold"]}}, {"i:13", 
  StyleBox[ 
  "Interrupt Evaluation", FontWeight -> 
    "Bold"]}, {"i:130", "Get"}, {"i:131", "Import"}, {"i:132", \
"NonlinearFit"}, {"i:133", "arrow"}, {"i:134", "trapezoidal rule"}, {"i:135", \
"Simpson's rule"}, {"i:136", "Bode's rule"}, {"i:137", "Gaussian \
quadrature"}, {"i:138", "Least-squares fit"}, {"i:15", 
  StyleBox[ "Im", FontWeight -> "Bold"]}, {"i:15", 
  StyleBox[ 
  "Re", FontWeight -> 
    "Bold"]}, {"i:16", "Exact mathematics"}, {"i:17", "Approximate \
mathematics"}, {"i:2", "Magnification"}, {"i:21", 
  StyleBox[ "Precision", FontWeight -> "Bold"]}, {"i:22", 
  StyleBox[ 
  "%", FontWeight -> 
    "Bold"]}, {"i:26", "Lists"}, {"i:3", "Notebook"}, {"i:34", 
  StyleBox[ "Inverse", FontWeight -> "Bold"]}, {"i:36", 
  StyleBox[ "Det", FontWeight -> "Bold"]}, {"i:37", 
  StyleBox[ "NullSpace", FontWeight -> "Bold"]}, {"i:38", 
  StyleBox[ "Table", FontWeight -> "Bold"]}, {"i:45", 
  StyleBox[ "Show", FontWeight -> "Bold"]}, {"i:48", 
  StyleBox[ "Plot3D", FontWeight -> "Bold"]}, {"i:49", 
  StyleBox[ 
  "ContourPlot", FontWeight -> 
    "Bold"]}, {"i:5", "Machine precision"}, {"i:50", "Parametric Plots"}, \
{"i:52", "Mobius strip"}, {"i:54", 
  StyleBox[ "RealTime3D", FontWeight -> "Bold"]}, {"i:55", 
  StyleBox[ 
  "Default3D", FontWeight -> 
    "Bold"]}, {"i:56", "Animations"}, {"i:57", "Add-on packages"}, {"i:58", \
"Fermat's spiral"}, {"i:59", "Eccentricity"}, {"i:6", "Arbitrary precision \
numbers"}, {"i:60", "Perihelion"}, {"i:61", "Options for intrinsic \
functions"}, {"i:62", 
  StyleBox[ "Expand", FontWeight -> "Bold"]}, {"i:63", 
  StyleBox[ 
  "Factor", FontWeight -> 
    "Bold"]}, {"i:64", "Simplifying expressions"}, {"i:64", 
  StyleBox[ "FullSimplify", FontWeight -> "Bold"]}, {"i:64", 
  StyleBox[ 
  "Simplify", FontWeight -> "Bold"]}, {"i:65", {"Replacing variables (", 
  StyleBox[ "/.", FontWeight -> "Bold"], ")"}}, {"i:7", 
  StyleBox[ "InputForm", FontWeight -> "Bold"]}, {"i:70", 
  StyleBox[ "D", FontWeight -> "Bold"]}, {"i:71", "Power series"}, {"i:74", 
  StyleBox[ "Integrate", FontWeight -> "Bold"]}, {"i:75", 
  StyleBox[ "NIntegrate", FontWeight -> "Bold"]}, {"i:76", 
  StyleBox[ "Series", FontWeight -> "Bold"]}, {"i:77", 
  StyleBox[ 
  "Normal", FontWeight -> 
    "Bold"]}, {"i:78", "Logical statements"}, {"i:79", "Logical statements"}, \
{"i:79", 
  StyleBox[ 
  "If", FontWeight -> 
    "Bold"]}, {"i:8", "Front End"}, {"i:8", "Kernel"}, {"i:80", "Logical \
statements"}, {"i:81", 
  StyleBox[ "Solve", FontWeight -> "Bold"]}, {"i:82", 
  StyleBox[ "NSolve", FontWeight -> "Bold"]}, {"i:84", 
  StyleBox[ 
  "FindRoot", FontWeight -> 
    "Bold"]}, {"i:85", "Underdetermined systems"}, {"i:92", 
  StyleBox[ "Interpolation", FontWeight -> "Bold"]}, {"i:95", 
  StyleBox[ "Fit", FontWeight -> "Bold"]}, {"i:96", 
  StyleBox[ "Random", FontWeight -> "Bold"]}, {"i:97", 
  StyleBox[ 
  "Random", FontWeight -> 
    "Bold"]}, {"i:98", "Vector and Matrix Operations"}, {"i:107", \
"Equilibrium", "of a vertical rod in gravity"}, {"i:109", "Equations", \
"meaning of =, := and =="}, {"i:11", "Greek letters", "from keyboard"}, \
{"i:110", "Solution of algebraic equations", {"numerical ", "(", 
  StyleBox[ "NSolve", FontWeight -> "Bold"], ")"}}, {"i:114", 
  StyleBox[ 
  "ContourPlot", FontWeight -> 
    "Bold"], "adding labels to contours"}, {"i:12", "Greek letters", "from \
palletes"}, {"i:139", "Splines", "cubic"}, {"i:15", "Complex arithmetic", \
{"complex conjugate  (", 
  StyleBox[ 
  "Conjugate", FontWeight -> 
    "Bold"], ")"}}, {"i:15", "Complex arithmetic", {"Imaginary Part ( ", 
  StyleBox[ 
  "Im", FontWeight -> 
    "Bold"], ")"}}, {"i:15", "Complex arithmetic", {"Real Part ( ", 
  StyleBox[ 
  "Re", FontWeight -> "Bold"], ")"}}, {"i:25", "Clearing variables", 
  StyleBox[ 
  "Clear", FontWeight -> 
    "Bold"]}, {"i:27", "Lists", "dimension"}, {"i:28", "Lists", {"in \
vector/matrix notation (", 
  StyleBox[ 
  "MatrixForm", FontWeight -> 
    "Bold"], ")"}}, {"i:29", "Lists", "extracting elements from"}, {"i:35", \
"Vector and Matrix Operations", "eigenvalues and eigenvectors"}, {"i:39", \
"Lists, operations on", 
  StyleBox[ 
  "Append", FontWeight -> "Bold"]}, {"i:40", "Lists, operations on", 
  StyleBox[ "Join", FontWeight -> "Bold"]}, {"i:41", "Lists, operations on", 
  StyleBox[ 
  "Flatten", FontWeight -> 
    "Bold"]}, {"i:42", "Vector and Matrix Operations", "vector magnitude \
(length)"}, {"i:47", "Data analysis", "plotting"}, {"i:47", "Plotting", \
{{"data (", 
  StyleBox[ "see", FontSlant -> Italic], " "}, 
  StyleBox[ 
  "ListPlot", FontWeight -> 
    "Bold"], ")"}}, {"i:48", "Plotting", {{"functions of two variables ( as a \
surface: ", 
  StyleBox[ "see", FontSlant -> Italic], " "}, 
  StyleBox[ 
  "Plot3D", FontWeight -> 
    "Bold"], ")"}}, {"i:49", "Plotting", {{"functions of two variables ( as a \
contour plot: ", 
  StyleBox[ "see", FontSlant -> Italic], " "}, 
  StyleBox[ 
  "ContourPlot", FontWeight -> 
    "Bold"], ")"}}, {"i:50", "Plotting", {"curves in 2D defined by a \
parameter (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Parametric Plots)"}}, {"i:72", "Integration", "analytic"}, \
{"i:73", "Integration", "numerical"}, {"i:83", "Solution of algebraic \
equations", {"analytic (", 
  StyleBox[ 
  "Solve", FontWeight -> 
    "Bold"], ")"}}, {"i:84", "Solution of algebraic equations", {"numerical \
(", 
  StyleBox[ 
  "FindRoot", FontWeight -> 
    "Bold"], ")"}}, {"i:86", "Solution of algebraic equations", "graphical, \
one variable"}, {"i:88", "Equilibrium", "of elastic band in gravity"}, \
{"i:90", "Equilibrium", "of pyramid in gravity"}, {"i:92", "Data analysis", \
"interpolation"}, {"i:93", 
  StyleBox[ 
  "Interpolation", FontWeight -> 
    "Bold"], "order"}, {"i:95", "Data analysis", "fitting"}, {"i:1", \
"Hyperlinks", "", ""}, {"i:10", "Contexts", "", ""}, {"i:100", 
  StyleBox[ 
  "InterpolatingFunction", FontWeight -> 
    "Bold"], "", ""}, {"i:101", "Function(s)", "pure", ""}, {"i:104", {"Unit \
matrix (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Delta function, Kronecker)"}, "", ""}, {"i:105", {
  StyleBox[ "Eigenvalues ", FontWeight -> "Bold"], "and ", 
  StyleBox[ 
  "Eigenvectors", FontWeight -> 
    "Bold"]}, "", ""}, {"i:14", "Complex arithmetic", "", ""}, {"i:18", \
"Function(s)", "intrinsic", ""}, {"i:19", "Function(s)", "user-defined", ""}, \
{"i:20", 
  StyleBox[ 
  "N", FontWeight -> "Bold"], "", ""}, {"i:23", "Clearing variables", 
  StyleBox[ 
  "Remove", FontWeight -> 
    "Bold"], ""}, {"i:24", "Clearing variables", "all user-defined \
variables", ""}, {"i:31", {"Dot product (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Inner products)"}, "", ""}, {"i:32", "Matrix multiplication", \
"", ""}, {"i:33", 
  StyleBox[ 
  "Transpose", FontWeight -> 
    "Bold"], "", ""}, {"i:35", "Eigenvalue problem", "eigenvalues and \
eigenvectors of a matrix", ""}, {"i:4", "Cell", "", ""}, {"i:43", "Plotting", \
{{"functions of one variable (", 
  StyleBox[ "see", FontSlant -> Italic], " "}, 
  StyleBox[ "Plot", FontWeight -> "Bold"], ")"}, ""}, {"i:43", 
  StyleBox[ "Plot", FontWeight -> "Bold"], "", ""}, {"i:44", 
  StyleBox[ 
  "Plot", FontWeight -> 
    "Bold"], "options for", ""}, {"i:45", "Plotting", {"repeating a previous \
plot (", 
  StyleBox[ "Show", FontWeight -> "Bold"], ")"}, ""}, {"i:46", 
  StyleBox[ 
  "Plot", FontWeight -> 
    "Bold"], "several curves", ""}, {"i:51", "Parametric Plots", {"for curves \
in two dimensions (", 
  StyleBox[ 
  "ParametricPlot", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:52", "Parametric Plots", {"for curves or surfaces \
in 3 dimensions (", 
  StyleBox[ 
  "ParametricPlot3D", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:52", "Plotting", {{"curves or surfaces in 3D \
defined by parameter(s) (", 
  StyleBox[ "see", FontSlant -> Italic], " "}, 
  StyleBox[ 
  "ParametricPlot3D", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:53", "Plotting", "changing the viewpoint in 3D \
plots", ""}, {"i:66", "Function(s)", "use of the underscore when defining", \
""}, {"i:67", "Function(s)", "of several variables", ""}, {"i:68", \
"Function(s)", {"delayed evaluation of (", 
  StyleBox[ 
  ":=", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:69", "Function(s)", {"adding conditions to the \
definition (", 
  StyleBox[ 
  "/;", FontWeight -> 
    "Bold"], ")"}, ""}, {"i:70", "Derivatives", "", ""}, {"i:87", "Solution \
of algebraic equations", "graphical, two variables", ""}, {"i:89", \
"Equilibrium", "of horizontal rod in gravity", ""}, {"i:99", "Equations", \
{"algebraic, solution (", 
  StyleBox[ 
  "see", FontSlant -> Italic], " Solution of algebraic equations)"}, ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(9.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(9.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(9.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(9.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(9.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(9.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Open  ]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "chapter 1"->{
    Cell[1727, 52, 177, 7, 69, "Title",
      CellTags->{"chapter 1", "c:1"}]},
  "c:1"->{
    Cell[1727, 52, 177, 7, 69, "Title",
      CellTags->{"chapter 1", "c:1"}]},
  "Sec. 9.1"->{
    Cell[6583, 201, 134, 5, 39, "Subtitle",
      CellTags->{"Sec. 9.1", "c:2"}]},
  "c:2"->{
    Cell[6583, 201, 134, 5, 39, "Subtitle",
      CellTags->{"Sec. 9.1", "c:2"}]},
  "i:3"->{
    Cell[7904, 239, 524, 13, 78, "Text",
      CellTags->"i:3"]},
  "Cell 9.1"->{
    Cell[9354, 279, 84, 3, 67, "Input",
      CellTags->"Cell 9.1"]},
  "i:4"->{
    Cell[11292, 348, 1214, 27, 154, "Text",
      CellTags->"i:4"]},
  "Sec. 9.2"->{
    Cell[13084, 403, 144, 6, 40, "Subtitle",
      CellTags->{"Sec. 9.2", "c:3"}]},
  "c:3"->{
    Cell[13084, 403, 144, 6, 40, "Subtitle",
      CellTags->{"Sec. 9.2", "c:3"}]},
  "c:4"->{
    Cell[13272, 415, 58, 1, 41, "Subsubtitle",
      CellTags->"c:4"]},
  "Cell 9.2"->{
    Cell[13630, 430, 94, 3, 66, "Input",
      CellTags->"Cell 9.2"]},
  "Cell 9.3"->{
    Cell[13853, 443, 87, 3, 66, "Input",
      CellTags->"Cell 9.3"]},
  "Cell 9.4"->{
    Cell[14203, 461, 86, 3, 66, "Input",
      CellTags->"Cell 9.4"]},
  "Cell 9.5"->{
    Cell[14475, 479, 89, 3, 66, "Input",
      CellTags->"Cell 9.5"]},
  "Cell 9.6"->{
    Cell[14728, 494, 82, 3, 66, "Input",
      CellTags->"Cell 9.6"]},
  "Cell 9.7"->{
    Cell[15019, 512, 92, 3, 66, "Input",
      CellTags->"Cell 9.7"]},
  "i:115"->{
    Cell[15165, 521, 484, 17, 43, "Text",
      CellTags->"i:115"]},
  "Table 9.1"->{
    Cell[15652, 540, 3669, 101, 185, "Text",
      CellTags->"Table 9.1"]},
  "c:5"->{
    Cell[19358, 646, 77, 1, 30, "Subsubtitle",
      CellTags->"c:5"]},
  "i:16"->{
    Cell[19438, 649, 244, 6, 43, "Text",
      CellTags->"i:16"]},
  "Cell 9.8"->{
    Cell[19707, 659, 92, 3, 66, "Input",
      CellTags->"Cell 9.8"]},
  "Cell 9.9"->{
    Cell[20022, 676, 84, 3, 66, "Input",
      CellTags->"Cell 9.9"]},
  "Cell 9.10"->{
    Cell[20204, 687, 90, 3, 66, "Input",
      CellTags->"Cell 9.10"]},
  "i:17"->{
    Cell[20379, 696, 360, 11, 43, "Text",
      CellTags->"i:17"]},
  "Cell 9.11"->{
    Cell[20764, 711, 92, 3, 66, "Input",
      CellTags->"Cell 9.11"]},
  "i:5"->{
    Cell[21180, 732, 1753, 43, 196, "Text",
      CellTags->"i:5"]},
  "Cell 9.12"->{
    Cell[23417, 795, 93, 3, 66, "Input",
      CellTags->"Cell 9.12"]},
  "c:6"->{
    Cell[23943, 816, 72, 1, 30, "Subsubtitle",
      CellTags->"c:6"]},
  "i:18"->{
    Cell[24018, 819, 388, 13, 43, "Text",
      CellTags->"i:18"]},
  "i:96"->{
    Cell[24409, 834, 6369, 165, 282, "Text",
      CellTags->{"i:96", "Table 9.2"}]},
  "Table 9.2"->{
    Cell[24409, 834, 6369, 165, 282, "Text",
      CellTags->{"i:96", "Table 9.2"}]},
  "c:7"->{
    Cell[36923, 1182, 63, 1, 30, "Subsubtitle",
      CellTags->"c:7"]},
  "Table 9.3"->{
    Cell[37291, 1196, 2192, 61, 185, "Text",
      CellTags->"Table 9.3"]},
  "Cell 9.13"->{
    Cell[39863, 1274, 95, 3, 66, "Input",
      CellTags->"Cell 9.13"]},
  "Cell 9.14"->{
    Cell[40755, 1311, 102, 3, 66, "Input",
      CellTags->"Cell 9.14"]},
  "Cell 9.15"->{
    Cell[41016, 1324, 92, 3, 66, "Input",
      CellTags->"Cell 9.15"]},
  "c:8"->{
    Cell[41542, 1345, 66, 1, 30, "Subsubtitle",
      CellTags->"c:8"]},
  "i:14"->{
    Cell[41611, 1348, 520, 12, 60, "Text",
      CellTags->"i:14"]},
  "i:15"->{
    Cell[42387, 1371, 4409, 114, 200, "Text",
      CellTags->"i:15"]},
  "Cell 9.16"->{
    Cell[47011, 1497, 113, 3, 66, "Input",
      CellTags->"Cell 9.16"]},
  "c:9"->{
    Cell[47216, 1509, 255, 9, 33, "Subsubtitle",
      CellTags->"c:9"]},
  "i:20"->{
    Cell[47474, 1520, 852, 31, 70, "Text",
      CellTags->"i:20"]},
  "Cell 9.17"->{
    Cell[48351, 1555, 85, 3, 70, "Input",
      CellTags->"Cell 9.17"]},
  "i:6"->{
    Cell[48506, 1564, 364, 9, 70, "Text",
      CellTags->"i:6"]},
  "Cell 9.18"->{
    Cell[48895, 1577, 89, 3, 70, "Input",
      CellTags->"Cell 9.18"]},
  "Cell 9.19"->{
    Cell[49765, 1605, 93, 3, 70, "Input",
      CellTags->"Cell 9.19"]},
  "i:7"->{
    Cell[49929, 1614, 484, 13, 70, "Text",
      CellTags->"i:7"]},
  "Cell 9.20"->{
    Cell[50438, 1631, 104, 3, 70, "Input",
      CellTags->"Cell 9.20"]},
  "Cell 9.21"->{
    Cell[51152, 1657, 94, 3, 70, "Input",
      CellTags->"Cell 9.21"]},
  "i:21"->{
    Cell[51961, 1682, 434, 12, 70, "Text",
      CellTags->"i:21"]},
  "Cell 9.22"->{
    Cell[52420, 1698, 122, 3, 70, "Input",
      CellTags->"Cell 9.22"]},
  "Table 9.5"->{
    Cell[52771, 1715, 3862, 94, 70, "Text",
      CellTags->"Table 9.5"]},
  "c:10"->{
    Cell[56670, 1814, 65, 1, 30, "Subsubtitle",
      CellTags->"c:10"]},
  "Sec. 9.3"->{
    Cell[57805, 1869, 210, 10, 40, "Subtitle",
      CellTags->{"Sec. 9.3", "c:11"}]},
  "c:11"->{
    Cell[57805, 1869, 210, 10, 40, "Subtitle",
      CellTags->{"Sec. 9.3", "c:11"}]},
  "i:8"->{
    Cell[58018, 1881, 956, 25, 111, "Text",
      CellTags->"i:8"]},
  "i:13"->{
    Cell[59596, 1919, 964, 27, 95, "Text",
      CellTags->"i:13"]},
  "Sec. 9.4"->{
    Cell[61319, 1966, 80, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.4", "c:12"}]},
  "c:12"->{
    Cell[61319, 1966, 80, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.4", "c:12"}]},
  "c:13"->{
    Cell[61443, 1973, 61, 1, 40, "Subsubtitle",
      CellTags->"c:13"]},
  "i:22"->{
    Cell[61507, 1976, 514, 15, 66, "Text",
      CellTags->"i:22"]},
  "Cell 9.23"->{
    Cell[62046, 1995, 84, 3, 66, "Input",
      CellTags->"Cell 9.23"]},
  "Cell 9.24"->{
    Cell[62272, 2008, 85, 3, 66, "Input",
      CellTags->"Cell 9.24"]},
  "Cell 9.25"->{
    Cell[62608, 2027, 90, 3, 66, "Input",
      CellTags->"Cell 9.25"]},
  "Cell 9.26"->{
    Cell[63401, 2060, 82, 3, 66, "Input",
      CellTags->"Cell 9.26"]},
  "c:14"->{
    Cell[63901, 2082, 58, 1, 30, "Subsubtitle",
      CellTags->"c:14"]},
  "Cell 9.27"->{
    Cell[65795, 2148, 101, 3, 66, "Input",
      CellTags->"Cell 9.27"]},
  "Cell 9.28"->{
    Cell[66135, 2167, 83, 3, 66, "Input",
      CellTags->"Cell 9.28"]},
  "Cell 9.29"->{
    Cell[66457, 2186, 92, 3, 66, "Input",
      CellTags->"Cell 9.29"]},
  "i:23"->{
    Cell[66605, 2195, 221, 8, 26, "Text",
      CellTags->"i:23"]},
  "Cell 9.30"->{
    Cell[66829, 2205, 89, 3, 66, "Input",
      CellTags->"Cell 9.30"]},
  "Cell 9.31"->{
    Cell[67357, 2231, 81, 3, 66, "Input",
      CellTags->"Cell 9.31"]},
  "i:24"->{
    Cell[67491, 2240, 174, 4, 43, "Text",
      CellTags->"i:24"]},
  "Cell 9.32"->{
    Cell[67668, 2246, 102, 3, 66, "Input",
      CellTags->"Cell 9.32"]},
  "i:10"->{
    Cell[67773, 2251, 1539, 51, 111, "Text",
      CellTags->"i:10"]},
  "i:25"->{
    Cell[70070, 2329, 5691, 136, 265, "Text",
      CellTags->{"i:25", "Table 9.6"}]},
  "Table 9.6"->{
    Cell[70070, 2329, 5691, 136, 265, "Text",
      CellTags->{"i:25", "Table 9.6"}]},
  "c:15"->{
    Cell[78306, 2533, 82, 1, 30, "Subsubtitle",
      CellTags->"c:15"]},
  "i:12"->{
    Cell[78391, 2536, 977, 28, 95, "Text",
      CellTags->"i:12"]},
  "Fig. 9.1"->{
    Cell[761765, 10996, 74, 1, 15, "Caption",
      CellTags->"Fig. 9.1"]},
  "Cell 9.33"->{
    Cell[765397, 11128, 85, 3, 66, "Input",
      CellTags->"Cell 9.33"]},
  "Cell 9.34"->{
    Cell[765911, 11152, 92, 3, 70, "Input",
      CellTags->"Cell 9.34"]},
  "i:11"->{
    Cell[766925, 11192, 789, 24, 77, "Text",
      CellTags->"i:11"]},
  "Sec. 9.5"->{
    Cell[768399, 11238, 85, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.5", "c:16"}]},
  "c:16"->{
    Cell[768399, 11238, 85, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.5", "c:16"}]},
  "c:17"->{
    Cell[768528, 11245, 86, 1, 41, "Subsubtitle",
      CellTags->"c:17"]},
  "i:26"->{
    Cell[768617, 11248, 395, 12, 43, "Text",
      CellTags->"i:26"]},
  "Cell 9.35"->{
    Cell[769037, 11264, 105, 3, 66, "Input",
      CellTags->"Cell 9.35"]},
  "i:27"->{
    Cell[769832, 11298, 414, 13, 43, "Text",
      CellTags->"i:27"]},
  "Cell 9.36"->{
    Cell[770271, 11315, 89, 3, 66, "Input",
      CellTags->"Cell 9.36"]},
  "Cell 9.37"->{
    Cell[770477, 11328, 116, 3, 66, "Input",
      CellTags->"Cell 9.37"]},
  "Cell 9.38"->{
    Cell[770945, 11346, 94, 3, 66, "Input",
      CellTags->"Cell 9.38"]},
  "Cell 9.39"->{
    Cell[771474, 11370, 90, 3, 66, "Input",
      CellTags->"Cell 9.39"]},
  "i:28"->{
    Cell[771662, 11379, 253, 8, 43, "Text",
      CellTags->"i:28"]},
  "Cell 9.40"->{
    Cell[771940, 11391, 93, 3, 66, "Input",
      CellTags->"Cell 9.40"]},
  "i:29"->{
    Cell[772280, 11405, 656, 24, 60, "Text",
      CellTags->"i:29"]},
  "Cell 9.41"->{
    Cell[772961, 11433, 104, 3, 66, "Input",
      CellTags->"Cell 9.41"]},
  "Cell 9.42"->{
    Cell[773430, 11457, 81, 3, 66, "Input",
      CellTags->"Cell 9.42"]},
  "Cell 9.43"->{
    Cell[774618, 11508, 93, 3, 66, "Input",
      CellTags->"Cell 9.43"]},
  "Cell 9.44"->{
    Cell[776363, 11582, 103, 3, 66, "Input",
      CellTags->"Cell 9.44"]},
  "i:98"->{
    Cell[779904, 11673, 87, 1, 30, "Subsubtitle",
      CellTags->{"i:98", "c:18"}]},
  "c:18"->{
    Cell[779904, 11673, 87, 1, 30, "Subsubtitle",
      CellTags->{"i:98", "c:18"}]},
  "c:19"->{
    Cell[780016, 11678, 54, 1, 42, "Section",
      CellTags->"c:19"]},
  "Fig. 9.2"->{
    Cell[866167, 12774, 244, 12, 16, "Caption",
      CellTags->"Fig. 9.2"]},
  "Cell 9.45"->{
    Cell[866699, 12799, 159, 4, 86, "Input",
      CellTags->"Cell 9.45"]},
  "i:31"->{
    Cell[867618, 12832, 60, 1, 31, "Section",
      CellTags->{"i:31", "c:20"}]},
  "c:20"->{
    Cell[867618, 12832, 60, 1, 31, "Section",
      CellTags->{"i:31", "c:20"}]},
  "(9.5.1)"->{
    Cell[867987, 12850, 1499, 44, 29, "NumberedEquation",
      CellTags->"(9.5.1)"]},
  "(9.5.2)"->{
    Cell[869755, 12904, 814, 25, 33, "NumberedEquation",
      CellTags->"(9.5.2)"]},
  "Cell 9.46"->{
    Cell[871221, 12960, 85, 3, 67, "Input",
      CellTags->"Cell 9.46"]},
  "i:42"->{
    Cell[871433, 12970, 369, 13, 30, "Text",
      CellTags->"i:42"]},
  "Cell 9.47"->{
    Cell[871827, 12987, 85, 3, 67, "Input",
      CellTags->"Cell 9.47"]},
  "(9.5.3)"->{
    Cell[872994, 13034, 417, 12, 27, "NumberedEquation",
      CellTags->"(9.5.3)"]},
  "(9.5.4)"->{
    Cell[873546, 13054, 610, 19, 27, "NumberedEquation",
      CellTags->"(9.5.4)"]},
  "i:32"->{
    Cell[874577, 13095, 70, 1, 31, "Section",
      CellTags->{"i:32", "c:21"}]},
  "c:21"->{
    Cell[874577, 13095, 70, 1, 31, "Section",
      CellTags->{"i:32", "c:21"}]},
  "(9.5.5)"->{
    Cell[875620, 13144, 2841, 83, 33, "NumberedEquation",
      CellTags->"(9.5.5)"]},
  "(9.5.6)"->{
    Cell[879379, 13266, 2302, 58, 191, "NumberedEquation",
      CellTags->"(9.5.6)"]},
  "Cell 9.48"->{
    Cell[881884, 13336, 89, 3, 67, "Input",
      CellTags->"Cell 9.48"]},
  "Table 9.8"->{
    Cell[882289, 13354, 763, 21, 95, "Text",
      CellTags->"Table 9.8"]},
  "c:22"->{
    Cell[883089, 13380, 62, 1, 31, "Section",
      CellTags->"c:22"]},
  "i:33"->{
    Cell[883176, 13385, 80, 2, 27, "Subsubsection",
      CellTags->"i:33"]},
  "Cell 9.49"->{
    Cell[883693, 13405, 104, 3, 67, "Input",
      CellTags->"Cell 9.49"]},
  "i:34"->{
    Cell[884106, 13424, 94, 2, 29, "Subsubsection",
      CellTags->"i:34"]},
  "Cell 9.50"->{
    Cell[884429, 13436, 144, 4, 86, "Input",
      CellTags->"Cell 9.50"]},
  "Cell 9.51"->{
    Cell[885228, 13469, 137, 4, 86, "Input",
      CellTags->"Cell 9.51"]},
  "i:104"->{
    Cell[885597, 13484, 533, 20, 47, "Text",
      CellTags->"i:104"]},
  "Cell 9.52"->{
    Cell[886155, 13508, 133, 4, 86, "Input",
      CellTags->"Cell 9.52"]},
  "Cell 9.53"->{
    Cell[886794, 13534, 93, 3, 67, "Input",
      CellTags->"Cell 9.53"]},
  "(9.5.7)"->{
    Cell[887432, 13560, 283, 8, 27, "NumberedEquation",
      CellTags->"(9.5.7)"]},
  "(9.5.8)"->{
    Cell[887904, 13577, 853, 25, 32, "NumberedEquation",
      CellTags->"(9.5.8)"]},
  "Cell 9.54"->{
    Cell[889391, 13631, 100, 3, 67, "Input",
      CellTags->"Cell 9.54"]},
  "i:35"->{
    Cell[889612, 13643, 98, 2, 29, "Subsubsection",
      CellTags->"i:35"]},
  "(9.5.9)"->{
    Cell[890273, 13667, 467, 14, 27, "NumberedEquation",
      CellTags->"(9.5.9)"]},
  "i:105"->{
    Cell[890743, 13683, 746, 29, 61, "Text",
      CellTags->"i:105"]},
  "Cell 9.55"->{
    Cell[891514, 13716, 95, 3, 67, "Input",
      CellTags->"Cell 9.55"]},
  "Cell 9.56"->{
    Cell[891728, 13727, 94, 3, 67, "Input",
      CellTags->"Cell 9.56"]},
  "Cell 9.57"->{
    Cell[892514, 13756, 125, 3, 67, "Input",
      CellTags->"Cell 9.57"]},
  "i:36"->{
    Cell[892731, 13768, 82, 2, 29, "Subsubsection",
      CellTags->"i:36"]},
  "Cell 9.58"->{
    Cell[893328, 13794, 86, 3, 67, "Input",
      CellTags->"Cell 9.58"]},
  "i:37"->{
    Cell[893789, 13818, 79, 2, 29, "Subsubsection",
      CellTags->"i:37"]},
  "Cell 9.59"->{
    Cell[894290, 13836, 92, 3, 67, "Input",
      CellTags->"Cell 9.59"]},
  "Cell 9.60"->{
    Cell[895105, 13868, 153, 4, 86, "Input",
      CellTags->"Cell 9.60"]},
  "Cell 9.61"->{
    Cell[896357, 13917, 98, 3, 67, "Input",
      CellTags->"Cell 9.61"]},
  "(9.5.10)"->{
    Cell[896696, 13934, 1781, 51, 27, "NumberedEquation",
      CellTags->"(9.5.10)"]},
  "Fig. 9.3"->{
    Cell[964829, 14823, 751, 27, 16, "Caption",
      CellTags->"Fig. 9.3"]},
  "(9.5.11)"->{
    Cell[966491, 14881, 2154, 60, 74, "NumberedEquation",
      CellTags->"(9.5.11)"]},
  "Table 9.9"->{
    Cell[969548, 14974, 3278, 89, 163, "Text",
      CellTags->"Table 9.9"]},
  "c:23"->{
    Cell[972887, 15070, 118, 4, 30, "Subsubtitle",
      CellTags->"c:23"]},
  "i:38"->{
    Cell[973008, 15076, 498, 15, 61, "Text",
      CellTags->"i:38"]},
  "Cell 9.62"->{
    Cell[973531, 15095, 106, 3, 67, "Input",
      CellTags->"Cell 9.62"]},
  "Cell 9.63"->{
    Cell[974291, 15125, 113, 3, 67, "Input",
      CellTags->"Cell 9.63"]},
  "Cell 9.64"->{
    Cell[975137, 15155, 124, 3, 67, "Input",
      CellTags->"Cell 9.64"]},
  "c:24"->{
    Cell[975371, 15167, 68, 1, 30, "Subsubtitle",
      CellTags->"c:24"]},
  "i:39"->{
    Cell[976528, 15207, 358, 9, 70, "Text",
      CellTags->"i:39"]},
  "Cell 9.65"->{
    Cell[976889, 15218, 117, 3, 70, "Input",
      CellTags->"Cell 9.65"]},
  "Cell 9.66"->{
    Cell[977031, 15225, 95, 3, 70, "Input",
      CellTags->"Cell 9.66"]},
  "Cell 9.67"->{
    Cell[977416, 15244, 96, 3, 70, "Input",
      CellTags->"Cell 9.67"]},
  "i:40"->{
    Cell[977599, 15253, 612, 22, 70, "Text",
      CellTags->"i:40"]},
  "Cell 9.68"->{
    Cell[978236, 15279, 132, 4, 70, "Input",
      CellTags->"Cell 9.68"]},
  "i:41"->{
    Cell[978459, 15289, 668, 23, 70, "Text",
      CellTags->"i:41"]},
  "Cell 9.69"->{
    Cell[979152, 15316, 90, 3, 70, "Input",
      CellTags->"Cell 9.69"]},
  "Table 9.10"->{
    Cell[979641, 15338, 7209, 164, 70, "Text",
      CellTags->"Table 9.10"]},
  "c:25"->{
    Cell[986887, 15507, 65, 1, 30, "Subsubtitle",
      CellTags->"c:25"]},
  "Sec. 9.6"->{
    Cell[992346, 15726, 74, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.6", "c:26"}]},
  "c:26"->{
    Cell[992346, 15726, 74, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.6", "c:26"}]},
  "i:43"->{
    Cell[992464, 15733, 188, 8, 41, "Subsubtitle",
      CellTags->{"i:43", "c:27"}]},
  "c:27"->{
    Cell[992464, 15733, 188, 8, 41, "Subsubtitle",
      CellTags->{"i:43", "c:27"}]},
  "Cell 9.70"->{
    Cell[993836, 15794, 107, 3, 66, "Input",
      CellTags->"Cell 9.70"]},
  "i:44"->{
    Cell[1021548, 16430, 456, 15, 43, "Text",
      CellTags->"i:44"]},
  "Cell 9.71"->{
    Cell[1022029, 16449, 138, 3, 66, "Input",
      CellTags->"Cell 9.71"]},
  "i:133"->{
    Cell[1046109, 17083, 1214, 45, 60, "Text",
      CellTags->"i:133"]},
  "Cell 9.72"->{
    Cell[1050842, 17255, 406, 9, 123, "Input",
      CellTags->"Cell 9.72"]},
  "i:45"->{
    Cell[1083851, 18053, 188, 8, 30, "Subsubtitle",
      CellTags->{"i:45", "c:28"}]},
  "c:28"->{
    Cell[1083851, 18053, 188, 8, 30, "Subsubtitle",
      CellTags->{"i:45", "c:28"}]},
  "Cell 9.73"->{
    Cell[1084553, 18085, 159, 4, 70, "Input",
      CellTags->"Cell 9.73"]},
  "i:46"->{
    Cell[1116298, 18967, 100, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:29"}]},
  "c:29"->{
    Cell[1116298, 18967, 100, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:29"}]},
  "Cell 9.74"->{
    Cell[1118319, 19033, 243, 6, 70, "Input",
      CellTags->"Cell 9.74"]},
  "Cell 9.75"->{
    Cell[1145246, 19711, 101, 3, 70, "Input",
      CellTags->"Cell 9.75"]},
  "Table 9.11"->{
    Cell[1182338, 20779, 6857, 174, 70, "Text",
      CellTags->"Table 9.11"]},
  "i:47"->{
    Cell[1189232, 20958, 193, 8, 30, "Subsubtitle",
      CellTags->{"i:47", "c:30"}]},
  "c:30"->{
    Cell[1189232, 20958, 193, 8, 30, "Subsubtitle",
      CellTags->{"i:47", "c:30"}]},
  "Cell 9.76"->{
    Cell[1189915, 20986, 129, 3, 70, "Input",
      CellTags->"Cell 9.76"]},
  "Cell 9.77"->{
    Cell[1190643, 21013, 129, 3, 70, "Input",
      CellTags->"Cell 9.77"]},
  "Cell 9.78"->{
    Cell[1208812, 21470, 119, 3, 70, "Input",
      CellTags->"Cell 9.78"]},
  "i:50"->{
    Cell[1230087, 21978, 75, 1, 30, "Subsubtitle",
      CellTags->{"i:50", "c:31"}]},
  "c:31"->{
    Cell[1230087, 21978, 75, 1, 30, "Subsubtitle",
      CellTags->{"i:50", "c:31"}]},
  "i:51"->{
    Cell[1230165, 21981, 856, 28, 70, "Text",
      CellTags->"i:51"]},
  "Cell 9.79"->{
    Cell[1232663, 22070, 160, 4, 70, "Input",
      CellTags->"Cell 9.79"]},
  "i:119"->{
    Cell[1297621, 23236, 463, 17, 70, "Text",
      CellTags->"i:119"]},
  "Cell 9.80"->{
    Cell[1298999, 23290, 268, 6, 70, "Input",
      CellTags->"Cell 9.80"]},
  "Table 9.12"->{
    Cell[1347520, 24464, 7113, 176, 70, "Text",
      CellTags->"Table 9.12"]},
  "c:32"->{
    Cell[1354670, 24645, 57, 1, 30, "Subsubtitle",
      CellTags->"c:32"]},
  "i:48"->{
    Cell[1354730, 24648, 596, 19, 60, "Text",
      CellTags->"i:48"]},
  "Cell 9.81"->{
    Cell[1355351, 24671, 131, 3, 65, "Input",
      CellTags->"Cell 9.81"]},
  "i:53"->{
    Cell[1477184, 26699, 694, 26, 42, "Text",
      CellTags->"i:53"]},
  "Cell 9.82"->{
    Cell[1477903, 26729, 134, 3, 65, "Input",
      CellTags->"Cell 9.82"]},
  "i:54"->{
    Cell[1642418, 29288, 252, 7, 70, "Text",
      CellTags->"i:54"]},
  "Cell 9.83"->{
    Cell[1642673, 29297, 94, 3, 70, "Input",
      CellTags->"Cell 9.83"]},
  "Cell 9.84"->{
    Cell[1643028, 29313, 89, 3, 70, "Input",
      CellTags->"Cell 9.84"]},
  "i:55"->{
    Cell[1728873, 30394, 205, 5, 70, "Text",
      CellTags->"i:55"]},
  "Cell 9.85"->{
    Cell[1729081, 30401, 93, 3, 70, "Input",
      CellTags->"Cell 9.85"]},
  "i:49"->{
    Cell[1729250, 30408, 544, 17, 70, "Text",
      CellTags->"i:49"]},
  "Cell 9.86"->{
    Cell[1729819, 30429, 158, 4, 70, "Input",
      CellTags->"Cell 9.86"]},
  "i:56"->{
    Cell[1919799, 34804, 69, 1, 30, "Subsubtitle",
      CellTags->{"i:56", "c:33"}]},
  "c:33"->{
    Cell[1919799, 34804, 69, 1, 30, "Subsubtitle",
      CellTags->{"i:56", "c:33"}]},
  "Cell 9.87"->{
    Cell[1920376, 34828, 188, 5, 67, "Input",
      CellTags->"Cell 9.87"]},
  "i:57"->{
    Cell[2302830, 42848, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:57", "c:34"}]},
  "c:34"->{
    Cell[2302830, 42848, 74, 1, 30, "Subsubtitle",
      CellTags->{"i:57", "c:34"}]},
  "i:113"->{
    Cell[2302907, 42851, 1440, 40, 146, "Text",
      CellTags->"i:113"]},
  "Cell 9.88"->{
    Cell[2305125, 42914, 92, 3, 67, "Input",
      CellTags->"Cell 9.88"]},
  "Cell 9.89"->{
    Cell[2305401, 42929, 153, 4, 73, "Input",
      CellTags->"Cell 9.89"]},
  "i:120"->{
    Cell[2335290, 43680, 484, 13, 61, "Text",
      CellTags->"i:120"]},
  "Cell 9.90"->{
    Cell[2335799, 43697, 153, 4, 73, "Input",
      CellTags->"Cell 9.90"]},
  "Cell 9.91"->{
    Cell[2336231, 43714, 221, 6, 111, "Input",
      CellTags->"Cell 9.91"]},
  "i:114"->{
    Cell[2338805, 43794, 1430, 34, 163, "Text",
      CellTags->"i:114"]},
  "Cell 9.92"->{
    Cell[2340238, 43830, 96, 3, 67, "Input",
      CellTags->"Cell 9.92"]},
  "Cell 9.93"->{
    Cell[2341101, 43865, 1014, 21, 219, "Input",
      CellTags->"Cell 9.93"]},
  "Ex. 9.6"->{
    Cell[2491800, 47558, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.6", "c:35"}],
    Cell[2491881, 47561, 453, 15, 47, "Text",
      CellTags->"Ex. 9.6"]},
  "c:35"->{
    Cell[2491800, 47558, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.6", "c:35"}]},
  "i:59"->{
    Cell[2493009, 47599, 846, 27, 73, "Text",
      CellTags->"i:59"]},
  "i:60"->{
    Cell[2494165, 47641, 317, 11, 27, "Text",
      CellTags->"i:60"]},
  "i:58"->{
    Cell[2495927, 47706, 1022, 32, 61, "Text",
      CellTags->"i:58"]},
  "i:52"->{
    Cell[2496952, 47740, 1364, 45, 95, "Text",
      CellTags->"i:52"]},
  "Sec. 9.7"->{
    Cell[2499398, 47828, 147, 6, 40, "Subtitle",
      CellTags->{"Sec. 9.7", "c:36"}]},
  "c:36"->{
    Cell[2499398, 47828, 147, 6, 40, "Subtitle",
      CellTags->{"Sec. 9.7", "c:36"}]},
  "i:122"->{
    Cell[2500957, 47876, 393, 13, 44, "Text",
      CellTags->"i:122"]},
  "Cell 9.94"->{
    Cell[2501375, 47893, 96, 3, 67, "Input",
      CellTags->"Cell 9.94"]},
  "Cell 9.95"->{
    Cell[2501909, 47914, 106, 3, 67, "Input",
      CellTags->"Cell 9.95"]},
  "Cell 9.96"->{
    Cell[2502093, 47923, 86, 3, 67, "Input",
      CellTags->"Cell 9.96"]},
  "Info3244700897-7405223"->{
    Cell[2502210, 47930, 435, 13, 31, "Print",
      CellTags->"Info3244700897-7405223"]},
  "i:121"->{
    Cell[2502660, 47946, 225, 5, 44, "Text",
      CellTags->"i:121"]},
  "Cell 9.97"->{
    Cell[2502910, 47955, 93, 3, 67, "Input",
      CellTags->"Cell 9.97"]},
  "Cell 9.98"->{
    Cell[2505380, 48029, 93, 3, 67, "Input",
      CellTags->"Cell 9.98"]},
  "i:61"->{
    Cell[2505735, 48043, 539, 19, 61, "Text",
      CellTags->"i:61"]},
  "Cell 9.99"->{
    Cell[2506299, 48066, 87, 3, 67, "Input",
      CellTags->"Cell 9.99"]},
  "Sec. 9.8"->{
    Cell[2508575, 48121, 74, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.8", "c:37"}]},
  "c:37"->{
    Cell[2508575, 48121, 74, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.8", "c:37"}]},
  "c:38"->{
    Cell[2508693, 48128, 73, 1, 41, "Subsubtitle",
      CellTags->"c:38"]},
  "Cell 9.100"->{
    Cell[2509009, 48140, 101, 3, 67, "Input",
      CellTags->"Cell 9.100"]},
  "i:62"->{
    Cell[2509168, 48149, 298, 12, 44, "Text",
      CellTags->"i:62"]},
  "Cell 9.101"->{
    Cell[2509491, 48165, 130, 3, 67, "Input",
      CellTags->"Cell 9.101"]},
  "Cell 9.102"->{
    Cell[2509743, 48176, 90, 3, 67, "Input",
      CellTags->"Cell 9.102"]},
  "i:63"->{
    Cell[2509904, 48185, 397, 12, 42, "Text",
      CellTags->"i:63"]},
  "Cell 9.103"->{
    Cell[2510326, 48201, 90, 3, 65, "Input",
      CellTags->"Cell 9.103"]},
  "Cell 9.104"->{
    Cell[2510725, 48218, 120, 3, 65, "Input",
      CellTags->"Cell 9.104"]},
  "Cell 9.105"->{
    Cell[2511128, 48237, 92, 3, 65, "Input",
      CellTags->"Cell 9.105"]},
  "Cell 9.106"->{
    Cell[2511650, 48261, 93, 3, 67, "Input",
      CellTags->"Cell 9.106"]},
  "Cell 9.107"->{
    Cell[2511832, 48272, 96, 3, 67, "Input",
      CellTags->"Cell 9.107"]},
  "i:64"->{
    Cell[2512012, 48281, 696, 20, 78, "Text",
      CellTags->"i:64"]},
  "Cell 9.108"->{
    Cell[2512733, 48305, 122, 3, 67, "Input",
      CellTags->"Cell 9.108"]},
  "Table 9.14"->{
    Cell[2513253, 48324, 2437, 68, 203, "Text",
      CellTags->"Table 9.14"]},
  "c:39"->{
    Cell[2515727, 48397, 60, 1, 30, "Subsubtitle",
      CellTags->"c:39"]},
  "i:65"->{
    Cell[2515790, 48400, 556, 19, 64, "Text",
      CellTags->"i:65"]},
  "Cell 9.109"->{
    Cell[2516371, 48423, 101, 3, 67, "Input",
      CellTags->"Cell 9.109"]},
  "Cell 9.110"->{
    Cell[2517386, 48466, 133, 3, 67, "Input",
      CellTags->"Cell 9.110"]},
  "Table 9.15"->{
    Cell[2517746, 48483, 3598, 93, 83, "Text",
      CellTags->"Table 9.15"]},
  "i:19"->{
    Cell[2521381, 48581, 77, 1, 30, "Subsubtitle",
      CellTags->{"i:19", "c:40"}]},
  "c:40"->{
    Cell[2521381, 48581, 77, 1, 30, "Subsubtitle",
      CellTags->{"i:19", "c:40"}]},
  "c:41"->{
    Cell[2521483, 48586, 64, 1, 41, "Section",
      CellTags->"c:41"]},
  "Cell 9.111"->{
    Cell[2522724, 48630, 107, 3, 65, "Input",
      CellTags->"Cell 9.111"]},
  "Cell 9.112"->{
    Cell[2523062, 48648, 85, 3, 65, "Input",
      CellTags->"Cell 9.112"]},
  "i:66"->{
    Cell[2523201, 48657, 1062, 34, 60, "Text",
      CellTags->"i:66"]},
  "Cell 9.113"->{
    Cell[2524288, 48695, 95, 3, 65, "Input",
      CellTags->"Cell 9.113"]},
  "Cell 9.114"->{
    Cell[2524622, 48713, 85, 3, 65, "Input",
      CellTags->"Cell 9.114"]},
  "Cell 9.115"->{
    Cell[2527942, 48838, 93, 3, 65, "Input",
      CellTags->"Cell 9.115"]},
  "Cell 9.116"->{
    Cell[2528110, 48849, 96, 3, 65, "Input",
      CellTags->"Cell 9.116"]},
  "Cell 9.117"->{
    Cell[2528452, 48867, 85, 3, 65, "Input",
      CellTags->"Cell 9.117"]},
  "Cell 9.118"->{
    Cell[2528763, 48885, 85, 3, 65, "Input",
      CellTags->"Cell 9.118"]},
  "c:42"->{
    Cell[2528935, 48897, 76, 1, 30, "Section",
      CellTags->"c:42"]},
  "Cell 9.119"->{
    Cell[2529480, 48918, 87, 3, 66, "Input",
      CellTags->"Cell 9.119"]},
  "i:67"->{
    Cell[2531985, 49009, 79, 1, 30, "Section",
      CellTags->{"i:67", "c:43"}]},
  "c:43"->{
    Cell[2531985, 49009, 79, 1, 30, "Section",
      CellTags->{"i:67", "c:43"}]},
  "Cell 9.120"->{
    Cell[2532333, 49020, 111, 3, 65, "Input",
      CellTags->"Cell 9.120"]},
  "Cell 9.121"->{
    Cell[2532469, 49027, 97, 3, 65, "Input",
      CellTags->"Cell 9.121"]},
  "c:44"->{
    Cell[2534950, 49099, 67, 1, 30, "Subsubtitle",
      CellTags->"c:44"]},
  "i:68"->{
    Cell[2538343, 49223, 90, 1, 30, "Subsubtitle",
      CellTags->{"i:68", "c:45"}]},
  "c:45"->{
    Cell[2538343, 49223, 90, 1, 30, "Subsubtitle",
      CellTags->{"i:68", "c:45"}]},
  "Cell 9.122"->{
    Cell[2539044, 49246, 97, 2, 67, "Input",
      CellTags->"Cell 9.122"]},
  "Cell 9.123"->{
    Cell[2540647, 49303, 122, 3, 66, "Input",
      CellTags->"Cell 9.123"]},
  "Cell 9.124"->{
    Cell[2541383, 49333, 85, 3, 66, "Input",
      CellTags->"Cell 9.124"]},
  "Table 9.17"->{
    Cell[2573924, 50024, 4628, 122, 82, "Text",
      CellTags->"Table 9.17"]},
  "i:69"->{
    Cell[2578589, 50151, 101, 1, 30, "Subsubtitle",
      CellTags->{"i:69", "c:46"}]},
  "c:46"->{
    Cell[2578589, 50151, 101, 1, 30, "Subsubtitle",
      CellTags->{"i:69", "c:46"}]},
  "i:123"->{
    Cell[2578693, 50154, 353, 11, 44, "Text",
      CellTags->"i:123"]},
  "(9.8.1)"->{
    Cell[2579049, 50167, 594, 21, 45, "NE2",
      CellTags->{"(9.8.1)", "i:106"}]},
  "i:106"->{
    Cell[2579049, 50167, 594, 21, 45, "NE2",
      CellTags->{"(9.8.1)", "i:106"}]},
  "Cell 9.125"->{
    Cell[2579848, 50197, 108, 3, 67, "Input",
      CellTags->"Cell 9.125"]},
  "Cell 9.126"->{
    Cell[2579959, 50202, 108, 3, 67, "Input",
      CellTags->"Cell 9.126"]},
  "Cell 9.127"->{
    Cell[2581176, 50249, 95, 3, 67, "Input",
      CellTags->"Cell 9.127"]},
  "Cell 9.128"->{
    Cell[2581806, 50276, 157, 4, 67, "Input",
      CellTags->"Cell 9.128"]},
  "i:111"->{
    Cell[2594630, 50645, 7139, 171, 287, "Text",
      CellTags->{"i:111", "Table 9.18"}]},
  "Table 9.18"->{
    Cell[2594630, 50645, 7139, 171, 287, "Text",
      CellTags->{"i:111", "Table 9.18"}]},
  "i:80"->{
    Cell[2601772, 50818, 967, 35, 44, "Text",
      CellTags->"i:80"]},
  "Cell 9.129"->{
    Cell[2602764, 50857, 127, 4, 86, "Input",
      CellTags->"Cell 9.129"]},
  "Ex. 9.8"->{
    Cell[2603141, 50875, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.8", "c:47"}]},
  "c:47"->{
    Cell[2603141, 50875, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.8", "c:47"}]},
  "Sec. 9.9"->{
    Cell[2608784, 51120, 66, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.9", "c:48"}]},
  "c:48"->{
    Cell[2608784, 51120, 66, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.9", "c:48"}]},
  "i:70"->{
    Cell[2608894, 51127, 70, 1, 41, "Subsubtitle",
      CellTags->{"i:70", "c:49"}]},
  "c:49"->{
    Cell[2608894, 51127, 70, 1, 41, "Subsubtitle",
      CellTags->{"i:70", "c:49"}]},
  "Cell 9.130"->{
    Cell[2609749, 51160, 106, 3, 67, "Input",
      CellTags->"Cell 9.130"]},
  "Cell 9.131"->{
    Cell[2610084, 51176, 91, 3, 67, "Input",
      CellTags->"Cell 9.131"]},
  "Cell 9.132"->{
    Cell[2611157, 51217, 90, 3, 67, "Input",
      CellTags->"Cell 9.132"]},
  "Cell 9.133"->{
    Cell[2611414, 51230, 91, 3, 67, "Input",
      CellTags->"Cell 9.133"]},
  "Cell 9.134"->{
    Cell[2612794, 51281, 96, 3, 67, "Input",
      CellTags->"Cell 9.134"]},
  "Cell 9.135"->{
    Cell[2613601, 51307, 108, 3, 67, "Input",
      CellTags->"Cell 9.135"]},
  "Cell 9.136"->{
    Cell[2613991, 51325, 90, 3, 67, "Input",
      CellTags->"Cell 9.136"]},
  "i:71"->{
    Cell[2615198, 51382, 71, 1, 30, "Subsubtitle",
      CellTags->{"i:71", "c:50"}]},
  "c:50"->{
    Cell[2615198, 51382, 71, 1, 30, "Subsubtitle",
      CellTags->{"i:71", "c:50"}]},
  "(9.9.1)"->{
    Cell[2615670, 51399, 448, 11, 41, "NE3",
      CellTags->"(9.9.1)"]},
  "i:116"->{
    Cell[2616121, 51412, 1020, 35, 61, "Text",
      CellTags->"i:116"]},
  "i:76"->{
    Cell[2618037, 51481, 741, 26, 94, "Text",
      CellTags->"i:76"]},
  "Cell 9.137"->{
    Cell[2618803, 51511, 115, 3, 67, "Input",
      CellTags->"Cell 9.137"]},
  "Cell 9.138"->{
    Cell[2621055, 51592, 102, 3, 67, "Input",
      CellTags->"Cell 9.138"]},
  "Cell 9.139"->{
    Cell[2621943, 51625, 97, 3, 67, "Input",
      CellTags->"Cell 9.139"]},
  "i:77"->{
    Cell[2622265, 51639, 356, 12, 44, "Text",
      CellTags->"i:77"]},
  "Cell 9.140"->{
    Cell[2622646, 51655, 90, 3, 67, "Input",
      CellTags->"Cell 9.140"]},
  "Cell 9.141"->{
    Cell[2623229, 51680, 257, 5, 105, "Input",
      CellTags->"Cell 9.141"]},
  "i:117"->{
    Cell[2648527, 52331, 1118, 33, 99, "Text",
      CellTags->"i:117"]},
  "Cell 9.142"->{
    Cell[2650255, 52388, 122, 3, 73, "Input",
      CellTags->"Cell 9.142"]},
  "i:72"->{
    Cell[2650944, 52411, 70, 1, 30, "Subsubtitle",
      CellTags->{"i:72", "c:51"}]},
  "c:51"->{
    Cell[2650944, 52411, 70, 1, 30, "Subsubtitle",
      CellTags->{"i:72", "c:51"}]},
  "i:74"->{
    Cell[2651017, 52414, 615, 18, 63, "Text",
      CellTags->"i:74"]},
  "Cell 9.143"->{
    Cell[2651657, 52436, 102, 3, 67, "Input",
      CellTags->"Cell 9.143"]},
  "Cell 9.144"->{
    Cell[2651916, 52449, 88, 3, 67, "Input",
      CellTags->"Cell 9.144"]},
  "Cell 9.145"->{
    Cell[2652585, 52477, 115, 3, 67, "Input",
      CellTags->"Cell 9.145"]},
  "Cell 9.146"->{
    Cell[2653480, 52510, 129, 3, 67, "Input",
      CellTags->"Cell 9.146"]},
  "i:79"->{
    Cell[2653973, 52526, 990, 32, 78, "Text",
      CellTags->"i:79"]},
  "Cell 9.147"->{
    Cell[2654988, 52562, 102, 3, 67, "Input",
      CellTags->"Cell 9.147"]},
  "Cell 9.148"->{
    Cell[2655723, 52590, 98, 3, 67, "Input",
      CellTags->"Cell 9.148"]},
  "Cell 9.149"->{
    Cell[2656092, 52607, 128, 3, 67, "Input",
      CellTags->"Cell 9.149"]},
  "Ex. 9.9"->{
    Cell[2667190, 52918, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.9", "c:52"}]},
  "c:52"->{
    Cell[2667190, 52918, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.9", "c:52"}]},
  "i:118"->{
    Cell[2673085, 53157, 87, 1, 26, "Text",
      CellTags->"i:118"]},
  "Sec. 9.10"->{
    Cell[2673221, 53164, 108, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.10", "i:99", "c:53"}]},
  "i:99"->{
    Cell[2673221, 53164, 108, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.10", "i:99", "c:53"}]},
  "c:53"->{
    Cell[2673221, 53164, 108, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.10", "i:99", "c:53"}]},
  "i:83"->{
    Cell[2673373, 53171, 280, 12, 41, "Subsubtitle",
      CellTags->{"i:83", "c:54"}]},
  "c:54"->{
    Cell[2673373, 53171, 280, 12, 41, "Subsubtitle",
      CellTags->{"i:83", "c:54"}]},
  "c:55"->{
    Cell[2673678, 53187, 72, 1, 42, "Section",
      CellTags->"c:55"]},
  "i:81"->{
    Cell[2674255, 53210, 676, 30, 27, "Text",
      CellTags->"i:81"]},
  "i:78"->{
    Cell[2675139, 53250, 1553, 55, 95, "Text",
      CellTags->"i:78"]},
  "Cell 9.150"->{
    Cell[2677414, 53333, 132, 3, 67, "Input",
      CellTags->"Cell 9.150"]},
  "Cell 9.151"->{
    Cell[2677941, 53352, 120, 3, 66, "Input",
      CellTags->"Cell 9.151"]},
  "Cell 9.152"->{
    Cell[2678466, 53372, 125, 3, 67, "Input",
      CellTags->"Cell 9.152"]},
  "Cell 9.153"->{
    Cell[2679669, 53413, 85, 3, 67, "Input",
      CellTags->"Cell 9.153"]},
  "i:82"->{
    Cell[2680246, 53430, 411, 12, 44, "Text",
      CellTags->"i:82"]},
  "Cell 9.154"->{
    Cell[2680682, 53446, 126, 3, 67, "Input",
      CellTags->"Cell 9.154"]},
  "c:56"->{
    Cell[2681334, 53466, 77, 1, 31, "Section",
      CellTags->"c:56"]},
  "(9.10.1)"->{
    Cell[2682333, 53514, 345, 12, 61, "NE4",
      CellTags->"(9.10.1)"]},
  "Cell 9.155"->{
    Cell[2682749, 53532, 173, 4, 67, "Input",
      CellTags->"Cell 9.155"]},
  "i:107"->{
    Cell[2686334, 53656, 689, 16, 95, "Text",
      CellTags->"i:107"]},
  "Cell 9.156"->{
    Cell[2688114, 53719, 128, 4, 86, "Input",
      CellTags->"Cell 9.156"]},
  "Cell 9.157"->{
    Cell[2688402, 53731, 205, 5, 67, "Input",
      CellTags->"Cell 9.157"]},
  "Cell 9.158"->{
    Cell[2688673, 53740, 204, 6, 67, "Input",
      CellTags->"Cell 9.158"]},
  "Cell 9.159"->{
    Cell[2688976, 53753, 173, 4, 86, "Input",
      CellTags->"Cell 9.159"]},
  "Cell 9.160"->{
    Cell[2690069, 53790, 352, 7, 124, "Input",
      CellTags->"Cell 9.160"]},
  "c:57"->{
    Cell[2706656, 54157, 84, 1, 31, "Section",
      CellTags->"c:57"]},
  "Cell 9.161"->{
    Cell[2708584, 54224, 186, 4, 86, "Input",
      CellTags->"Cell 9.161"]},
  "i:85"->{
    Cell[2708824, 54234, 352, 10, 44, "Text",
      CellTags->"i:85"]},
  "Cell 9.162"->{
    Cell[2709201, 54248, 131, 3, 67, "Input",
      CellTags->"Cell 9.162"]},
  "c:58"->{
    Cell[2710047, 54286, 58, 1, 31, "Section",
      CellTags->"c:58"]},
  "i:110"->{
    Cell[2710108, 54289, 854, 32, 61, "Text",
      CellTags->"i:110"]},
  "Cell 9.163"->{
    Cell[2711365, 54343, 117, 3, 67, "Input",
      CellTags->"Cell 9.163"]},
  "Cell 9.164"->{
    Cell[2711772, 54359, 118, 3, 67, "Input",
      CellTags->"Cell 9.164"]},
  "i:109"->{
    Cell[2712285, 54378, 4984, 135, 103, "Text",
      CellTags->"i:109"]},
  "Ex. 9.10"->{
    Cell[2720007, 54588, 80, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.10", "c:59"}]},
  "c:59"->{
    Cell[2720007, 54588, 80, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.10", "c:59"}]},
  "Fig. 9.4"->{
    Cell[2787732, 55446, 51, 1, 16, "Caption",
      CellTags->"Fig. 9.4"]},
  "Fig. 9.5"->{
    Cell[2914850, 57035, 51, 1, 16, "Caption",
      CellTags->"Fig. 9.5"]},
  "i:88"->{
    Cell[2916256, 57102, 1834, 60, 97, "Text",
      CellTags->"i:88"]},
  "i:89"->{
    Cell[2924725, 57364, 2713, 82, 119, "Text",
      CellTags->"i:89"]},
  "Cell 9.165"->{
    Cell[2927441, 57448, 122, 3, 67, "Input",
      CellTags->"Cell 9.165"]},
  "Cell 9.166"->{
    Cell[2927588, 57455, 410, 8, 143, "Input",
      CellTags->"Cell 9.166"]},
  "Cell 9.167"->{
    Cell[2944878, 57882, 462, 13, 79, "Input",
      CellTags->"Cell 9.167"]},
  "Cell 9.168"->{
    Cell[2948643, 57998, 379, 10, 105, "Input",
      CellTags->"Cell 9.168"]},
  "Cell 9.169"->{
    Cell[2951063, 58073, 306, 7, 105, "Input",
      CellTags->"Cell 9.169"]},
  "Cell 9.170"->{
    Cell[2951441, 58084, 334, 8, 86, "Input",
      CellTags->"Cell 9.170"]},
  "i:112"->{
    Cell[2955037, 58207, 662, 14, 78, "Text",
      CellTags->"i:112"]},
  "i:90"->{
    Cell[2956506, 58248, 2085, 69, 84, "Text",
      CellTags->"i:90"]},
  "Cell 9.171"->{
    Cell[2958616, 58321, 399, 9, 143, "Input",
      CellTags->"Cell 9.171"]},
  "Fig. 9.6"->{
    Cell[3005835, 59384, 71, 1, 16, "Caption",
      CellTags->"Fig. 9.6"]},
  "Sec. 9.11"->{
    Cell[3006294, 59406, 78, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.11", "c:60"}]},
  "c:60"->{
    Cell[3006294, 59406, 78, 1, 40, "Subtitle",
      CellTags->{"Sec. 9.11", "c:60"}]},
  "c:61"->{
    Cell[3007181, 59428, 91, 1, 41, "Subsubtitle",
      CellTags->"c:61"]},
  "i:86"->{
    Cell[3007275, 59431, 623, 19, 61, "Text",
      CellTags->"i:86"]},
  "Cell 9.172"->{
    Cell[3007923, 59454, 167, 4, 67, "Input",
      CellTags->"Cell 9.172"]},
  "i:84"->{
    Cell[3035985, 60051, 3203, 110, 137, "Text",
      CellTags->"i:84"]},
  "Cell 9.173"->{
    Cell[3039213, 60165, 132, 3, 67, "Input",
      CellTags->"Cell 9.173"]},
  "i:125"->{
    Cell[3039433, 60174, 698, 20, 61, "Text",
      CellTags->"i:125"]},
  "Cell 9.174"->{
    Cell[3040156, 60198, 107, 3, 67, "Input",
      CellTags->"Cell 9.174"]},
  "i:102"->{
    Cell[3040344, 60207, 490, 11, 78, "Text",
      CellTags->"i:102"]},
  "Cell 9.175"->{
    Cell[3040859, 60222, 164, 4, 67, "Input",
      CellTags->"Cell 9.175"]},
  "Cell 9.176"->{
    Cell[3041210, 60236, 101, 3, 67, "Input",
      CellTags->"Cell 9.176"]},
  "Cell 9.177"->{
    Cell[3041617, 60255, 119, 3, 67, "Input",
      CellTags->"Cell 9.177"]},
  "Cell 9.178"->{
    Cell[3042079, 60274, 129, 3, 67, "Input",
      CellTags->"Cell 9.178"]},
  "Cell 9.179"->{
    Cell[3043470, 60328, 124, 3, 67, "Input",
      CellTags->"Cell 9.179"]},
  "(9.11.1)"->{
    Cell[3044099, 60351, 212, 8, 49, "NE5",
      CellTags->"(9.11.1)"]},
  "Cell 9.180"->{
    Cell[3044383, 60365, 193, 4, 67, "Input",
      CellTags->"Cell 9.180"]},
  "i:87"->{
    Cell[3044706, 60376, 591, 13, 78, "Text",
      CellTags->"i:87"]},
  "Cell 9.181"->{
    Cell[3045889, 60414, 260, 6, 86, "Input",
      CellTags->"Cell 9.181"]},
  "Cell 9.182"->{
    Cell[3089304, 61503, 325, 7, 105, "Input",
      CellTags->"Cell 9.182"]},
  "Cell 9.183"->{
    Cell[3123929, 62418, 97, 3, 67, "Input",
      CellTags->"Cell 9.183"]},
  "Cell 9.184"->{
    Cell[3170462, 63601, 193, 4, 67, "Input",
      CellTags->"Cell 9.184"]},
  "Table 9.22"->{
    Cell[3171478, 63633, 7569, 183, 151, "Text",
      CellTags->"Table 9.22"]},
  "i:73"->{
    Cell[3179084, 63821, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:73", "c:62"}]},
  "c:62"->{
    Cell[3179084, 63821, 81, 1, 30, "Subsubtitle",
      CellTags->{"i:73", "c:62"}]},
  "i:75"->{
    Cell[3179168, 63824, 680, 20, 83, "Text",
      CellTags->"i:75"]},
  "Cell 9.185"->{
    Cell[3179873, 63848, 129, 3, 67, "Input",
      CellTags->"Cell 9.185"]},
  "Cell 9.186"->{
    Cell[3181064, 63889, 122, 3, 67, "Input",
      CellTags->"Cell 9.186"]},
  "i:103"->{
    Cell[3181258, 63898, 566, 14, 78, "Text",
      CellTags->"i:103"]},
  "Cell 9.187"->{
    Cell[3181849, 63916, 229, 6, 86, "Input",
      CellTags->"Cell 9.187"]},
  "i:92"->{
    Cell[3186982, 64070, 73, 1, 30, "Subsubtitle",
      CellTags->{"i:92", "c:63"}]},
  "c:63"->{
    Cell[3186982, 64070, 73, 1, 30, "Subsubtitle",
      CellTags->{"i:92", "c:63"}]},
  "Cell 9.188"->{
    Cell[3188292, 64116, 172, 4, 86, "Input",
      CellTags->"Cell 9.188"]},
  "i:100"->{
    Cell[3188606, 64128, 934, 27, 95, "Text",
      CellTags->"i:100"]},
  "i:101"->{
    Cell[3189543, 64157, 791, 25, 78, "Text",
      CellTags->"i:101"]},
  "Cell 9.189"->{
    Cell[3190359, 64186, 87, 3, 67, "Input",
      CellTags->"Cell 9.189"]},
  "Cell 9.190"->{
    Cell[3190540, 64197, 92, 3, 67, "Input",
      CellTags->"Cell 9.190"]},
  "Cell 9.191"->{
    Cell[3191117, 64223, 112, 3, 67, "Input",
      CellTags->"Cell 9.191"]},
  "Cell 9.192"->{
    Cell[3217250, 64825, 92, 3, 67, "Input",
      CellTags->"Cell 9.192"]},
  "i:127"->{
    Cell[3217415, 64834, 1593, 37, 180, "Text",
      CellTags->"i:127"]},
  "Cell 9.193"->{
    Cell[3219272, 64884, 129, 3, 67, "Input",
      CellTags->"Cell 9.193"]},
  "i:93"->{
    Cell[3251281, 65783, 634, 21, 61, "Text",
      CellTags->"i:93"]},
  "Cell 9.194"->{
    Cell[3251940, 65808, 196, 4, 86, "Input",
      CellTags->"Cell 9.194"]},
  "i:95"->{
    Cell[3279661, 66401, 67, 1, 30, "Subsubtitle",
      CellTags->{"i:95", "c:64"}]},
  "c:64"->{
    Cell[3279661, 66401, 67, 1, 30, "Subsubtitle",
      CellTags->{"i:95", "c:64"}]},
  "Cell 9.195"->{
    Cell[3283210, 66518, 121, 3, 67, "Input",
      CellTags->"Cell 9.195"]},
  "i:132"->{
    Cell[3283914, 66542, 434, 13, 61, "Text",
      CellTags->"i:132"]},
  "c:82"->{
    Cell[3288157, 66655, 71, 1, 42, "Section",
      CellTags->"c:82"]},
  "i:128"->{
    Cell[3288231, 66658, 585, 15, 78, "Text",
      CellTags->"i:128"]},
  "Cell 9.196"->{
    Cell[3288841, 66677, 92, 3, 67, "Input",
      CellTags->"Cell 9.196"]},
  "i:129"->{
    Cell[3288999, 66686, 575, 17, 61, "Text",
      CellTags->"i:129"]},
  "Cell 9.197"->{
    Cell[3289599, 66707, 123, 3, 67, "Input",
      CellTags->"Cell 9.197"]},
  "Cell 9.198"->{
    Cell[3290283, 66732, 104, 3, 67, "Input",
      CellTags->"Cell 9.198"]},
  "i:130"->{
    Cell[3290390, 66737, 220, 7, 27, "Text",
      CellTags->"i:130"]},
  "Cell 9.199"->{
    Cell[3290635, 66748, 85, 3, 67, "Input",
      CellTags->"Cell 9.199"]},
  "i:131"->{
    Cell[3290896, 66758, 561, 18, 61, "Text",
      CellTags->"i:131"]},
  "Cell 9.200"->{
    Cell[3292123, 66800, 121, 3, 67, "Input",
      CellTags->"Cell 9.200"]},
  "Ex. 9.11"->{
    Cell[3292997, 66831, 80, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.11", "c:65"}]},
  "c:65"->{
    Cell[3292997, 66831, 80, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 9.11", "c:65"}]},
  "Cell 9.201"->{
    Cell[3295048, 66908, 126, 3, 67, "Input",
      CellTags->"Cell 9.201"]},
  "Cell 9.202"->{
    Cell[3295947, 66944, 3182, 95, 67, "Input",
      CellTags->"Cell 9.202"]},
  "i:97"->{
    Cell[3299132, 67041, 407, 13, 44, "Text",
      CellTags->"i:97"]},
  "i:124"->{
    Cell[3299542, 67056, 1043, 32, 78, "Text",
      CellTags->"i:124"]},
  "(9.11.2)"->{
    Cell[3300931, 67105, 165, 6, 30, "NE5",
      CellTags->"(9.11.2)"]},
  "Fig. 9.7"->{
    Cell[3355309, 67788, 85, 1, 16, "Caption",
      CellTags->"Fig. 9.7"]},
  "i:126"->{
    Cell[3357970, 67873, 966, 29, 81, "Text",
      CellTags->"i:126"]},
  "Cell 9.203"->{
    Cell[3360780, 67973, 156, 4, 67, "Input",
      CellTags->"Cell 9.203"]},
  "(9.11.3)"->{
    Cell[3361880, 68018, 242, 4, 43, "NE5",
      CellTags->"(9.11.3)"]},
  "i:138"->{
    Cell[3362125, 68024, 605, 17, 61, "Text",
      CellTags->"i:138"]},
  "Cell 9.204"->{
    Cell[3363083, 68058, 193, 5, 67, "Input",
      CellTags->"Cell 9.204"]},
  "(9.11.4)"->{
    Cell[3365164, 68130, 260, 7, 38, "NE5",
      CellTags->"(9.11.4)"]},
  "(9.11.5)"->{
    Cell[3367315, 68201, 511, 13, 40, "NE5",
      CellTags->{"(9.11.5)", "i:134"}]},
  "i:134"->{
    Cell[3367315, 68201, 511, 13, 40, "NE5",
      CellTags->{"(9.11.5)", "i:134"}]},
  "(9.11.6)"->{
    Cell[3370260, 68309, 525, 15, 76, "NE5",
      CellTags->"(9.11.6)"]},
  "Cell 9.205"->{
    Cell[3371583, 68351, 323, 8, 86, "Input",
      CellTags->"Cell 9.205"]},
  "Cell 9.206"->{
    Cell[3372980, 68390, 122, 3, 67, "Input",
      CellTags->"Cell 9.206"]},
  "i:135"->{
    Cell[3373474, 68409, 744, 20, 40, "NE5",
      CellTags->"i:135"]},
  "Cell 9.207"->{
    Cell[3374766, 68451, 331, 9, 86, "Input",
      CellTags->"Cell 9.207"]},
  "i:136"->{
    Cell[3376561, 68513, 252, 8, 27, "Text",
      CellTags->"i:136"]},
  "i:137"->{
    Cell[3378490, 68576, 1274, 36, 129, "Text",
      CellTags->"i:137"]},
  "i:139"->{
    Cell[3380142, 68628, 1456, 41, 136, "Text",
      CellTags->"i:139"]},
  "Cell 9.208"->{
    Cell[3384250, 68767, 320, 7, 124, "Input",
      CellTags->"Cell 9.208"]},
  "c:67"->{
    Cell[3386776, 68845, 145, 6, 40, "Subtitle",
      CellTags->"c:67"]},
  "c:68"->{
    Cell[3387570, 68877, 70, 1, 41, "Subsubtitle",
      CellTags->"c:68"]},
  "c:69"->{
    Cell[3407069, 69384, 119, 4, 30, "Subsubtitle",
      CellTags->"c:69"]},
  "c:70"->{
    Cell[3424621, 69826, 83, 1, 30, "Subsubtitle",
      CellTags->"c:70"]},
  "c:72"->{
    Cell[3447736, 70440, 58, 1, 30, "Subsubtitle",
      CellTags->"c:72"]},
  "c:73"->{
    Cell[3447819, 70445, 53, 1, 41, "Section",
      CellTags->"c:73"]},
  "c:74"->{
    Cell[3463265, 70821, 64, 1, 30, "Section",
      CellTags->"c:74"]},
  "c:75"->{
    Cell[3469214, 70971, 78, 1, 30, "Section",
      CellTags->"c:75"]},
  "c:76"->{
    Cell[3470987, 71018, 61, 1, 30, "Section",
      CellTags->"c:76"]},
  "c:77"->{
    Cell[3476807, 71159, 55, 1, 30, "Section",
      CellTags->"c:77"]},
  "c:78"->{
    Cell[3483466, 71329, 55, 1, 30, "Section",
      CellTags->"c:78"]},
  "c:79"->{
    Cell[3495776, 71617, 70, 1, 30, "Subsubtitle",
      CellTags->"c:79"]},
  "c:80"->{
    Cell[3510328, 71988, 59, 1, 42, "Section",
      CellTags->"c:80"]},
  "Cell 9.209"->{
    Cell[3517701, 72184, 157, 4, 73, "Input",
      CellTags->"Cell 9.209"]},
  "c:81"->{
    Cell[3518084, 72199, 62, 1, 31, "Section",
      CellTags->"c:81"]},
  "Cell 9.210"->{
    Cell[3520743, 72275, 152, 4, 67, "Input",
      CellTags->"Cell 9.210"]},
  "Cell 9.211"->{
    Cell[3521023, 72287, 175, 4, 67, "Input",
      CellTags->"Cell 9.211"]},
  "Cell 9.212"->{
    Cell[3523360, 72353, 208, 5, 97, "Input",
      CellTags->"Cell 9.212"]},
  "Cell 9.213"->{
    Cell[3523886, 72372, 107, 3, 67, "Input",
      CellTags->"Cell 9.213"]},
  "Cell 9.214"->{
    Cell[3524195, 72386, 108, 3, 67, "Input",
      CellTags->"Cell 9.214"]},
  "refs"->{
    Cell[3595755, 73733, 50, 1, 40, "Subtitle",
      CellTags->"refs"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"chapter 1", 3639839, 75084},
  {"c:1", 3639930, 75087},
  {"Sec. 9.1", 3640026, 75090},
  {"c:2", 3640120, 75093},
  {"i:3", 3640214, 75096},
  {"Cell 9.1", 3640296, 75099},
  {"i:4", 3640377, 75102},
  {"Sec. 9.2", 3640462, 75105},
  {"c:3", 3640557, 75108},
  {"c:4", 3640652, 75111},
  {"Cell 9.2", 3640740, 75114},
  {"Cell 9.3", 3640827, 75117},
  {"Cell 9.4", 3640914, 75120},
  {"Cell 9.5", 3641001, 75123},
  {"Cell 9.6", 3641088, 75126},
  {"Cell 9.7", 3641175, 75129},
  {"i:115", 3641259, 75132},
  {"Table 9.1", 3641345, 75135},
  {"c:5", 3641432, 75138},
  {"i:16", 3641516, 75141},
  {"Cell 9.8", 3641599, 75144},
  {"Cell 9.9", 3641686, 75147},
  {"Cell 9.10", 3641774, 75150},
  {"i:17", 3641858, 75153},
  {"Cell 9.11", 3641943, 75156},
  {"i:5", 3642026, 75159},
  {"Cell 9.12", 3642112, 75162},
  {"c:6", 3642195, 75165},
  {"i:18", 3642279, 75168},
  {"i:96", 3642359, 75171},
  {"Table 9.2", 3642462, 75174},
  {"c:7", 3642559, 75177},
  {"Table 9.3", 3642649, 75180},
  {"Cell 9.13", 3642742, 75183},
  {"Cell 9.14", 3642832, 75186},
  {"Cell 9.15", 3642923, 75189},
  {"c:8", 3643007, 75192},
  {"i:14", 3643092, 75195},
  {"i:15", 3643173, 75198},
  {"Cell 9.16", 3643262, 75201},
  {"c:9", 3643347, 75204},
  {"i:20", 3643433, 75207},
  {"Cell 9.17", 3643519, 75210},
  {"i:6", 3643603, 75213},
  {"Cell 9.18", 3643687, 75216},
  {"Cell 9.19", 3643777, 75219},
  {"i:7", 3643861, 75222},
  {"Cell 9.20", 3643946, 75225},
  {"Cell 9.21", 3644037, 75228},
  {"i:21", 3644122, 75231},
  {"Cell 9.22", 3644208, 75234},
  {"Table 9.5", 3644299, 75237},
  {"c:10", 3644386, 75240},
  {"Sec. 9.3", 3644476, 75243},
  {"c:11", 3644575, 75246},
  {"i:8", 3644673, 75249},
  {"i:13", 3644754, 75252},
  {"Sec. 9.4", 3644839, 75255},
  {"c:12", 3644936, 75258},
  {"c:13", 3645033, 75261},
  {"i:22", 3645119, 75264},
  {"Cell 9.23", 3645205, 75267},
  {"Cell 9.24", 3645295, 75270},
  {"Cell 9.25", 3645385, 75273},
  {"Cell 9.26", 3645475, 75276},
  {"c:14", 3645560, 75279},
  {"Cell 9.27", 3645651, 75282},
  {"Cell 9.28", 3645742, 75285},
  {"Cell 9.29", 3645832, 75288},
  {"i:23", 3645917, 75291},
  {"Cell 9.30", 3646002, 75294},
  {"Cell 9.31", 3646092, 75297},
  {"i:24", 3646177, 75300},
  {"Cell 9.32", 3646262, 75303},
  {"i:10", 3646348, 75306},
  {"i:25", 3646431, 75309},
  {"Table 9.6", 3646535, 75312},
  {"c:15", 3646634, 75315},
  {"i:12", 3646720, 75318},
  {"Fig. 9.1", 3646805, 75321},
  {"Cell 9.33", 3646898, 75324},
  {"Cell 9.34", 3646990, 75327},
  {"i:11", 3647077, 75330},
  {"Sec. 9.5", 3647164, 75333},
  {"c:16", 3647263, 75336},
  {"c:17", 3647362, 75339},
  {"i:26", 3647450, 75342},
  {"Cell 9.35", 3647538, 75345},
  {"i:27", 3647626, 75348},
  {"Cell 9.36", 3647714, 75351},
  {"Cell 9.37", 3647806, 75354},
  {"Cell 9.38", 3647899, 75357},
  {"Cell 9.39", 3647991, 75360},
  {"i:28", 3648078, 75363},
  {"Cell 9.40", 3648165, 75366},
  {"i:29", 3648252, 75369},
  {"Cell 9.41", 3648340, 75372},
  {"Cell 9.42", 3648433, 75375},
  {"Cell 9.43", 3648525, 75378},
  {"Cell 9.44", 3648617, 75381},
  {"i:98", 3648705, 75384},
  {"c:18", 3648803, 75387},
  {"c:19", 3648901, 75390},
  {"Fig. 9.2", 3648989, 75393},
  {"Cell 9.45", 3649084, 75396},
  {"i:31", 3649172, 75399},
  {"c:20", 3649266, 75402},
  {"(9.5.1)", 3649363, 75405},
  {"(9.5.2)", 3649465, 75408},
  {"Cell 9.46", 3649568, 75411},
  {"i:42", 3649655, 75414},
  {"Cell 9.47", 3649743, 75417},
  {"(9.5.3)", 3649833, 75420},
  {"(9.5.4)", 3649934, 75423},
  {"i:32", 3650032, 75426},
  {"c:21", 3650126, 75429},
  {"(9.5.5)", 3650223, 75432},
  {"(9.5.6)", 3650325, 75435},
  {"Cell 9.48", 3650430, 75438},
  {"Table 9.8", 3650522, 75441},
  {"c:22", 3650610, 75444},
  {"i:33", 3650694, 75447},
  {"Cell 9.49", 3650789, 75450},
  {"i:34", 3650877, 75453},
  {"Cell 9.50", 3650972, 75456},
  {"Cell 9.51", 3651065, 75459},
  {"i:104", 3651154, 75462},
  {"Cell 9.52", 3651243, 75465},
  {"Cell 9.53", 3651336, 75468},
  {"(9.5.7)", 3651426, 75471},
  {"(9.5.8)", 3651526, 75474},
  {"Cell 9.54", 3651629, 75477},
  {"i:35", 3651717, 75480},
  {"(9.5.9)", 3651810, 75483},
  {"i:105", 3651909, 75486},
  {"Cell 9.55", 3651998, 75489},
  {"Cell 9.56", 3652090, 75492},
  {"Cell 9.57", 3652182, 75495},
  {"i:36", 3652270, 75498},
  {"Cell 9.58", 3652365, 75501},
  {"i:37", 3652452, 75504},
  {"Cell 9.59", 3652547, 75507},
  {"Cell 9.60", 3652639, 75510},
  {"Cell 9.61", 3652732, 75513},
  {"(9.5.10)", 3652823, 75516},
  {"Fig. 9.3", 3652927, 75519},
  {"(9.5.11)", 3653021, 75522},
  {"Table 9.9", 3653126, 75525},
  {"c:23", 3653216, 75528},
  {"i:38", 3653305, 75531},
  {"Cell 9.62", 3653393, 75534},
  {"Cell 9.63", 3653486, 75537},
  {"Cell 9.64", 3653579, 75540},
  {"c:24", 3653667, 75543},
  {"i:39", 3653755, 75546},
  {"Cell 9.65", 3653842, 75549},
  {"Cell 9.66", 3653935, 75552},
  {"Cell 9.67", 3654027, 75555},
  {"i:40", 3654114, 75558},
  {"Cell 9.68", 3654202, 75561},
  {"i:41", 3654290, 75564},
  {"Cell 9.69", 3654378, 75567},
  {"Table 9.10", 3654471, 75570},
  {"c:25", 3654562, 75573},
  {"Sec. 9.6", 3654654, 75576},
  {"c:26", 3654753, 75579},
  {"i:43", 3654852, 75582},
  {"c:27", 3654951, 75585},
  {"Cell 9.70", 3655055, 75588},
  {"i:44", 3655143, 75591},
  {"Cell 9.71", 3655232, 75594},
  {"i:133", 3655322, 75597},
  {"Cell 9.72", 3655413, 75600},
  {"i:45", 3655503, 75603},
  {"c:28", 3655603, 75606},
  {"Cell 9.73", 3655708, 75609},
  {"i:46", 3655797, 75612},
  {"c:29", 3655897, 75615},
  {"Cell 9.74", 3656002, 75618},
  {"Cell 9.75", 3656096, 75621},
  {"Table 9.11", 3656191, 75624},
  {"i:47", 3656283, 75627},
  {"c:30", 3656383, 75630},
  {"Cell 9.76", 3656488, 75633},
  {"Cell 9.77", 3656582, 75636},
  {"Cell 9.78", 3656676, 75639},
  {"i:50", 3656765, 75642},
  {"c:31", 3656864, 75645},
  {"i:51", 3656963, 75648},
  {"Cell 9.79", 3657052, 75651},
  {"i:119", 3657142, 75654},
  {"Cell 9.80", 3657232, 75657},
  {"Table 9.12", 3657327, 75660},
  {"c:32", 3657419, 75663},
  {"i:48", 3657508, 75666},
  {"Cell 9.81", 3657597, 75669},
  {"i:53", 3657686, 75672},
  {"Cell 9.82", 3657775, 75675},
  {"i:54", 3657864, 75678},
  {"Cell 9.83", 3657952, 75681},
  {"Cell 9.84", 3658045, 75684},
  {"i:55", 3658133, 75687},
  {"Cell 9.85", 3658221, 75690},
  {"i:49", 3658309, 75693},
  {"Cell 9.86", 3658398, 75696},
  {"i:56", 3658487, 75699},
  {"c:33", 3658586, 75702},
  {"Cell 9.87", 3658690, 75705},
  {"i:57", 3658779, 75708},
  {"c:34", 3658878, 75711},
  {"i:113", 3658978, 75714},
  {"Cell 9.88", 3659070, 75717},
  {"Cell 9.89", 3659163, 75720},
  {"i:120", 3659253, 75723},
  {"Cell 9.90", 3659343, 75726},
  {"Cell 9.91", 3659437, 75729},
  {"i:114", 3659528, 75732},
  {"Cell 9.92", 3659620, 75735},
  {"Cell 9.93", 3659713, 75738},
  {"Ex. 9.6", 3659808, 75741},
  {"c:35", 3659984, 75746},
  {"i:59", 3660086, 75749},
  {"i:60", 3660170, 75752},
  {"i:58", 3660254, 75755},
  {"i:52", 3660339, 75758},
  {"Sec. 9.7", 3660428, 75761},
  {"c:36", 3660529, 75764},
  {"i:122", 3660631, 75767},
  {"Cell 9.94", 3660721, 75770},
  {"Cell 9.95", 3660814, 75773},
  {"Cell 9.96", 3660908, 75776},
  {"Info3244700897-7405223", 3661014, 75779},
  {"i:121", 3661118, 75782},
  {"Cell 9.97", 3661207, 75785},
  {"Cell 9.98", 3661300, 75788},
  {"i:61", 3661388, 75791},
  {"Cell 9.99", 3661477, 75794},
  {"Sec. 9.8", 3661569, 75797},
  {"c:37", 3661669, 75800},
  {"c:38", 3661769, 75803},
  {"Cell 9.100", 3661864, 75806},
  {"i:62", 3661954, 75809},
  {"Cell 9.101", 3662044, 75812},
  {"Cell 9.102", 3662140, 75815},
  {"i:63", 3662229, 75818},
  {"Cell 9.103", 3662319, 75821},
  {"Cell 9.104", 3662414, 75824},
  {"Cell 9.105", 3662510, 75827},
  {"Cell 9.106", 3662605, 75830},
  {"Cell 9.107", 3662700, 75833},
  {"i:64", 3662789, 75836},
  {"Cell 9.108", 3662879, 75839},
  {"Table 9.14", 3662975, 75842},
  {"c:39", 3663067, 75845},
  {"i:65", 3663156, 75848},
  {"Cell 9.109", 3663246, 75851},
  {"Cell 9.110", 3663342, 75854},
  {"Table 9.15", 3663438, 75857},
  {"i:19", 3663529, 75860},
  {"c:40", 3663628, 75863},
  {"c:41", 3663727, 75866},
  {"Cell 9.111", 3663818, 75869},
  {"Cell 9.112", 3663914, 75872},
  {"i:66", 3664003, 75875},
  {"Cell 9.113", 3664094, 75878},
  {"Cell 9.114", 3664189, 75881},
  {"Cell 9.115", 3664284, 75884},
  {"Cell 9.116", 3664379, 75887},
  {"Cell 9.117", 3664474, 75890},
  {"Cell 9.118", 3664569, 75893},
  {"c:42", 3664658, 75896},
  {"Cell 9.119", 3664749, 75899},
  {"i:67", 3664838, 75902},
  {"c:43", 3664933, 75905},
  {"Cell 9.120", 3665034, 75908},
  {"Cell 9.121", 3665130, 75911},
  {"c:44", 3665219, 75914},
  {"i:68", 3665308, 75917},
  {"c:45", 3665407, 75920},
  {"Cell 9.122", 3665512, 75923},
  {"Cell 9.123", 3665607, 75926},
  {"Cell 9.124", 3665703, 75929},
  {"Table 9.17", 3665798, 75932},
  {"i:69", 3665890, 75935},
  {"c:46", 3665990, 75938},
  {"i:123", 3666091, 75941},
  {"(9.8.1)", 3666179, 75944},
  {"i:106", 3666277, 75947},
  {"Cell 9.125", 3666380, 75950},
  {"Cell 9.126", 3666476, 75953},
  {"Cell 9.127", 3666572, 75956},
  {"Cell 9.128", 3666667, 75959},
  {"i:111", 3666758, 75962},
  {"Table 9.18", 3666868, 75965},
  {"i:80", 3666972, 75968},
  {"Cell 9.129", 3667062, 75971},
  {"Ex. 9.8", 3667155, 75974},
  {"c:47", 3667257, 75977},
  {"Sec. 9.9", 3667363, 75980},
  {"c:48", 3667463, 75983},
  {"i:70", 3667563, 75986},
  {"c:49", 3667662, 75989},
  {"Cell 9.130", 3667767, 75992},
  {"Cell 9.131", 3667863, 75995},
  {"Cell 9.132", 3667958, 75998},
  {"Cell 9.133", 3668053, 76001},
  {"Cell 9.134", 3668148, 76004},
  {"Cell 9.135", 3668243, 76007},
  {"Cell 9.136", 3668339, 76010},
  {"i:71", 3668428, 76013},
  {"c:50", 3668527, 76016},
  {"(9.9.1)", 3668629, 76019},
  {"i:116", 3668716, 76022},
  {"i:76", 3668802, 76025},
  {"Cell 9.137", 3668892, 76028},
  {"Cell 9.138", 3668988, 76031},
  {"Cell 9.139", 3669084, 76034},
  {"i:77", 3669173, 76037},
  {"Cell 9.140", 3669263, 76040},
  {"Cell 9.141", 3669358, 76043},
  {"i:117", 3669450, 76046},
  {"Cell 9.142", 3669542, 76049},
  {"i:72", 3669632, 76052},
  {"c:51", 3669731, 76055},
  {"i:74", 3669830, 76058},
  {"Cell 9.143", 3669920, 76061},
  {"Cell 9.144", 3670016, 76064},
  {"Cell 9.145", 3670111, 76067},
  {"Cell 9.146", 3670207, 76070},
  {"i:79", 3670297, 76073},
  {"Cell 9.147", 3670387, 76076},
  {"Cell 9.148", 3670483, 76079},
  {"Cell 9.149", 3670578, 76082},
  {"Ex. 9.9", 3670671, 76085},
  {"c:52", 3670773, 76088},
  {"i:118", 3670876, 76091},
  {"Sec. 9.10", 3670964, 76094},
  {"i:99", 3671074, 76097},
  {"c:53", 3671184, 76100},
  {"i:83", 3671294, 76103},
  {"c:54", 3671395, 76106},
  {"c:55", 3671496, 76109},
  {"i:81", 3671581, 76112},
  {"i:78", 3671665, 76115},
  {"Cell 9.150", 3671756, 76118},
  {"Cell 9.151", 3671852, 76121},
  {"Cell 9.152", 3671948, 76124},
  {"Cell 9.153", 3672044, 76127},
  {"i:82", 3672133, 76130},
  {"Cell 9.154", 3672223, 76133},
  {"c:56", 3672313, 76136},
  {"(9.10.1)", 3672402, 76139},
  {"Cell 9.155", 3672495, 76142},
  {"i:107", 3672586, 76145},
  {"Cell 9.156", 3672677, 76148},
  {"Cell 9.157", 3672773, 76151},
  {"Cell 9.158", 3672869, 76154},
  {"Cell 9.159", 3672965, 76157},
  {"Cell 9.160", 3673061, 76160},
  {"c:57", 3673152, 76163},
  {"Cell 9.161", 3673243, 76166},
  {"i:85", 3673333, 76169},
  {"Cell 9.162", 3673423, 76172},
  {"c:58", 3673513, 76175},
  {"i:110", 3673599, 76178},
  {"Cell 9.163", 3673690, 76181},
  {"Cell 9.164", 3673786, 76184},
  {"i:109", 3673877, 76187},
  {"Ex. 9.10", 3673969, 76190},
  {"c:59", 3674072, 76193},
  {"Fig. 9.4", 3674179, 76196},
  {"Fig. 9.5", 3674272, 76199},
  {"i:88", 3674361, 76202},
  {"i:89", 3674446, 76205},
  {"Cell 9.165", 3674538, 76208},
  {"Cell 9.166", 3674634, 76211},
  {"Cell 9.167", 3674731, 76214},
  {"Cell 9.168", 3674828, 76217},
  {"Cell 9.169", 3674926, 76220},
  {"Cell 9.170", 3675023, 76223},
  {"i:112", 3675114, 76226},
  {"i:90", 3675199, 76229},
  {"Cell 9.171", 3675290, 76232},
  {"Fig. 9.6", 3675385, 76235},
  {"Sec. 9.11", 3675479, 76238},
  {"c:60", 3675580, 76241},
  {"c:61", 3675681, 76244},
  {"i:86", 3675770, 76247},
  {"Cell 9.172", 3675860, 76250},
  {"i:84", 3675950, 76253},
  {"Cell 9.173", 3676043, 76256},
  {"i:125", 3676134, 76259},
  {"Cell 9.174", 3676225, 76262},
  {"i:102", 3676316, 76265},
  {"Cell 9.175", 3676407, 76268},
  {"Cell 9.176", 3676503, 76271},
  {"Cell 9.177", 3676599, 76274},
  {"Cell 9.178", 3676695, 76277},
  {"Cell 9.179", 3676791, 76280},
  {"(9.11.1)", 3676885, 76283},
  {"Cell 9.180", 3676977, 76286},
  {"i:87", 3677067, 76289},
  {"Cell 9.181", 3677157, 76292},
  {"Cell 9.182", 3677253, 76295},
  {"Cell 9.183", 3677350, 76298},
  {"Cell 9.184", 3677445, 76301},
  {"Table 9.22", 3677541, 76304},
  {"i:73", 3677634, 76307},
  {"c:62", 3677733, 76310},
  {"i:75", 3677832, 76313},
  {"Cell 9.185", 3677922, 76316},
  {"Cell 9.186", 3678018, 76319},
  {"i:103", 3678109, 76322},
  {"Cell 9.187", 3678200, 76325},
  {"i:92", 3678290, 76328},
  {"c:63", 3678389, 76331},
  {"Cell 9.188", 3678494, 76334},
  {"i:100", 3678585, 76337},
  {"i:101", 3678671, 76340},
  {"Cell 9.189", 3678762, 76343},
  {"Cell 9.190", 3678857, 76346},
  {"Cell 9.191", 3678952, 76349},
  {"Cell 9.192", 3679048, 76352},
  {"i:127", 3679138, 76355},
  {"Cell 9.193", 3679231, 76358},
  {"i:93", 3679321, 76361},
  {"Cell 9.194", 3679411, 76364},
  {"i:95", 3679501, 76367},
  {"c:64", 3679600, 76370},
  {"Cell 9.195", 3679705, 76373},
  {"i:132", 3679796, 76376},
  {"c:82", 3679881, 76379},
  {"i:128", 3679967, 76382},
  {"Cell 9.196", 3680058, 76385},
  {"i:129", 3680148, 76388},
  {"Cell 9.197", 3680239, 76391},
  {"Cell 9.198", 3680335, 76394},
  {"i:130", 3680426, 76397},
  {"Cell 9.199", 3680516, 76400},
  {"i:131", 3680606, 76403},
  {"Cell 9.200", 3680697, 76406},
  {"Ex. 9.11", 3680791, 76409},
  {"c:65", 3680894, 76412},
  {"Cell 9.201", 3681003, 76415},
  {"Cell 9.202", 3681099, 76418},
  {"i:97", 3681191, 76421},
  {"i:124", 3681276, 76424},
  {"(9.11.2)", 3681366, 76427},
  {"Fig. 9.7", 3681456, 76430},
  {"i:126", 3681546, 76433},
  {"Cell 9.203", 3681637, 76436},
  {"(9.11.3)", 3681731, 76439},
  {"i:138", 3681818, 76442},
  {"Cell 9.204", 3681909, 76445},
  {"(9.11.4)", 3682003, 76448},
  {"(9.11.5)", 3682093, 76451},
  {"i:134", 3682192, 76454},
  {"(9.11.6)", 3682294, 76457},
  {"Cell 9.205", 3682387, 76460},
  {"Cell 9.206", 3682483, 76463},
  {"i:135", 3682574, 76466},
  {"Cell 9.207", 3682664, 76469},
  {"i:136", 3682755, 76472},
  {"i:137", 3682840, 76475},
  {"i:139", 3682928, 76478},
  {"Cell 9.208", 3683021, 76481},
  {"c:67", 3683112, 76484},
  {"c:68", 3683199, 76487},
  {"c:69", 3683288, 76490},
  {"c:70", 3683378, 76493},
  {"c:72", 3683467, 76496},
  {"c:73", 3683556, 76499},
  {"c:74", 3683641, 76502},
  {"c:75", 3683726, 76505},
  {"c:76", 3683811, 76508},
  {"c:77", 3683896, 76511},
  {"c:78", 3683981, 76514},
  {"c:79", 3684066, 76517},
  {"c:80", 3684155, 76520},
  {"Cell 9.209", 3684246, 76523},
  {"c:81", 3684336, 76526},
  {"Cell 9.210", 3684427, 76529},
  {"Cell 9.211", 3684523, 76532},
  {"Cell 9.212", 3684619, 76535},
  {"Cell 9.213", 3684715, 76538},
  {"Cell 9.214", 3684811, 76541},
  {"refs", 3684901, 76544}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 177, 7, 69, "Title",
  CellTags->{"chapter 1", "c:1"}],
Cell[1907, 61, 861, 23, 95, "Text"],
Cell[2771, 86, 1627, 46, 129, "Text"],
Cell[4401, 134, 491, 13, 61, "Text"],
Cell[4895, 149, 652, 19, 78, "Text"],
Cell[5550, 170, 528, 10, 78, "Text"],
Cell[6081, 182, 248, 7, 64, "Text"],
Cell[6332, 191, 226, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[6583, 201, 134, 5, 39, "Subtitle",
  CellTags->{"Sec. 9.1", "c:2"}],
Cell[6720, 208, 917, 21, 112, "Text"],
Cell[7640, 231, 261, 6, 44, "Text"],
Cell[7904, 239, 524, 13, 78, "Text",
  CellTags->"i:3"],
Cell[8431, 254, 898, 21, 112, "Text"],

Cell[CellGroupData[{
Cell[9354, 279, 84, 3, 67, "Input",
  CellTags->"Cell 9.1"],
Cell[9441, 284, 35, 1, 46, "Output"]
}, Open  ]],
Cell[9491, 288, 1060, 32, 95, "Text"],
Cell[10554, 322, 735, 24, 78, "Text"],
Cell[11292, 348, 1214, 27, 154, "Text",
  CellTags->"i:4"],
Cell[12509, 377, 538, 21, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13084, 403, 144, 6, 40, "Subtitle",
  CellTags->{"Sec. 9.2", "c:3"}],
Cell[13231, 411, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[13272, 415, 58, 1, 41, "Subsubtitle",
  CellTags->"c:4"],
Cell[13333, 418, 229, 6, 43, "Text"],
Cell[13565, 426, 40, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[13630, 430, 94, 3, 66, "Input",
  CellTags->"Cell 9.2"],
Cell[13727, 435, 58, 1, 45, "Output"]
}, Open  ]],
Cell[13800, 439, 28, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[13853, 443, 87, 3, 66, "Input",
  CellTags->"Cell 9.3"],
Cell[13943, 448, 52, 1, 45, "Output"]
}, Open  ]],
Cell[14010, 452, 131, 3, 26, "Text"],
Cell[14144, 457, 34, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[14203, 461, 86, 3, 66, "Input",
  CellTags->"Cell 9.4"],
Cell[14292, 466, 40, 1, 45, "Output"]
}, Open  ]],
Cell[14347, 470, 103, 5, 75, "Text"],

Cell[CellGroupData[{
Cell[14475, 479, 89, 3, 66, "Input",
  CellTags->"Cell 9.5"],
Cell[14567, 484, 40, 1, 45, "Output"]
}, Open  ]],
Cell[14622, 488, 52, 0, 26, "Text"],
Cell[14677, 490, 26, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[14728, 494, 82, 3, 66, "Input",
  CellTags->"Cell 9.6"],
Cell[14813, 499, 36, 1, 45, "Output"]
}, Open  ]],
Cell[14864, 503, 97, 3, 26, "Text"],
Cell[14964, 508, 30, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[15019, 512, 92, 3, 66, "Input",
  CellTags->"Cell 9.7"],
Cell[15114, 517, 36, 1, 45, "Output"]
}, Open  ]],
Cell[15165, 521, 484, 17, 43, "Text",
  CellTags->"i:115"],
Cell[15652, 540, 3669, 101, 185, "Text",
  CellTags->"Table 9.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[19358, 646, 77, 1, 30, "Subsubtitle",
  CellTags->"c:5"],
Cell[19438, 649, 244, 6, 43, "Text",
  CellTags->"i:16"],

Cell[CellGroupData[{
Cell[19707, 659, 92, 3, 66, "Input",
  CellTags->"Cell 9.8"],
Cell[19802, 664, 40, 1, 63, "Output"]
}, Open  ]],
Cell[19857, 668, 140, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[20022, 676, 84, 3, 66, "Input",
  CellTags->"Cell 9.9"],
Cell[20109, 681, 58, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20204, 687, 90, 3, 66, "Input",
  CellTags->"Cell 9.10"],
Cell[20297, 692, 67, 1, 63, "Output"]
}, Open  ]],
Cell[20379, 696, 360, 11, 43, "Text",
  CellTags->"i:17"],

Cell[CellGroupData[{
Cell[20764, 711, 92, 3, 66, "Input",
  CellTags->"Cell 9.11"],
Cell[20859, 716, 56, 1, 50, "Output"]
}, Open  ]],
Cell[20930, 720, 247, 10, 26, "Text"],
Cell[21180, 732, 1753, 43, 196, "Text",
  CellTags->"i:5"],
Cell[22936, 777, 456, 14, 43, "Text"],

Cell[CellGroupData[{
Cell[23417, 795, 93, 3, 66, "Input",
  CellTags->"Cell 9.12"],
Cell[23513, 800, 53, 1, 45, "Output"]
}, Open  ]],
Cell[23581, 804, 325, 7, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[23943, 816, 72, 1, 30, "Subsubtitle",
  CellTags->"c:6"],
Cell[24018, 819, 388, 13, 43, "Text",
  CellTags->"i:18"],
Cell[24409, 834, 6369, 165, 282, "Text",
  CellTags->{"i:96", "Table 9.2"}],
Cell[30781, 1001, 749, 28, 81, "Text"],
Cell[31533, 1031, 211, 4, 43, "Text"],
Cell[31747, 1037, 5139, 140, 105, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[36923, 1182, 63, 1, 30, "Subsubtitle",
  CellTags->"c:7"],
Cell[36989, 1185, 299, 9, 43, "Text"],
Cell[37291, 1196, 2192, 61, 185, "Text",
  CellTags->"Table 9.3"],
Cell[39486, 1259, 103, 3, 26, "Text"],
Cell[39592, 1264, 246, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[39863, 1274, 95, 3, 66, "Input",
  CellTags->"Cell 9.13"],
Cell[39961, 1279, 40, 1, 68, "Output"]
}, Open  ]],
Cell[40016, 1283, 714, 24, 43, "Text"],

Cell[CellGroupData[{
Cell[40755, 1311, 102, 3, 66, "Input",
  CellTags->"Cell 9.14"],
Cell[40860, 1316, 53, 1, 45, "Output"]
}, Open  ]],
Cell[40928, 1320, 63, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[41016, 1324, 92, 3, 66, "Input",
  CellTags->"Cell 9.15"],
Cell[41111, 1329, 126, 2, 45, "Output"]
}, Open  ]],
Cell[41252, 1334, 253, 6, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[41542, 1345, 66, 1, 30, "Subsubtitle",
  CellTags->"c:8"],
Cell[41611, 1348, 520, 12, 60, "Text",
  CellTags->"i:14"],
Cell[42134, 1362, 250, 7, 43, "Text"],
Cell[42387, 1371, 4409, 114, 200, "Text",
  CellTags->"i:15"],
Cell[46799, 1487, 187, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[47011, 1497, 113, 3, 66, "Input",
  CellTags->"Cell 9.16"],
Cell[47127, 1502, 40, 1, 63, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[47216, 1509, 255, 9, 33, "Subsubtitle",
  CellTags->"c:9"],
Cell[47474, 1520, 852, 31, 70, "Text",
  CellTags->"i:20"],

Cell[CellGroupData[{
Cell[48351, 1555, 85, 3, 70, "Input",
  CellTags->"Cell 9.17"],
Cell[48439, 1560, 52, 1, 70, "Output"]
}, Open  ]],
Cell[48506, 1564, 364, 9, 70, "Text",
  CellTags->"i:6"],

Cell[CellGroupData[{
Cell[48895, 1577, 89, 3, 70, "Input",
  CellTags->"Cell 9.18"],
Cell[48987, 1582, 76, 1, 70, "Output"]
}, Open  ]],
Cell[49078, 1586, 662, 15, 70, "Text"],

Cell[CellGroupData[{
Cell[49765, 1605, 93, 3, 70, "Input",
  CellTags->"Cell 9.19"],
Cell[49861, 1610, 53, 1, 70, "Output"]
}, Open  ]],
Cell[49929, 1614, 484, 13, 70, "Text",
  CellTags->"i:7"],

Cell[CellGroupData[{
Cell[50438, 1631, 104, 3, 70, "Input",
  CellTags->"Cell 9.20"],
Cell[50545, 1636, 36, 0, 70, "Output"]
}, Open  ]],
Cell[50596, 1639, 531, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[51152, 1657, 94, 3, 70, "Input",
  CellTags->"Cell 9.21"],
Cell[51249, 1662, 72, 1, 70, "Output"]
}, Open  ]],
Cell[51336, 1666, 622, 14, 70, "Text"],
Cell[51961, 1682, 434, 12, 70, "Text",
  CellTags->"i:21"],

Cell[CellGroupData[{
Cell[52420, 1698, 122, 3, 70, "Input",
  CellTags->"Cell 9.22"],
Cell[52545, 1703, 36, 1, 70, "Output"]
}, Open  ]],
Cell[52596, 1707, 172, 6, 70, "Text"],
Cell[52771, 1715, 3862, 94, 70, "Text",
  CellTags->"Table 9.5"]
}, Closed]],

Cell[CellGroupData[{
Cell[56670, 1814, 65, 1, 30, "Subsubtitle",
  CellTags->"c:10"],
Cell[56738, 1817, 202, 7, 26, "Text"],
Cell[56943, 1826, 173, 7, 26, "Text"],
Cell[57119, 1835, 227, 10, 30, "Text"],
Cell[57349, 1847, 173, 7, 26, "Text"],
Cell[57525, 1856, 231, 7, 30, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[57805, 1869, 210, 10, 40, "Subtitle",
  CellTags->{"Sec. 9.3", "c:11"}],
Cell[58018, 1881, 956, 25, 111, "Text",
  CellTags->"i:8"],
Cell[58977, 1908, 616, 9, 95, "Text"],
Cell[59596, 1919, 964, 27, 95, "Text",
  CellTags->"i:13"],
Cell[60563, 1948, 719, 13, 136, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[61319, 1966, 80, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.4", "c:12"}],
Cell[61402, 1969, 16, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[61443, 1973, 61, 1, 40, "Subsubtitle",
  CellTags->"c:13"],
Cell[61507, 1976, 514, 15, 66, "Text",
  CellTags->"i:22"],

Cell[CellGroupData[{
Cell[62046, 1995, 84, 3, 66, "Input",
  CellTags->"Cell 9.23"],
Cell[62133, 2000, 38, 1, 45, "Output"]
}, Open  ]],
Cell[62186, 2004, 61, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[62272, 2008, 85, 3, 66, "Input",
  CellTags->"Cell 9.24"],
Cell[62360, 2013, 38, 1, 45, "Output"]
}, Open  ]],
Cell[62413, 2017, 170, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[62608, 2027, 90, 3, 66, "Input",
  CellTags->"Cell 9.25"],
Cell[62701, 2032, 35, 1, 45, "Output"]
}, Open  ]],
Cell[62751, 2036, 625, 20, 60, "Text"],

Cell[CellGroupData[{
Cell[63401, 2060, 82, 3, 66, "Input",
  CellTags->"Cell 9.26"],
Cell[63486, 2065, 38, 1, 45, "Output"]
}, Open  ]],
Cell[63539, 2069, 325, 8, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[63901, 2082, 58, 1, 30, "Subsubtitle",
  CellTags->"c:14"],
Cell[63962, 2085, 1808, 59, 170, "Text"],

Cell[CellGroupData[{
Cell[65795, 2148, 101, 3, 66, "Input",
  CellTags->"Cell 9.27"],
Cell[65899, 2153, 37, 1, 50, "Output"]
}, Open  ]],
Cell[65951, 2157, 159, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[66135, 2167, 83, 3, 66, "Input",
  CellTags->"Cell 9.28"],
Cell[66221, 2172, 35, 1, 45, "Output"]
}, Open  ]],
Cell[66271, 2176, 161, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[66457, 2186, 92, 3, 66, "Input",
  CellTags->"Cell 9.29"],
Cell[66552, 2191, 38, 1, 50, "Output"]
}, Open  ]],
Cell[66605, 2195, 221, 8, 26, "Text",
  CellTags->"i:23"],
Cell[66829, 2205, 89, 3, 66, "Input",
  CellTags->"Cell 9.30"],
Cell[66921, 2210, 411, 17, 26, "Text"],

Cell[CellGroupData[{
Cell[67357, 2231, 81, 3, 66, "Input",
  CellTags->"Cell 9.31"],
Cell[67441, 2236, 35, 1, 45, "Output"]
}, Open  ]],
Cell[67491, 2240, 174, 4, 43, "Text",
  CellTags->"i:24"],
Cell[67668, 2246, 102, 3, 66, "Input",
  CellTags->"Cell 9.32"],
Cell[67773, 2251, 1539, 51, 111, "Text",
  CellTags->"i:10"],
Cell[69315, 2304, 359, 12, 43, "Text"],
Cell[69677, 2318, 390, 9, 68, "Text"],
Cell[70070, 2329, 5691, 136, 265, "Text",
  CellTags->{"i:25", "Table 9.6"}],
Cell[75764, 2467, 51, 1, 22, "Text"],
Cell[75818, 2470, 2451, 58, 158, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[78306, 2533, 82, 1, 30, "Subsubtitle",
  CellTags->"c:15"],
Cell[78391, 2536, 977, 28, 95, "Text",
  CellTags->"i:12"],
Cell[79371, 2566, 682391, 8428, 483, 682274, 8424, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[761765, 10996, 74, 1, 15, "Caption",
  CellTags->"Fig. 9.1"],
Cell[761842, 10999, 551, 19, 51, "Text"],
Cell[762396, 11020, 1158, 39, 65, "Text"],
Cell[763557, 11061, 1510, 51, 63, "Text"],
Cell[765070, 11114, 302, 10, 26, "Text"],

Cell[CellGroupData[{
Cell[765397, 11128, 85, 3, 66, "Input",
  CellTags->"Cell 9.33"],
Cell[765485, 11133, 35, 1, 45, "Output"]
}, Open  ]],
Cell[765535, 11137, 351, 11, 28, "Text"],

Cell[CellGroupData[{
Cell[765911, 11152, 92, 3, 70, "Input",
  CellTags->"Cell 9.34"],
Cell[766006, 11157, 38, 1, 50, "Output"]
}, Open  ]],
Cell[766059, 11161, 863, 29, 45, "Text"],
Cell[766925, 11192, 789, 24, 77, "Text",
  CellTags->"i:11"],
Cell[767717, 11218, 438, 8, 102, "Text"],
Cell[768158, 11228, 192, 4, 43, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[768399, 11238, 85, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.5", "c:16"}],
Cell[768487, 11241, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[768528, 11245, 86, 1, 41, "Subsubtitle",
  CellTags->"c:17"],
Cell[768617, 11248, 395, 12, 43, "Text",
  CellTags->"i:26"],

Cell[CellGroupData[{
Cell[769037, 11264, 105, 3, 66, "Input",
  CellTags->"Cell 9.35"],
Cell[769145, 11269, 51, 1, 45, "Output"]
}, Open  ]],
Cell[769211, 11273, 90, 3, 26, "Text"],
Cell[769304, 11278, 525, 18, 60, "Text"],
Cell[769832, 11298, 414, 13, 43, "Text",
  CellTags->"i:27"],

Cell[CellGroupData[{
Cell[770271, 11315, 89, 3, 66, "Input",
  CellTags->"Cell 9.36"],
Cell[770363, 11320, 35, 1, 45, "Output"]
}, Open  ]],
Cell[770413, 11324, 39, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[770477, 11328, 116, 3, 66, "Input",
  CellTags->"Cell 9.37"],
Cell[770596, 11333, 59, 1, 52, "Output"]
}, Open  ]],
Cell[770670, 11337, 250, 5, 43, "Text"],

Cell[CellGroupData[{
Cell[770945, 11346, 94, 3, 66, "Input",
  CellTags->"Cell 9.38"],
Cell[771042, 11351, 56, 1, 45, "Output"]
}, Open  ]],
Cell[771113, 11355, 336, 11, 43, "Text"],

Cell[CellGroupData[{
Cell[771474, 11370, 90, 3, 66, "Input",
  CellTags->"Cell 9.39"],
Cell[771567, 11375, 80, 1, 52, "Output"]
}, Open  ]],
Cell[771662, 11379, 253, 8, 43, "Text",
  CellTags->"i:28"],

Cell[CellGroupData[{
Cell[771940, 11391, 93, 3, 66, "Input",
  CellTags->"Cell 9.40"],
Cell[772036, 11396, 229, 6, 70, "Output"]
}, Open  ]],
Cell[772280, 11405, 656, 24, 60, "Text",
  CellTags->"i:29"],

Cell[CellGroupData[{
Cell[772961, 11433, 104, 3, 66, "Input",
  CellTags->"Cell 9.41"],
Cell[773068, 11438, 41, 1, 45, "Output"]
}, Open  ]],
Cell[773124, 11442, 281, 11, 26, "Text"],

Cell[CellGroupData[{
Cell[773430, 11457, 81, 3, 66, "Input",
  CellTags->"Cell 9.42"],
Cell[773514, 11462, 65, 1, 52, "Output"]
}, Open  ]],
Cell[773594, 11466, 649, 25, 43, "Text"],
Cell[774246, 11493, 347, 11, 43, "Text"],

Cell[CellGroupData[{
Cell[774618, 11508, 93, 3, 66, "Input",
  CellTags->"Cell 9.43"],
Cell[774714, 11513, 35, 1, 45, "Output"]
}, Open  ]],
Cell[774764, 11517, 1037, 40, 60, "Text"],
Cell[775804, 11559, 534, 19, 43, "Text"],

Cell[CellGroupData[{
Cell[776363, 11582, 103, 3, 66, "Input",
  CellTags->"Cell 9.44"],
Cell[776469, 11587, 35, 1, 45, "Output"]
}, Open  ]],
Cell[776519, 11591, 3348, 77, 256, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[779904, 11673, 87, 1, 30, "Subsubtitle",
  CellTags->{"i:98", "c:18"}],

Cell[CellGroupData[{
Cell[780016, 11678, 54, 1, 42, "Section",
  CellTags->"c:19"],
Cell[780073, 11681, 1222, 38, 78, "Text"],
Cell[781298, 11721, 84866, 1051, 370, 84744, 1047, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[866167, 12774, 244, 12, 16, "Caption",
  CellTags->"Fig. 9.2"],
Cell[866414, 12788, 260, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[866699, 12799, 159, 4, 86, "Input",
  CellTags->"Cell 9.45"],
Cell[866861, 12805, 40, 1, 46, "Output"]
}, Open  ]],
Cell[866916, 12809, 525, 13, 78, "Text"],
Cell[867444, 12824, 137, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[867618, 12832, 60, 1, 31, "Section",
  CellTags->{"i:31", "c:20"}],
Cell[867681, 12835, 303, 13, 27, "Text"],
Cell[867987, 12850, 1499, 44, 29, "NumberedEquation",
  CellTags->"(9.5.1)"],
Cell[869489, 12896, 263, 6, 44, "Text"],
Cell[869755, 12904, 814, 25, 33, "NumberedEquation",
  CellTags->"(9.5.2)"],
Cell[870572, 12931, 344, 14, 27, "Text"],
Cell[870919, 12947, 277, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[871221, 12960, 85, 3, 67, "Input",
  CellTags->"Cell 9.46"],
Cell[871309, 12965, 109, 2, 46, "Output"]
}, Open  ]],
Cell[871433, 12970, 369, 13, 30, "Text",
  CellTags->"i:42"],

Cell[CellGroupData[{
Cell[871827, 12987, 85, 3, 67, "Input",
  CellTags->"Cell 9.47"],
Cell[871915, 12992, 36, 1, 46, "Output"]
}, Open  ]],
Cell[871966, 12996, 515, 18, 48, "Text"],
Cell[872484, 13016, 507, 16, 86, "Text"],
Cell[872994, 13034, 417, 12, 27, "NumberedEquation",
  CellTags->"(9.5.3)"],
Cell[873414, 13048, 129, 4, 52, "Text"],
Cell[873546, 13054, 610, 19, 27, "NumberedEquation",
  CellTags->"(9.5.4)"],
Cell[874159, 13075, 381, 15, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[874577, 13095, 70, 1, 31, "Section",
  CellTags->{"i:32", "c:21"}],
Cell[874650, 13098, 967, 44, 61, "Text"],
Cell[875620, 13144, 2841, 83, 33, "NumberedEquation",
  CellTags->"(9.5.5)"],
Cell[878464, 13229, 551, 19, 27, "Text"],
Cell[879018, 13250, 358, 14, 44, "Text"],
Cell[879379, 13266, 2302, 58, 191, "NumberedEquation",
  CellTags->"(9.5.6)"],
Cell[881684, 13326, 175, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[881884, 13336, 89, 3, 67, "Input",
  CellTags->"Cell 9.48"],
Cell[881976, 13341, 120, 2, 46, "Output"]
}, Open  ]],
Cell[882111, 13346, 175, 6, 27, "Text"],
Cell[882289, 13354, 763, 21, 95, "Text",
  CellTags->"Table 9.8"]
}, Closed]],

Cell[CellGroupData[{
Cell[883089, 13380, 62, 1, 31, "Section",
  CellTags->"c:22"],

Cell[CellGroupData[{
Cell[883176, 13385, 80, 2, 27, "Subsubsection",
  CellTags->"i:33"],
Cell[883259, 13389, 409, 12, 44, "Text"],

Cell[CellGroupData[{
Cell[883693, 13405, 104, 3, 67, "Input",
  CellTags->"Cell 9.49"],
Cell[883800, 13410, 257, 8, 110, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[884106, 13424, 94, 2, 29, "Subsubsection",
  CellTags->"i:34"],
Cell[884203, 13428, 201, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[884429, 13436, 144, 4, 86, "Input",
  CellTags->"Cell 9.50"],
Cell[884576, 13442, 192, 6, 64, "Output"]
}, Open  ]],
Cell[884783, 13451, 420, 14, 47, "Text"],

Cell[CellGroupData[{
Cell[885228, 13469, 137, 4, 86, "Input",
  CellTags->"Cell 9.51"],
Cell[885368, 13475, 214, 6, 84, "Output"]
}, Open  ]],
Cell[885597, 13484, 533, 20, 47, "Text",
  CellTags->"i:104"],

Cell[CellGroupData[{
Cell[886155, 13508, 133, 4, 86, "Input",
  CellTags->"Cell 9.52"],
Cell[886291, 13514, 189, 6, 64, "Output"]
}, Open  ]],
Cell[886495, 13523, 274, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[886794, 13534, 93, 3, 67, "Input",
  CellTags->"Cell 9.53"],
Cell[886890, 13539, 40, 1, 46, "Output"]
}, Open  ]],
Cell[886945, 13543, 484, 15, 61, "Text"],
Cell[887432, 13560, 283, 8, 27, "NumberedEquation",
  CellTags->"(9.5.7)"],
Cell[887718, 13570, 183, 5, 27, "Text"],
Cell[887904, 13577, 853, 25, 32, "NumberedEquation",
  CellTags->"(9.5.8)"],
Cell[888760, 13604, 606, 23, 44, "Text"],

Cell[CellGroupData[{
Cell[889391, 13631, 100, 3, 67, "Input",
  CellTags->"Cell 9.54"],
Cell[889494, 13636, 69, 1, 62, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[889612, 13643, 98, 2, 29, "Subsubsection",
  CellTags->"i:35"],
Cell[889713, 13647, 557, 18, 61, "Text"],
Cell[890273, 13667, 467, 14, 27, "NumberedEquation",
  CellTags->"(9.5.9)"],
Cell[890743, 13683, 746, 29, 61, "Text",
  CellTags->"i:105"],

Cell[CellGroupData[{
Cell[891514, 13716, 95, 3, 67, "Input",
  CellTags->"Cell 9.55"],
Cell[891612, 13721, 79, 1, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[891728, 13727, 94, 3, 67, "Input",
  CellTags->"Cell 9.56"],
Cell[891825, 13732, 72, 1, 46, "Output"]
}, Open  ]],
Cell[891912, 13736, 577, 16, 61, "Text"],

Cell[CellGroupData[{
Cell[892514, 13756, 125, 3, 67, "Input",
  CellTags->"Cell 9.57"],
Cell[892642, 13761, 40, 1, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[892731, 13768, 82, 2, 29, "Subsubsection",
  CellTags->"i:36"],
Cell[892816, 13772, 487, 18, 44, "Text"],

Cell[CellGroupData[{
Cell[893328, 13794, 86, 3, 67, "Input",
  CellTags->"Cell 9.58"],
Cell[893417, 13799, 35, 1, 46, "Output"]
}, Open  ]],
Cell[893467, 13803, 101, 3, 27, "Text"],
Cell[893571, 13808, 181, 5, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[893789, 13818, 79, 2, 29, "Subsubsection",
  CellTags->"i:37"],
Cell[893871, 13822, 394, 10, 61, "Text"],

Cell[CellGroupData[{
Cell[894290, 13836, 92, 3, 67, "Input",
  CellTags->"Cell 9.59"],
Cell[894385, 13841, 36, 1, 46, "Output"]
}, Open  ]],
Cell[894436, 13845, 644, 19, 80, "Text"],

Cell[CellGroupData[{
Cell[895105, 13868, 153, 4, 86, "Input",
  CellTags->"Cell 9.60"],
Cell[895261, 13874, 66, 1, 46, "Output"]
}, Open  ]],
Cell[895342, 13878, 990, 35, 44, "Text"],

Cell[CellGroupData[{
Cell[896357, 13917, 98, 3, 67, "Input",
  CellTags->"Cell 9.61"],
Cell[896458, 13922, 43, 1, 46, "Output"]
}, Open  ]],
Cell[896516, 13926, 177, 6, 27, "Text"],
Cell[896696, 13934, 1781, 51, 27, "NumberedEquation",
  CellTags->"(9.5.10)"],
Cell[898480, 13987, 526, 16, 61, "Text"],
Cell[899009, 14005, 65817, 816, 252, 65697, 812, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[964829, 14823, 751, 27, 16, "Caption",
  CellTags->"Fig. 9.3"],
Cell[965583, 14852, 905, 27, 64, "Text"],
Cell[966491, 14881, 2154, 60, 74, "NumberedEquation",
  CellTags->"(9.5.11)"],
Cell[968648, 14943, 175, 5, 27, "Text"],
Cell[968826, 14950, 554, 14, 61, "Text"],
Cell[969383, 14966, 162, 6, 27, "Text"],
Cell[969548, 14974, 3278, 89, 163, "Text",
  CellTags->"Table 9.9"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[972887, 15070, 118, 4, 30, "Subsubtitle",
  CellTags->"c:23"],
Cell[973008, 15076, 498, 15, 61, "Text",
  CellTags->"i:38"],

Cell[CellGroupData[{
Cell[973531, 15095, 106, 3, 67, "Input",
  CellTags->"Cell 9.62"],
Cell[973640, 15100, 58, 1, 46, "Output"]
}, Open  ]],
Cell[973713, 15104, 416, 12, 61, "Text"],
Cell[974132, 15118, 134, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[974291, 15125, 113, 3, 67, "Input",
  CellTags->"Cell 9.63"],
Cell[974407, 15130, 265, 4, 65, "Output"]
}, Open  ]],
Cell[974687, 15137, 138, 5, 27, "Text"],
Cell[974828, 15144, 284, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[975137, 15155, 124, 3, 67, "Input",
  CellTags->"Cell 9.64"],
Cell[975264, 15160, 58, 1, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[975371, 15167, 68, 1, 30, "Subsubtitle",
  CellTags->"c:24"],
Cell[975442, 15170, 1083, 35, 70, "Text"],
Cell[976528, 15207, 358, 9, 70, "Text",
  CellTags->"i:39"],
Cell[976889, 15218, 117, 3, 70, "Input",
  CellTags->"Cell 9.65"],

Cell[CellGroupData[{
Cell[977031, 15225, 95, 3, 70, "Input",
  CellTags->"Cell 9.66"],
Cell[977129, 15230, 69, 1, 70, "Output"]
}, Open  ]],
Cell[977213, 15234, 178, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[977416, 15244, 96, 3, 70, "Input",
  CellTags->"Cell 9.67"],
Cell[977515, 15249, 69, 1, 70, "Output"]
}, Open  ]],
Cell[977599, 15253, 612, 22, 70, "Text",
  CellTags->"i:40"],

Cell[CellGroupData[{
Cell[978236, 15279, 132, 4, 70, "Input",
  CellTags->"Cell 9.68"],
Cell[978371, 15285, 73, 1, 70, "Output"]
}, Open  ]],
Cell[978459, 15289, 668, 23, 70, "Text",
  CellTags->"i:41"],

Cell[CellGroupData[{
Cell[979152, 15316, 90, 3, 70, "Input",
  CellTags->"Cell 9.69"],
Cell[979245, 15321, 57, 1, 70, "Output"]
}, Open  ]],
Cell[979317, 15325, 145, 3, 70, "Text"],
Cell[979465, 15330, 173, 6, 70, "Text"],
Cell[979641, 15338, 7209, 164, 70, "Text",
  CellTags->"Table 9.10"]
}, Closed]],

Cell[CellGroupData[{
Cell[986887, 15507, 65, 1, 30, "Subsubtitle",
  CellTags->"c:25"],
Cell[986955, 15510, 202, 7, 26, "Text"],
Cell[987160, 15519, 211, 5, 43, "Text"],
Cell[987374, 15526, 433, 11, 60, "Text"],
Cell[987810, 15539, 324, 13, 67, "Text"],
Cell[988137, 15554, 362, 14, 87, "Text"],
Cell[988502, 15570, 424, 15, 82, "Text"],
Cell[988929, 15587, 410, 14, 62, "Text"],
Cell[989342, 15603, 115, 3, 26, "Text"],
Cell[989460, 15608, 580, 21, 26, "Text"],
Cell[990043, 15631, 636, 24, 42, "Text"],
Cell[990682, 15657, 549, 21, 62, "Text"],
Cell[991234, 15680, 1063, 40, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[992346, 15726, 74, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.6", "c:26"}],
Cell[992423, 15729, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[992464, 15733, 188, 8, 41, "Subsubtitle",
  CellTags->{"i:43", "c:27"}],
Cell[992655, 15743, 222, 6, 43, "Text"],
Cell[992880, 15751, 245, 11, 26, "Text"],
Cell[993128, 15764, 683, 26, 60, "Text"],

Cell[CellGroupData[{
Cell[993836, 15794, 107, 3, 66, "Input",
  CellTags->"Cell 9.70"],
Cell[993946, 15799, 26413, 593, 232, 4588, 320, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1020362, 16394, 130, 3, 45, "Output"]
}, Open  ]],
Cell[1020507, 16400, 504, 16, 60, "Text"],
Cell[1021014, 16418, 157, 3, 43, "Text"],
Cell[1021174, 16423, 371, 5, 60, "Text"],
Cell[1021548, 16430, 456, 15, 43, "Text",
  CellTags->"i:44"],

Cell[CellGroupData[{
Cell[1022029, 16449, 138, 3, 66, "Input",
  CellTags->"Cell 9.71"],
Cell[1022170, 16454, 23791, 621, 232, 5570, 392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1045964, 17077, 130, 3, 45, "Output"]
}, Open  ]],
Cell[1046109, 17083, 1214, 45, 60, "Text",
  CellTags->"i:133"],
Cell[1047326, 17130, 244, 6, 43, "Text"],
Cell[1047573, 17138, 139, 5, 26, "Text"],
Cell[1047715, 17145, 141, 5, 26, "Text"],
Cell[1047859, 17152, 2410, 76, 95, "Text"],
Cell[1050272, 17230, 328, 12, 26, "Text"],
Cell[1050603, 17244, 214, 7, 26, "Text"],

Cell[CellGroupData[{
Cell[1050842, 17255, 406, 9, 123, "Input",
  CellTags->"Cell 9.72"],
Cell[1051251, 17266, 32418, 776, 232, 7982, 470, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1083672, 18044, 130, 3, 45, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1083851, 18053, 188, 8, 30, "Subsubtitle",
  CellTags->{"i:45", "c:28"}],
Cell[1084042, 18063, 486, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[1084553, 18085, 159, 4, 70, "Input",
  CellTags->"Cell 9.73"],
Cell[1084715, 18091, 31401, 865, 70, 9225, 587, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1116119, 18958, 130, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1116298, 18967, 100, 1, 30, "Subsubtitle",
  CellTags->{"i:46", "c:29"}],
Cell[1116401, 18970, 1893, 59, 70, "Text"],

Cell[CellGroupData[{
Cell[1118319, 19033, 243, 6, 70, "Input",
  CellTags->"Cell 9.74"],
Cell[1118565, 19041, 25443, 620, 70, 5304, 367, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1144011, 19663, 130, 3, 70, "Output"]
}, Open  ]],
Cell[1144156, 19669, 655, 22, 70, "Text"],
Cell[1144814, 19693, 407, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[1145246, 19711, 101, 3, 70, "Input",
  CellTags->"Cell 9.75"],
Cell[1145350, 19716, 36273, 1032, 70, 11243, 718, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1181626, 20750, 130, 3, 70, "Output"]
}, Open  ]],
Cell[1181771, 20756, 564, 21, 70, "Text"],
Cell[1182338, 20779, 6857, 174, 70, "Text",
  CellTags->"Table 9.11"]
}, Closed]],

Cell[CellGroupData[{
Cell[1189232, 20958, 193, 8, 30, "Subsubtitle",
  CellTags->{"i:47", "c:30"}],
Cell[1189428, 20968, 462, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[1189915, 20986, 129, 3, 70, "Input",
  CellTags->"Cell 9.76"],
Cell[1190047, 20991, 308, 5, 70, "Output"]
}, Open  ]],
Cell[1190370, 20999, 248, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[1190643, 21013, 129, 3, 70, "Input",
  CellTags->"Cell 9.77"],
Cell[1190775, 21018, 17412, 425, 70, 3554, 250, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1208190, 21445, 130, 3, 70, "Output"]
}, Open  ]],
Cell[1208335, 21451, 452, 15, 70, "Text"],

Cell[CellGroupData[{
Cell[1208812, 21470, 119, 3, 70, "Input",
  CellTags->"Cell 9.78"],
Cell[1208934, 21475, 20034, 459, 70, 3528, 251, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1228971, 21936, 130, 3, 70, "Output"]
}, Open  ]],
Cell[1229116, 21942, 934, 31, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1230087, 21978, 75, 1, 30, "Subsubtitle",
  CellTags->{"i:50", "c:31"}],
Cell[1230165, 21981, 856, 28, 70, "Text",
  CellTags->"i:51"],
Cell[1231024, 22011, 1614, 55, 70, "Text"],

Cell[CellGroupData[{
Cell[1232663, 22070, 160, 4, 70, "Input",
  CellTags->"Cell 9.79"],
Cell[1232826, 22076, 64647, 1152, 70, 6087, 425, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1297476, 23230, 130, 3, 70, "Output"]
}, Open  ]],
Cell[1297621, 23236, 463, 17, 70, "Text",
  CellTags->"i:119"],
Cell[1298087, 23255, 887, 31, 70, "Text"],

Cell[CellGroupData[{
Cell[1298999, 23290, 268, 6, 70, "Input",
  CellTags->"Cell 9.80"],
Cell[1299270, 23298, 47787, 1143, 70, 9427, 666, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1347060, 24443, 130, 3, 70, "Output"]
}, Open  ]],
Cell[1347205, 24449, 312, 13, 70, "Text"],
Cell[1347520, 24464, 7113, 176, 70, "Text",
  CellTags->"Table 9.12"]
}, Closed]],

Cell[CellGroupData[{
Cell[1354670, 24645, 57, 1, 30, "Subsubtitle",
  CellTags->"c:32"],
Cell[1354730, 24648, 596, 19, 60, "Text",
  CellTags->"i:48"],

Cell[CellGroupData[{
Cell[1355351, 24671, 131, 3, 65, "Input",
  CellTags->"Cell 9.81"],
Cell[1355485, 24676, 121544, 2015, 300, 20636, 765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1477032, 26693, 137, 3, 45, "Output"]
}, Open  ]],
Cell[1477184, 26699, 694, 26, 42, "Text",
  CellTags->"i:53"],

Cell[CellGroupData[{
Cell[1477903, 26729, 134, 3, 65, "Input",
  CellTags->"Cell 9.82"],
Cell[1478040, 26734, 164009, 2538, 370, 19563, 751, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1642064, 29275, 351, 11, 70, "Text"],
Cell[1642418, 29288, 252, 7, 70, "Text",
  CellTags->"i:54"],
Cell[1642673, 29297, 94, 3, 70, "Input",
  CellTags->"Cell 9.83"],
Cell[1642770, 29302, 233, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[1643028, 29313, 89, 3, 70, "Input",
  CellTags->"Cell 9.84"],
Cell[1643120, 29318, 85598, 1068, 70, 2495, 40, "BoxData", "Graphics3D", \
"Graphics"],
Cell[1728721, 30388, 137, 3, 70, "Output"]
}, Open  ]],
Cell[1728873, 30394, 205, 5, 70, "Text",
  CellTags->"i:55"],
Cell[1729081, 30401, 93, 3, 70, "Input",
  CellTags->"Cell 9.85"],
Cell[1729177, 30406, 70, 0, 70, "Text"],
Cell[1729250, 30408, 544, 17, 70, "Text",
  CellTags->"i:49"],

Cell[CellGroupData[{
Cell[1729819, 30429, 158, 4, 70, "Input",
  CellTags->"Cell 9.86"],
Cell[1729980, 30435, 177972, 4051, 70, 31517, 2239, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1907955, 34488, 137, 3, 70, "Output"]
}, Open  ]],
Cell[1908107, 34494, 521, 13, 70, "Text"],
Cell[1908631, 34509, 1199, 36, 70, "Text"],
Cell[1909833, 34547, 9929, 252, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1919799, 34804, 69, 1, 30, "Subsubtitle",
  CellTags->{"i:56", "c:33"}],
Cell[1919871, 34807, 480, 17, 44, "Text"],

Cell[CellGroupData[{
Cell[1920376, 34828, 188, 5, 67, "Input",
  CellTags->"Cell 9.87"],

Cell[CellGroupData[{
Cell[1920589, 34837, 21565, 538, 233, 4648, 325, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1942157, 35377, 26300, 598, 233, 4685, 327, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1968460, 35977, 28914, 651, 70, 5072, 353, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1997377, 36630, 32561, 718, 70, 5507, 380, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2029941, 37350, 36880, 769, 70, 5460, 377, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2066824, 38121, 39618, 827, 70, 5910, 407, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2106445, 38950, 43755, 877, 70, 5900, 406, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2150203, 39829, 46543, 929, 70, 6250, 428, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2196749, 40760, 50399, 996, 233, 6610, 451, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2247151, 41758, 54659, 1050, 233, 6642, 453, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[2301837, 42812, 683, 21, 82, "Text"],
Cell[2302523, 42835, 270, 8, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2302830, 42848, 74, 1, 30, "Subsubtitle",
  CellTags->{"i:57", "c:34"}],
Cell[2302907, 42851, 1440, 40, 146, "Text",
  CellTags->"i:113"],
Cell[2304350, 42893, 772, 19, 103, "Text"],
Cell[2305125, 42914, 92, 3, 67, "Input",
  CellTags->"Cell 9.88"],
Cell[2305220, 42919, 156, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[2305401, 42929, 153, 4, 73, "Input",
  CellTags->"Cell 9.89"],
Cell[2305557, 42935, 28876, 711, 233, 9488, 467, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2334436, 43648, 130, 3, 46, "Output"]
}, Open  ]],
Cell[2334581, 43654, 706, 24, 61, "Text"],
Cell[2335290, 43680, 484, 13, 61, "Text",
  CellTags->"i:120"],

Cell[CellGroupData[{
Cell[2335799, 43697, 153, 4, 73, "Input",
  CellTags->"Cell 9.90"],
Cell[2335955, 43703, 93, 1, 53, "Output"]
}, Open  ]],
Cell[2336063, 43707, 143, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[2336231, 43714, 221, 6, 111, "Input",
  CellTags->"Cell 9.91"],
Cell[2336455, 43722, 93, 1, 53, "Output"]
}, Open  ]],
Cell[2336563, 43726, 2239, 66, 230, "Text"],
Cell[2338805, 43794, 1430, 34, 163, "Text",
  CellTags->"i:114"],
Cell[2340238, 43830, 96, 3, 67, "Input",
  CellTags->"Cell 9.92"],
Cell[2340337, 43835, 739, 26, 61, "Text"],

Cell[CellGroupData[{
Cell[2341101, 43865, 1014, 21, 219, "Input",
  CellTags->"Cell 9.93"],

Cell[CellGroupData[{
Cell[2342140, 43890, 69795, 1601, 370, 15706, 929, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2411938, 45493, 79801, 2058, 266, 22337, 1344, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2491800, 47558, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 9.6", "c:35"}],
Cell[2491881, 47561, 453, 15, 47, "Text",
  CellTags->"Ex. 9.6"],
Cell[2492337, 47578, 669, 19, 67, "Text"],
Cell[2493009, 47599, 846, 27, 73, "Text",
  CellTags->"i:59"],
Cell[2493858, 47628, 304, 11, 27, "Text"],
Cell[2494165, 47641, 317, 11, 27, "Text",
  CellTags->"i:60"],
Cell[2494485, 47654, 1439, 50, 127, "Text"],
Cell[2495927, 47706, 1022, 32, 61, "Text",
  CellTags->"i:58"],
Cell[2496952, 47740, 1364, 45, 95, "Text",
  CellTags->"i:52"],
Cell[2498319, 47787, 1030, 35, 81, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2499398, 47828, 147, 6, 40, "Subtitle",
  CellTags->{"Sec. 9.7", "c:36"}],
Cell[2499548, 47836, 1163, 31, 129, "Text"],
Cell[2500714, 47869, 240, 5, 44, "Text"],
Cell[2500957, 47876, 393, 13, 44, "Text",
  CellTags->"i:122"],

Cell[CellGroupData[{
Cell[2501375, 47893, 96, 3, 67, "Input",
  CellTags->"Cell 9.94"],
Cell[2501474, 47898, 292, 8, 50, "Print"]
}, Open  ]],
Cell[2501781, 47909, 125, 3, 27, "Text"],
Cell[2501909, 47914, 106, 3, 67, "Input",
  CellTags->"Cell 9.95"],
Cell[2502018, 47919, 50, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2502093, 47923, 86, 3, 67, "Input",
  CellTags->"Cell 9.96"],
Cell[2502182, 47928, 25, 0, 30, "Print"],
Cell[2502210, 47930, 435, 13, 31, "Print",
  CellTags->"Info3244700897-7405223"]
}, Open  ]],
Cell[2502660, 47946, 225, 5, 44, "Text",
  CellTags->"i:121"],

Cell[CellGroupData[{
Cell[2502910, 47955, 93, 3, 67, "Input",
  CellTags->"Cell 9.97"],
Cell[2503006, 47960, 1717, 42, 94, "Print"]
}, Open  ]],
Cell[2504738, 48005, 418, 12, 44, "Text"],
Cell[2505159, 48019, 196, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[2505380, 48029, 93, 3, 67, "Input",
  CellTags->"Cell 9.98"],
Cell[2505476, 48034, 194, 3, 50, "Message"],
Cell[2505673, 48039, 47, 1, 46, "Output"]
}, Open  ]],
Cell[2505735, 48043, 539, 19, 61, "Text",
  CellTags->"i:61"],

Cell[CellGroupData[{
Cell[2506299, 48066, 87, 3, 67, "Input",
  CellTags->"Cell 9.99"],
Cell[2506389, 48071, 367, 9, 69, "Print"],
Cell[2506759, 48082, 1767, 33, 256, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2508575, 48121, 74, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.8", "c:37"}],
Cell[2508652, 48124, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2508693, 48128, 73, 1, 41, "Subsubtitle",
  CellTags->"c:38"],
Cell[2508769, 48131, 215, 5, 44, "Text"],

Cell[CellGroupData[{
Cell[2509009, 48140, 101, 3, 67, "Input",
  CellTags->"Cell 9.100"],
Cell[2509113, 48145, 40, 1, 46, "Output"]
}, Open  ]],
Cell[2509168, 48149, 298, 12, 44, "Text",
  CellTags->"i:62"],

Cell[CellGroupData[{
Cell[2509491, 48165, 130, 3, 67, "Input",
  CellTags->"Cell 9.101"],
Cell[2509624, 48170, 82, 1, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2509743, 48176, 90, 3, 67, "Input",
  CellTags->"Cell 9.102"],
Cell[2509836, 48181, 53, 1, 50, "Output"]
}, Open  ]],
Cell[2509904, 48185, 397, 12, 42, "Text",
  CellTags->"i:63"],

Cell[CellGroupData[{
Cell[2510326, 48201, 90, 3, 65, "Input",
  CellTags->"Cell 9.103"],
Cell[2510419, 48206, 67, 1, 50, "Output"]
}, Open  ]],
Cell[2510501, 48210, 199, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[2510725, 48218, 120, 3, 65, "Input",
  CellTags->"Cell 9.104"],
Cell[2510848, 48223, 69, 1, 62, "Output"]
}, Open  ]],
Cell[2510932, 48227, 171, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[2511128, 48237, 92, 3, 65, "Input",
  CellTags->"Cell 9.105"],
Cell[2511223, 48242, 91, 1, 72, "Output"]
}, Open  ]],
Cell[2511329, 48246, 296, 11, 44, "Text"],

Cell[CellGroupData[{
Cell[2511650, 48261, 93, 3, 67, "Input",
  CellTags->"Cell 9.106"],
Cell[2511746, 48266, 49, 1, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2511832, 48272, 96, 3, 67, "Input",
  CellTags->"Cell 9.107"],
Cell[2511931, 48277, 66, 1, 52, "Output"]
}, Open  ]],
Cell[2512012, 48281, 696, 20, 78, "Text",
  CellTags->"i:64"],

Cell[CellGroupData[{
Cell[2512733, 48305, 122, 3, 67, "Input",
  CellTags->"Cell 9.108"],
Cell[2512858, 48310, 40, 1, 46, "Output"]
}, Open  ]],
Cell[2512913, 48314, 337, 8, 44, "Text"],
Cell[2513253, 48324, 2437, 68, 203, "Text",
  CellTags->"Table 9.14"]
}, Closed]],

Cell[CellGroupData[{
Cell[2515727, 48397, 60, 1, 30, "Subsubtitle",
  CellTags->"c:39"],
Cell[2515790, 48400, 556, 19, 64, "Text",
  CellTags->"i:65"],

Cell[CellGroupData[{
Cell[2516371, 48423, 101, 3, 67, "Input",
  CellTags->"Cell 9.109"],
Cell[2516475, 48428, 35, 1, 46, "Output"]
}, Open  ]],
Cell[2516525, 48432, 836, 30, 61, "Text"],

Cell[CellGroupData[{
Cell[2517386, 48466, 133, 3, 67, "Input",
  CellTags->"Cell 9.110"],
Cell[2517522, 48471, 37, 1, 51, "Output"]
}, Open  ]],
Cell[2517574, 48475, 169, 6, 27, "Text"],
Cell[2517746, 48483, 3598, 93, 83, "Text",
  CellTags->"Table 9.15"]
}, Closed]],

Cell[CellGroupData[{
Cell[2521381, 48581, 77, 1, 30, "Subsubtitle",
  CellTags->{"i:19", "c:40"}],

Cell[CellGroupData[{
Cell[2521483, 48586, 64, 1, 41, "Section",
  CellTags->"c:41"],
Cell[2521550, 48589, 1149, 37, 65, "Text"],

Cell[CellGroupData[{
Cell[2522724, 48630, 107, 3, 65, "Input",
  CellTags->"Cell 9.111"],
Cell[2522834, 48635, 49, 1, 50, "Output"]
}, Open  ]],
Cell[2522898, 48639, 139, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[2523062, 48648, 85, 3, 65, "Input",
  CellTags->"Cell 9.112"],
Cell[2523150, 48653, 36, 1, 45, "Output"]
}, Open  ]],
Cell[2523201, 48657, 1062, 34, 60, "Text",
  CellTags->"i:66"],

Cell[CellGroupData[{
Cell[2524288, 48695, 95, 3, 65, "Input",
  CellTags->"Cell 9.113"],
Cell[2524386, 48700, 38, 1, 50, "Output"]
}, Open  ]],
Cell[2524439, 48704, 158, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[2524622, 48713, 85, 3, 65, "Input",
  CellTags->"Cell 9.114"],
Cell[2524710, 48718, 38, 1, 45, "Output"]
}, Open  ]],
Cell[2524763, 48722, 1617, 59, 60, "Text"],
Cell[2526383, 48783, 1534, 51, 62, "Text"],

Cell[CellGroupData[{
Cell[2527942, 48838, 93, 3, 65, "Input",
  CellTags->"Cell 9.115"],
Cell[2528038, 48843, 35, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2528110, 48849, 96, 3, 65, "Input",
  CellTags->"Cell 9.116"],
Cell[2528209, 48854, 38, 1, 50, "Output"]
}, Open  ]],
Cell[2528262, 48858, 165, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[2528452, 48867, 85, 3, 65, "Input",
  CellTags->"Cell 9.117"],
Cell[2528540, 48872, 35, 1, 45, "Output"]
}, Open  ]],
Cell[2528590, 48876, 148, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[2528763, 48885, 85, 3, 65, "Input",
  CellTags->"Cell 9.118"],
Cell[2528851, 48890, 35, 1, 45, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2528935, 48897, 76, 1, 30, "Section",
  CellTags->"c:42"],
Cell[2529014, 48900, 441, 14, 43, "Text"],

Cell[CellGroupData[{
Cell[2529480, 48918, 87, 3, 66, "Input",
  CellTags->"Cell 9.119"],
Cell[2529570, 48923, 43, 1, 30, "Print"],
Cell[2529616, 48926, 445, 14, 75, "Print"]
}, Open  ]],
Cell[2530076, 48943, 1872, 61, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2531985, 49009, 79, 1, 30, "Section",
  CellTags->{"i:67", "c:43"}],
Cell[2532067, 49012, 263, 6, 42, "Text"],
Cell[2532333, 49020, 111, 3, 65, "Input",
  CellTags->"Cell 9.120"],

Cell[CellGroupData[{
Cell[2532469, 49027, 97, 3, 65, "Input",
  CellTags->"Cell 9.121"],
Cell[2532569, 49032, 37, 1, 50, "Output"]
}, Open  ]],
Cell[2532621, 49036, 2280, 57, 101, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2534950, 49099, 67, 1, 30, "Subsubtitle",
  CellTags->"c:44"],
Cell[2535020, 49102, 251, 8, 70, "Text"],
Cell[2535274, 49112, 460, 18, 70, "Text"],
Cell[2535737, 49132, 1671, 53, 70, "Text"],
Cell[2537411, 49187, 895, 31, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2538343, 49223, 90, 1, 30, "Subsubtitle",
  CellTags->{"i:68", "c:45"}],
Cell[2538436, 49226, 583, 16, 60, "Text"],

Cell[CellGroupData[{
Cell[2539044, 49246, 97, 2, 67, "Input",
  CellTags->"Cell 9.122"],
Cell[2539144, 49250, 161, 3, 50, "Message"],
Cell[2539308, 49255, 62, 1, 45, "Output"]
}, Open  ]],
Cell[2539385, 49259, 698, 22, 60, "Text"],
Cell[2540086, 49283, 435, 11, 60, "Text"],
Cell[2540524, 49296, 120, 5, 26, "Text"],
Cell[2540647, 49303, 122, 3, 66, "Input",
  CellTags->"Cell 9.123"],
Cell[2540772, 49308, 586, 21, 43, "Text"],

Cell[CellGroupData[{
Cell[2541383, 49333, 85, 3, 66, "Input",
  CellTags->"Cell 9.124"],
Cell[2541471, 49338, 32112, 670, 232, 4713, 328, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2573586, 50010, 130, 3, 45, "Output"]
}, Open  ]],
Cell[2573731, 50016, 190, 6, 26, "Text"],
Cell[2573924, 50024, 4628, 122, 82, "Text",
  CellTags->"Table 9.17"]
}, Closed]],

Cell[CellGroupData[{
Cell[2578589, 50151, 101, 1, 30, "Subsubtitle",
  CellTags->{"i:69", "c:46"}],
Cell[2578693, 50154, 353, 11, 44, "Text",
  CellTags->"i:123"],
Cell[2579049, 50167, 594, 21, 45, "NE2",
  CellTags->{"(9.8.1)", "i:106"}],
Cell[2579646, 50190, 199, 5, 27, "Text"],
Cell[2579848, 50197, 108, 3, 67, "Input",
  CellTags->"Cell 9.125"],
Cell[2579959, 50202, 108, 3, 67, "Input",
  CellTags->"Cell 9.126"],
Cell[2580070, 50207, 510, 16, 61, "Text"],
Cell[2580583, 50225, 568, 20, 44, "Text"],

Cell[CellGroupData[{
Cell[2581176, 50249, 95, 3, 67, "Input",
  CellTags->"Cell 9.127"],
Cell[2581274, 50254, 38, 1, 64, "Output"]
}, Open  ]],
Cell[2581327, 50258, 454, 14, 44, "Text"],

Cell[CellGroupData[{
Cell[2581806, 50276, 157, 4, 67, "Input",
  CellTags->"Cell 9.128"],
Cell[2581966, 50282, 12449, 352, 233, 3272, 235, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2594430, 50637, 197, 6, 27, "Text"],
Cell[2594630, 50645, 7139, 171, 287, "Text",
  CellTags->{"i:111", "Table 9.18"}],
Cell[2601772, 50818, 967, 35, 44, "Text",
  CellTags->"i:80"],

Cell[CellGroupData[{
Cell[2602764, 50857, 127, 4, 86, "Input",
  CellTags->"Cell 9.129"],
Cell[2602894, 50863, 39, 1, 46, "Output"]
}, Open  ]],
Cell[2602948, 50867, 156, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2603141, 50875, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 9.8", "c:47"}],
Cell[2603222, 50878, 239, 10, 26, "Text"],
Cell[2603464, 50890, 208, 8, 30, "Text"],
Cell[2603675, 50900, 238, 7, 37, "Text"],
Cell[2603916, 50909, 207, 8, 37, "Text"],
Cell[2604126, 50919, 109, 4, 26, "Text"],
Cell[2604238, 50925, 148, 7, 30, "Text"],
Cell[2604389, 50934, 177, 7, 30, "Text"],
Cell[2604569, 50943, 202, 8, 30, "Text"],
Cell[2604774, 50953, 240, 7, 43, "Text"],
Cell[2605017, 50962, 195, 6, 37, "Text"],
Cell[2605215, 50970, 182, 5, 26, "Text"],
Cell[2605400, 50977, 304, 11, 26, "Text"],
Cell[2605707, 50990, 236, 10, 30, "Text"],
Cell[2605946, 51002, 314, 13, 30, "Text"],
Cell[2606263, 51017, 166, 5, 26, "Text"],
Cell[2606432, 51024, 245, 10, 32, "Text"],
Cell[2606680, 51036, 413, 16, 40, "Text"],
Cell[2607096, 51054, 864, 33, 26, "Text"],
Cell[2607963, 51089, 772, 25, 76, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2608784, 51120, 66, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.9", "c:48"}],
Cell[2608853, 51123, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2608894, 51127, 70, 1, 41, "Subsubtitle",
  CellTags->{"i:70", "c:49"}],
Cell[2608967, 51130, 719, 26, 61, "Text"],
Cell[2609689, 51158, 57, 0, 27, "Text"],
Cell[2609749, 51160, 106, 3, 67, "Input",
  CellTags->"Cell 9.130"],
Cell[2609858, 51165, 201, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[2610084, 51176, 91, 3, 67, "Input",
  CellTags->"Cell 9.131"],
Cell[2610178, 51181, 52, 1, 53, "Output"]
}, Open  ]],
Cell[2610245, 51185, 887, 28, 27, "Text"],

Cell[CellGroupData[{
Cell[2611157, 51217, 90, 3, 67, "Input",
  CellTags->"Cell 9.132"],
Cell[2611250, 51222, 52, 1, 53, "Output"]
}, Open  ]],
Cell[2611317, 51226, 72, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2611414, 51230, 91, 3, 67, "Input",
  CellTags->"Cell 9.133"],
Cell[2611508, 51235, 84, 1, 53, "Output"]
}, Open  ]],
Cell[2611607, 51239, 1162, 38, 27, "Text"],

Cell[CellGroupData[{
Cell[2612794, 51281, 96, 3, 67, "Input",
  CellTags->"Cell 9.134"],
Cell[2612893, 51286, 84, 1, 53, "Output"]
}, Open  ]],
Cell[2612992, 51290, 584, 13, 82, "Text"],

Cell[CellGroupData[{
Cell[2613601, 51307, 108, 3, 67, "Input",
  CellTags->"Cell 9.135"],
Cell[2613712, 51312, 145, 3, 73, "Output"]
}, Open  ]],
Cell[2613872, 51318, 94, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[2613991, 51325, 90, 3, 67, "Input",
  CellTags->"Cell 9.136"],
Cell[2614084, 51330, 89, 1, 68, "Output"]
}, Open  ]],
Cell[2614188, 51334, 198, 8, 27, "Text"],
Cell[2614389, 51344, 293, 9, 44, "Text"],
Cell[2614685, 51355, 227, 9, 28, "Text"],
Cell[2614915, 51366, 246, 11, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2615198, 51382, 71, 1, 30, "Subsubtitle",
  CellTags->{"i:71", "c:50"}],
Cell[2615272, 51385, 395, 12, 44, "Text"],
Cell[2615670, 51399, 448, 11, 41, "NE3",
  CellTags->"(9.9.1)"],
Cell[2616121, 51412, 1020, 35, 61, "Text",
  CellTags->"i:116"],
Cell[2617144, 51449, 385, 12, 47, "Text"],
Cell[2617532, 51463, 203, 6, 36, "Text"],
Cell[2617738, 51471, 296, 8, 47, "Text"],
Cell[2618037, 51481, 741, 26, 94, "Text",
  CellTags->"i:76"],

Cell[CellGroupData[{
Cell[2618803, 51511, 115, 3, 67, "Input",
  CellTags->"Cell 9.137"],
Cell[2618921, 51516, 400, 11, 69, "Output"]
}, Open  ]],
Cell[2619336, 51530, 1096, 38, 91, "Text"],
Cell[2620435, 51570, 595, 18, 65, "Text"],

Cell[CellGroupData[{
Cell[2621055, 51592, 102, 3, 67, "Input",
  CellTags->"Cell 9.138"],
Cell[2621160, 51597, 454, 11, 69, "Output"]
}, Open  ]],
Cell[2621629, 51611, 289, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[2621943, 51625, 97, 3, 67, "Input",
  CellTags->"Cell 9.139"],
Cell[2622043, 51630, 157, 3, 50, "Message"],
Cell[2622203, 51635, 47, 1, 46, "Output"]
}, Open  ]],
Cell[2622265, 51639, 356, 12, 44, "Text",
  CellTags->"i:77"],

Cell[CellGroupData[{
Cell[2622646, 51655, 90, 3, 67, "Input",
  CellTags->"Cell 9.140"],
Cell[2622739, 51660, 82, 1, 69, "Output"]
}, Open  ]],
Cell[2622836, 51664, 368, 12, 52, "Text"],

Cell[CellGroupData[{
Cell[2623229, 51680, 257, 5, 105, "Input",
  CellTags->"Cell 9.141"],
Cell[2623489, 51687, 25023, 641, 233, 5486, 395, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2648527, 52331, 1118, 33, 99, "Text",
  CellTags->"i:117"],
Cell[2649648, 52366, 582, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[2650255, 52388, 122, 3, 73, "Input",
  CellTags->"Cell 9.142"],
Cell[2650380, 52393, 515, 12, 69, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2650944, 52411, 70, 1, 30, "Subsubtitle",
  CellTags->{"i:72", "c:51"}],
Cell[2651017, 52414, 615, 18, 63, "Text",
  CellTags->"i:74"],

Cell[CellGroupData[{
Cell[2651657, 52436, 102, 3, 67, "Input",
  CellTags->"Cell 9.143"],
Cell[2651762, 52441, 46, 1, 46, "Output"]
}, Open  ]],
Cell[2651823, 52445, 68, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2651916, 52449, 88, 3, 67, "Input",
  CellTags->"Cell 9.144"],
Cell[2652007, 52454, 41, 1, 46, "Output"]
}, Open  ]],
Cell[2652063, 52458, 497, 15, 47, "Text"],

Cell[CellGroupData[{
Cell[2652585, 52477, 115, 3, 67, "Input",
  CellTags->"Cell 9.145"],
Cell[2652703, 52482, 39, 1, 46, "Output"]
}, Open  ]],
Cell[2652757, 52486, 698, 20, 87, "Text"],

Cell[CellGroupData[{
Cell[2653480, 52510, 129, 3, 67, "Input",
  CellTags->"Cell 9.146"],
Cell[2653612, 52515, 346, 8, 75, "Output"]
}, Open  ]],
Cell[2653973, 52526, 990, 32, 78, "Text",
  CellTags->"i:79"],

Cell[CellGroupData[{
Cell[2654988, 52562, 102, 3, 67, "Input",
  CellTags->"Cell 9.147"],
Cell[2655093, 52567, 236, 4, 59, "Message"],
Cell[2655332, 52573, 213, 5, 82, "Output"]
}, Open  ]],
Cell[2655560, 52581, 138, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[2655723, 52590, 98, 3, 67, "Input",
  CellTags->"Cell 9.148"],
Cell[2655824, 52595, 60, 1, 64, "Output"]
}, Open  ]],
Cell[2655899, 52599, 168, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[2656092, 52607, 128, 3, 67, "Input",
  CellTags->"Cell 9.149"],
Cell[2656223, 52612, 247, 6, 68, "Output"]
}, Open  ]],
Cell[2656485, 52621, 260, 9, 27, "Text"],
Cell[2656748, 52632, 10405, 281, 169, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2667190, 52918, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 9.9", "c:52"}],
Cell[2667271, 52921, 211, 7, 30, "Text"],
Cell[2667485, 52930, 410, 14, 68, "Text"],
Cell[2667898, 52946, 126, 3, 26, "Text"],
Cell[2668027, 52951, 491, 11, 77, "Text"],
Cell[2668521, 52964, 204, 8, 42, "Text"],
Cell[2668728, 52974, 201, 8, 30, "Text"],
Cell[2668932, 52984, 192, 8, 42, "Text"],
Cell[2669127, 52994, 118, 4, 26, "Text"],
Cell[2669248, 53000, 370, 14, 36, "Text"],
Cell[2669621, 53016, 284, 11, 31, "Text"],
Cell[2669908, 53029, 223, 8, 45, "Text"],
Cell[2670134, 53039, 624, 20, 60, "Text"],
Cell[2670761, 53061, 344, 11, 50, "Text"],
Cell[2671108, 53074, 407, 16, 26, "Text"],
Cell[2671518, 53092, 173, 7, 26, "Text"],
Cell[2671694, 53101, 364, 13, 43, "Text"],
Cell[2672061, 53116, 279, 9, 30, "Text"],
Cell[2672343, 53127, 485, 16, 52, "Text"],
Cell[2672831, 53145, 251, 10, 26, "Text"],
Cell[2673085, 53157, 87, 1, 26, "Text",
  CellTags->"i:118"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2673221, 53164, 108, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.10", "i:99", "c:53"}],
Cell[2673332, 53167, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2673373, 53171, 280, 12, 41, "Subsubtitle",
  CellTags->{"i:83", "c:54"}],

Cell[CellGroupData[{
Cell[2673678, 53187, 72, 1, 42, "Section",
  CellTags->"c:55"],
Cell[2673753, 53190, 499, 18, 44, "Text"],
Cell[2674255, 53210, 676, 30, 27, "Text",
  CellTags->"i:81"],
Cell[2674934, 53242, 202, 6, 44, "Text"],
Cell[2675139, 53250, 1553, 55, 95, "Text",
  CellTags->"i:78"],
Cell[2676695, 53307, 393, 11, 44, "Text"],
Cell[2677091, 53320, 298, 9, 47, "Text"],

Cell[CellGroupData[{
Cell[2677414, 53333, 132, 3, 67, "Input",
  CellTags->"Cell 9.150"],
Cell[2677549, 53338, 89, 1, 46, "Output"]
}, Open  ]],
Cell[2677653, 53342, 263, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[2677941, 53352, 120, 3, 66, "Input",
  CellTags->"Cell 9.151"],
Cell[2678064, 53357, 43, 1, 45, "Output"]
}, Open  ]],
Cell[2678122, 53361, 319, 7, 61, "Text"],

Cell[CellGroupData[{
Cell[2678466, 53372, 125, 3, 67, "Input",
  CellTags->"Cell 9.152"],
Cell[2678594, 53377, 288, 5, 102, "Output"]
}, Open  ]],
Cell[2678897, 53385, 747, 24, 78, "Text"],

Cell[CellGroupData[{
Cell[2679669, 53413, 85, 3, 67, "Input",
  CellTags->"Cell 9.153"],
Cell[2679757, 53418, 474, 9, 65, "Output"]
}, Open  ]],
Cell[2680246, 53430, 411, 12, 44, "Text",
  CellTags->"i:82"],

Cell[CellGroupData[{
Cell[2680682, 53446, 126, 3, 67, "Input",
  CellTags->"Cell 9.154"],
Cell[2680811, 53451, 474, 9, 65, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2681334, 53466, 77, 1, 31, "Section",
  CellTags->"c:56"],
Cell[2681414, 53469, 276, 11, 27, "Text"],
Cell[2681693, 53482, 363, 19, 27, "Text"],
Cell[2682059, 53503, 271, 9, 44, "Text"],
Cell[2682333, 53514, 345, 12, 61, "NE4",
  CellTags->"(9.10.1)"],
Cell[2682681, 53528, 43, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[2682749, 53532, 173, 4, 67, "Input",
  CellTags->"Cell 9.155"],
Cell[2682925, 53538, 85, 1, 46, "Output"]
}, Open  ]],
Cell[2683025, 53542, 3306, 112, 132, "Text"],
Cell[2686334, 53656, 689, 16, 95, "Text",
  CellTags->"i:107"],
Cell[2687026, 53674, 214, 7, 27, "Text"],
Cell[2687243, 53683, 129, 3, 27, "Text"],
Cell[2687375, 53688, 149, 6, 27, "Text"],
Cell[2687527, 53696, 186, 6, 27, "Text"],
Cell[2687716, 53704, 395, 13, 44, "Text"],
Cell[2688114, 53719, 128, 4, 86, "Input",
  CellTags->"Cell 9.156"],
Cell[2688245, 53725, 154, 4, 27, "Text"],
Cell[2688402, 53731, 205, 5, 67, "Input",
  CellTags->"Cell 9.157"],
Cell[2688610, 53738, 60, 0, 27, "Text"],
Cell[2688673, 53740, 204, 6, 67, "Input",
  CellTags->"Cell 9.158"],
Cell[2688880, 53748, 93, 3, 27, "Text"],
Cell[2688976, 53753, 173, 4, 86, "Input",
  CellTags->"Cell 9.159"],
Cell[2689152, 53759, 396, 8, 61, "Text"],
Cell[2689551, 53769, 493, 17, 46, "Text"],

Cell[CellGroupData[{
Cell[2690069, 53790, 352, 7, 124, "Input",
  CellTags->"Cell 9.160"],
Cell[2690424, 53799, 15453, 331, 233, 2693, 170, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2705892, 54133, 208, 4, 44, "Text"],
Cell[2706103, 54139, 516, 13, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2706656, 54157, 84, 1, 31, "Section",
  CellTags->"c:57"],
Cell[2706743, 54160, 203, 6, 27, "Text"],
Cell[2706949, 54168, 328, 12, 27, "Text"],
Cell[2707280, 54182, 1279, 38, 131, "Text"],

Cell[CellGroupData[{
Cell[2708584, 54224, 186, 4, 86, "Input",
  CellTags->"Cell 9.161"],
Cell[2708773, 54230, 36, 1, 46, "Output"]
}, Open  ]],
Cell[2708824, 54234, 352, 10, 44, "Text",
  CellTags->"i:85"],

Cell[CellGroupData[{
Cell[2709201, 54248, 131, 3, 67, "Input",
  CellTags->"Cell 9.162"],
Cell[2709335, 54253, 138, 3, 50, "Message"],
Cell[2709476, 54258, 63, 1, 46, "Output"]
}, Open  ]],
Cell[2709554, 54262, 456, 19, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2710047, 54286, 58, 1, 31, "Section",
  CellTags->"c:58"],
Cell[2710108, 54289, 854, 32, 61, "Text",
  CellTags->"i:110"],
Cell[2710965, 54323, 123, 4, 27, "Text"],
Cell[2711091, 54329, 249, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[2711365, 54343, 117, 3, 67, "Input",
  CellTags->"Cell 9.163"],
Cell[2711485, 54348, 175, 3, 50, "Message"],
Cell[2711663, 54353, 72, 1, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2711772, 54359, 118, 3, 67, "Input",
  CellTags->"Cell 9.164"],
Cell[2711893, 54364, 175, 3, 50, "Message"],
Cell[2712071, 54369, 73, 1, 48, "Output"]
}, Open  ]],
Cell[2712159, 54373, 123, 3, 27, "Text"],
Cell[2712285, 54378, 4984, 135, 103, "Text",
  CellTags->"i:109"],
Cell[2717272, 54515, 51, 1, 23, "Text"],
Cell[2717326, 54518, 2632, 64, 183, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2720007, 54588, 80, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 9.10", "c:59"}],
Cell[2720090, 54591, 841, 23, 95, "Text"],
Cell[2720934, 54616, 66795, 828, 183, 66674, 824, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[2787732, 55446, 51, 1, 16, "Caption",
  CellTags->"Fig. 9.4"],
Cell[2787786, 55449, 343, 14, 27, "Text"],
Cell[2788132, 55465, 126715, 1568, 262, 126593, 1564, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[2914850, 57035, 51, 1, 16, "Caption",
  CellTags->"Fig. 9.5"],
Cell[2914904, 57038, 1079, 48, 52, "Text"],
Cell[2915986, 57088, 109, 4, 30, "Text"],
Cell[2916098, 57094, 96, 4, 30, "Text"],
Cell[2916197, 57100, 56, 0, 27, "Text"],
Cell[2916256, 57102, 1834, 60, 97, "Text",
  CellTags->"i:88"],
Cell[2918093, 57164, 1187, 33, 27, "Text"],
Cell[2919283, 57199, 5439, 163, 112, "Text"],
Cell[2924725, 57364, 2713, 82, 119, "Text",
  CellTags->"i:89"],
Cell[2927441, 57448, 122, 3, 67, "Input",
  CellTags->"Cell 9.165"],

Cell[CellGroupData[{
Cell[2927588, 57455, 410, 8, 143, "Input",
  CellTags->"Cell 9.166"],
Cell[2928001, 57465, 15074, 359, 73, 3299, 210, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[2943090, 57827, 1785, 53, 81, "Text"],
Cell[2944878, 57882, 462, 13, 79, "Input",
  CellTags->"Cell 9.167"],
Cell[2945343, 57897, 3297, 99, 135, "Text"],
Cell[2948643, 57998, 379, 10, 105, "Input",
  CellTags->"Cell 9.168"],
Cell[2949025, 58010, 530, 16, 44, "Text"],
Cell[2949558, 58028, 1502, 43, 27, "Text"],
Cell[2951063, 58073, 306, 7, 105, "Input",
  CellTags->"Cell 9.169"],
Cell[2951372, 58082, 66, 0, 27, "Text"],
Cell[2951441, 58084, 334, 8, 86, "Input",
  CellTags->"Cell 9.170"],
Cell[2951778, 58094, 1301, 38, 82, "Text"],
Cell[2953082, 58134, 594, 19, 47, "Text"],
Cell[2953679, 58155, 748, 27, 64, "Text"],
Cell[2954430, 58184, 202, 5, 44, "Text"],
Cell[2954635, 58191, 213, 6, 28, "Text"],
Cell[2954851, 58199, 183, 6, 28, "Text"],
Cell[2955037, 58207, 662, 14, 78, "Text",
  CellTags->"i:112"],
Cell[2955702, 58223, 801, 23, 81, "Text"],
Cell[2956506, 58248, 2085, 69, 84, "Text",
  CellTags->"i:90"],

Cell[CellGroupData[{
Cell[2958616, 58321, 399, 9, 143, "Input",
  CellTags->"Cell 9.171"],
Cell[2959018, 58332, 22331, 506, 272, 3173, 266, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2981364, 58841, 719, 21, 78, "Text"],
Cell[2982086, 58864, 23746, 518, 296, 3617, 266, "GraphicsData", \
"PostScript", "Picture"],
Cell[3005835, 59384, 71, 1, 16, "Caption",
  CellTags->"Fig. 9.6"],
Cell[3005909, 59387, 336, 13, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3006294, 59406, 78, 1, 40, "Subtitle",
  CellTags->{"Sec. 9.11", "c:60"}],
Cell[3006375, 59409, 781, 15, 112, "Text"],

Cell[CellGroupData[{
Cell[3007181, 59428, 91, 1, 41, "Subsubtitle",
  CellTags->"c:61"],
Cell[3007275, 59431, 623, 19, 61, "Text",
  CellTags->"i:86"],

Cell[CellGroupData[{
Cell[3007923, 59454, 167, 4, 67, "Input",
  CellTags->"Cell 9.172"],
Cell[3008093, 59460, 27877, 588, 233, 4115, 291, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3035985, 60051, 3203, 110, 137, "Text",
  CellTags->"i:84"],

Cell[CellGroupData[{
Cell[3039213, 60165, 132, 3, 67, "Input",
  CellTags->"Cell 9.173"],
Cell[3039348, 60170, 70, 1, 46, "Output"]
}, Open  ]],
Cell[3039433, 60174, 698, 20, 61, "Text",
  CellTags->"i:125"],

Cell[CellGroupData[{
Cell[3040156, 60198, 107, 3, 67, "Input",
  CellTags->"Cell 9.174"],
Cell[3040266, 60203, 63, 1, 50, "Output"]
}, Open  ]],
Cell[3040344, 60207, 490, 11, 78, "Text",
  CellTags->"i:102"],

Cell[CellGroupData[{
Cell[3040859, 60222, 164, 4, 67, "Input",
  CellTags->"Cell 9.175"],
Cell[3041026, 60228, 70, 1, 46, "Output"]
}, Open  ]],
Cell[3041111, 60232, 74, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[3041210, 60236, 101, 3, 67, "Input",
  CellTags->"Cell 9.176"],
Cell[3041314, 60241, 57, 1, 50, "Output"]
}, Open  ]],
Cell[3041386, 60245, 206, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[3041617, 60255, 119, 3, 67, "Input",
  CellTags->"Cell 9.177"],
Cell[3041739, 60260, 70, 1, 46, "Output"]
}, Open  ]],
Cell[3041824, 60264, 230, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[3042079, 60274, 129, 3, 67, "Input",
  CellTags->"Cell 9.178"],
Cell[3042211, 60279, 142, 2, 46, "Output"]
}, Open  ]],
Cell[3042368, 60284, 575, 20, 44, "Text"],
Cell[3042946, 60306, 499, 18, 44, "Text"],

Cell[CellGroupData[{
Cell[3043470, 60328, 124, 3, 67, "Input",
  CellTags->"Cell 9.179"],
Cell[3043597, 60333, 184, 3, 50, "Message"],
Cell[3043784, 60338, 65, 1, 46, "Output"]
}, Open  ]],
Cell[3043864, 60342, 232, 7, 44, "Text"],
Cell[3044099, 60351, 212, 8, 49, "NE5",
  CellTags->"(9.11.1)"],
Cell[3044314, 60361, 44, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[3044383, 60365, 193, 4, 67, "Input",
  CellTags->"Cell 9.180"],
Cell[3044579, 60371, 112, 2, 46, "Output"]
}, Open  ]],
Cell[3044706, 60376, 591, 13, 78, "Text",
  CellTags->"i:87"],
Cell[3045300, 60391, 564, 19, 44, "Text"],

Cell[CellGroupData[{
Cell[3045889, 60414, 260, 6, 86, "Input",
  CellTags->"Cell 9.181"],
Cell[3046152, 60422, 42623, 1058, 370, 7670, 622, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3088790, 61483, 101, 3, 27, "Text"],
Cell[3088894, 61488, 385, 11, 47, "Text"],

Cell[CellGroupData[{
Cell[3089304, 61503, 325, 7, 105, "Input",
  CellTags->"Cell 9.182"],
Cell[3089632, 61512, 34022, 892, 370, 6557, 548, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3123669, 62407, 235, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[3123929, 62418, 97, 3, 67, "Input",
  CellTags->"Cell 9.183"],
Cell[3124029, 62423, 45818, 1156, 370, 8779, 694, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3169862, 63582, 575, 15, 78, "Text"],

Cell[CellGroupData[{
Cell[3170462, 63601, 193, 4, 67, "Input",
  CellTags->"Cell 9.184"],
Cell[3170658, 63607, 108, 2, 46, "Output"]
}, Open  ]],
Cell[3170781, 63612, 441, 7, 78, "Text"],
Cell[3171225, 63621, 250, 10, 27, "Text"],
Cell[3171478, 63633, 7569, 183, 151, "Text",
  CellTags->"Table 9.22"]
}, Closed]],

Cell[CellGroupData[{
Cell[3179084, 63821, 81, 1, 30, "Subsubtitle",
  CellTags->{"i:73", "c:62"}],
Cell[3179168, 63824, 680, 20, 83, "Text",
  CellTags->"i:75"],

Cell[CellGroupData[{
Cell[3179873, 63848, 129, 3, 67, "Input",
  CellTags->"Cell 9.185"],
Cell[3180005, 63853, 110, 2, 31, "Message"],
Cell[3180118, 63857, 110, 2, 31, "Message"],
Cell[3180231, 63861, 110, 2, 31, "Message"],
Cell[3180344, 63865, 165, 3, 50, "Message"],
Cell[3180512, 63870, 54, 1, 46, "Output"]
}, Open  ]],
Cell[3180581, 63874, 458, 11, 61, "Text"],

Cell[CellGroupData[{
Cell[3181064, 63889, 122, 3, 67, "Input",
  CellTags->"Cell 9.186"],
Cell[3181189, 63894, 54, 1, 46, "Output"]
}, Open  ]],
Cell[3181258, 63898, 566, 14, 78, "Text",
  CellTags->"i:103"],

Cell[CellGroupData[{
Cell[3181849, 63916, 229, 6, 86, "Input",
  CellTags->"Cell 9.187"],
Cell[3182081, 63924, 395, 6, 126, "Message"],
Cell[3182479, 63932, 3235, 93, 122, "Output"]
}, Open  ]],
Cell[3185729, 64028, 1216, 37, 112, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3186982, 64070, 73, 1, 30, "Subsubtitle",
  CellTags->{"i:92", "c:63"}],
Cell[3187058, 64073, 624, 18, 61, "Text"],
Cell[3187685, 64093, 582, 19, 64, "Text"],

Cell[CellGroupData[{
Cell[3188292, 64116, 172, 4, 86, "Input",
  CellTags->"Cell 9.188"],
Cell[3188467, 64122, 124, 3, 46, "Output"]
}, Open  ]],
Cell[3188606, 64128, 934, 27, 95, "Text",
  CellTags->"i:100"],
Cell[3189543, 64157, 791, 25, 78, "Text",
  CellTags->"i:101"],

Cell[CellGroupData[{
Cell[3190359, 64186, 87, 3, 67, "Input",
  CellTags->"Cell 9.189"],
Cell[3190449, 64191, 54, 1, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3190540, 64197, 92, 3, 67, "Input",
  CellTags->"Cell 9.190"],
Cell[3190635, 64202, 61, 1, 46, "Output"]
}, Open  ]],
Cell[3190711, 64206, 381, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[3191117, 64223, 112, 3, 67, "Input",
  CellTags->"Cell 9.191"],
Cell[3191232, 64228, 25981, 592, 233, 4502, 323, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3217250, 64825, 92, 3, 67, "Input",
  CellTags->"Cell 9.192"],
Cell[3217345, 64830, 55, 1, 46, "Output"]
}, Open  ]],
Cell[3217415, 64834, 1593, 37, 180, "Text",
  CellTags->"i:127"],
Cell[3219011, 64873, 236, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[3219272, 64884, 129, 3, 67, "Input",
  CellTags->"Cell 9.193"],
Cell[3219404, 64889, 31862, 891, 233, 8992, 605, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3251281, 65783, 634, 21, 61, "Text",
  CellTags->"i:93"],

Cell[CellGroupData[{
Cell[3251940, 65808, 196, 4, 86, "Input",
  CellTags->"Cell 9.194"],
Cell[3252139, 65814, 27473, 581, 233, 3951, 287, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3279661, 66401, 67, 1, 30, "Subsubtitle",
  CellTags->{"i:95", "c:64"}],
Cell[3279731, 66404, 3454, 110, 136, "Text"],

Cell[CellGroupData[{
Cell[3283210, 66518, 121, 3, 67, "Input",
  CellTags->"Cell 9.195"],
Cell[3283334, 66523, 194, 3, 73, "Output"]
}, Open  ]],
Cell[3283543, 66529, 368, 11, 50, "Text"],
Cell[3283914, 66542, 434, 13, 61, "Text",
  CellTags->"i:132"],
Cell[3284351, 66557, 3781, 94, 225, "Text"],

Cell[CellGroupData[{
Cell[3288157, 66655, 71, 1, 42, "Section",
  CellTags->"c:82"],
Cell[3288231, 66658, 585, 15, 78, "Text",
  CellTags->"i:128"],

Cell[CellGroupData[{
Cell[3288841, 66677, 92, 3, 67, "Input",
  CellTags->"Cell 9.196"],
Cell[3288936, 66682, 48, 1, 46, "Output"]
}, Open  ]],
Cell[3288999, 66686, 575, 17, 61, "Text",
  CellTags->"i:129"],

Cell[CellGroupData[{
Cell[3289599, 66707, 123, 3, 67, "Input",
  CellTags->"Cell 9.197"],
Cell[3289725, 66712, 58, 1, 46, "Output"]
}, Open  ]],
Cell[3289798, 66716, 482, 14, 61, "Text"],
Cell[3290283, 66732, 104, 3, 67, "Input",
  CellTags->"Cell 9.198"],
Cell[3290390, 66737, 220, 7, 27, "Text",
  CellTags->"i:130"],

Cell[CellGroupData[{
Cell[3290635, 66748, 85, 3, 67, "Input",
  CellTags->"Cell 9.199"],
Cell[3290723, 66753, 158, 2, 52, "Output"]
}, Open  ]],
Cell[3290896, 66758, 561, 18, 61, "Text",
  CellTags->"i:131"],
Cell[3291460, 66778, 638, 18, 161, "Text"],

Cell[CellGroupData[{
Cell[3292123, 66800, 121, 3, 67, "Input",
  CellTags->"Cell 9.200"],
Cell[3292247, 66805, 119, 2, 52, "Output"]
}, Open  ]],
Cell[3292381, 66810, 567, 15, 61, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3292997, 66831, 80, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 9.11", "c:65"}],
Cell[3293080, 66834, 272, 7, 47, "Text"],
Cell[3293355, 66843, 657, 20, 64, "Text"],
Cell[3294015, 66865, 192, 5, 27, "Text"],
Cell[3294210, 66872, 217, 8, 33, "Text"],
Cell[3294430, 66882, 219, 8, 45, "Text"],
Cell[3294652, 66892, 275, 8, 32, "Text"],
Cell[3294930, 66902, 115, 4, 27, "Text"],
Cell[3295048, 66908, 126, 3, 67, "Input",
  CellTags->"Cell 9.201"],
Cell[3295177, 66913, 385, 14, 44, "Text"],
Cell[3295565, 66929, 244, 7, 27, "Text"],
Cell[3295812, 66938, 132, 4, 27, "Text"],
Cell[3295947, 66944, 3182, 95, 67, "Input",
  CellTags->"Cell 9.202"],
Cell[3299132, 67041, 407, 13, 44, "Text",
  CellTags->"i:97"],
Cell[3299542, 67056, 1043, 32, 78, "Text",
  CellTags->"i:124"],
Cell[3300588, 67090, 175, 6, 28, "Text"],
Cell[3300766, 67098, 162, 5, 27, "Text"],
Cell[3300931, 67105, 165, 6, 30, "NE5",
  CellTags->"(9.11.2)"],
Cell[3301099, 67113, 54207, 673, 165, 54086, 669, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[3355309, 67788, 85, 1, 16, "Caption",
  CellTags->"Fig. 9.7"],
Cell[3355397, 67791, 1553, 47, 137, "Text"],
Cell[3356953, 67840, 1014, 31, 78, "Text"],
Cell[3357970, 67873, 966, 29, 81, "Text",
  CellTags->"i:126"],
Cell[3358939, 67904, 815, 25, 65, "Text"],
Cell[3359757, 67931, 451, 17, 44, "Text"],
Cell[3360211, 67950, 233, 7, 31, "Text"],
Cell[3360447, 67959, 330, 12, 30, "Text"],
Cell[3360780, 67973, 156, 4, 67, "Input",
  CellTags->"Cell 9.203"],
Cell[3360939, 67979, 153, 6, 27, "Text"],
Cell[3361095, 67987, 378, 11, 44, "Text"],
Cell[3361476, 68000, 146, 6, 41, "Text"],
Cell[3361625, 68008, 252, 8, 27, "Text"],
Cell[3361880, 68018, 242, 4, 43, "NE5",
  CellTags->"(9.11.3)"],
Cell[3362125, 68024, 605, 17, 61, "Text",
  CellTags->"i:138"],
Cell[3362733, 68043, 347, 13, 30, "Text"],
Cell[3363083, 68058, 193, 5, 67, "Input",
  CellTags->"Cell 9.204"],
Cell[3363279, 68065, 252, 9, 27, "Text"],
Cell[3363534, 68076, 1627, 52, 83, "Text"],
Cell[3365164, 68130, 260, 7, 38, "NE5",
  CellTags->"(9.11.4)"],
Cell[3365427, 68139, 227, 6, 44, "Text"],
Cell[3365657, 68147, 478, 14, 36, "Text"],
Cell[3366138, 68163, 644, 16, 78, "Text"],
Cell[3366785, 68181, 417, 13, 36, "Text"],
Cell[3367205, 68196, 107, 3, 27, "Text"],
Cell[3367315, 68201, 511, 13, 40, "NE5",
  CellTags->{"(9.11.5)", "i:134"}],
Cell[3367829, 68216, 297, 9, 44, "Text"],
Cell[3368129, 68227, 700, 24, 65, "Text"],
Cell[3368832, 68253, 176, 7, 30, "Text"],
Cell[3369011, 68262, 196, 7, 48, "Text"],
Cell[3369210, 68271, 167, 6, 32, "Text"],
Cell[3369380, 68279, 416, 13, 48, "Text"],
Cell[3369799, 68294, 458, 13, 61, "Text"],
Cell[3370260, 68309, 525, 15, 76, "NE5",
  CellTags->"(9.11.6)"],
Cell[3370788, 68326, 770, 21, 78, "Text"],

Cell[CellGroupData[{
Cell[3371583, 68351, 323, 8, 86, "Input",
  CellTags->"Cell 9.205"],
Cell[3371909, 68361, 458, 8, 106, "Output"]
}, Open  ]],
Cell[3372382, 68372, 573, 14, 78, "Text"],

Cell[CellGroupData[{
Cell[3372980, 68390, 122, 3, 67, "Input",
  CellTags->"Cell 9.206"],
Cell[3373105, 68395, 229, 4, 46, "Output"]
}, Open  ]],
Cell[3373349, 68402, 122, 5, 27, "Text"],
Cell[3373474, 68409, 744, 20, 40, "NE5",
  CellTags->"i:135"],
Cell[3374221, 68431, 520, 16, 47, "Text"],

Cell[CellGroupData[{
Cell[3374766, 68451, 331, 9, 86, "Input",
  CellTags->"Cell 9.207"],
Cell[3375100, 68462, 598, 16, 64, "Output"]
}, Open  ]],
Cell[3375713, 68481, 372, 11, 44, "Text"],
Cell[3376088, 68494, 470, 17, 44, "Text"],
Cell[3376561, 68513, 252, 8, 27, "Text",
  CellTags->"i:136"],
Cell[3376816, 68523, 837, 21, 40, "NE5"],
Cell[3377656, 68546, 281, 9, 44, "Text"],
Cell[3377940, 68557, 547, 17, 32, "Text"],
Cell[3378490, 68576, 1274, 36, 129, "Text",
  CellTags->"i:137"],
Cell[3379767, 68614, 372, 12, 44, "Text"],
Cell[3380142, 68628, 1456, 41, 136, "Text",
  CellTags->"i:139"],
Cell[3381601, 68671, 569, 13, 100, "NE5"],
Cell[3382173, 68686, 568, 18, 61, "Text"],
Cell[3382744, 68706, 161, 5, 30, "NE5"],
Cell[3382908, 68713, 405, 15, 27, "Text"],
Cell[3383316, 68730, 931, 35, 62, "Text"],
Cell[3384250, 68767, 320, 7, 124, "Input",
  CellTags->"Cell 9.208"],
Cell[3384573, 68776, 2154, 63, 104, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3386776, 68845, 145, 6, 40, "Subtitle",
  CellTags->"c:67"],
Cell[3386924, 68853, 16, 0, 27, "Text"],
Cell[3386943, 68855, 201, 4, 44, "Text"],
Cell[3387147, 68861, 398, 12, 44, "Text"],

Cell[CellGroupData[{
Cell[3387570, 68877, 70, 1, 41, "Subsubtitle",
  CellTags->"c:68"],
Cell[3387643, 68880, 16, 0, 26, "Text"],
Cell[3387662, 68882, 495, 14, 130, "Text"],
Cell[3388160, 68898, 40, 0, 15, "Caption"],
Cell[3388203, 68900, 337, 11, 72, "Text"],
Cell[3388543, 68913, 55, 0, 16, "Caption"],
Cell[3388601, 68915, 6520, 165, 246, "Text"],
Cell[3395124, 69082, 59, 0, 16, "Caption"],
Cell[3395186, 69084, 1370, 36, 136, "Text"],
Cell[3396559, 69122, 55, 0, 16, "Caption"],
Cell[3396617, 69124, 1901, 48, 67, "Text"],
Cell[3398521, 69174, 49, 0, 16, "Caption"],
Cell[3398573, 69176, 5336, 120, 142, "Text"],
Cell[3403912, 69298, 46, 0, 16, "Caption"],
Cell[3403961, 69300, 3017, 77, 160, "Text"],
Cell[3406981, 69379, 51, 0, 16, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3407069, 69384, 119, 4, 30, "Subsubtitle",
  CellTags->"c:69"],
Cell[3407191, 69390, 16, 0, 27, "Text"],
Cell[3407210, 69392, 2058, 52, 110, "Text"],
Cell[3409271, 69446, 98, 3, 16, "Caption"],
Cell[3409372, 69451, 3426, 87, 194, "Text"],
Cell[3412801, 69540, 62, 0, 15, "Caption"],
Cell[3412866, 69542, 750, 35, 96, "Text"],
Cell[3413619, 69579, 121, 4, 15, "Caption"],
Cell[3413743, 69585, 2073, 51, 71, "Text"],
Cell[3415819, 69638, 57, 0, 15, "Caption"],
Cell[3415879, 69640, 6169, 118, 373, "Text"],
Cell[3422051, 69760, 74, 0, 15, "Caption"],
Cell[3422128, 69762, 2380, 57, 91, "Text"],
Cell[3424511, 69821, 73, 0, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3424621, 69826, 83, 1, 30, "Subsubtitle",
  CellTags->"c:70"],
Cell[3424707, 69829, 2759, 68, 91, "Text"],
Cell[3427469, 69899, 48, 0, 15, "Caption"],
Cell[3427520, 69901, 5801, 152, 131, "Text"],
Cell[3433324, 70055, 40, 0, 15, "Caption"],
Cell[3433367, 70057, 5998, 155, 171, "Text"],
Cell[3439368, 70214, 66, 0, 15, "Caption"],
Cell[3439437, 70216, 560, 14, 90, "Text"],
Cell[3440000, 70232, 72, 0, 15, "Caption"],
Cell[3440075, 70234, 5076, 128, 190, "Text"],
Cell[3445154, 70364, 73, 0, 15, "Caption"],
Cell[3445230, 70366, 2343, 62, 110, "Text"],
Cell[3447576, 70430, 123, 5, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3447736, 70440, 58, 1, 30, "Subsubtitle",
  CellTags->"c:72"],

Cell[CellGroupData[{
Cell[3447819, 70445, 53, 1, 41, "Section",
  CellTags->"c:73"],
Cell[3447875, 70448, 3750, 88, 111, "Text"],
Cell[3451628, 70538, 45, 0, 15, "Caption"],
Cell[3451676, 70540, 2890, 73, 91, "Text"],
Cell[3454569, 70615, 36, 0, 15, "Caption"],
Cell[3454608, 70617, 8366, 187, 535, "Text"],
Cell[3462977, 70806, 251, 10, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3463265, 70821, 64, 1, 30, "Section",
  CellTags->"c:74"],
Cell[3463332, 70824, 2757, 64, 111, "Text"],
Cell[3466092, 70890, 46, 0, 15, "Caption"],
Cell[3466141, 70892, 2872, 66, 275, "Text"],
Cell[3469016, 70960, 161, 6, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3469214, 70971, 78, 1, 30, "Section",
  CellTags->"c:75"],
Cell[3469295, 70974, 1605, 37, 71, "Text"],
Cell[3470903, 71013, 47, 0, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3470987, 71018, 61, 1, 30, "Section",
  CellTags->"c:76"],
Cell[3471051, 71021, 16, 0, 26, "Text"],
Cell[3471070, 71023, 5640, 129, 177, "Text"],
Cell[3476713, 71154, 57, 0, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3476807, 71159, 55, 1, 30, "Section",
  CellTags->"c:77"],
Cell[3476865, 71162, 18, 0, 26, "Text"],
Cell[3476886, 71164, 3140, 76, 177, "Text"],
Cell[3480029, 71242, 62, 0, 15, "Caption"],
Cell[3480094, 71244, 3269, 78, 160, "Text"],
Cell[3483366, 71324, 63, 0, 15, "Caption"]
}, Closed]],

Cell[CellGroupData[{
Cell[3483466, 71329, 55, 1, 30, "Section",
  CellTags->"c:78"],
Cell[3483524, 71332, 12063, 273, 380, "Text"],
Cell[3495590, 71607, 137, 4, 15, "Caption"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3495776, 71617, 70, 1, 30, "Subsubtitle",
  CellTags->"c:79"],
Cell[3495849, 71620, 3330, 84, 132, "Text"],
Cell[3499182, 71706, 39, 0, 16, "Caption"],
Cell[3499224, 71708, 4782, 116, 70, "Text"],
Cell[3504009, 71826, 57, 0, 16, "Caption"],
Cell[3504069, 71828, 6173, 154, 178, "Text"],
Cell[3510245, 71984, 58, 0, 16, "Caption"],

Cell[CellGroupData[{
Cell[3510328, 71988, 59, 1, 42, "Section",
  CellTags->"c:80"],
Cell[3510390, 71991, 1031, 28, 90, "Text"],
Cell[3511424, 72021, 45, 0, 16, "Caption"],
Cell[3511472, 72023, 3856, 95, 212, "Text"],
Cell[3515331, 72120, 38, 0, 16, "Caption"],
Cell[3515372, 72122, 2240, 56, 90, "Text"],
Cell[3517615, 72180, 61, 0, 16, "Caption"],

Cell[CellGroupData[{
Cell[3517701, 72184, 157, 4, 73, "Input",
  CellTags->"Cell 9.209"],
Cell[3517861, 72190, 174, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3518084, 72199, 62, 1, 31, "Section",
  CellTags->"c:81"],
Cell[3518149, 72202, 1049, 27, 50, "Text"],
Cell[3519201, 72231, 1441, 38, 52, "Text"],
Cell[3520645, 72271, 73, 0, 16, "Caption"],

Cell[CellGroupData[{
Cell[3520743, 72275, 152, 4, 67, "Input",
  CellTags->"Cell 9.210"],
Cell[3520898, 72281, 88, 1, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3521023, 72287, 175, 4, 67, "Input",
  CellTags->"Cell 9.211"],
Cell[3521201, 72293, 65, 1, 53, "Output"]
}, Open  ]],
Cell[3521281, 72297, 1958, 47, 72, "Text"],
Cell[3523242, 72346, 93, 3, 16, "Caption"],

Cell[CellGroupData[{
Cell[3523360, 72353, 208, 5, 97, "Input",
  CellTags->"Cell 9.212"],
Cell[3523571, 72360, 278, 7, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3523886, 72372, 107, 3, 67, "Input",
  CellTags->"Cell 9.213"],
Cell[3523996, 72377, 162, 4, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3524195, 72386, 108, 3, 67, "Input",
  CellTags->"Cell 9.214"],
Cell[3524306, 72391, 71376, 1334, 200, 8022, 548, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3595755, 73733, 50, 1, 40, "Subtitle",
  CellTags->"refs"],
Cell[3595808, 73736, 331, 9, 52, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

